(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[  15568825,     262488]
NotebookOptionsPosition[  15560558,     262354]
NotebookOutlinePosition[  15560899,     262369]
CellTagsIndexPosition[  15560856,     262366]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["      A Two-Parameter Computer Deformation of a Circle", "Title",
 CellChangeTimes->{3.822259767306814*^9},
 TextAlignment->Center,ExpressionUUID->"a88fa96b-c83f-43f0-97e7-c9aea94dd85f"],

Cell["      Mathematica Notebook", "Subtitle",
 CellChangeTimes->{3.8222597924173203`*^9},
 TextAlignment->Center,ExpressionUUID->"82de6776-2a2a-4cda-b909-0ec76589094f"],

Cell["February 13, 2021", "Text",
 CellChangeTimes->{3.822259809697545*^9},
 TextAlignment->Center,ExpressionUUID->"47d19951-184a-4f40-9c99-1a0e02f1f23f"],

Cell["\<\

Beginning Note: If it popped up, click \[OpenCurlyDoubleQuote]Enable Dynamics\
\[CloseCurlyDoubleQuote] on the upper right corner. 
Run Sections 1, 2, 3 and 4.1 in this order by clicking on their cell wrappers \
and then hit Shift+Enter.
It takes more than 30 minutes to run Section 4.2, but the result has already \
been stored and displayed. 
You are encouraged to copy, change, or take away any part or all of this \
notebook for your personal study. \
\>", "Text",
 CellChangeTimes->{{3.822260857770646*^9, 3.822261049039938*^9}, {
   3.822261098153678*^9, 3.822261217629115*^9}, {3.822261255846158*^9, 
   3.822261256030262*^9}, {3.822261992363936*^9, 3.8222620883344717`*^9}, {
   3.822262129383711*^9, 3.8222622335707903`*^9}, {3.8222625115888*^9, 
   3.8222625376928988`*^9}, {3.822265212722427*^9, 3.822265250426257*^9}, {
   3.8222653368131123`*^9, 3.822265374975491*^9}, {3.822265577478221*^9, 
   3.8222655778461103`*^9}, 3.82226562987983*^9, {3.822266274259461*^9, 
   3.822266278627172*^9}, {3.822266612631152*^9, 
   3.822266655376244*^9}},ExpressionUUID->"1d13517f-375f-4539-a14b-\
ebe834f67022"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1. Deformation of Cross Section in the Lower (0\
\[LessSlantEqual]z\[LessSlantEqual]1/2) Cylinder for 0\[LessSlantEqual]t\
\[LessSlantEqual]1", "Section"]], "Section",
 CellChangeTimes->{{3.822259824746265*^9, 3.822259847458035*^9}},
 TextAlignment->Center,ExpressionUUID->"79deb966-cdb1-479d-b1d6-b0e67aae5e30"],

Cell[CellGroupData[{

Cell["\<\
1.1 Functions k1[z] and k2[z] will be used to smoothly combine the upper and \
lower cylinders.\
\>", "Subsection",
 CellChangeTimes->{{3.822259840242773*^9, 
  3.822259844329852*^9}},ExpressionUUID->"7d040900-e4ba-4a1d-a576-\
3383159eb650"],

Cell[TextData[{
 StyleBox["k1 is a strictly increasing ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "8a6788a3-1291-493d-900d-b15392580d54"],
 StyleBox[" function from [0,1/2] to [0,1/2] with k1[0]=0 and k1[1/2]=1/2.",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{
  3.8222598591238747`*^9},ExpressionUUID->"d5a98af2-3ad3-4211-8823-\
52cccaeed9fb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"k1", "[", "z_", "]"}], "=", 
    RowBox[{
     RowBox[{"1", "/", "4"}], "-", 
     RowBox[{
      RowBox[{"1", "/", "4"}], 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "Pi", " ", "z"}], "]"}]}]}]}], ";"}], " "}]], "Input",
 CellLabel->"In[1]:=",ExpressionUUID->"546535da-f7a7-463a-87be-7d1a56cd8bed"],

Cell[TextData[{
 StyleBox["k2 is a strictly increasing ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "6904b211-d832-4f2e-b595-3215747e08a9"],
 StyleBox[" function from [1/2,1] to [1/2,1] with k2[1/2]=1/2 and k2[1]=1. k1 \
and k2 together define a ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "2f5600d7-5962-4825-b641-2c518a8ebcb9"],
 StyleBox[" function from [0,1] to [0,1].",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{
  3.822259877463175*^9},ExpressionUUID->"c2d3ddb3-ebac-47f8-8664-\
68e3104813d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"k2", "[", "z_", "]"}], "=", 
   RowBox[{
    RowBox[{"k1", "[", 
     RowBox[{"z", "-", 
      RowBox[{"1", "/", "2"}]}], "]"}], "+", 
    RowBox[{"1", "/", "2"}]}]}], ";"}]], "Input",
 CellChangeTimes->{3.8222647539422894`*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"9679bb40-ef5f-43df-8c77-4e7752cefc22"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Construct the figure 8 curve as the base curve . ", "Subsection",
 CellChangeTimes->{{3.8222599027244587`*^9, 
  3.822259905963727*^9}},ExpressionUUID->"1b19b952-785f-403e-bd84-\
50c9d2a0cbab"],

Cell[TextData[{
 StyleBox["Design an ordered sequence of control points for the base curve. \
The first three and the last three points were chosen symmetrically along a \
three-edge polygonal curve such that the figure 8 it will generate is a ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "5f40ddd2-8350-48e1-b453-90a44f0a815d"],
 StyleBox[" closed curve. ",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{
  3.822259924830001*^9},ExpressionUUID->"08bfaa36-de59-4a3f-b8f6-\
571d18f3764f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"bfpts", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "0.85"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "0.75"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2"}], ",", "0.6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25"}], ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3"}], ",", "0.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3"}], ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.25"}], ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.2"}], ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.1"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.25", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.25", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2", ",", "0.6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "0.75"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "0.85"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[3]:=",ExpressionUUID->"d2a194f3-217e-4838-aff7-d33467cd279a"],

Cell[TextData[StyleBox["The following generates the parametrized figure 8 \
base curve \[LeftAngleBracket]bf1[s], bf2[s]\[RightAngleBracket] using \
B-splines, which are piecewise polynomial functions of the curve parameter s. \
Third degree polynomials suffice for our purpose. ",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822259939869835*^9},ExpressionUUID->"8c80fb1a-6974-4dc3-9104-\
bdce5aee9df3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mbf", "=", 
   RowBox[{"Length", "[", "bfpts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"bfknots", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "4"}], "]"}], ",", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"mbf", "-", "4"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"mbf", "-", "3"}], ")"}]}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "}"}], "//", "Flatten"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"bf1", "[", "s_", "]"}], ",", 
     RowBox[{"bf2", "[", "s_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "bfpts", "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "bfknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mbf"}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellLabel->"In[4]:=",ExpressionUUID->"8b90cd71-fd01-4c04-91a3-b61a3c0063d2"],

Cell[TextData[StyleBox["Calculate unit tangent vectors and the right-handed \
orthonormal frame Rf[s] consisting of this vector and the unit normal vector.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822259962814508*^9},ExpressionUUID->"23609d4a-5492-465d-8715-\
9c3f8e7acfad"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Dbf1", "[", "s_", "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"bf1", "[", "s", "]"}], ",", "s"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Dbf2", "[", "s_", "]"}], "=", 
   RowBox[{"D", "[", 
    RowBox[{
     RowBox[{"bf2", "[", "s", "]"}], ",", "s"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"NDbf1", "[", "s_", "]"}], ",", 
     RowBox[{"NDbf2", "[", "s_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Dbf1", "[", "s", "]"}], ",", 
      RowBox[{"Dbf2", "[", "s", "]"}]}], "}"}], "/", 
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Dbf1", "[", "s", "]"}], "^", "2"}], "+", 
      RowBox[{
       RowBox[{"Dbf2", "[", "s", "]"}], "^", "2"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Rf", "[", "s_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NDbf1", "[", "s", "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"NDbf2", "[", "s", "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"NDbf2", "[", "s", "]"}], ",", 
       RowBox[{"NDbf1", "[", "s", "]"}]}], "}"}]}], "}"}]}], ";"}]}], "Input",\

 CellLabel->"In[7]:=",ExpressionUUID->"500232ae-9f84-4ea4-a76e-73bf74ccdd0a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.3 Construct the simple closed curve added to the above base figure 8 curve.\
\
\>", "Subsection",
 CellChangeTimes->{{3.822259979543015*^9, 
  3.822259981933969*^9}},ExpressionUUID->"9ca5ad62-e298-4112-8d7c-\
b25466a3eccb"],

Cell[TextData[StyleBox["Deforming control points of the added curve along \
parameter z at t=0, t=1/2 and t=1. Make sure they have the same number of \
points. The curve also starts and ends with 0 velocity with growing and \
vanishing tangents pointing along the horizontal axis.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.8222599913353252`*^9},ExpressionUUID->"ea3e0006-f8ea-4433-8ff3-\
35c3bc11ee78"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"fInitial", "[", "z_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.7", "+", 
          RowBox[{"6.3", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.8"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"9", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"9", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.8"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.6"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fMiddle", "[", "z_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.15", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.05"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.15", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.15", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.05"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.15"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"11", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.05"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.1"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"fTerminal", "[", "z_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"9", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"2", "+", 
          RowBox[{"9", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1.7", "+", 
          RowBox[{"6.3", 
           RowBox[{"k1", "[", "z", "]"}]}]}], ")"}], "0.2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0.05"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";"}]}], "Input",
 CellLabel->"In[11]:=",ExpressionUUID->"7c6e1943-5dda-482a-835d-7a609e7fe7db"],

Cell[TextData[StyleBox["They are also linearly deformed along parameter t.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260006474165*^9},ExpressionUUID->"bf26ebfa-5920-4b4e-b012-\
3827bbbc6989"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Afpts1", "[", 
    RowBox[{"t_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"2", "t", " ", 
     RowBox[{"fMiddle", "[", "z", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"2", "t"}]}], ")"}], 
     RowBox[{"fInitial", "[", "z", "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Afpts2", "[", 
    RowBox[{"t_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", "t"}]}], ")"}], 
     RowBox[{"fMiddle", "[", "z", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "t"}], "-", "1"}], ")"}], " ", 
     RowBox[{"fTerminal", "[", "z", "]"}]}]}]}], ";"}]}], "Input",
 CellLabel->"In[14]:=",ExpressionUUID->"5710ee0c-3c79-40d6-ab20-f6f3b8a018a7"],

Cell[TextData[StyleBox["Simple closed curve are then constructed using \
B-splines.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.8222600185440063`*^9},ExpressionUUID->"817322f5-ae87-4769-a974-\
0c8bbd788b16"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"mAf", "=", 
   RowBox[{"Length", "[", 
    RowBox[{"fMiddle", "[", "z", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"afknots", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "4"}], "]"}], ",", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"mAf", "-", "4"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"mAf", "-", "3"}], ")"}]}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "}"}], "//", "Flatten"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aaf11", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"aaf12", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Afpts1", "[", 
      RowBox[{"t", ",", "z"}], "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "afknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mAf"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aaf21", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"aaf22", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Afpts2", "[", 
      RowBox[{"t", ",", "z"}], "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "afknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mAf"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aaf1", "[", 
    RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"aaf11", "[", 
         RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"aaf21", "[", 
         RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"aaf2", "[", 
    RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"aaf12", "[", 
         RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"aaf22", "[", 
         RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[16]:=",ExpressionUUID->"982fd364-a76c-4b7c-ae1d-82e0cc7ed8a0"],

Cell[TextData[StyleBox["Then we rotate them using the orthonormal frames to \
align with the tangent directions of the base figure 8 curve.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260048304932*^9},ExpressionUUID->"a0365a1e-b252-477c-a3c8-\
f19f1d138a77"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AAf11", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"AAf12", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Rf", "[", "s", "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"aaf11", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "0.4"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "0.1", "-", 
           RowBox[{"0.4", "t"}]}], ")"}]}], ",", "t", ",", "z"}], "]"}], ",", 
      
      RowBox[{"aaf12", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "0.4"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "0.1", "-", 
           RowBox[{"0.4", "t"}]}], ")"}]}], ",", "t", ",", "z"}], "]"}]}], 
     "}"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"AAf21", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"AAf22", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Rf", "[", "s", "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"aaf21", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "0.4"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "0.1", "-", 
           RowBox[{"0.4", "t"}]}], ")"}]}], ",", "t", ",", "z"}], "]"}], ",", 
      
      RowBox[{"aaf22", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "/", "0.4"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "0.1", "-", 
           RowBox[{"0.4", "t"}]}], ")"}]}], ",", "t", ",", "z"}], "]"}]}], 
     "}"}]}]}], ";"}]}], "Input",
 CellLabel->"In[22]:=",ExpressionUUID->"b4052c02-13b4-4a97-8bad-5144ada99a5e"],

Cell[TextData[StyleBox["And add them to the base curve to generate the \
guiding immersed curve of turning tangent number 1. As we change the \
parameter t, the added curve is super-imposed to different parts of the base \
curve. This generates the inner kink traveling effect.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260065521656*^9},ExpressionUUID->"f5e7fdb5-503c-4231-8335-\
6e490bf175b2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f1", "[", 
    RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", "\n", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf1", "[", "s", "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "s", "<", 
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"bf1", "[", "s", "]"}], "+", 
              RowBox[{"AAf11", "[", 
               RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf1", "[", "s", "]"}], ",", 
             RowBox[{
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", "\n", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf1", "[", "s", "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "s", "<", 
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"bf1", "[", "s", "]"}], "+", 
              RowBox[{"AAf21", "[", 
               RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf1", "[", "s", "]"}], ",", 
             RowBox[{
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "\n", "}"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"f2", "[", 
    RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", "\n", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf2", "[", "s", "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "s", "<", 
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"bf2", "[", "s", "]"}], "+", 
              RowBox[{"AAf12", "[", 
               RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf2", "[", "s", "]"}], ",", 
             RowBox[{
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", "\n", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf2", "[", "s", "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "s", "<", 
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"bf2", "[", "s", "]"}], "+", 
              RowBox[{"AAf22", "[", 
               RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], ",", 
             RowBox[{
              RowBox[{"0.1", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"bf2", "[", "s", "]"}], ",", 
             RowBox[{
              RowBox[{"0.5", "+", 
               RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "\n", "}"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[24]:=",ExpressionUUID->"4459d1f5-a8c8-4571-bc13-4c808698615e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.4 Sample 20 points (21 points, if we count the first and the last \
separately) on the above composite curve \
\[LeftAngleBracket]f1[s,t,z],f2[s,t,z]\[RightAngleBracket], to be used for \
our curve deformation.\
\>", "Subsection",
 CellChangeTimes->{{3.822260086522105*^9, 3.822260098673566*^9}, {
  3.822260133339265*^9, 
  3.822260135578988*^9}},ExpressionUUID->"686d69c9-271c-4370-a5c7-\
44d7d8223174"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Pts", "[", 
    RowBox[{"t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f1", "[", 
        RowBox[{"i", ",", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"f2", "[", 
        RowBox[{"i", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1", ",", "0.05"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[26]:=",ExpressionUUID->"9679838d-7578-4db1-acc7-c62e5a757417"],

Cell[TextData[{
 StyleBox["We replace the two points close to the base point to make the \
closed curve ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "3ac0130c-3b91-412b-85d0-64378d91f2ac"],
 StyleBox[".",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{
  3.822260161111603*^9},ExpressionUUID->"f59416f1-6065-4886-9f20-\
5d22a73895fd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Pts", "[", 
    RowBox[{"t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{
     RowBox[{"Pts", "[", 
      RowBox[{"t", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"Pts", "[", 
           RowBox[{"t", ",", "z"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{"0.1", ",", "0"}], "}"}]}]}], ",", 
       RowBox[{"20", "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"Pts", "[", 
           RowBox[{"t", ",", "z"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.1"}], ",", "0"}], "}"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[27]:=",ExpressionUUID->"e981bb7c-7909-4fda-8b3b-874ccd87c45d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
1.5 Generate circle deformation \[LeftAngleBracket]p1[s,t,z], p2[s,t,z]\
\[RightAngleBracket] for 0\[LessSlantEqual]t\[LessSlantEqual]1 and 0\
\[LessSlantEqual]z\[LessSlantEqual]1/2.\
\>", "Subsection",
 CellChangeTimes->{{3.822260172676681*^9, 
  3.822260174931793*^9}},ExpressionUUID->"7e9acf5b-f433-40f0-b56f-\
9e6f3e2cf52a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "0"}], ")"}], "/", "0.05"}], "+", "1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"knots", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "4"}], "]"}], ",", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"n", "-", "4"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"n", "-", "3"}], ")"}]}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "}"}], "//", "Flatten"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"p1", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"p2", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Pts", "[", 
      RowBox[{"t", ",", "z"}], "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "knots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}]}], ";"}]}], "Input",
 CellLabel->"In[28]:=",ExpressionUUID->"8b6dafce-20d6-405b-9a76-da740e04aa52"],

Cell[TextData[StyleBox["The following animation shows (1) the added curve, \
(2) the base curve, (3) the composite curve with the 20 sampled points, and \
(4) the generated curve by these sampled points.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260208482382*^9},ExpressionUUID->"8bb25d83-7778-4b5f-809a-\
6a8bb462b39f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Gray", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"Afpts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"Afpts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"aaf1", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
            RowBox[{"aaf2", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}], "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"Ticks", "\[Rule]", "None"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Gray", ",", 
           RowBox[{"Point", "[", "bfpts", "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", "bfpts", "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bf1", "[", "s", "]"}], ",", 
            RowBox[{"bf2", "[", "s", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", 
            RowBox[{"0.1", "+", 
             RowBox[{"0.4", "t"}]}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bf1", "[", "s", "]"}], ",", 
            RowBox[{"bf2", "[", "s", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", 
            RowBox[{"0.1", "+", 
             RowBox[{"0.4", "t"}]}], ",", 
            RowBox[{"0.5", "+", 
             RowBox[{"0.4", "t"}]}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bf1", "[", "s", "]"}], ",", 
            RowBox[{"bf2", "[", "s", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", 
            RowBox[{"0.5", "+", 
             RowBox[{"0.4", "t"}]}], ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"bf1", "[", 
               RowBox[{"0.1", "+", 
                RowBox[{"0.4", "t"}]}], "]"}], ",", 
              RowBox[{"bf2", "[", 
               RowBox[{"0.1", "+", 
                RowBox[{"0.4", "t"}]}], "]"}]}], "}"}], "]"}], ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"bf1", "[", 
               RowBox[{"0.5", "+", 
                RowBox[{"0.4", "t"}]}], "]"}], ",", 
              RowBox[{"bf2", "[", 
               RowBox[{"0.5", "+", 
                RowBox[{"0.4", "t"}]}], "]"}]}], "}"}], "]"}]}], "}"}], "]"}],
         ",", "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bf1", "[", "s", "]"}], ",", 
            RowBox[{"bf2", "[", "s", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", 
            RowBox[{"0.1", "+", 
             RowBox[{"0.4", "t"}]}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f1", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
            RowBox[{"f2", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", 
            RowBox[{"0.1", "+", 
             RowBox[{"0.4", "t"}]}], ",", 
            RowBox[{"0.5", "+", 
             RowBox[{"0.4", "t"}]}]}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"bf1", "[", "s", "]"}], ",", 
            RowBox[{"bf2", "[", "s", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", 
            RowBox[{"0.5", "+", 
             RowBox[{"0.4", "t"}]}], ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}]}], "]"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"Pts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"Pts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"p1", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
            RowBox[{"p2", "[", 
             RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.01", "]"}]}], "]"}]}]}], "]"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"Pts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"Pts", "[", 
             RowBox[{"t", ",", "z"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", 
     RowBox[{"1", "/", "2"}]}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",ExpressionUUID->"b3ee557c-d1cd-4eed-afdb-f65b145a233e"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0, $CellContext`z$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 1}, {
      Hold[$CellContext`z$$], 0, 
      Rational[1, 2]}}, Typeset`size$$ = {600., {110., 115.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`t$2311$$ = 0, $CellContext`z$2312$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`t$$ = 0, $CellContext`z$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$2311$$, 0], 
        Hold[$CellContext`z$$, $CellContext`z$2312$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> GraphicsRow[{
         Show[
          Graphics[{
            PointSize[Medium], Gray, 
            Point[
             $CellContext`Afpts[$CellContext`t$$, $CellContext`z$$]], Gray, 
            Line[
             $CellContext`Afpts[$CellContext`t$$, $CellContext`z$$]]}], 
          ParametricPlot[{
            $CellContext`aaf1[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$], 
            $CellContext`aaf2[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$]}, {$CellContext`s, 0, 1}, PlotStyle -> Blue], 
          Graphics[{
            PointSize[Medium], 
            Point[{0, 0}]}], PlotRange -> {{-1, 1}, {-0.5, 2}}, Axes -> True, 
          Ticks -> None], 
         Show[
          Graphics[{
            PointSize[Medium], Gray, 
            Point[$CellContext`bfpts], Gray, 
            Line[$CellContext`bfpts]}], 
          ParametricPlot[{
            $CellContext`bf1[$CellContext`s], 
            $CellContext`bf2[$CellContext`s]}, {$CellContext`s, 0, 0.1 + 
            0.4 $CellContext`t$$}, PlotStyle -> Directive[Black, 
             Thickness[0.005]]], 
          ParametricPlot[{
            $CellContext`bf1[$CellContext`s], 
            $CellContext`bf2[$CellContext`s]}, {$CellContext`s, 0.1 + 
            0.4 $CellContext`t$$, 0.5 + 0.4 $CellContext`t$$}, PlotStyle -> 
           Blue], 
          ParametricPlot[{
            $CellContext`bf1[$CellContext`s], 
            $CellContext`bf2[$CellContext`s]}, {$CellContext`s, 0.5 + 
            0.4 $CellContext`t$$, 1}, PlotStyle -> Directive[Black, 
             Thickness[0.005]]], 
          Graphics[{
            PointSize[Medium], 
            Point[{
              $CellContext`bf1[0.1 + 0.4 $CellContext`t$$], 
              $CellContext`bf2[0.1 + 0.4 $CellContext`t$$]}], 
            Point[{
              $CellContext`bf1[0.5 + 0.4 $CellContext`t$$], 
              $CellContext`bf2[0.5 + 0.4 $CellContext`t$$]}]}], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False], 
         Show[
          ParametricPlot[{
            $CellContext`bf1[$CellContext`s], 
            $CellContext`bf2[$CellContext`s]}, {$CellContext`s, 0, 0.1 + 
            0.4 $CellContext`t$$}, PlotStyle -> Directive[Black, 
             Thickness[0.005]]], 
          ParametricPlot[{
            $CellContext`f1[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$], 
            $CellContext`f2[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$]}, {$CellContext`s, 0.1 + 0.4 $CellContext`t$$, 0.5 + 
            0.4 $CellContext`t$$}, PlotStyle -> Blue], 
          ParametricPlot[{
            $CellContext`bf1[$CellContext`s], 
            $CellContext`bf2[$CellContext`s]}, {$CellContext`s, 0.5 + 
            0.4 $CellContext`t$$, 1}, PlotStyle -> Directive[Black, 
             Thickness[0.005]]], 
          Graphics[{
            PointSize[Medium], Red, 
            Point[
             $CellContext`Pts[$CellContext`t$$, $CellContext`z$$]], Gray, 
            Line[
             $CellContext`Pts[$CellContext`t$$, $CellContext`z$$]]}], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False], 
         Show[
          ParametricPlot[{
            $CellContext`p1[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$], 
            $CellContext`p2[$CellContext`s, $CellContext`t$$, \
$CellContext`z$$]}, {$CellContext`s, 0, 1}, PlotStyle -> Directive[Black, 
             Thickness[0.01]]], 
          Graphics[{
            PointSize[Medium], Red, 
            Point[
             $CellContext`Pts[$CellContext`t$$, $CellContext`z$$]], Gray, 
            Line[
             $CellContext`Pts[$CellContext`t$$, $CellContext`z$$]]}], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False]}], 
      "Specifications" :> {{$CellContext`t$$, 0, 1}, {$CellContext`z$$, 0, 
         Rational[1, 2]}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{645., {169., 175.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`Afpts[
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       Piecewise[{{{{0, 0}, {0, 0}, {0.2 $CellContext`t, 0}, {
            0.3 $CellContext`t, 0.05 (1 - 2 $CellContext`t) + 
             0.1 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {
            0.3 $CellContext`t, 0.1 (1 - 2 $CellContext`t) + 
             0.2 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {
            0.3 $CellContext`t, 0.15 (1 - 2 $CellContext`t) + 
             0.4 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {
            0.1 $CellContext`t, 0.2 (1 - 2 $CellContext`t) + 
             0.4 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.6) (1 - 
               2 $CellContext`t) - 0.1 $CellContext`t, 
             0.2 (1 - 2 $CellContext`t) (1.7 + 
               6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.4 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.8) (1 - 
               2 $CellContext`t) - 0.3 $CellContext`t, 
             0.2 (1 - 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.4 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {-1 + 
             1.7 $CellContext`t, 
             0.2 (1 - 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 $CellContext`t (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.8) (1 - 
               2 $CellContext`t) - 0.3 $CellContext`t, 
             0.1 $CellContext`t (1 + 
              11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.6) (1 - 
               2 $CellContext`t) - 0.2 $CellContext`t, 0}, {0, 0}, {0, 0}}, 
           0 <= $CellContext`t <= 
           1/2}, {{{0, 0}, {0, 0}, {
            0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t), 0}, {
            0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t), 
             0.05 (2 - 2 $CellContext`t) (1 + 
              11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {-1 + 
             0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t, 
             0.2 (-1 + 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.1 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {
            0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t), 
             0.2 (-1 + 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {
            0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t), 
             0.2 (-1 + 2 $CellContext`t) (1.7 + 
               6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.05) (2 - 
              2 $CellContext`t), 0.2 (-1 + 2 $CellContext`t) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.15) (2 - 
              2 $CellContext`t), 0.15 (-1 + 2 $CellContext`t) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.15) (2 - 
              2 $CellContext`t), 0.1 (-1 + 2 $CellContext`t) + 
             0.1 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.15) (2 - 
              2 $CellContext`t), 0.05 (-1 + 2 $CellContext`t) + 
             0.05 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))}, {(-0.1) (2 - 
              2 $CellContext`t), 0}, {0, 0}, {0, 0}}, 1/2 <= $CellContext`t <= 
           1}}, 0], $CellContext`aaf1[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       Piecewise[{{
          0.2 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 2, $CellContext`s] + 
           0.3 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 3, $CellContext`s] + 
           0.3 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 4, $CellContext`s] + 
           0.3 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 5, $CellContext`s] + 
           0.1 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 
              6, $CellContext`s] + ((-0.6) (1 - 2 $CellContext`t) - 
             0.1 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 
              7, $CellContext`s] + ((-0.8) (1 - 2 $CellContext`t) - 
             0.3 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 8, $CellContext`s] + (-1 + 
             1.7 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 
              9, $CellContext`s] + ((-0.8) (1 - 2 $CellContext`t) - 
             0.3 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 
              10, $CellContext`s] + ((-0.6) (1 - 2 $CellContext`t) - 
             0.2 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 11, $CellContext`s], 
           0 <= $CellContext`t <= 
           1/2}, {(0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 2, $CellContext`s] + (
             0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 3, $CellContext`s] + (-1 + 
             0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 4, $CellContext`s] + (
             0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 5, $CellContext`s] + (
             0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 6, $CellContext`s] - 
           0.05 (2 - 2 $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
               9/11, 10/11, 1, 1, 1, 1}}, 7, $CellContext`s] - 
           0.15 (2 - 2 $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
               9/11, 10/11, 1, 1, 1, 1}}, 8, $CellContext`s] - 
           0.15 (2 - 2 $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
               9/11, 10/11, 1, 1, 1, 1}}, 9, $CellContext`s] - 
           0.15 (2 - 2 $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
               9/11, 10/11, 1, 1, 1, 1}}, 10, $CellContext`s] - 
           0.1 (2 - 2 $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
               9/11, 10/11, 1, 1, 1, 1}}, 11, $CellContext`s], 
           1/2 <= $CellContext`t <= 1}}, 0], $CellContext`aaf2[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       Piecewise[{{
          BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 3, $CellContext`s] (
             0.05 (1 - 2 $CellContext`t) + 
             0.1 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 4, $CellContext`s] (
             0.1 (1 - 2 $CellContext`t) + 
             0.2 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 9, $CellContext`s] (
             0.2 (1 - 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 5, $CellContext`s] (
             0.15 (1 - 2 $CellContext`t) + 
             0.4 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 6, $CellContext`s] (
             0.2 (1 - 2 $CellContext`t) + 
             0.4 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 7, $CellContext`s] (
             0.2 (1 - 2 $CellContext`t) (1.7 + 
               6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.4 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 8, $CellContext`s] (
             0.2 (1 - 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.4 $CellContext`t (1 + 11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           0.1 $CellContext`t 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 10, $CellContext`s] (1 + 
             11 (1/4 - Cos[2 Pi $CellContext`z]/4)), 0 <= $CellContext`t <= 
           1/2}, {BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 10, $CellContext`s] (
             0.05 (-1 + 2 $CellContext`t) + 
             0.05 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 9, $CellContext`s] (
             0.1 (-1 + 2 $CellContext`t) + 
             0.1 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 4, $CellContext`s] (
             0.2 (-1 + 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.1 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 8, $CellContext`s] (
             0.15 (-1 + 2 $CellContext`t) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 7, $CellContext`s] (
             0.2 (-1 + 2 $CellContext`t) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 6, $CellContext`s] (
             0.2 (-1 + 2 $CellContext`t) (1.7 + 
               6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 5, $CellContext`s] (
             0.2 (-1 + 2 $CellContext`t) (2 + 
               9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
             0.2 (2 - 2 $CellContext`t) (1 + 
               11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
           0.05 (2 - 2 $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/11, 
                9/11, 10/11, 1, 1, 1, 1}}, 3, $CellContext`s] (1 + 
             11 (1/4 - Cos[2 Pi $CellContext`z]/4)), 1/2 <= $CellContext`t <= 
           1}}, 0], $CellContext`bfpts = {{0, 1}, {0.06, 1}, {0.06, 
         0.85}, {-0.06, 0.75}, {-0.2, 0.6}, {-0.25, 0.5}, {-0.3, 0.4}, {-0.3, 
         0.2}, {-0.25, 0.1}, {-0.2, 0.05}, {-0.1, 0}, {0, 0}, {0.1, 0}, {0.2, 
         0.05}, {0.25, 0.1}, {0.3, 0.2}, {0.3, 0.4}, {0.25, 0.5}, {0.2, 
         0.6}, {0.06, 0.75}, {-0.06, 0.85}, {-0.06, 1}, {0, 
         1}}, $CellContext`bf1[
         Pattern[$CellContext`s, 
          Blank[]]] = 
       0.06 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 1, $CellContext`s] + 
        0.06 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 2, $CellContext`s] - 0.06 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 3, $CellContext`s] - 0.2 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 4, $CellContext`s] - 0.25 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 5, $CellContext`s] - 0.3 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 6, $CellContext`s] - 0.3 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 7, $CellContext`s] - 0.25 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 8, $CellContext`s] - 0.2 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 9, $CellContext`s] - 0.1 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 10, $CellContext`s] + 
        0.1 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 12, $CellContext`s] + 
        0.2 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 13, $CellContext`s] + 
        0.25 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 14, $CellContext`s] + 
        0.3 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 15, $CellContext`s] + 
        0.3 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 16, $CellContext`s] + 
        0.25 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 17, $CellContext`s] + 
        0.2 BSplineBasis[{
           3, {
            0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 1/
             2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
             1, 1}}, 18, $CellContext`s] + 
        0.06 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 19, $CellContext`s] - 0.06 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 20, $CellContext`s] - 0.06 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 21, $CellContext`s], $CellContext`bf2[
         Pattern[$CellContext`s, 
          Blank[]]] = 
       BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 0, $CellContext`s] + 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 1, $CellContext`s] + 
        0.85 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 2, $CellContext`s] + 
        0.75 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 3, $CellContext`s] + 
        0.6 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 4, $CellContext`s] + 
        0.5 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 5, $CellContext`s] + 
        0.4 
         BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 6, $CellContext`s] + 
        0.2 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 7, $CellContext`s] + 
        0.1 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 8, $CellContext`s] + 
        0.05 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 9, $CellContext`s] + 
        0.05 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 13, $CellContext`s] + 
        0.1 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 14, $CellContext`s] + 
        0.2 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 15, $CellContext`s] + 
        0.4 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 16, $CellContext`s] + 
        0.5 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 17, $CellContext`s] + 
        0.6 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 18, $CellContext`s] + 
        0.75 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 19, $CellContext`s] + 
        0.85 BSplineBasis[{
           3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
             1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1,
              1, 1}}, 20, $CellContext`s] + 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 21, $CellContext`s] + 
        BSplineBasis[{
          3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/20, 
            1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/20, 1, 1, 
            1, 1}}, 22, $CellContext`s], $CellContext`f1[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = Piecewise[{{
           
           Piecewise[{{
             0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s], 
              Inequality[
              0, LessEqual, $CellContext`s, Less, 0.1 + 
               0.4 $CellContext`t]}, {((
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (
                  20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s])) (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)]))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (
                    20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (
                    20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {
                 0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/
                  20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/
                  20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 
                21, $CellContext`s] - (((-30) 
                 BSplineBasis[{
                   2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                0.85 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                0.75 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                0.6 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                0.5 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                0.4 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                0.05 (
                  20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                0.05 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                0.4 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                0.5 (20 
                   BSplineBasis[{
                    2, {
                    0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                    9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10,
                     19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                0.6 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                0.75 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                0.85 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                30 BSplineBasis[{
                   2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) (
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.05 (1 - 2 $CellContext`t) + 
                  0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.1 (1 - 2 $CellContext`t) + 
                  0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.15 (1 - 2 $CellContext`t) + 
                  0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (1 - 2 $CellContext`t) + 
                  0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                0.1 $CellContext`t 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (1 + 
                  11 (1/4 - Cos[2 Pi $CellContext`z]/4))))/
              Sqrt[((-30) 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                 0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                 0.85 (
                   20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                 30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (
                   20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (30 
                   BSplineBasis[{
                    2, {
                    0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                    9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10,
                     19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2], 
              0.1 + 0.4 $CellContext`t <= $CellContext`s <= 
              0.5 + 0.4 $CellContext`t}, {
             0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s], 
              0.5 + 0.4 $CellContext`t <= $CellContext`s <= 1}}, 0], 
           0 <= $CellContext`t <= 1/2}, {
           
           Piecewise[{{
             0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {
                 0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/
                  20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 19/
                  20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s], 
              Inequality[
              0, LessEqual, $CellContext`s, Less, 0.1 + 
               0.4 $CellContext`t]}, {((
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {
                    0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                    9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10,
                     19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s])) ((
                   0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)]))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (
                    20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {
                    0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                    9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10,
                     19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (
                   20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 
                21, $CellContext`s] - (((-30) 
                 BSplineBasis[{
                   2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                0.85 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                0.75 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                0.6 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                0.5 (
                  20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                0.4 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                0.05 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                0.05 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                0.4 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                0.5 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                0.6 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                0.75 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                0.85 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                30 BSplineBasis[{
                   2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) (
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.05 (-1 + 2 $CellContext`t) + 
                  0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.1 (-1 + 2 $CellContext`t) + 
                  0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.15 (-1 + 2 $CellContext`t) + 
                  0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (-1 + 2 $CellContext`t) + 
                  0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                  0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                  0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (1 + 
                  11 (1/4 - Cos[2 Pi $CellContext`z]/4))))/
              Sqrt[((-30) 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                 0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                 0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (
                   20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2], 
              0.1 + 0.4 $CellContext`t <= $CellContext`s <= 
              0.5 + 0.4 $CellContext`t}, {
             0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 0.3 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 0.25 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 0.2 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 0.1 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 10, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 9/
                   20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 12, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.25 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 0.06 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s], 
              0.5 + 0.4 $CellContext`t <= $CellContext`s <= 1}}, 0], 
           1/2 <= $CellContext`t <= 1}}, 0], $CellContext`f2[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = Piecewise[{{
           
           Piecewise[{{
             BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 22, $CellContext`s], 
              Inequality[
              0, LessEqual, $CellContext`s, Less, 0.1 + 
               0.4 $CellContext`t]}, {(((-30) 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                 0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                 0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                 30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 + $CellContext`s - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)]))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 
                22, $CellContext`s] + ((
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (
                  20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s])) (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2], 
              0.1 + 0.4 $CellContext`t <= $CellContext`s <= 
              0.5 + 0.4 $CellContext`t}, {
             BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 22, $CellContext`s], 
              0.5 + 0.4 $CellContext`t <= $CellContext`s <= 1}}, 0], 
           0 <= $CellContext`t <= 1/2}, {
           
           Piecewise[{{
             BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 22, $CellContext`s], 
              Inequality[
              0, LessEqual, $CellContext`s, Less, 0.1 + 
               0.4 $CellContext`t]}, {(((-30) 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                 0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                 0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                 0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                 30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) ((
                   0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)]))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (
                   20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 
                22, $CellContext`s] + ((
                 0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                 0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                 0.3 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                 0.25 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                 0.2 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                 0.1 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                 0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                 0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                 0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                 0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                 0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                 0.06 (20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                 0.06 (
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                  BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s])) (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 + $CellContext`s - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))))/
               Sqrt[((-30) 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.85 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) + 
                  0.6 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) + 
                  0.05 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.4 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.5 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.6 (
                    20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.75 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) + 
                  0.85 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) + 
                  30 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s])^2 + (
                  0.06 (60 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 1, $CellContext`s] - 30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s]) + 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 2, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 3, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 4, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 5, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 6, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s]) - 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 7, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s]) - 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 8, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s]) - 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 9, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s]) - 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 10, $CellContext`s] - 20 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 11, $CellContext`s]) + 
                  0.1 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 12, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 13, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 14, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 15, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s]) + 
                  0.3 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 16, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s]) + 
                  0.25 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 17, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s]) + 
                  0.2 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 18, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s]) + 
                  0.06 (
                    20 BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 19, $CellContext`s] - 20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s]) - 
                  0.06 (20 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 20, $CellContext`s] - 30 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s]) - 
                  0.06 (30 
                    BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 21, $CellContext`s] - 60 
                   BSplineBasis[{
                    2, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/
                    5, 9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/
                    10, 19/20, 1, 1, 1, 1}}, 22, $CellContext`s]))^2], 
              0.1 + 0.4 $CellContext`t <= $CellContext`s <= 
              0.5 + 0.4 $CellContext`t}, {
             BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 0, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 1, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 2, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 3, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 4, $CellContext`s] + 
              0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 5, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 6, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 7, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 8, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 9, $CellContext`s] + 
              0.05 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 13, $CellContext`s] + 
              0.1 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 14, $CellContext`s] + 
              0.2 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 15, $CellContext`s] + 
              0.4 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 16, $CellContext`s] + 
              0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 17, $CellContext`s] + 
              0.6 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 18, $CellContext`s] + 
              0.75 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 19, $CellContext`s] + 
              0.85 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                   9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                   19/20, 1, 1, 1, 1}}, 20, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 21, $CellContext`s] + 
              BSplineBasis[{
                3, {0, 0, 0, 0, 1/20, 1/10, 3/20, 1/5, 1/4, 3/10, 7/20, 2/5, 
                  9/20, 1/2, 11/20, 3/5, 13/20, 7/10, 3/4, 4/5, 17/20, 9/10, 
                  19/20, 1, 1, 1, 1}}, 22, $CellContext`s], 
              0.5 + 0.4 $CellContext`t <= $CellContext`s <= 1}}, 0], 
           1/2 <= $CellContext`t <= 1}}, 0], $CellContext`Pts[
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = {{
          Piecewise[{{
             
             Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {0.1 + Piecewise[{{
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
              1/2}, {
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
              1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.06333333333333332, 0.1 < 
                0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                0.720833064901856 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                0.6931087162517846 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.06333333333333332, 0.1 < 
                0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0. - 0.4 $CellContext`t)]) + 
                0.6931087162517846 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666665 - 
                0.6931087162517846 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666665 - 
                0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0. - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                0.6050832675335577 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                0.7961621941231026 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                0.7961621941231026 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.6083333333333336, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333336 - 
                0.7961621941231026 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                0.6050832675335577 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.6083333333333336, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333336 - 
                0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                0.6050832675335577 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
           0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.24999999999999997`, 0.2 < 
                0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                0.44721359549995787` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                0.8944271909999157 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.24999999999999997`, 0.2 < 
                0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.1 - 0.4 $CellContext`t)]) + 
                0.8944271909999157 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999999 - 
                0.8944271909999157 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                0.44721359549995787` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999999 - 
                0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.1 - 0.4 $CellContext`t)]) - 
                0.44721359549995787` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.29166666666666646`, 0.25 < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                0.16439898730535726` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                0.9863939238321439 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.29166666666666646`, 0.25 < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.15 - 0.4 $CellContext`t)]) + 
                0.9863939238321439 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
               0.38333333333333314` - 
                0.9863939238321439 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                0.16439898730535726` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
               0.38333333333333314` - 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.15 - 0.4 $CellContext`t)]) - 
                0.16439898730535726` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                0.16439898730535776` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.9863939238321435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.9863939238321435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.2166666666666664, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {
               0.2166666666666664 - 
                0.9863939238321435 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.16439898730535776` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2166666666666664, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {
               0.2166666666666664 - 
                0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.16439898730535776` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
           0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                0.5547001962252291 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.8320502943378435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.8320502943378435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.10833333333333342`, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {
               0.10833333333333342` - 
                0.8320502943378435 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.10833333333333342`, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {
               0.10833333333333342` - 
                0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
           0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.19166666666666668`, 0.4 < 
                0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                0.8320502943378437 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.19166666666666668`, 0.4 < 
                0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
               0.049999999999999996` - 
                0.5547001962252291 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.8320502943378437 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
               0.049999999999999996` - 
                0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.8320502943378437 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-0.09999999999999996, 0.45 < 
                0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                0.9701425001453319 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.24253562503633297` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.09999999999999996, 0.45 < 
                0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.24253562503633297` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333328 - 
                0.24253562503633297` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.9701425001453319 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333328 - 
                0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.9701425001453319 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                1. (0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                1. ((0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{
               0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.09999999999999992 + 
                0.9701425001453318 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                0.24253562503633322` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.09999999999999992 + 
                0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                0.24253562503633322` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333337 + 
                0.24253562503633322` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                0.9701425001453318 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333337 + 
                0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                0.9701425001453318 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{
               0.19166666666666685`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.19166666666666685` + 
                0.8320502943378433 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                0.5547001962252295 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.19166666666666685`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.19166666666666685` + 
                0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                0.5547001962252295 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.050000000000000086`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.050000000000000086` + 
                0.5547001962252295 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                0.8320502943378433 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.050000000000000086`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.050000000000000086` + 
                0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                0.8320502943378433 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
         
          Piecewise[{{
             
             Piecewise[{{
               0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.24999999999999958` + 
                0.5547001962252289 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                0.8320502943378439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.24999999999999958` + 
                0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                0.8320502943378439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.1083333333333332 + 
                0.8320502943378439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                0.5547001962252289 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.1083333333333332 + 
                0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                0.5547001962252289 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{
               0.2916666666666669, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.2916666666666669 + 
                0.16439898730535663` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2916666666666669, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.2916666666666669 + 
                0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.216666666666667, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.216666666666667 + 
                0.9863939238321439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                0.16439898730535663` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             Piecewise[{{
               0.216666666666667, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.216666666666667 + 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                0.16439898730535663` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
         
          Piecewise[{{
             
             Piecewise[{{
               0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.29166666666666724` - 
                0.16439898730535732` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.29166666666666724` - 
                0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.3833333333333341 + 
                0.9863939238321439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.16439898730535732` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.3833333333333341 + 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.16439898730535732` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{
               0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.2499999999999996 - 
                0.4472135954999579 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.8944271909999159 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.2499999999999996 - 
                0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.8944271909999159 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999994 + 
                0.8944271909999159 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.4472135954999579 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999994 + 
                0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.4472135954999579 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{
               0.18499999999999991`, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.18499999999999991` - 
                0.6050832675335581 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.7961621941231023 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.18499999999999991`, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.18499999999999991` - 
                0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.7961621941231023 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.6083333333333337, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333337 + 
                0.7961621941231023 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.6050832675335581 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.6083333333333337, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333337 + 
                0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.6050832675335581 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
         
          Piecewise[{{
             
             Piecewise[{{
               0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.06333333333333312 - 
                0.720833064901856 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.6931087162517844 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.06333333333333312 - 
                0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.6931087162517844 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666654 + 
                0.6931087162517844 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666654 + 
                0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {-0.1 + Piecewise[{{
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
              1/2}, {
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
              1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}, {
          Piecewise[{{
             
             Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], 
          Piecewise[{{
             
             Piecewise[{{
               1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
               1.0000000000000027` + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
               1.0000000000000027` + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}}, $CellContext`p1[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           5, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.29166666666666646`, 0.25 < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                0.16439898730535726` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                0.9863939238321439 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.29166666666666646`, 0.25 < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.15 - 0.4 $CellContext`t)]) + 
                0.9863939238321439 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           6, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                0.16439898730535776` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.9863939238321435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.9863939238321435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           7, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                0.5547001962252291 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.8320502943378435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.8320502943378435 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           4, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.24999999999999997`, 0.2 < 
                0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                0.44721359549995787` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                0.8944271909999157 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.24999999999999997`, 0.2 < 
                0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.1 - 0.4 $CellContext`t)]) + 
                0.8944271909999157 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           8, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.19166666666666668`, 0.4 < 
                0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                0.8320502943378437 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.19166666666666668`, 0.4 < 
                0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           3, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                0.6050832675335577 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                0.7961621941231026 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                0.7961621941231026 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           9, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.09999999999999996, 0.45 < 
                0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                0.9701425001453319 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.24253562503633297` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.09999999999999996, 0.45 < 
                0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.24253562503633297` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           2, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-0.06333333333333332, 0.1 < 
                0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                0.720833064901856 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                0.6931087162517846 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-0.06333333333333332, 0.1 < 
                0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0. - 0.4 $CellContext`t)]) + 
                0.6931087162517846 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           10, $CellContext`s] Piecewise[{{
             
             Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                1. (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                1. ((0.1 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 1/2 <= $CellContext`t <= 
             1}}, 0] + BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           19, $CellContext`s] (-0.1 + Piecewise[{{
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
              1/2}, {
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
              1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           0, $CellContext`s] Piecewise[{{
             
             Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           1, $CellContext`s] (0.1 + Piecewise[{{
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
              1/2}, {
              
              Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                 0.1 + 0.4 $CellContext`t <= 0. <= 
                 0.5 + 0.4 $CellContext`t}, {
                0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
              1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           20, $CellContext`s] Piecewise[{{
             
             Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           18, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.06333333333333312 - 
                0.720833064901856 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.6931087162517844 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.06333333333333312 - 
                0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.8 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.6931087162517844 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           11, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.09999999999999992 + 
                0.9701425001453318 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                0.24253562503633322` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.09999999999999992 + 
                0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                0.24253562503633322` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           17, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.18499999999999991`, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.18499999999999991` - 
                0.6050832675335581 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.7961621941231023 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.18499999999999991`, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.18499999999999991` - 
                0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.7961621941231023 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           12, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.19166666666666685`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.19166666666666685` + 
                0.8320502943378433 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                0.5547001962252295 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.19166666666666685`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.19166666666666685` + 
                0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                0.5547001962252295 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           13, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.24999999999999958` + 
                0.5547001962252289 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                0.8320502943378439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.24999999999999958` + 
                0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                0.8320502943378439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           16, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.2499999999999996 - 
                0.4472135954999579 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.8944271909999159 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.2499999999999996 - 
                0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.8944271909999159 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           14, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.2916666666666669, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.2916666666666669 + 
                0.16439898730535663` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2916666666666669, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.2916666666666669 + 
                0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           15, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.29166666666666724` - 
                0.16439898730535732` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.29166666666666724` - 
                0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.65 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.9863939238321439 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0], $CellContext`p2[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           10, $CellContext`s] Piecewise[{{
             
             Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
               0. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
               0. + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.5 <= 
                0.5 + 0.4 $CellContext`t}, {
               0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           9, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333328 - 
                0.24253562503633297` (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.9701425001453319 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333328 - 
                0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.35 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.35 - 0.4 $CellContext`t)]) + 
                0.9701425001453319 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.45 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           11, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333337 + 
                0.24253562503633322` (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                0.9701425001453318 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
               0.008333333333333337 + 
                0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                0.9701425001453318 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.55 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           8, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
               0.049999999999999996` - 
                0.5547001962252291 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.8320502943378437 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
               0.049999999999999996` - 
                0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                0.8320502943378437 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.4 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           12, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.050000000000000086`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.050000000000000086` + 
                0.5547001962252295 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                0.8320502943378433 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.050000000000000086`, 0.6000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.050000000000000086` + 
                0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                0.8320502943378433 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           13, $CellContext`s] Piecewise[{{
             Piecewise[{{
               0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.1083333333333332 + 
                0.8320502943378439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                0.5547001962252289 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
               0.1083333333333332 + 
                0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                0.5547001962252289 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.65 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           7, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.10833333333333342`, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {
               0.10833333333333342` - 
                0.8320502943378435 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.10833333333333342`, 0.35000000000000003` < 
                0.1 + 0.4 $CellContext`t}, {
               0.10833333333333342` - 
                0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.25 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.25 - 0.4 $CellContext`t)]) + 
                0.5547001962252291 (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           6, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.2166666666666664, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {
               0.2166666666666664 - 
                0.9863939238321435 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.16439898730535776` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.2166666666666664, 0.30000000000000004` < 
                0.1 + 0.4 $CellContext`t}, {
               0.2166666666666664 - 
                0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                0.16439898730535776` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           14, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.216666666666667, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.216666666666667 + 
                0.9863939238321439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                0.16439898730535663` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.216666666666667, 0.7000000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.216666666666667 + 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                0.16439898730535663` (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           5, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
               0.38333333333333314` - 
                0.9863939238321439 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                0.16439898730535726` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
               0.38333333333333314` - 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.15 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.15 - 0.4 $CellContext`t)]) - 
                0.16439898730535726` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.25 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           15, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.3833333333333341 + 
                0.9863939238321439 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.16439898730535732` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
               0.3833333333333341 + 
                0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                0.16439898730535732` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.75 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           16, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999994 + 
                0.8944271909999159 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.4472135954999579 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             Piecewise[{{
               0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999994 + 
                0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                0.4472135954999579 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           4, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999999 - 
                0.8944271909999157 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                0.44721359549995787` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
               0.4999999999999999 - 
                0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.1 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.1 - 0.4 $CellContext`t)]) - 
                0.44721359549995787` (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.2 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           3, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.6083333333333336, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333336 - 
                0.7961621941231026 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   1.7 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                   0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                   0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                0.6050832675335577 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.6083333333333336, 0.15000000000000002` < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333336 - 
                0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                0.6050832675335577 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           17, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.6083333333333337, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333337 + 
                0.7961621941231023 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.6050832675335581 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.6083333333333337, 0.8500000000000001 < 
                0.1 + 0.4 $CellContext`t}, {
               0.6083333333333337 + 
                0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                0.6050832675335581 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           18, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666654 + 
                0.6931087162517844 (
                  0.2 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.3 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666654 + 
                0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.15 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                  0.1 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.9 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           2, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666665 - 
                0.6931087162517846 (
                 0.2 $CellContext`t 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.3 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.05 (1 - 2 $CellContext`t) + 
                   0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.1 (1 - 2 $CellContext`t) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.15 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.1 $CellContext`t 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
               0.7416666666666665 - 
                0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                   0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                   0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                   0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t)) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                 0.05 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.15 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                   2.5 (0. - 0.4 $CellContext`t)] - 
                 0.1 (2 - 2 $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                   2.5 (0. - 0.4 $CellContext`t)]) - 
                0.720833064901856 (
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.05 (-1 + 2 $CellContext`t) + 
                   0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.1 (-1 + 2 $CellContext`t) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.15 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                   0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                   0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                 0.05 (2 - 2 $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                   11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0.1 <= 
                0.5 + 0.4 $CellContext`t}, {
               0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           0, $CellContext`s] Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           1, $CellContext`s] Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           19, $CellContext`s] Piecewise[{{
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 1. (
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 0 <= $CellContext`t <= 
             1/2}, {
             
             Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
               1. + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 0. <= 0.5 + 0.4 $CellContext`t}, {
               1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0] + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
             0.16666666666666666`, 0.2222222222222222, 0.2777777777777778, 
             0.3333333333333333, 0.38888888888888884`, 0.4444444444444444, 
             0.5, 0.5555555555555556, 0.611111111111111, 0.6666666666666666, 
             0.7222222222222222, 0.7777777777777777, 0.8333333333333333, 
             0.8888888888888888, 0.9444444444444444, 1, 1, 1, 1}}, 
           20, $CellContext`s] Piecewise[{{
             
             Piecewise[{{
               1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
               1.0000000000000027` + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.1 $CellContext`t 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             0 <= $CellContext`t <= 1/2}, {
             
             Piecewise[{{
               1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
               1.0000000000000027` + 
                1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                  0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                0.1 + 0.4 $CellContext`t <= 1. <= 0.5 + 0.4 $CellContext`t}, {
               1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
             1/2 <= $CellContext`t <= 1}}, 0]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.822261272634788*^9, 3.822265177321969*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"c2dda8bc-d621-4c51-92e5-9526e0ab10cb"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Deformation of Cross Section in the Upper (1/2\
\[LessSlantEqual]z\[LessSlantEqual]1) Cylinder for 0\[LessSlantEqual]t\
\[LessSlantEqual]1", "Section"]], "Section",
 CellChangeTimes->{
  3.822260228238328*^9, {3.822260275247512*^9, 3.8222602753988132`*^9}},
 TextAlignment->Center,ExpressionUUID->"7bb6c2cd-a9bc-4cb6-9bb9-87a04502d32a"],

Cell[CellGroupData[{

Cell["\<\
2.1 Deforming control points along the parameter t for the terminal curve \
(z=1).\
\>", "Subsection",
 CellChangeTimes->{{3.822260259031247*^9, 
  3.8222602777909517`*^9}},ExpressionUUID->"e5c5d87f-f94c-43c0-aa1a-\
b2ed9960d4b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gpts1", "[", "t_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.5", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", "1.5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"0.3", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "+", "t"}], ")"}]}], ",", "1.5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5"}], ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5"}], ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.5"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.3"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"1", "/", "2"}], "-", "t"}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gpts2", "[", "t_", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{"t", "-", 
           RowBox[{"1", "/", "2"}]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.06", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5", ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", "1.5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", "1.5"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", "1"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{"t", "-", 
           RowBox[{"1", "/", "2"}]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.5"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{"t", "-", 
          RowBox[{"1", "/", "2"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "0.3"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", "/", "2"}], "-", "t"}], ")"}]}], ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{"t", "-", 
          RowBox[{"1", "/", "2"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", 
       RowBox[{"0", "+", 
        RowBox[{"(", 
         RowBox[{"t", "-", 
          RowBox[{"1", "/", "2"}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", 
       RowBox[{"0.5", "+", 
        RowBox[{"0.5", 
         RowBox[{"(", 
          RowBox[{"t", "-", 
           RowBox[{"1", "/", "2"}]}], ")"}]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.06"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gpts", "[", "t_", "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"gpts1", "[", "t", "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"gpts2", "[", "t", "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[32]:=",ExpressionUUID->"b63dda93-3cea-427f-bd8c-d5563cc0d58a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.2 Construct the terminal curve for all t in [0,1]. ", "Subsection",
 CellChangeTimes->{{3.8222602726273413`*^9, 
  3.82226028013494*^9}},ExpressionUUID->"93baff90-1925-4ab4-b071-\
3d135c037f2e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"mg", "=", 
    RowBox[{"Length", "[", 
     RowBox[{"gpts1", "[", "t", "]"}], "]"}]}], ";"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gknots", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"ConstantArray", "[", 
       RowBox[{"0", ",", "4"}], "]"}], ",", 
      RowBox[{
       RowBox[{"Range", "[", 
        RowBox[{"mg", "-", "4"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"mg", "-", "3"}], ")"}]}], ",", 
      RowBox[{"ConstantArray", "[", 
       RowBox[{"1", ",", "4"}], "]"}]}], "}"}], "//", "Flatten"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g11", "[", 
      RowBox[{"s_", ",", "t_"}], "]"}], ",", 
     RowBox[{"g12", "[", 
      RowBox[{"s_", ",", "t_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"gpts1", "[", "t", "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "gknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mg"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"g21", "[", 
      RowBox[{"s_", ",", "t_"}], "]"}], ",", 
     RowBox[{"g22", "[", 
      RowBox[{"s_", ",", "t_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"gpts2", "[", "t", "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "gknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mg"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g1", "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g11", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g21", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g2", "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g12", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", 
         RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"g22", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{
         RowBox[{"1", "/", "2"}], "\[LessEqual]", "t", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}]}], "Input",
 CellLabel->"In[35]:=",ExpressionUUID->"dcf17c07-d75d-468b-b918-b97f650b2233"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2.3 Sample 20 points on the above curve \
\[LeftAngleBracket]g1[s,t],g2[s,t]\[RightAngleBracket].", "Subsection",
 CellChangeTimes->{{3.822260309752995*^9, 
  3.822260312087861*^9}},ExpressionUUID->"94d1423d-ced9-400f-8e61-\
1f12a2d39206"],

Cell[TextData[StyleBox["First we define the following piecewise linear \
function for 0<=s<=1 with parameter 0<=t<=1.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.8222603222470818`*^9},ExpressionUUID->"416784b3-9936-48f9-9a49-\
b5fd00d75607"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"l", "[", 
    RowBox[{"s_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"0.04", "+", 
            RowBox[{"0.13", "t"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"0.1", "+", 
            RowBox[{"0.4", "t"}]}], ")"}]}], "s"}], ",", 
        RowBox[{"0", "\[LessEqual]", "s", "\[LessEqual]", 
         RowBox[{"0.1", "+", 
          RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.04", "+", 
         RowBox[{"0.13", "t"}], "+", 
         RowBox[{
          RowBox[{"0.79", "/", "0.4"}], 
          RowBox[{"(", 
           RowBox[{"s", "-", "0.1", "-", 
            RowBox[{"0.4", "t"}]}], ")"}]}]}], ",", 
        RowBox[{
         RowBox[{"0.1", "+", 
          RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
         RowBox[{"0.5", "+", 
          RowBox[{"0.4", "t"}]}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"0.83", "+", 
         RowBox[{"0.13", "t"}], "+", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "0.83", "-", 
             RowBox[{"0.13", "t"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", "0.5", "-", 
             RowBox[{"0.4", "t"}]}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{"s", "-", "0.5", "-", 
            RowBox[{"0.4", "t"}]}], ")"}]}]}], ",", 
        RowBox[{
         RowBox[{"0.5", "+", 
          RowBox[{"0.4", "t"}]}], "\[LessEqual]", "s", "\[LessEqual]", 
         "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[41]:=",ExpressionUUID->"69f9eb0f-6af7-4187-893b-00d51f828d31"],

Cell[TextData[StyleBox["Then we sample the curve unevenly use the above \
function.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260333192729*^9},ExpressionUUID->"088ffc91-a892-4065-ac02-\
f0b706b94afe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PTS", "[", "t_", "]"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g1", "[", 
        RowBox[{
         RowBox[{"l", "[", 
          RowBox[{"i", ",", "t"}], "]"}], ",", "t"}], "]"}], ",", 
       RowBox[{"g2", "[", 
        RowBox[{
         RowBox[{"l", "[", 
          RowBox[{"i", ",", "t"}], "]"}], ",", "t"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "1", ",", "0.05"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[42]:=",ExpressionUUID->"7ee7af4c-1e64-4568-be4b-1de04e7d80e9"],

Cell[TextData[{
 StyleBox["We replace the four points close to the base point to make the \
closed curve ",
  FontColor->GrayLevel[0.5]],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["C", "1"], TraditionalForm]],
  FontColor->GrayLevel[0.5],ExpressionUUID->
  "265ecde9-6514-4fc5-bf14-206a31b58df0"],
 StyleBox[".",
  FontColor->GrayLevel[0.5]]
}], "Text",
 CellChangeTimes->{{3.822260345698965*^9, 
  3.8222603577724743`*^9}},ExpressionUUID->"41116717-7414-4830-ac1e-\
a0781d94abe4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PTS", "[", "t_", "]"}], "=", 
   RowBox[{"ReplacePart", "[", 
    RowBox[{
     RowBox[{"PTS", "[", "t", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"PTS", "[", "t", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{"0.06", ",", "0"}], "}"}]}]}], ",", 
       RowBox[{"3", "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"PTS", "[", "t", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{"0.06", ",", 
           RowBox[{"-", "0.1"}]}], "}"}]}]}], ",", 
       RowBox[{"19", "\[Rule]", 
        RowBox[{
         RowBox[{
          RowBox[{"PTS", "[", "t", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.06"}], ",", 
           RowBox[{"-", "0.1"}]}], "}"}]}]}], ",", 
       RowBox[{"20", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"PTS", "[", "t", "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "+", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "0.06"}], ",", "0"}], "}"}]}]}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[43]:=",ExpressionUUID->"a6b648dd-2d13-461c-ad48-db512e7dc56a"],

Cell[TextData[StyleBox["We deform the 20 points at z=1/2 to the above points \
(at z=1) via straight lines.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260376466909*^9},ExpressionUUID->"5e7fe9db-24ac-4e7e-a22d-\
71d2503616ed"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SecondStagePts", "[", 
    RowBox[{"t_", ",", "z_"}], "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "-", 
       RowBox[{"2", 
        RowBox[{"k2", "[", "z", "]"}]}]}], ")"}], 
     RowBox[{"Pts", "[", 
      RowBox[{"t", ",", 
       RowBox[{"1", "/", "2"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        RowBox[{"k2", "[", "z", "]"}]}], "-", "1"}], ")"}], " ", 
     RowBox[{"PTS", "[", "t", "]"}]}]}]}], ";"}]], "Input",
 CellLabel->"In[44]:=",ExpressionUUID->"2b9046f2-5478-44a7-b05a-b2d595144f7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
2.4 Generate circle deformation \[LeftAngleBracket]q1[s,t,z], q2[s,t,z]\
\[RightAngleBracket] for 0\[LessSlantEqual]t\[LessSlantEqual]1 and 1/2\
\[LessSlantEqual]z\[LessSlantEqual]1.\
\>", "Subsection",
 CellChangeTimes->{{3.822260389243141*^9, 
  3.8222603923462763`*^9}},ExpressionUUID->"98c374c5-5477-4f12-98c8-\
2efcce8e7fbf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q1", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], ",", 
     RowBox[{"q2", "[", 
      RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"SecondStagePts", "[", 
      RowBox[{"t", ",", "z"}], "]"}], "]"}], ".", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"BSplineBasis", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "gknots"}], "}"}], ",", 
        RowBox[{"i", "-", "1"}], ",", "s"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "mg"}], "}"}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[45]:=",ExpressionUUID->"73ad7b89-15c9-4dc1-8778-a1c2fa4974e7"],

Cell[TextData[StyleBox["The following animation shows (1) the terminal curve, \
(2) the terminal curve with the 20 unevenly sampled points, and (3) the the \
generated deformation by these sampled points at z=1.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.8222604176601152`*^9},ExpressionUUID->"eda63c09-280b-4c68-b725-\
afd561758115"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GraphicsRow", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Gray", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"gpts", "[", "t", "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"gpts", "[", "t", "]"}], "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"g1", "[", 
             RowBox[{"s", ",", "t"}], "]"}], ",", 
            RowBox[{"g2", "[", 
             RowBox[{"s", ",", "t"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"g1", "[", 
             RowBox[{"s", ",", "t"}], "]"}], ",", 
            RowBox[{"g2", "[", 
             RowBox[{"s", ",", "t"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Blue"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"SecondStagePts", "[", 
             RowBox[{"t", ",", "1"}], "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"SecondStagePts", "[", 
             RowBox[{"t", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"ParametricPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"q1", "[", 
             RowBox[{"s", ",", "t", ",", "1"}], "]"}], ",", 
            RowBox[{"q2", "[", 
             RowBox[{"s", ",", "t", ",", "1"}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", 
           RowBox[{"Directive", "[", 
            RowBox[{"Black", ",", 
             RowBox[{"Thickness", "[", "0.01", "]"}]}], "]"}]}]}], "]"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"SecondStagePts", "[", 
             RowBox[{"t", ",", "1"}], "]"}], "]"}], ",", "Gray", ",", 
           RowBox[{"Line", "[", 
            RowBox[{"SecondStagePts", "[", 
             RowBox[{"t", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"PlotRange", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "0.5"}], ",", "2"}], "}"}]}], "}"}]}], ",", 
        RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
     "\[IndentingNewLine]", "}"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[46]:=",ExpressionUUID->"bacee7aa-cdd0-411d-8a23-b113b95cf4c1"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 1}}, Typeset`size$$ = {522., {136., 141.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`t$4126$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`t$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$4126$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> GraphicsRow[{
         Show[
          Graphics[{
            PointSize[Medium], Gray, 
            Point[
             $CellContext`gpts[$CellContext`t$$]], Gray, 
            Line[
             $CellContext`gpts[$CellContext`t$$]]}], 
          ParametricPlot[{
            $CellContext`g1[$CellContext`s, $CellContext`t$$], 
            $CellContext`g2[$CellContext`s, $CellContext`t$$]}, \
{$CellContext`s, 0, 1}, PlotStyle -> Blue], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False], 
         Show[
          ParametricPlot[{
            $CellContext`g1[$CellContext`s, $CellContext`t$$], 
            $CellContext`g2[$CellContext`s, $CellContext`t$$]}, \
{$CellContext`s, 0, 1}, PlotStyle -> Blue], 
          Graphics[{
            PointSize[Medium], Red, 
            Point[
             $CellContext`SecondStagePts[$CellContext`t$$, 1]], Gray, 
            Line[
             $CellContext`SecondStagePts[$CellContext`t$$, 1]]}], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False], 
         Show[
          ParametricPlot[{
            $CellContext`q1[$CellContext`s, $CellContext`t$$, 1], 
            $CellContext`q2[$CellContext`s, $CellContext`t$$, 
             1]}, {$CellContext`s, 0, 1}, PlotStyle -> Directive[Black, 
             Thickness[0.01]]], 
          Graphics[{
            PointSize[Medium], Red, 
            Point[
             $CellContext`SecondStagePts[$CellContext`t$$, 1]], Gray, 
            Line[
             $CellContext`SecondStagePts[$CellContext`t$$, 1]]}], 
          PlotRange -> {{-0.8, 0.8}, {-0.5, 2}}, Axes -> False]}], 
      "Specifications" :> {{$CellContext`t$$, 0, 1}}, "Options" :> {}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{567., {181., 187.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`gpts[
         Pattern[$CellContext`t, 
          Blank[]]] = 
       Piecewise[{{{{0, 1}, {0.06, 1}, {
            0.06, 0.5 + 0.5 (1/2 - $CellContext`t)}, {
            0.06, 1/2 - $CellContext`t}, {
            0.3 (1/2 + $CellContext`t), 1/2 - $CellContext`t}, {
            0.5 (1/2 + $CellContext`t), 1/2 - $CellContext`t}, {
            0.5 (1/2 + $CellContext`t), 0.5 + 0.5 (1/2 - $CellContext`t)}, {
            0.5 (1/2 + $CellContext`t), 1}, {
            0.5 (1/2 + $CellContext`t), 1.5}, {
            0.3 (1/2 + $CellContext`t), 1.5}, {0, 1.5}, {-0.3, 1.5}, {-0.5, 
            1.5}, {-0.5, 1}, {-0.5, 
            0.5}, {-0.5, 0}, {-0.3, 0}, {-0.06, 0}, {-0.06, 0.5 + 
             0.5 (1/2 - $CellContext`t)}, {-0.06, 1}, {0, 1}}, 
           0 <= $CellContext`t <= 
           1/2}, {{{0, 1}, {0.06, 1}, {
            0.06, 0.5 + 0.5 ((-1)/2 + $CellContext`t)}, {0.06, 0}, {0.3, 0}, {
            0.5, 0}, {0.5, 0.5}, {0.5, 1}, {0.5, 1.5}, {0.3, 1.5}, {
            0, 1.5}, {(-0.3) (3/2 - $CellContext`t), 
             1.5}, {(-0.5) (3/2 - $CellContext`t), 
             1.5}, {(-0.5) (3/2 - $CellContext`t), 
             1}, {(-0.5) (3/2 - $CellContext`t), 0.5 + 
             0.5 ((-1)/2 + $CellContext`t)}, {(-0.5) (
              3/2 - $CellContext`t), (-1)/2 + $CellContext`t}, {(-0.3) (
              3/2 - $CellContext`t), (-1)/2 + $CellContext`t}, {-0.06, (-1)/
              2 + $CellContext`t}, {-0.06, 0.5 + 
             0.5 ((-1)/2 + $CellContext`t)}, {-0.06, 1}, {0, 1}}, 
           1/2 <= $CellContext`t <= 1}}, 0], $CellContext`g1[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]]] = 
       Piecewise[{{
          0.06 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              1, $CellContext`s] + 
           0.06 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              2, $CellContext`s] + 
           0.06 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              3, $CellContext`s] + 
           0.3 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              4, $CellContext`s] + 
           0.5 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              5, $CellContext`s] + 
           0.5 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              6, $CellContext`s] + 
           0.5 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              7, $CellContext`s] + 
           0.5 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              8, $CellContext`s] + 
           0.3 (1/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              9, $CellContext`s] - 0.3 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             11, $CellContext`s] - 0.5 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             12, $CellContext`s] - 0.5 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             13, $CellContext`s] - 0.5 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             14, $CellContext`s] - 0.5 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             15, $CellContext`s] - 0.3 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             16, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             17, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             18, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             19, $CellContext`s], 0 <= $CellContext`t <= 1/2}, {
          0.06 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              1, $CellContext`s] + 
           0.06 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              2, $CellContext`s] + 
           0.06 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              3, $CellContext`s] + 
           0.3 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              4, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              5, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              6, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              7, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              8, $CellContext`s] + 
           0.3 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              9, $CellContext`s] - 0.3 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             11, $CellContext`s] - 0.5 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             12, $CellContext`s] - 0.5 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             13, $CellContext`s] - 0.5 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             14, $CellContext`s] - 0.5 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             15, $CellContext`s] - 0.3 (3/2 - $CellContext`t) 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             16, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             17, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             18, $CellContext`s] - 0.06 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             19, $CellContext`s], 1/2 <= $CellContext`t <= 1}}, 
         0], $CellContext`g2[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]]] = 
       Piecewise[{{
          BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             0, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             1, $CellContext`s] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              2, $CellContext`s] + (1/2 - $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              3, $CellContext`s] + (1/2 - $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              4, $CellContext`s] + (1/2 - $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              5, $CellContext`s] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              6, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             7, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              8, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              9, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              10, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              11, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              12, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             13, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              14, $CellContext`s] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              18, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             19, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             20, $CellContext`s], 0 <= $CellContext`t <= 1/2}, {
          BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             0, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             1, $CellContext`s] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              2, $CellContext`s] + 
           0.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              6, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             7, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              8, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              9, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              10, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              11, $CellContext`s] + 
           1.5 BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              12, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             13, $CellContext`s] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              14, $CellContext`s] + ((-1)/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              15, $CellContext`s] + ((-1)/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              16, $CellContext`s] + ((-1)/2 + $CellContext`t) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              17, $CellContext`s] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
            BSplineBasis[{
              3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
              18, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             19, $CellContext`s] + 
           BSplineBasis[{
             3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
               5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
             20, $CellContext`s], 1/2 <= $CellContext`t <= 1}}, 
         0], $CellContext`SecondStagePts[
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          
          Blank[]]] = {{(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4))
             
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.1 + 
            Piecewise[{{
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]), (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 0]]
                  - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.06333333333333332, 0.1 < 
                  0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                  0.6931087162517846 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.720833064901856 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                  0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.06333333333333332, 0.1 < 
                  0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                  0.6931087162517846 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                  0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                1.5 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666665 - 
                  0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.6931087162517846 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666665 - 
                  0.720833064901856 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  17, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 0 <= $CellContext`t <= 
               1/2}, {0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 1/2 <= $CellContext`t <= 1}},
              0] + (2 - 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
               
               Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                  0.7961621941231026 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.6050832675335577 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                  0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                  0.7961621941231026 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                  0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 0 <= $CellContext`t <= 
               1/2}, {BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 11, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 1/2 <= $CellContext`t <= 1}},
              0] + (2 - 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
               
               Piecewise[{{
                 0.6083333333333336, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333336 - 
                  0.6050832675335577 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.7961621941231026 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                  0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.6083333333333336, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333336 - 
                  0.6050832675335577 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                  0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 0\
.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.24999999999999997`, 0.2 < 
                  0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                  0.8944271909999157 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.44721359549995787` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                  0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.24999999999999997`, 0.2 < 
                  0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                  0.8944271909999157 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                  0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  20, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999999 - 
                  0.44721359549995787` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.8944271909999157 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999999 - 
                  0.44721359549995787` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 1, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.29166666666666646`, 0.25 < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.16439898730535726` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.29166666666666646`, 0.25 < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               Piecewise[{{
                 0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                 0.38333333333333314` - 
                  0.16439898730535726` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.9863939238321439 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                 0.38333333333333314` - 
                  0.16439898730535726` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                  0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                  0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2166666666666664, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2166666666666664 + 
                  0.16439898730535776` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                  0.9863939238321435 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                  0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2166666666666664, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2166666666666664 + 
                  0.16439898730535776` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                  0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                  0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                  0.8320502943378435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                  0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                  0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                  0.8320502943378435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                  0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                  0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.10833333333333342`, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.10833333333333342` + 
                  0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                  0.8320502943378435 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                  0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.10833333333333342`, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.10833333333333342` + 
                  0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                  0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                  0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.19166666666666668`, 0.4 < 
                  0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                  0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                  0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                  0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.19166666666666668`, 0.4 < 
                  0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                  0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                  0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                  0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                 0.049999999999999996` + 
                  0.8320502943378437 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                  0.5547001962252291 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                 0.049999999999999996` + 
                  0.8320502943378437 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                  0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.09999999999999996, 0.45 < 
                  0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                  0.24253562503633297` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                  0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                  0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.09999999999999996, 0.45 < 
                  0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                  0.24253562503633297` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                  0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                  0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333328 + 
                  0.9701425001453319 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                  0.24253562503633297` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333328 + 
                  0.9701425001453319 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                  0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                  0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                  1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                  0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                  0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                  1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                  0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                 0. + 
                  1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.09999999999999992 - 
                  0.24253562503633322` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.09999999999999992 - 
                  0.24253562503633322` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333337 + 
                  0.9701425001453318 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333337 + 
                  0.9701425001453318 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.19166666666666685`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.19166666666666685` - 
                  0.5547001962252295 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.19166666666666685`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.19166666666666685` - 
                  0.5547001962252295 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 12, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.050000000000000086`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.050000000000000086` + 
                  0.8320502943378433 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.050000000000000086`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.050000000000000086` + 
                  0.8320502943378433 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.24999999999999958` - 
                  0.8320502943378439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.24999999999999958` - 
                  0.8320502943378439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.1083333333333332 + 
                  0.5547001962252289 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.1083333333333332 + 
                  0.5547001962252289 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2916666666666669, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2916666666666669 - 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2916666666666669, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2916666666666669 - 
                  0.9863939238321439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.216666666666667, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.216666666666667 + 
                  0.16439898730535663` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.216666666666667, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.216666666666667 + 
                  0.16439898730535663` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               Piecewise[{{
                 0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.29166666666666724` - 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                  0.16439898730535732` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.29166666666666724` - 
                  0.9863939238321439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                  0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.3833333333333341 - 
                  0.16439898730535732` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.3833333333333341 - 
                  0.16439898730535732` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.2499999999999996 - 
                  0.8944271909999159 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                  0.4472135954999579 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.2499999999999996 - 
                  0.8944271909999159 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                  0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999994 - 
                  0.4472135954999579 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999994 - 
                  0.4472135954999579 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.18499999999999991`, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.18499999999999991` - 
                  0.7961621941231023 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                  0.6050832675335581 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.18499999999999991`, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.18499999999999991` - 
                  0.7961621941231023 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                  0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 0 <= $\
CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.6083333333333337, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333337 - 
                  0.6050832675335581 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                  0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.6083333333333337, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333337 - 
                  0.6050832675335581 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                  0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.06333333333333312 - 
                  0.6931087162517844 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                  0.720833064901856 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.06333333333333312 - 
                  0.6931087162517844 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                  0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666654 - 
                  0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                  0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666654 - 
                  0.720833064901856 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                  0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                0.5 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 
                   1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]), (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  18, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                 1.0000000000000027` + 
                  1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                 1.0000000000000027` + 
                  1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]}}, $CellContext`q1[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           5, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.29166666666666646`, 0.25 < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.16439898730535726` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.29166666666666646`, 0.25 < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           6, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                  0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                  0.9863939238321435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                  0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                  0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           7, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  16, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                  0.8320502943378435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                  0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                  0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                  0.8320502943378435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                  0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                  0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           4, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  18, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.24999999999999997`, 0.2 < 
                  0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                  0.8944271909999157 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.44721359549995787` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                  0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.24999999999999997`, 0.2 < 
                  0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                  0.8944271909999157 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                  0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           8, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.19166666666666668`, 0.4 < 
                  0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                  0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                  0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                  0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.19166666666666668`, 0.4 < 
                  0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                  0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                  0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                  0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           3, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 0 <= $CellContext`t <= 
               1/2}, {0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 1/2 <= $CellContext`t <= 1}},
              0] + (2 - 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
               
               Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                  0.7961621941231026 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.6050832675335577 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                  0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                  0.7961621941231026 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                  0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           9, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.09999999999999996, 0.45 < 
                  0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                  0.24253562503633297` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                  0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                  0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.09999999999999996, 0.45 < 
                  0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                  0.24253562503633297` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                  0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                  0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           2, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 0]]
                   - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-0.06333333333333332, 0.1 < 
                  0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                  0.6931087162517846 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.720833064901856 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                  0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-0.06333333333333332, 0.1 < 
                  0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                  0.6931087162517846 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                  0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           10, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                  0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                  1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                  0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
               1/2}, {
               
               Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                  0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                  1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                  0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           19, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0])) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           0, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           1, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.1 + 
            Piecewise[{{
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0])) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           20, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           18, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
            Piecewise[{{
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 0]]
                   + 
                0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               0.06 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                0.5 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.5 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] - 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.06333333333333312 - 
                  0.6931087162517844 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                  0.720833064901856 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.06333333333333312 - 
                  0.6931087162517844 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                  0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           11, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.09999999999999992 - 
                  0.24253562503633322` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.09999999999999992 - 
                  0.24253562503633322` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           17, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.18499999999999991`, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.18499999999999991` - 
                  0.7961621941231023 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                  0.6050832675335581 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.18499999999999991`, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.18499999999999991` - 
                  0.7961621941231023 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                  0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           12, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.19166666666666685`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.19166666666666685` - 
                  0.5547001962252295 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.19166666666666685`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.19166666666666685` - 
                  0.5547001962252295 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           13, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.24999999999999958` - 
                  0.8320502943378439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.24999999999999958` - 
                  0.8320502943378439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           16, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.2499999999999996 - 
                  0.8944271909999159 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                  0.4472135954999579 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.2499999999999996 - 
                  0.8944271909999159 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                  0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           14, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.3 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
               0.06 BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2916666666666669, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2916666666666669 - 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2916666666666669, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2916666666666669 - 
                  0.9863939238321439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           15, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 (1/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.3 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.3 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.5 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.3 (3/2 - $CellContext`t) 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               Piecewise[{{
                 0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.29166666666666724` - 
                  0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                  0.16439898730535732` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.29166666666666724` - 
                  0.9863939238321439 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                  0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]), $CellContext`q2[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           10, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                 0. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.5 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           9, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333328 + 
                  0.9701425001453319 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                  0.24253562503633297` (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333328 + 
                  0.9701425001453319 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                  0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.45 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           11, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               Piecewise[{{
                 0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333337 + 
                  0.9701425001453318 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                 0.008333333333333337 + 
                  0.9701425001453318 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                  0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.55 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           8, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                 0.049999999999999996` + 
                  0.8320502943378437 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                  0.5547001962252291 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                 0.049999999999999996` + 
                  0.8320502943378437 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                  0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.4 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           12, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.050000000000000086`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.050000000000000086` + 
                  0.8320502943378433 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.050000000000000086`, 0.6000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.050000000000000086` + 
                  0.8320502943378433 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                  0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                  0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           13, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.1083333333333332 + 
                  0.5547001962252289 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                 0.1083333333333332 + 
                  0.5547001962252289 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                  0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.65 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           7, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.10833333333333342`, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.10833333333333342` + 
                  0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                  0.8320502943378435 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                  0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.10833333333333342`, 0.35000000000000003` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.10833333333333342` + 
                  0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                  0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 8/
                    11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                  0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]) + BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           6, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.2166666666666664, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2166666666666664 + 
                  0.16439898730535776` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                  0.9863939238321435 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                  0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.2166666666666664, 0.30000000000000004` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.2166666666666664 + 
                  0.16439898730535776` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                  0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                  0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           14, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.216666666666667, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.216666666666667 + 
                  0.16439898730535663` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.216666666666667, 0.7000000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.216666666666667 + 
                  0.16439898730535663` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                  0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           5, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                 0.38333333333333314` - 
                  0.16439898730535726` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.9863939238321439 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0],
                0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                 0.38333333333333314` - 
                  0.16439898730535726` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.25 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 0],
                1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           15, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.3833333333333341 - 
                  0.16439898730535732` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                 0.3833333333333341 - 
                  0.16439898730535732` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                  0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.75 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           16, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999994 - 
                  0.4472135954999579 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999994 - 
                  0.4472135954999579 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                  0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           4, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999999 - 
                  0.44721359549995787` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.8944271909999157 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                 0.4999999999999999 - 
                  0.44721359549995787` (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                  0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.2 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           3, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 0 <= $CellContext`t <= 
               1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.35 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0]], 1/2 <= $CellContext`t <= 1}},
              0] + (2 - 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
               
               Piecewise[{{
                 0.6083333333333336, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333336 - 
                  0.6050832675335577 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.7961621941231026 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                  0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.6083333333333336, 0.15000000000000002` < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333336 - 
                  0.6050832675335577 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                  0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                  0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
             0]) + BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           17, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                 0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.6083333333333337, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333337 - 
                  0.6050832675335581 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                  0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.6083333333333337, 0.8500000000000001 < 
                  0.1 + 0.4 $CellContext`t}, {
                 0.6083333333333337 - 
                  0.6050832675335581 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                  0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                  0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           18, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 0]]
                   + 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666654 - 
                  0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                  0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666654 - 
                  0.720833064901856 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                  0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0.9 <= 
                  0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           2, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
            Piecewise[{{
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 0 <= $CellContext`t <= 1/2}, {
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                0.5 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                 BSplineBasis[{
                   3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                   
                   Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666665 - 
                  0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.6931087162517846 (
                   0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                   0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                 0.7416666666666665 - 
                  0.720833064901856 (
                   0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                  0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.05 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.15 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                   0.1 (2 - 2 $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                  0.1 <= 0.5 + 0.4 $CellContext`t}, {
                 0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           0, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           1, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           19, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 0.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + 1.5 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + ((-1)/2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                   0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]] + BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                  0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                 1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 0. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0]) + 
        BSplineBasis[{
           3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
             9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
           20, $CellContext`s] ((-1 + 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
           Piecewise[{{
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                 1/2 - $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 (1/2 - $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               0 <= $CellContext`t <= 1/2}, {
              BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 0, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 1, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               0.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               1.5 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 13, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                  2 + $CellContext`t) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                 0.5 ((-1)/2 + $CellContext`t)) 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                  
                  Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, 
                 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 20, 
                 Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                   0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
               1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
            2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
               
               Piecewise[{{
                 1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                 1.0000000000000027` + 
                  1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               0 <= $CellContext`t <= 1/2}, {
               
               Piecewise[{{
                 1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                 1.0000000000000027` + 
                  1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                  0.1 + 0.4 $CellContext`t <= 1. <= 
                  0.5 + 0.4 $CellContext`t}, {
                 1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
               1/2 <= $CellContext`t <= 1}}, 0])}; Typeset`initDone$$ = True),
    
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.822261277312476*^9, 3.822265205771594*^9},
 CellLabel->"Out[46]=",ExpressionUUID->"d141eb1f-1f1e-4490-9d10-5c5c2466b2aa"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["3. Deformation of Cross Section in the Entire (0\
\[LessSlantEqual]z\[LessSlantEqual]1) Cylinder for 0\[LessSlantEqual]t\
\[LessSlantEqual]1", "Section"]], "Section",
 CellChangeTimes->{{3.822260466573895*^9, 3.822260482229026*^9}},
 TextAlignment->Center,ExpressionUUID->"cd4bd3c9-2403-429e-8ba2-ff83b0aa25da"],

Cell[CellGroupData[{

Cell["\<\
3.1 Generate circle deformation F[s,t,z] for 0\[LessSlantEqual]t\
\[LessSlantEqual]1 and 0\[LessSlantEqual]z\[LessSlantEqual]1.\
\>", "Subsection",
 CellChangeTimes->{{3.8222604767980833`*^9, 
  3.8222604869491243`*^9}},ExpressionUUID->"4d2332dd-5c47-44eb-a2ca-\
c4b9b4e935e6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"F", "[", 
     RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
    RowBox[{"Piecewise", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"p1", "[", 
            RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
           RowBox[{"p2", "[", 
            RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
         RowBox[{"0", "\[LessEqual]", "z", "\[LessEqual]", 
          RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"q1", "[", 
            RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
           RowBox[{"q2", "[", 
            RowBox[{"s", ",", "t", ",", "z"}], "]"}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "\[LessEqual]", "z", "\[LessEqual]", 
          "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PointDeformation", "[", 
     RowBox[{"t_", ",", "z_"}], "]"}], "=", 
    RowBox[{"Piecewise", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Pts", "[", 
          RowBox[{"t", ",", "z"}], "]"}], ",", 
         RowBox[{"0", "\[LessEqual]", "z", "\[LessEqual]", 
          RowBox[{"1", "/", "2"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SecondStagePts", "[", 
          RowBox[{"t", ",", "z"}], "]"}], ",", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "\[LessEqual]", "z", "\[LessEqual]", 
          "1"}]}], "}"}]}], "}"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ParametricPlot", "[", 
      RowBox[{
       RowBox[{"F", "[", 
        RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
       RowBox[{"Axes", "\[Rule]", "None"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.1"}], ",", "1.5"}], "}"}]}], "}"}]}]}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Medium", "]"}], ",", "Red", ",", 
        RowBox[{"Point", "[", 
         RowBox[{"PointDeformation", "[", 
          RowBox[{"t", ",", "z"}], "]"}], "]"}], ",", "Gray", ",", 
        RowBox[{"Line", "[", 
         RowBox[{"PointDeformation", "[", 
          RowBox[{"t", ",", "z"}], "]"}], "]"}]}], "}"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8222605086786757`*^9, 3.8222605150066557`*^9}},
 CellLabel->"In[47]:=",ExpressionUUID->"c71f1249-ef64-408c-89b1-2d26b5efb483"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = 0, $CellContext`z$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], 0, 1}, {
      Hold[$CellContext`z$$], 0, 1}}, Typeset`size$$ = {360., {178., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`t$4782$$ = 0, $CellContext`z$4783$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`t$$ = 0, $CellContext`z$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$4782$$, 0], 
        Hold[$CellContext`z$$, $CellContext`z$4783$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        ParametricPlot[
         $CellContext`F[$CellContext`s, $CellContext`t$$, $CellContext`z$$], \
{$CellContext`s, 0, 1}, PlotStyle -> Black, Axes -> None, AspectRatio -> 
         Automatic, PlotRange -> {{-0.8, 0.8}, {-0.1, 1.5}}], 
        Graphics[{
          PointSize[Medium], Red, 
          Point[
           $CellContext`PointDeformation[$CellContext`t$$, $CellContext`z$$]],
           Gray, 
          Line[
           $CellContext`PointDeformation[$CellContext`t$$, \
$CellContext`z$$]]}]], 
      "Specifications" :> {{$CellContext`t$$, 0, 1}, {$CellContext`z$$, 0, 
         1}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {237., 243.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`F[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = 
       Piecewise[{{{
           BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                    0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                    0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                    0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                    0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                    0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                    0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                    0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                    0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                    0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                    0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                    0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                    0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] (-0.1 + 
              Piecewise[{{
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] (0.1 + 
              Piecewise[{{
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                   0.06333333333333312 - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                  0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                   0.06333333333333312 - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                  1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {
                0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                   0.09999999999999992 + 
                    0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                    0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                   0.09999999999999992 + 
                    0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                    0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {
                0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.18499999999999991` - 
                    0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.18499999999999991` - 
                    0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {
                0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.19166666666666685` + 
                    0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                    0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.19166666666666685` + 
                    0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                    0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {
                0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                   0.24999999999999958` + 
                    0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                    0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                   0.24999999999999958` + 
                    0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                    0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                   0.2499999999999996 - 
                    0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                   0.2499999999999996 - 
                    0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.2916666666666669 + 
                    0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.2916666666666669 + 
                    0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                   0.29166666666666724` - 
                    0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                   0.29166666666666724` - 
                    0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0], 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                   0.008333333333333328 - 
                    0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                   0.008333333333333328 - 
                    0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                   0.008333333333333337 + 
                    0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                   0.008333333333333337 + 
                    0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                   0.049999999999999996` - 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                   0.049999999999999996` - 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.050000000000000086` + 
                    0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.050000000000000086` + 
                    0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                   0.1083333333333332 + 
                    0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                  0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                   0.1083333333333332 + 
                    0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0],
                  1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.10833333333333342` - 
                    0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                 
                 Piecewise[{{
                   0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.10833333333333342` - 
                    0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.2166666666666664 - 
                    0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                 
                 Piecewise[{{
                   0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.2166666666666664 - 
                    0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.216666666666667 + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.216666666666667 + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                   0.38333333333333314` - 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                   0.38333333333333314` - 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                  0], 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                   0.3833333333333341 + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                  0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                   0.3833333333333341 + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0],
                  1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                   0.4999999999999994 + 
                    0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                   0.4999999999999994 + 
                    0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                   0.4999999999999999 - 
                    0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                   0.4999999999999999 - 
                    0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.6083333333333336 - 
                    0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                 
                 Piecewise[{{
                   0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.6083333333333336 - 
                    0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.6083333333333337 + 
                    0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                   0.6083333333333337 + 
                    0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
               0] + BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                   0.7416666666666654 + 
                    0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                   0.7416666666666654 + 
                    0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                   0.7416666666666665 - 
                    0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                   0.7416666666666665 - 
                    0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 
                    1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                   1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0] + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                 0.16666666666666666`, 0.2222222222222222, 0.2777777777777778,
                  0.3333333333333333, 0.38888888888888884`, 
                 0.4444444444444444, 0.5, 0.5555555555555556, 
                 0.611111111111111, 0.6666666666666666, 0.7222222222222222, 
                 0.7777777777777777, 0.8333333333333333, 0.8888888888888888, 
                 0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] 
             Piecewise[{{
                 
                 Piecewise[{{
                   1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                   1.0000000000000027` + 
                    1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{
                   1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                   1.0000000000000027` + 
                    1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0]}, 0 <= $CellContext`z <= 
           1/2}, {{BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               5, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               6, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               7, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               4, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               8, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               3, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               9, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               2, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
                Piecewise[{{
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               10, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               19, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
                Piecewise[{{
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0])) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               0, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {
                0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
                 9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               1, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
                Piecewise[{{
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.1 + 
                Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0])) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               20, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               18, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
                Piecewise[{{
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               11, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {
                0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 5/
                 9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               17, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               12, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               13, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               16, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               14, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                   0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               15, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]), 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               10, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               9, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               11, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               8, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               12, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               13, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               7, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                   
                   Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               6, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                   
                   Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               14, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               5, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               15, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               16, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               4, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               3, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                   
                   Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               17, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                 0]) + BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               18, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                Piecewise[{{
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               2, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                Piecewise[{{
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               0, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               1, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               19, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]) + 
            BSplineBasis[{
               3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                  5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}}, 
               20, $CellContext`s] ((-1 + 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                   0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                   1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                   
                   Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                    0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                    1/2 <= $CellContext`t <= 1}}, 0])}, 1/2 <= $CellContext`z <= 
           1}}, 0], $CellContext`PointDeformation[
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = Piecewise[{{{{
             Piecewise[{{
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {0.1 + Piecewise[{{
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.06333333333333332, 0.1 < 
                   0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                   0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                   0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.1 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                   0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 0 <= $CellContext`t <= 
                1/2}, {
                
                Piecewise[{{-0.06333333333333332, 0.1 < 
                   0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                   0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                   0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.1 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                   0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                  0.7416666666666665 - 
                   0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                   0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.1 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                  0.7416666666666665 - 
                   0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                   0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.1 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                   0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                   0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                   0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                   0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                   0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                   0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                   0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                   0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.6083333333333336, 0.15000000000000002` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.6083333333333336 - 
                   0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                   0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                   0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                Piecewise[{{
                  0.6083333333333336, 0.15000000000000002` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.6083333333333336 - 
                   0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                   0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                   0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.24999999999999997`, 0.2 < 
                   0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                   0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                   0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.2 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                   0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 0 <= $CellContext`t <= 
                1/2}, {
                
                Piecewise[{{-0.24999999999999997`, 0.2 < 
                   0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                   0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                   0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.2 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                   0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                  0.4999999999999999 - 
                   0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                   0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.2 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                  0.4999999999999999 - 
                   0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                   0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.2 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.29166666666666646`, 0.25 < 
                   0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                   0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.25 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                   0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{-0.29166666666666646`, 0.25 < 
                   0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                   0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.25 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                   0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                  0.38333333333333314` - 
                   0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                   0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.25 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                  0.38333333333333314` - 
                   0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                   0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.25 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                   0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                   0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                   0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                   0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                   0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                   0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                   0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                   0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.2166666666666664, 0.30000000000000004` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.2166666666666664 - 
                   0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                   0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                   0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.2166666666666664, 0.30000000000000004` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.2166666666666664 - 
                   0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                   0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                   0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                   0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                   0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                   0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                   0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                   0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                   0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                   0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                   0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                   0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.10833333333333342`, 0.35000000000000003` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.10833333333333342` - 
                   0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                   0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                   0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.10833333333333342`, 0.35000000000000003` < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.10833333333333342` - 
                   0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                   0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                   0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                Piecewise[{{-0.19166666666666668`, 0.4 < 
                   0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                   0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                   0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.4 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                   0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 0 <= $CellContext`t <= 
                1/2}, {
                
                Piecewise[{{-0.19166666666666668`, 0.4 < 
                   0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                   0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                   0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.4 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                   0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                  0.049999999999999996` - 
                   0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                   0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.4 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                  0.049999999999999996` - 
                   0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                   0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.4 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-0.09999999999999996, 0.45 < 
                   0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                   0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                   0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.45 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                   0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{-0.09999999999999996, 0.45 < 
                   0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                   0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                   0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.45 <= 
                   0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                   0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                  0.008333333333333328 - 
                   0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                   0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.45 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                  0.008333333333333328 - 
                   0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                   0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.45 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                   0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                   1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0.5 <= 
                   0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                   0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 0 <= $CellContext`t <= 
                1/2}, {
                
                Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                   0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                   1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 0.5 <= 
                   0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                   0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.5 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.5 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                  0.09999999999999992 + 
                   0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                   0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.55 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                  0.09999999999999992 + 
                   0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                   0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.55 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 0],
                 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                  0.008333333333333337 + 
                   0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                   0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.55 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                  0.008333333333333337 + 
                   0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                   0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.55 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.19166666666666685`, 0.6000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.19166666666666685` + 
                   0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                   0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                   0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                Piecewise[{{
                  0.19166666666666685`, 0.6000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.19166666666666685` + 
                   0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                   0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                   0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.050000000000000086`, 0.6000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.050000000000000086` + 
                   0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                   0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                   0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.050000000000000086`, 0.6000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.050000000000000086` + 
                   0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                   0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                   0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                  0.24999999999999958` + 
                   0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                   0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.65 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                  0.24999999999999958` + 
                   0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                   0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.65 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                  0.1083333333333332 + 
                   0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                   0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.65 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                  0.1083333333333332 + 
                   0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                   0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.65 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.2916666666666669, 0.7000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.2916666666666669 + 
                   0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                   0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.2916666666666669, 0.7000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.2916666666666669 + 
                   0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                   0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.216666666666667, 0.7000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.216666666666667 + 
                   0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                   0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                   0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.216666666666667, 0.7000000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.216666666666667 + 
                   0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                   0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                   0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                  0.29166666666666724` - 
                   0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.75 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                  0.29166666666666724` - 
                   0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                   0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.75 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                 0], 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                  0.3833333333333341 + 
                   0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                   0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.75 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                  0.3833333333333341 + 
                   0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                   0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.75 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                  0.2499999999999996 - 
                   0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                   0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                  0.2499999999999996 - 
                   0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                   0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                  0.4999999999999994 + 
                   0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                   0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                  0.4999999999999994 + 
                   0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                   0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.18499999999999991`, 0.8500000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.18499999999999991` - 
                   0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                   0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                   0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.18499999999999991`, 0.8500000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.18499999999999991` - 
                   0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                   0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                   0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.6083333333333337, 0.8500000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.6083333333333337 + 
                   0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                   0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                   0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.6083333333333337, 0.8500000000000001 < 
                   0.1 + 0.4 $CellContext`t}, {
                  0.6083333333333337 + 
                   0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                   0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                   0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
              0]}, {
             Piecewise[{{
                
                Piecewise[{{
                  0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                  0.06333333333333312 - 
                   0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                   0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.9 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                  0.06333333333333312 - 
                   0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                   0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.9 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                  0.7416666666666654 + 
                   0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                   0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.9 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                  0.7416666666666654 + 
                   0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                   0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0.9 <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {-0.1 + Piecewise[{{
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 0 <= $CellContext`t <= 1/2}, {
                 
                 Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                   0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                   0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                 1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                  1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 0. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}, {
             Piecewise[{{
                
                Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 1. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                  0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                   0.1 + 0.4 $CellContext`t <= 1. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0], 
             Piecewise[{{
                
                Piecewise[{{
                  1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                  1.0000000000000027` + 
                   1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 1. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                0 <= $CellContext`t <= 1/2}, {
                
                Piecewise[{{
                  1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                  1.0000000000000027` + 
                   1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                   0.1 + 0.4 $CellContext`t <= 1. <= 
                   0.5 + 0.4 $CellContext`t}, {
                  1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                1/2 <= $CellContext`t <= 1}}, 0]}}, 0 <= $CellContext`z <= 
           1/2}, {{{(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.1 + 
               Piecewise[{{
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]), (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                   1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                  
                  Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                  
                  Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                 
                  
                  Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0], (-1 + 2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                   0], 0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                   0], 1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
               Piecewise[{{
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
               Piecewise[{{
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
               Piecewise[{{
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   0 <= $CellContext`t <= 1/2}, {
                   
                   Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                   1/2 <= $CellContext`t <= 1}}, 0]), (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0]}, {(-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.3 (1/2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.3 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.5 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                  0.3 (3/2 - $CellContext`t) 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                  0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                  1/2 <= $CellContext`t <= 1}}, 0], (-1 + 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
              Piecewise[{{
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                  0 <= $CellContext`t <= 1/2}, {
                 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                  1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
               2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) Piecewise[{{
                  
                  Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                   0 <= $CellContext`t <= 1/2}, {
                  
                  Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                   1/2 <= $CellContext`t <= 1}}, 0]}}, 1/2 <= $CellContext`z <= 
           1}}, 0]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.822261284119225*^9, 3.822263200100381*^9, 
  3.822265282367869*^9},
 CellLabel->"Out[49]=",ExpressionUUID->"22cf6857-8386-4281-b8fc-db7d751c8762"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4. Deformation of Cross Section in the Entire (0\
\[LessSlantEqual]z\[LessSlantEqual]1) Cylinder for -1\[LessSlantEqual]t\
\[LessSlantEqual]2", "Section"]], "Section",
 CellChangeTimes->{{3.82226055882456*^9, 3.822260560983397*^9}},
 TextAlignment->Center,ExpressionUUID->"79e240d1-d499-4075-9776-609e4f97f564"],

Cell[CellGroupData[{

Cell["\<\
4.1 And lastly, generate circle deformation H[s,t,z] for -1\[LessSlantEqual]t\
\[LessSlantEqual]2 and 0\[LessSlantEqual]z\[LessSlantEqual]1.\
\>", "Subsection",
 CellChangeTimes->{{3.822260580778061*^9, 
  3.8222605831200457`*^9}},ExpressionUUID->"3f6a9819-8a09-494f-bc68-\
173ffd81778a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"H", "[", 
    RowBox[{"s_", ",", "t_", ",", "z_"}], "]"}], "=", 
   RowBox[{"Piecewise", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{"s", ",", "0", ",", 
               RowBox[{
                RowBox[{"-", "t"}], "+", "z"}]}], "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "z", "\[LessEqual]", 
              RowBox[{"t", "+", "1"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{"s", ",", "0", ",", "1"}], "]"}], ",", 
             RowBox[{
              RowBox[{"t", "+", "1"}], "\[LessEqual]", "z", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{
         RowBox[{"-", "1"}], "\[LessEqual]", "t", "\[LessEqual]", "0"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"F", "[", 
         RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Piecewise", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{"s", ",", "1", ",", 
               RowBox[{"t", "-", "1", "+", "z"}]}], "]"}], ",", 
             RowBox[{"0", "\[LessEqual]", "z", "\[LessEqual]", 
              RowBox[{"2", "-", "t"}]}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"F", "[", 
              RowBox[{"s", ",", "1", ",", "1"}], "]"}], ",", 
             RowBox[{
              RowBox[{"2", "-", "t"}], "\[LessEqual]", "z", "\[LessEqual]", 
              "1"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"1", "\[LessEqual]", "t", "\[LessEqual]", "2"}]}], "}"}]}], 
     "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[50]:=",ExpressionUUID->"d56f8a52-2928-44ec-b7fc-2322f544ead5"],

Cell[TextData[StyleBox["Below is an animation generating the immersed circle \
for all t and z.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.8222606078977413`*^9},ExpressionUUID->"a73f091f-7aee-47c6-a89c-\
4f1118041779"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"ParametricPlot", "[", 
    RowBox[{
     RowBox[{"H", "[", 
      RowBox[{"s", ",", "t", ",", "z"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
     RowBox[{"Axes", "\[Rule]", "None"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.8"}], ",", "0.8"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.1"}], ",", "1.5"}], "}"}]}], "}"}]}]}], "]"}], ",", 
   
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "1"}], "}"}], ",", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[51]:=",ExpressionUUID->"59a768c0-565a-4ea5-a793-46100a5770a5"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`t$$ = -1, $CellContext`z$$ = 0, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`t$$], -1, 2}, {
      Hold[$CellContext`z$$], 0, 1}}, Typeset`size$$ = {360., {178., 182.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`t$5051$$ = 0, $CellContext`z$5052$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`t$$ = -1, $CellContext`z$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`t$$, $CellContext`t$5051$$, 0], 
        Hold[$CellContext`z$$, $CellContext`z$5052$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ParametricPlot[
        $CellContext`H[$CellContext`s, $CellContext`t$$, $CellContext`z$$], \
{$CellContext`s, 0, 1}, PlotStyle -> Black, Axes -> None, AspectRatio -> 
        Automatic, PlotRange -> {{-0.8, 0.8}, {-0.1, 1.5}}], 
      "Specifications" :> {{$CellContext`t$$, -1, 2}, {$CellContext`z$$, 0, 
         1}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {237., 243.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`H[
         Pattern[$CellContext`s, 
          Blank[]], 
         Pattern[$CellContext`t, 
          Blank[]], 
         Pattern[$CellContext`z, 
          Blank[]]] = Piecewise[{{
           Piecewise[{{
              
              Piecewise[{{{
                 0. + 0.1 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] - 
                  0.06333333333333332 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] - 
                  0.16845216272957034` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] - 
                  0.17173762078750737` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] - 
                  3.8163916471489756`*^-17 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] + 
                  0.09999999999999992 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] + 
                  0.19166666666666685` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] + 
                  0.24999999999999958` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] + 
                  0.2916666666666669 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] + 
                  0.29166666666666724` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] + 
                  0.2499999999999996 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] + 
                  0.18499999999999991` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] + 
                  0.06333333333333312 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] - 
                  0.1 BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                    5, $CellContext`s] (-0.2916345574894584 + 
                    0.9863939238321439 (0.1561686197916666 + 
                    0.00032552083333333245` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))))) + BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                    9, $CellContext`s] (-0.7272135480269015 + 
                    0.24253562503633297` (0. + 
                    0.008789062499999977 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                    6, $CellContext`s] (-0.34167135863871284` + 
                    0.9863939238321435 (0.09895833333333308 + 
                    0.4791666666666673 (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))) + 0.020833333333333502` (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                    8, $CellContext`s] (-0.9587130317593667 + 
                    0.5547001962252291 (0. + 
                    0.6822916666666664 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                    7, $CellContext`s] (-0.6798204254865032 + 
                    0.8320502943378435 (0.00006510416666666649 + 
                    0.23600260416666685` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))) + 0.7636718750000008 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))), 0. + 
                  1. BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] + 
                  1. BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] + 
                  0.7416666666666665 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.595756977007807 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] + 
                  0.4608688103937536 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] + 
                  0.008333333333333337 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] + 
                  0.050000000000000086` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] + 
                  0.1083333333333332 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] + 
                  0.216666666666667 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] + 
                  0.3833333333333341 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] + 
                  0.4999999999999994 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] + 
                  0.6083333333333337 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] + 
                  0.7416666666666654 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] + 
                  1. BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] + 
                  1.0000000000000027` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] (
                    0.3835259883965816 - 
                    0.16439898730535726` (0.1561686197916666 + 
                    0.00032552083333333245` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))))) + BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] (
                    0.16513672034005872` + 
                    0.9701425001453319 (0. + 
                    0.008789062499999977 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] (
                    0.5166948184989438 + 
                    0.16439898730535776` (0.09895833333333308 + 
                    0.4791666666666673 (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))) + 0.020833333333333502` (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] (
                    0.5613642433951335 + 
                    0.8320502943378437 (0. + 
                    0.6822916666666664 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] (
                    0.7530639715630876 + 
                    0.5547001962252291 (0.00006510416666666649 + 
                    0.23600260416666685` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - Cos[2 Pi (-$CellContext`t + $CellContext`z)]/
                    4))) + 0.7636718750000008 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-$CellContext`t + $CellContext`z)]/4)))))}, 
                 0 <= -$CellContext`t + $CellContext`z <= 1/2}, {{
                 0. + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    9, $CellContext`s] ((-0.7244423890299043) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.4998569661458338 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    8, $CellContext`s] ((-0.4667055139616767) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.492246387499999 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    10, $CellContext`s] ((-3.8163916471489756`*^-17) (2 - 
                    2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.306455573333333 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] (
                    0.09999999999999992 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.23869773701333288` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, $CellContext`s] (
                    0.3367462305107346 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.18002498242187542` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] (
                    0.19166666666666685` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.17364842837333294` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] (
                    0.24999999999999958` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.119326059893333 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, $CellContext`s] (
                    0.2916666666666669 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.08337108223999992 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] (
                    0.29166666666666724` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.06595507999999997 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] (
                    0.2499999999999996 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.060449576960000036` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    19, $CellContext`s] ((-0.1) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] (
                    0.06333333333333312 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] (
                    0.18499999999999991` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) - 
                    0.05996691792000008 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    2, $CellContext`s] ((-0.06333333333333332) (2 - 
                    2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] (
                    0.1 (2 - 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    3, $CellContext`s] ((-0.16845216272957034`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.10688348979166673` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] (
                    0.24112305135877912` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.16215322499999982` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    4, $CellContext`s] ((-0.17173762078750737`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.24364869791666682` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    5, $CellContext`s] ((-0.1372793208147878) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.24999758828125013` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))), 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, $CellContext`s] (0. + 
                    0.00001799999999999945 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] (
                    0.008333333333333337 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.0018608669999999748` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] (
                    0.050000000000000086` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.021024575999999906` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] (
                    0.1083333333333332 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.07895358899999985 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, $CellContext`s] (
                    0.216666666666667 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.19575894800000024` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] (
                    0.3833333333333341 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.36462068750000076` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, $CellContext`s] (
                    0.17622135632804733` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.4191075846354164 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] (
                    0.595756977007807 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.505286849609375 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] (
                    0.4999999999999994 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.5541993919999999 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] (
                    0.4608688103937536 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.5846282552083337 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] (
                    0.6083333333333337 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.7323297895000018 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] (
                    0.7416666666666654 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.9 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] (
                    0.7416666666666665 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    0.9 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, $CellContext`s] (
                    1.0000000000000027` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1.0000000000000016` (-1 + 
                    2 (3/4 - 
                    Cos[2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] (
                    0.3578001156174698 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1.061680610026042 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, $CellContext`s] (
                    1.2993755200916686` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1.288115968749996 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] (
                    0.6138272201651929 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1.4995905833333327` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, $CellContext`s] (
                    1.4307750755612463` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)) + 
                    1.5000000000000018` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-1)/2 - $CellContext`t + $CellContext`z)]/4)))}, 
                 1/2 <= -$CellContext`t + $CellContext`z <= 1}}, 0], 
              0 <= $CellContext`z <= 1 + $CellContext`t}, {{
              0. + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] + 
               0.10688348979166673` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] + 
               0.24364869791666682` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] + 
               0.24999758828125013` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] + 
               0.16215322499999982` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] - 0.18002498242187542` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 7, $CellContext`s] - 0.492246387499999 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 8, $CellContext`s] - 0.4998569661458338 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 9, $CellContext`s] - 0.306455573333333 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 10, $CellContext`s] - 0.23869773701333288` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 11, $CellContext`s] - 0.17364842837333294` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 12, $CellContext`s] - 0.119326059893333 
               BSplineBasis[{
                 3, {
                  0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2, 
                   5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 1}},
                  13, $CellContext`s] - 0.08337108223999992 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, $CellContext`s] - 0.06595507999999997 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, $CellContext`s] - 0.060449576960000036` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, $CellContext`s] - 0.05996691792000008 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, $CellContext`s] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, $CellContext`s] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, $CellContext`s], 
               1. BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, $CellContext`s] + 
               1. BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] + 
               0.9 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] + 
               0.505286849609375 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] + 
               0.5846282552083337 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] + 
               1.061680610026042 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] + 
               1.4995905833333327` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] + 
               1.5000000000000018` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, $CellContext`s] + 
               1.288115968749996 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, $CellContext`s] + 
               0.4191075846354164 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, $CellContext`s] + 
               0.00001799999999999945 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, $CellContext`s] + 
               0.0018608669999999748` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] + 
               0.021024575999999906` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] + 
               0.07895358899999985 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] + 
               0.19575894800000024` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, $CellContext`s] + 
               0.36462068750000076` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] + 
               0.5541993919999999 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] + 
               0.7323297895000018 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] + 
               0.9 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] + 
               1. BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, $CellContext`s] + 
               1.0000000000000016` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, $CellContext`s]}, 
              1 + $CellContext`t <= $CellContext`z <= 1}}, 
            0], -1 <= $CellContext`t <= 0}, {
           
           Piecewise[{{{
              BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                    0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` - 
                    0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.9863939238321435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.8320502943378435 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                    0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                    0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` - 
                    0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) + 
                    0.8944271909999157 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                    0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                    0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` - 
                    0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) + 
                    0.7961621941231026 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.24253562503633297` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                    0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) + 
                    0.6931087162517846 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 
                  19, $CellContext`s] (-0.1 + Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] (0.1 + 
                 Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.6931087162517844 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 + 
                    0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                    0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 + 
                    0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) - 
                    0.24253562503633322` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.7961621941231023 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` + 
                    0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                    0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` + 
                    0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) - 
                    0.5547001962252295 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] 
                Piecewise[{{
                    Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` + 
                    0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                    0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` + 
                    0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) - 
                    0.8320502943378439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.8944271909999159 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 + 
                    0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 + 
                    0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0], 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 - 
                    0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 - 
                    0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` - 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` - 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` - 
                    0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                    
                    Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` - 
                    0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 - 
                    0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                    
                    Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 - 
                    0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 + 
                    0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 + 
                    0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                   
                    
                    Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 + 
                    0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 + 
                    0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                  0] + BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 + 
                    0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 + 
                    0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0.1 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0] + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] 
                Piecewise[{{
                    
                    Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (1 - 2 $CellContext`t) + 
                    0.1 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (1 - 2 $CellContext`t) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (1 - 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.4 $CellContext`t (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. (BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.05 (-1 + 2 $CellContext`t) + 
                    0.05 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.1 (-1 + 2 $CellContext`t) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.1 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.15 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (1.7 + 
                    6.3 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (
                    0.2 (-1 + 2 $CellContext`t) (2 + 
                    9 (1/4 - Cos[2 Pi $CellContext`z]/4)) + 
                    0.2 (2 - 2 $CellContext`t) (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))) + 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] (1 + 
                    11 (1/4 - Cos[2 Pi $CellContext`z]/4))), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]}, 0 <= $CellContext`z <= 
              1/2}, {{BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  5, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.29166666666666646`, 0.25 < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.16439898730535726` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  6, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.29166666666666646`, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {-0.29166666666666646` + 
                    0.9863939238321435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) + 
                    0.16439898730535776` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.29166666666666646`, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  7, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.2500000000000003, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {-0.2500000000000003 + 
                    0.8320502943378435 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) + 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.2500000000000003, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  4, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.24999999999999997`, 0.2 < 
                    0.1 + 0.4 $CellContext`t}, {-0.24999999999999997` + 
                    0.8944271909999157 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.44721359549995787` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.24999999999999997`, 
                    0.5 + 0.4 $CellContext`t <= 0.2}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  8, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.19166666666666668`, 0.4 < 
                    0.1 + 0.4 $CellContext`t}, {-0.19166666666666668` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) + 
                    0.8320502943378437 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.19166666666666668`, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  3, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.18500000000000008`, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {-0.18500000000000008` + 
                    0.7961621941231026 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.6050832675335577 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {-0.18500000000000008`, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  9, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.09999999999999996, 0.45 < 
                    0.1 + 0.4 $CellContext`t}, {-0.09999999999999996 + 
                    0.24253562503633297` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) + 
                    0.9701425001453319 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {-0.09999999999999996, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  2, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
                   Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-0.06333333333333332, 0.1 < 
                    0.1 + 0.4 $CellContext`t}, {-0.06333333333333332 + 
                    0.6931087162517846 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {-0.06333333333333332, 
                    0.5 + 0.4 $CellContext`t <= 0.1}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  10, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. (0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{-3.8163916471489756`*^-17, 0.5 < 
                    0.1 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17 + 
                    1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {-3.8163916471489756`*^-17, 
                    0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  19, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
                   Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                   Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0])) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  0, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 1, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.06 + 
                   Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (0.1 + 
                   Piecewise[{{
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0])) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  20, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 1. < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 1.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  18, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.06 + 
                   Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.06333333333333312, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.06333333333333312 - 
                    0.6931087162517844 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) - 
                    0.720833064901856 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.06333333333333312, 0.5 + 0.4 $CellContext`t <= 0.9}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  11, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.09999999999999992, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.09999999999999992 - 
                    0.24253562503633322` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.9701425001453318 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.09999999999999992, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  17, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.18499999999999991`, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.18499999999999991` - 
                    0.7961621941231023 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) - 
                    0.6050832675335581 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.18499999999999991`, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  12, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.19166666666666685`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.19166666666666685` - 
                    0.5547001962252295 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8320502943378433 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.19166666666666685`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  13, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.24999999999999958`, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.24999999999999958` - 
                    0.8320502943378439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.5547001962252289 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.24999999999999958`, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  16, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.2499999999999996, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.2499999999999996 - 
                    0.8944271909999159 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) - 
                    0.4472135954999579 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2499999999999996, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  14, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.3 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] - 
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.2916666666666669, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2916666666666669 - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.16439898730535663` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2916666666666669, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  15, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 (1/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    0.06 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.3 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.5 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.3 (3/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] - 0.06 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.29166666666666724`, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.29166666666666724` - 
                    0.9863939238321439 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) - 
                    0.16439898730535732` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.29166666666666724`, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]), 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  10, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.5 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.5 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.4 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0. - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.5}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{0., 0.5 < 0.1 + 0.4 $CellContext`t}, {
                    0. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.4 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.4 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.5 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0., 0.5 + 0.4 $CellContext`t <= 0.5}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 9, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.45 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.45 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.35 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.04999999999999999 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.45}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.008333333333333328, 0.45 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333328 + 
                    0.9701425001453319 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)]) - 
                    0.24253562503633297` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.35 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.35 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.35 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.45 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333328, 0.5 + 0.4 $CellContext`t <= 0.45}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  11, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.55 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.55 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.45000000000000007` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.050000000000000044` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.55}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.008333333333333337, 0.55 < 0.1 + 0.4 $CellContext`t}, {
                    0.008333333333333337 + 
                    0.9701425001453318 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]) + 
                    0.24253562503633322` ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.45000000000000007` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.55 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.008333333333333337, 0.5 + 0.4 $CellContext`t <= 0.55}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  8, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.4 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.4 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.30000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.09999999999999998 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.4}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.049999999999999996`, 0.4 < 0.1 + 0.4 $CellContext`t}, {
                    0.049999999999999996` + 
                    0.8320502943378437 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]) - 
                    0.5547001962252291 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.30000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.4 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.049999999999999996`, 0.5 + 0.4 $CellContext`t <= 0.4}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  12, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.6000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.6000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.5000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.6000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.10000000000000009` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.6000000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.050000000000000086`, 0.6000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.050000000000000086` + 
                    0.8320502943378433 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]) + 
                    0.5547001962252295 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.5000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.6000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.050000000000000086`, 0.5 + 0.4 $CellContext`t <= 
                    0.6000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  13, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.65 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.65 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.55 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.15000000000000002` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.65}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.1083333333333332, 0.65 < 0.1 + 0.4 $CellContext`t}, {
                    0.1083333333333332 + 
                    0.5547001962252289 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)]) + 
                    0.8320502943378439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.55 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.55 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.55 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.65 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.1083333333333332, 0.5 + 0.4 $CellContext`t <= 0.65}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  7, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.35000000000000003` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.35000000000000003` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.25 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.35000000000000003` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.14999999999999997` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.35000000000000003`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    
                    Piecewise[{{
                    0.10833333333333342`, 0.35000000000000003` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.10833333333333342` + 
                    0.5547001962252291 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)]) - 
                    0.8320502943378435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.25 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.25 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.25 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.35000000000000003` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.10833333333333342`, 0.5 + 0.4 $CellContext`t <= 
                    0.35000000000000003`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  6, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.30000000000000004` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.30000000000000004` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.20000000000000004` - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.30000000000000004` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.19999999999999996` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.30000000000000004`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    
                    Piecewise[{{
                    0.2166666666666664, 0.30000000000000004` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.2166666666666664 + 
                    0.16439898730535776` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]) - 
                    0.9863939238321435 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.20000000000000004` - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.30000000000000004` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.2166666666666664, 0.5 + 0.4 $CellContext`t <= 
                    0.30000000000000004`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  14, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.7000000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.7000000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.6000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.7000000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.20000000000000007` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.7000000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.216666666666667, 0.7000000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.216666666666667 + 
                    0.16439898730535663` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.6000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.7000000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.216666666666667, 0.5 + 0.4 $CellContext`t <= 
                    0.7000000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  5, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.25 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.25 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.15 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.25 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.25}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.38333333333333314`, 0.25 < 0.1 + 0.4 $CellContext`t}, {
                    0.38333333333333314` - 
                    0.16439898730535726` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)]) - 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.15 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.15 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.15 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.25 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.38333333333333314`, 0.5 + 0.4 $CellContext`t <= 0.25}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  15, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.75 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.75 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.65 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.25 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.3833333333333341, 0.75 < 0.1 + 0.4 $CellContext`t}, {
                    0.3833333333333341 - 
                    0.16439898730535732` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)]) + 
                    0.9863939238321439 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.65 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.65 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.65 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.75 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.3833333333333341, 0.5 + 0.4 $CellContext`t <= 0.75}}, 
                    0], 1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  16, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.8 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7000000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.30000000000000004` - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.4999999999999994, 0.8 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999994 - 
                    0.4472135954999579 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]) + 
                    0.8944271909999159 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7000000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999994, 0.5 + 0.4 $CellContext`t <= 0.8}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  4, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(0.2 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.2 <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.3 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.2}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.4999999999999999, 0.2 < 0.1 + 0.4 $CellContext`t}, {
                    0.4999999999999999 - 
                    0.44721359549995787` (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)]) - 
                    0.8944271909999157 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.1 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.1 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.2 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.4999999999999999, 0.5 + 0.4 $CellContext`t <= 0.2}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  3, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.15000000000000002` (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.15000000000000002` <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.05000000000000002 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.15000000000000002` <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.35 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.15000000000000002`}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.8) (1 - 2 $CellContext`t) - 
                    0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 
                    0.4 $CellContext`t)] + ((-0.6) (1 - 2 $CellContext`t) - 
                    0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    
                    Piecewise[{{
                    0.6083333333333336, 0.15000000000000002` < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333336 - 
                    0.6050832675335577 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]) - 
                    0.7961621941231026 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.05000000000000002 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.15000000000000002` <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333336, 0.5 + 0.4 $CellContext`t <= 
                    0.15000000000000002`}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  17, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + (
                    0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(
                    0.8500000000000001 (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 0.8500000000000001 <= 
                    0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.7500000000000001 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 
                    0.8500000000000001 <= 0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((0.3500000000000001 - 0.4 $CellContext`t) (
                    0.17000000000000004` - 0.13 $CellContext`t))/(0.5 - 
                    0.4 $CellContext`t) + 0.13 $CellContext`t, 
                    0.5 + 0.4 $CellContext`t <= 0.8500000000000001}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.8) (
                    1 - 2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + ((-0.6) (
                    1 - 2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.6083333333333337, 0.8500000000000001 < 
                    0.1 + 0.4 $CellContext`t}, {
                    0.6083333333333337 - 
                    0.6050832675335581 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]) + 
                    0.7961621941231023 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.7500000000000001 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.8500000000000001 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.6083333333333337, 0.5 + 0.4 $CellContext`t <= 
                    0.8500000000000001}}, 0], 1/2 <= $CellContext`t <= 1}}, 
                    0]) + BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  18, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                   Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    1.7 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    Piecewise[{{
                    0.7416666666666654, 0.9 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666654 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)]) + 
                    0.6931087162517844 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.8 - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.8 - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0.8 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0.9 <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666654, 0.5 + 0.4 $CellContext`t <= 0.9}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  2, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) (-0.1 + 
                   Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0]) + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 (
                    0.2 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.3 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + 
                    0.1 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.1 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 1.7 $CellContext`t)
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.8) (1 - 
                    2 $CellContext`t) - 0.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] + ((-0.6) (1 - 
                    2 $CellContext`t) - 0.2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    0.7416666666666665, 0.1 < 0.1 + 0.4 $CellContext`t}, {
                    0.7416666666666665 - 
                    0.720833064901856 (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)]) - 
                    0.6931087162517846 ((0.1 (2 - 2 $CellContext`t) + 
                    0.6 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 2, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0. - 0.4 $CellContext`t)] + (-1 + 
                    0.15 (2 - 2 $CellContext`t) + 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.15 (2 - 2 $CellContext`t) + 0.8 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0. - 0.4 $CellContext`t)] + (
                    0.05 (2 - 2 $CellContext`t) + 0.6 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.05 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.15 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0. - 0.4 $CellContext`t)] - 
                    0.1 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 11, 
                    2.5 (0. - 0.4 $CellContext`t)]), 0.1 + 0.4 $CellContext`t <= 
                    0.1 <= 0.5 + 0.4 $CellContext`t}, {
                    0.7416666666666665, 0.5 + 0.4 $CellContext`t <= 0.1}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  0, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  1, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  19, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 0.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + 1.5 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + ((-1)/2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + (0.5 + 0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]] + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{0., 0. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (-0.1 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    0.83 + ((-0.5 - 0.4 $CellContext`t) (0.17000000000000004` - 
                    0.13 $CellContext`t))/(0.5 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.5 + 0.4 $CellContext`t <= 0.}}, 
                    0]], 1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. ((0.05 (1 - 2 $CellContext`t) + 
                    0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{1., 0. < 0.1 + 0.4 $CellContext`t}, {
                    1. + 1. (
                    0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (-0.1 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (-0.1 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 0. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 0.}}, 0], 
                    1/2 <= $CellContext`t <= 1}}, 0]) + 
               BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                  20, $CellContext`s] ((-1 + 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (
                    1/2 - $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, 
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 (1/2 - $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                    0 <= $CellContext`t <= 1/2}, {
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    0.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    1.5 BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + ((-1)/
                    2 + $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + (0.5 + 
                    0.5 ((-1)/2 + $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]] + 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, 
                    
                    Piecewise[{{(1. (0.04 + 0.13 $CellContext`t))/(0.1 + 
                    0.4 $CellContext`t), 1. <= 0.1 + 0.4 $CellContext`t}, {
                    0.04 + 1.975 (0.9 - 0.4 $CellContext`t) + 
                    0.13 $CellContext`t, 0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1., 0.5 + 0.4 $CellContext`t <= 1.}}, 0]], 
                    1/2 <= $CellContext`t <= 1}}, 0] + (2 - 
                   2 (3/4 - Cos[2 Pi ((-1)/2 + $CellContext`z)]/4)) 
                  Piecewise[{{
                    
                    Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. ((0.05 (1 - 2 $CellContext`t) + 0.65 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.1 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.15 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.2 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.97 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 2.6 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (1 - 2 $CellContext`t) + 1.3 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + 
                    0.65 $CellContext`t 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                     0 <= $CellContext`t <= 1/2}, {
                    
                    Piecewise[{{
                    1.0000000000000027`, 1. < 0.1 + 0.4 $CellContext`t}, {
                    1.0000000000000027` + 
                    1. (0.325 (2 - 2 $CellContext`t) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 3, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 4, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 1.3 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 5, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.97 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 6, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.2 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 7, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    1.3 (2 - 2 $CellContext`t) + 0.15 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 8, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.65 (2 - 2 $CellContext`t) + 0.1 (-1 + 2 $CellContext`t))
                     BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 9, 
                    2.5 (0.9 - 0.4 $CellContext`t)] + (
                    0.325 (2 - 2 $CellContext`t) + 
                    0.05 (-1 + 2 $CellContext`t)) 
                    BSplineBasis[{
                    3, {0, 0, 0, 0, 1/11, 2/11, 3/11, 4/11, 5/11, 6/11, 7/11, 
                    8/11, 9/11, 10/11, 1, 1, 1, 1}}, 10, 
                    2.5 (0.9 - 0.4 $CellContext`t)]), 
                    0.1 + 0.4 $CellContext`t <= 1. <= 
                    0.5 + 0.4 $CellContext`t}, {
                    1.0000000000000027`, 0.5 + 0.4 $CellContext`t <= 1.}}, 0],
                     1/2 <= $CellContext`t <= 1}}, 0])}, 
              1/2 <= $CellContext`z <= 1}}, 0], 0 <= $CellContext`t <= 1}, {
           Piecewise[{{
              
              Piecewise[{{{
                 0. + 0.1 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] - 
                  0.06333333333333332 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] - 
                  0.18500000000000008` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] - 
                  0.24999999999999997` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] - 
                  0.29166666666666646` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] - 
                  0.29166666666666646` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] - 
                  0.2500000000000003 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] - 
                  0.19166666666666668` 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] - 
                  0.09999999999999996 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] - 
                  3.8163916471489756`*^-17 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 10, $CellContext`s] + 
                  0.17173762078750698` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] + 
                  0.1684521627295703 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] + 
                  0.06333333333333312 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] - 
                  0.1 BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] (
                    0.29163455748945916` - 
                    0.9863939238321439 (0.1561686197916668 + 
                    0.00032552083333333245` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] (
                    0.7272135480269026 - 
                    0.24253562503633322` (0. + 
                    0.008789062500000085 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] (
                    0.3416713586387127 - 
                    0.9863939238321439 (0.09895833333333369 + 
                    0.47916666666666485` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))) + 
                    0.020833333333332975` (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] (
                    0.9587130317593663 - 
                    0.5547001962252295 (0. + 
                    0.6822916666666683 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] (
                    0.6798204254865017 - 
                    0.8320502943378439 (0.00006510416666666745 + 
                    0.23600260416666702` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))) + 
                    0.7636718749999993 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))), 
                  0. + 1. 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 0, $CellContext`s] + 
                  1. BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 1, $CellContext`s] + 
                  0.7416666666666665 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 2, $CellContext`s] + 
                  0.6083333333333336 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 3, $CellContext`s] + 
                  0.4999999999999999 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 4, $CellContext`s] + 
                  0.38333333333333314` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 5, $CellContext`s] + 
                  0.2166666666666664 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 6, $CellContext`s] + 
                  0.10833333333333342` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 7, $CellContext`s] + 
                  0.049999999999999996` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 8, $CellContext`s] + 
                  0.008333333333333328 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 9, $CellContext`s] + 
                  0.46086881039375305` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 16, $CellContext`s] + 
                  0.5957569770078072 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 17, $CellContext`s] + 
                  0.7416666666666654 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 18, $CellContext`s] + 
                  1. 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 19, $CellContext`s] + 
                  1.0000000000000027` 
                   BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 20, $CellContext`s] + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 15, $CellContext`s] (
                    0.38352598839658253` - 
                    0.16439898730535732` (0.1561686197916668 + 
                    0.00032552083333333245` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 11, $CellContext`s] (
                    0.1651367203400592 + 
                    0.9701425001453318 (0. + 
                    0.008789062500000085 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 14, $CellContext`s] (
                    0.5166948184989428 + 
                    0.16439898730535663` (0.09895833333333369 + 
                    0.47916666666666485` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))) + 
                    0.020833333333332975` (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 12, $CellContext`s] (
                    0.5613642433951336 + 
                    0.8320502943378433 (0. + 
                    0.6822916666666683 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 0.05555555555555555, 0.1111111111111111, 
                    0.16666666666666666`, 0.2222222222222222, 
                    0.2777777777777778, 0.3333333333333333, 
                    0.38888888888888884`, 0.4444444444444444, 0.5, 
                    0.5555555555555556, 0.611111111111111, 0.6666666666666666,
                     0.7222222222222222, 0.7777777777777777, 
                    0.8333333333333333, 0.8888888888888888, 
                    0.9444444444444444, 1, 1, 1, 1}}, 13, $CellContext`s] (
                    0.7530639715630867 + 
                    0.5547001962252289 (0.00006510416666666745 + 
                    0.23600260416666702` (0. + 
                    0.2 (1.7 + 
                    6.3 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4))) + 
                    0.7636718749999993 (0. + 
                    0.2 (2 + 9 (1/4 - 
                    Cos[2 Pi (-1 + $CellContext`t + $CellContext`z)]/4)))))}, 
                 0 <= -1 + $CellContext`t + $CellContext`z <= 1/2}, {{
                 0. + BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] (
                    0.1372793208147884 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.24999758828124946` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] (
                    0.17173762078750698` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.24364869791666693` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    14, $CellContext`s] ((-0.2411230513587771) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.16215322500000043` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] (
                    0.1684521627295703 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.10688348979166601` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    19, $CellContext`s] ((-0.1) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] (
                    0.06333333333333312 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) - 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    3, $CellContext`s] ((-0.18500000000000008`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.05996691792 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    2, $CellContext`s] ((-0.06333333333333332) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] (
                    0.1 (2 - 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.06 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    4, $CellContext`s] ((-0.24999999999999997`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.06044957696 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    5, $CellContext`s] ((-0.29166666666666646`) (2 - 
                    2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.06595507999999999 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    6, $CellContext`s] ((-0.29166666666666646`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.08337108224000003 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    7, $CellContext`s] ((-0.2500000000000003) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.11932605989333342` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    8, $CellContext`s] ((-0.19166666666666668`) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.17364842837333339` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    13, $CellContext`s] ((-0.3367462305107352) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.18002498242187487` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    9, $CellContext`s] ((-0.09999999999999996) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.23869773701333347` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 
                    10, $CellContext`s] ((-3.8163916471489756`*^-17) (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.3064555733333334 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] (
                    0.4667055139616745 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.4922463875000001 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] (
                    0.7244423890299054 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.4998569661458335 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))), 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, $CellContext`s] (0. + 
                    0.00001800000000000035 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, $CellContext`s] (
                    0.008333333333333328 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.0018608669999999863` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, $CellContext`s] (
                    0.049999999999999996` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.02102457599999996 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, $CellContext`s] (
                    0.10833333333333342` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.07895358899999985 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] (
                    0.2166666666666664 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.19575894799999977` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] (
                    0.38333333333333314` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.36462068749999976` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] (
                    0.17622135632804795` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.4191075846354178 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] (
                    0.5957569770078072 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.5052868496093741 (-1 + 
                    2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] (
                    0.4999999999999999 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.5541993919999999 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] (
                    0.46086881039375305` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.5846282552083336 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] (
                    0.6083333333333336 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.7323297894999998 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] (
                    0.7416666666666654 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.9 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] (
                    0.7416666666666665 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    0.9 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, $CellContext`s] (
                    1. (2 - 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1. (-1 + 2 (3/4 - 
                    Cos[2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, $CellContext`s] (
                    1.0000000000000027` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1.0000000000000016` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] (
                    0.3578001156174707 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1.061680610026039 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] (
                    1.2993755200916703` (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1.288115968750002 (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {
                    0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                    2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 14, $CellContext`s] (
                    0.6138272201651906 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1.4995905833333345` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4))) + 
                  BSplineBasis[{
                    3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9,
                     1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] (
                    1.430775075561244 (2 - 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)) + 
                    1.5000000000000013` (-1 + 
                    2 (3/4 - Cos[
                    2 Pi ((-3)/2 + $CellContext`t + $CellContext`z)]/4)))}, 
                 1/2 <= -1 + $CellContext`t + $CellContext`z <= 1}}, 0], 
              0 <= $CellContext`z <= 2 - $CellContext`t}, {{
              0. + 0.06 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] + 
               0.06 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] + 
               0.05996691792 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] + 
               0.06044957696 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] + 
               0.06595507999999999 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] + 
               0.08337108224000003 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] + 
               0.11932605989333342` 
                BSplineBasis[{
                  3, {
                   0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/2,
                     5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                    1}}, 7, $CellContext`s] + 
               0.17364842837333339` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, $CellContext`s] + 
               0.23869773701333347` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, $CellContext`s] + 
               0.3064555733333334 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, $CellContext`s] + 
               0.4998569661458335 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] + 
               0.4922463875000001 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] + 
               0.18002498242187487` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] - 0.16215322500000043` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 14, $CellContext`s] - 0.24999758828124946` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 15, $CellContext`s] - 0.24364869791666693` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 16, $CellContext`s] - 0.10688348979166601` 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 17, $CellContext`s] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 18, $CellContext`s] - 0.06 
               BSplineBasis[{
                 3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 1/
                   2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 1, 
                   1}}, 19, $CellContext`s], 
               1. BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 0, $CellContext`s] + 
               1. BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 1, $CellContext`s] + 
               0.9 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 2, $CellContext`s] + 
               0.7323297894999998 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 3, $CellContext`s] + 
               0.5541993919999999 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 4, $CellContext`s] + 
               0.36462068749999976` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 5, $CellContext`s] + 
               0.19575894799999977` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 6, $CellContext`s] + 
               0.07895358899999985 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 7, $CellContext`s] + 
               0.02102457599999996 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 8, $CellContext`s] + 
               0.0018608669999999863` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 9, $CellContext`s] + 
               0.00001800000000000035 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 10, $CellContext`s] + 
               0.4191075846354178 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 11, $CellContext`s] + 
               1.288115968750002 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 12, $CellContext`s] + 
               1.5000000000000013` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 13, $CellContext`s] + 
               1.4995905833333345` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 14, $CellContext`s] + 
               1.061680610026039 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 15, $CellContext`s] + 
               0.5846282552083336 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 16, $CellContext`s] + 
               0.5052868496093741 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 17, $CellContext`s] + 
               0.9 BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 18, $CellContext`s] + 
               1. 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 19, $CellContext`s] + 
               1.0000000000000016` 
                BSplineBasis[{
                  3, {0, 0, 0, 0, 1/18, 1/9, 1/6, 2/9, 5/18, 1/3, 7/18, 4/9, 
                    1/2, 5/9, 11/18, 2/3, 13/18, 7/9, 5/6, 8/9, 17/18, 1, 1, 
                    1, 1}}, 20, $CellContext`s]}, 
              2 - $CellContext`t <= $CellContext`z <= 1}}, 0], 
           1 <= $CellContext`t <= 2}}, 0]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.822261288544629*^9, 3.822263231726118*^9, 
  3.822265301329899*^9},
 CellLabel->"Out[51]=",ExpressionUUID->"6a6387a8-50b7-4e43-835a-d4eecf255da9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
4.2 Sketch immersed cylinders for t = -1, -1/2, 0, 1/2, 1, 3/2 and 2\
\>", "Subsection",
 CellChangeTimes->{{3.822260636507867*^9, 
  3.822260656754446*^9}},ExpressionUUID->"57197f72-f6bf-4bc6-a7f5-\
5dc4e9f55050"],

Cell[TextData[StyleBox["Define colors. To distinguish the upper and lower \
cylinders, we use Light Purple and Purple. Then we plot these cylinders in a \
row.",
 FontColor->GrayLevel[0.5]]], "Text",
 CellChangeTimes->{
  3.822260666514526*^9},ExpressionUUID->"3d4de0e5-ff3e-4550-af61-\
31d56ed5a1ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MammothPurple", "=", 
  RowBox[{"RGBColor", "[", 
   RowBox[{
    RowBox[{"63", "/", "255"}], ",", 
    RowBox[{"31", "/", "255"}], ",", 
    RowBox[{"105", "/", "255"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.822260678787624*^9},
 CellLabel->"In[52]:=",ExpressionUUID->"1183e96a-4558-424d-9ac7-7bcc6138881e"],

Cell[BoxData[
 InterpretationBox[
  ButtonBox[
   TooltipBox[
    GraphicsBox[{
      {GrayLevel[0], RectangleBox[{0, 0}]}, 
      {GrayLevel[0], RectangleBox[{1, -1}]}, 
      {RGBColor[
        Rational[21, 85], 
        Rational[31, 255], 
        Rational[7, 17]], RectangleBox[{0, -1}, {2, 1}]}},
     AspectRatio->1,
     DefaultBaseStyle->"ColorSwatchGraphics",
     Frame->True,
     FrameStyle->RGBColor[
      0.16470588235294117`, 0.08104575163398693, 0.27450980392156865`],
     FrameTicks->None,
     ImageSize->
      Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
        AbsoluteCurrentValue[Magnification]}],
     PlotRangePadding->None],
    StyleBox[
     RowBox[{"RGBColor", "[", 
       RowBox[{
         FractionBox["21", "85"], ",", 
         FractionBox["31", "255"], ",", 
         FractionBox["7", "17"]}], "]"}], NumberMarks -> False]],
   Appearance->None,
   BaseStyle->{},
   BaselinePosition->Baseline,
   ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
     If[
      Not[
       AbsoluteCurrentValue["Deployed"]], 
      SelectionMove[Typeset`box$, All, Expression]; 
      FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
      FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
         Rational[21, 85], 
         Rational[31, 255], 
         Rational[7, 17]]; FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
      MathLink`CallFrontEnd[
        FrontEnd`AttachCell[Typeset`box$, 
         FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
         Left, Top}, 
         "ClosingActions" -> {
          "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
   DefaultBaseStyle->{},
   Evaluator->Automatic,
   Method->"Preemptive"],
  RGBColor[
   Rational[21, 85], 
   Rational[31, 255], 
   Rational[7, 17]],
  Editable->False,
  Selectable->False]], "Output",
 CellChangeTimes->{3.8222612906383667`*^9, 3.822263234235549*^9, 
  3.82226545278292*^9},
 CellLabel->"Out[52]=",ExpressionUUID->"36ae4bcf-731c-4b23-8141-75e3047ed69e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MammothPurpleLight", "=", 
  RowBox[{"RGBColor", "[", 
   RowBox[{
    RowBox[{"133", "/", "255"}], ",", 
    RowBox[{"108", "/", "255"}], ",", 
    RowBox[{"176", "/", "255"}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.822260679443174*^9},
 CellLabel->"In[53]:=",ExpressionUUID->"d26d407d-0471-4f0e-b721-3942ed98c9f6"],

Cell[BoxData[
 InterpretationBox[
  ButtonBox[
   TooltipBox[
    GraphicsBox[{
      {GrayLevel[0], RectangleBox[{0, 0}]}, 
      {GrayLevel[0], RectangleBox[{1, -1}]}, 
      {RGBColor[
        Rational[133, 255], 
        Rational[36, 85], 
        Rational[176, 255]], RectangleBox[{0, -1}, {2, 1}]}},
     AspectRatio->1,
     DefaultBaseStyle->"ColorSwatchGraphics",
     Frame->True,
     FrameStyle->RGBColor[
      0.3477124183006536, 0.2823529411764706, 0.46013071895424834`],
     FrameTicks->None,
     ImageSize->
      Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
        AbsoluteCurrentValue[Magnification]}],
     PlotRangePadding->None],
    StyleBox[
     RowBox[{"RGBColor", "[", 
       RowBox[{
         FractionBox["133", "255"], ",", 
         FractionBox["36", "85"], ",", 
         FractionBox["176", "255"]}], "]"}], NumberMarks -> False]],
   Appearance->None,
   BaseStyle->{},
   BaselinePosition->Baseline,
   ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
     If[
      Not[
       AbsoluteCurrentValue["Deployed"]], 
      SelectionMove[Typeset`box$, All, Expression]; 
      FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
      FrontEnd`Private`$ColorSelectorInitialColor = RGBColor[
         Rational[133, 255], 
         Rational[36, 85], 
         Rational[176, 255]]; 
      FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
      MathLink`CallFrontEnd[
        FrontEnd`AttachCell[Typeset`box$, 
         FrontEndResource["RGBColorValueSelector"], {0, {Left, Bottom}}, {
         Left, Top}, 
         "ClosingActions" -> {
          "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
   DefaultBaseStyle->{},
   Evaluator->Automatic,
   Method->"Preemptive"],
  RGBColor[
   Rational[133, 255], 
   Rational[36, 85], 
   Rational[176, 255]],
  Editable->False,
  Selectable->False]], "Output",
 CellChangeTimes->{3.8222612906479673`*^9, 3.822263234245072*^9, 
  3.82226545292933*^9},
 CellLabel->"Out[53]=",ExpressionUUID->"4df6ecfd-c086-43a8-9c78-639016331515"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsRow", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Table", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Show", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"H", "[", 
            RowBox[{"s", ",", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"0.5", "j"}]}], ",", "z"}], "]"}], ",", "z"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", 
           RowBox[{"1", "/", "2"}]}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"FaceForm", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.6", "]"}], ",", "MammothPurple"}], 
             "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Opacity", "[", "1", "]"}], ",", "White"}], "}"}]}], 
           "]"}]}], ",", 
         RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
         RowBox[{"Axes", "\[Rule]", "None"}], ",", 
         RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
         RowBox[{"PlotTheme", "\[Rule]", "\"\<Business\>\""}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "30"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"H", "[", 
            RowBox[{"s", ",", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"0.5", "j"}]}], ",", "z"}], "]"}], ",", "z"}], "]"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "/", "2"}], ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"FaceForm", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Opacity", "[", "0.6", "]"}], ",", 
              "MammothPurpleLight"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"Opacity", "[", "1", "]"}], ",", "White"}], "}"}]}], 
           "]"}]}], ",", 
         RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
         RowBox[{"Axes", "\[Rule]", "None"}], ",", 
         RowBox[{"Mesh", "\[Rule]", "None"}], ",", 
         RowBox[{"PlotTheme", "\[Rule]", "\"\<Business\>\""}], ",", 
         RowBox[{"PlotPoints", "\[Rule]", "30"}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ParametricPlot3D", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"H", "[", 
              RowBox[{"s", ",", 
               RowBox[{
                RowBox[{"-", "1"}], "+", 
                RowBox[{"0.5", "j"}]}], ",", 
               RowBox[{"0.1", "i"}]}], "]"}], ",", 
             RowBox[{"0.1", "i"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "10"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{"Black", ",", 
            RowBox[{"Thickness", "[", "0.005", "]"}]}], "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "0", ",", "6"}], "}"}]}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.822260688541431*^9, 3.822260716229587*^9}, {
  3.822264613482575*^9, 3.822264613548333*^9}},
 CellLabel->"In[54]:=",ExpressionUUID->"b5d62608-21de-4724-b1be-e7c0c8153636"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx1nXuUl2W5v9EtiWcndKeYVmB5gJ2KombCNxUxS0XRhNKd4fmYgmS7gNrK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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQe0FEXThm8A7u6d3ZkNJkARUAEDCpg/A4qKoqKioKKiohhJgpgwAWbM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               "]],
              Annotation[#, "Charting`Private`Tag$5333#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUVWUaxkG8oSQX0wFSwQwVmtERY3QVtlPHSlMLxUBlwkhEUqMBExmF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          "]], {}}, {GraphicsComplex3DBox[CompressedData["
1:eJx13Xm0n2V97/1IHaLggOhTjXWoUFCIA4iiHuIuivFxDI5wFI9GUIxDKXGq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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQe0FEXThm8A7u6d3ZkNJkARUAEDCpg/A4qKoqKioKKiohhJgpgwAWbM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               "]],
              Annotation[#, "Charting`Private`Tag$5374#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUVWUaxkG8oSQX0wFSwQwVmtERY3QVtlPHSlMLxUBlwkhEUqMBExmF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          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23c019//APDMZEUUISOjUslK0kdXEjJCg5IykhJlU5KoiNIQ2ZS93/YK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            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDUosbSFiPJI4pBVqp80djSMTarJJG+yVg3Srpi1RA/R
C2sxGmGMHhrDmphGLsZbjMgrMZ4RGY1H1Amrf+7t7D3n/vM595zf/X2/3/u9
V8uTetxntZSUFHllSq9M46smyyMg6JDd8rcxhaWlfhs8TFJBumdqQscs9rEc
Fd8gjz/dfjA7mYUtqMxETv2KXIrdrHYmNA+TH0qJCs4QQ09Sji7aWpGPaaQs
GvdFT0I/UOIrJgxyMOLwPh+22QfoG+Ke3cz8UoAFaktbv2eOQ9dQ51bTg//F
aC1jPOuPY9B1qh/iKO5cbGH6xNZSo1HoWlOjAZUKJRhHzrQk8OwI9Jt/Vskt
BfCx8EgF/uuGIegsGVmaz2GA2WvZjLrkD0LPeIcP8hNVYBruAxSXtcgLYyUt
V65XYfIljre9ugeg23cS3Xfsq8XmZB7bhpmg9Y41KrXN3HpM44RTAk4Wfbdt
dgv3RncjRgtZH0E8NQy9i3VVp9qtCdNobPLXX0D7N4y2lsH5NmN/OxTpiCTo
f207d3tv/NyMlYlG1IY9UdwYG1nnzNYIMXdcHsMVh+KfKyEmbmE0Y2K+VcrT
LJTHh395FzoLmzBDY4HxTk0J9LS6tM3L6S8xWo2D8pDHNHRRi0XVp/EGTG6x
dA0laQbl/ez8fmmvOkxulYZuSPUsqh9C2ODMchVG1rpWZCScg15c63qnVFKO
nfLUeNuU+gn6hK+MILWrGHsk3hWkZDwPXS7uTFfYdA4We80fl/kP8uJI77e8
yjigPKw6z6lFvnYhMtGXXQga3C5YmnznHf0TxIvmFWCbHSOedR95k3aF3N2k
OiBOsWqwJX+3XktkIVsjBEmOqQ2kabTPk8s3OdJJbYDEo448ISO/eix9dEzc
Abr4dsrtUeh/Bx9NxgXndoOj9wmruZdRfHbqV08n9vcAw1Tc7Xo9FM+jBa28
zQ96wQ78RHi5B8pLtCRpgMTpA5jAC9zJQufOxMRptkBNBPqc3zxOwaN6CFsX
b39ovg+cX7d0sec1qiuZiOLxKUofYOn+RPPpRPXMIn8McnbqBV1HAsT1Hm+h
K5QeiqG29gCmfKWH++/t0AOdf5CxV3gDHA3OR6vrCaEriqjJnnc6ACN7adWo
zQvoemUzc6++vgYxjyN0lo0KoT/x4xUmZLWBujhKDj+bCf1Ir3ojzrcViN9f
y21LSoS+Gz8nSHB+BbL8WyeD1SKhk/D5l0wjWsDCWJCaUzMVOp9qXtntv5LH
XIZ/aC/yOZ9jXVZ1TWAXKb1KJBUKPVtUzQw3eAlytLnKmQ+ioGtraZbuTmsA
zprTuoSBG9ClT8oKohTrQYhhyGf8pnvQ3VIJOpd/qQFiC5IXczQd+pZ7Hi6S
aAFYtBIqqeXnQrd4oh20VbsCZGq6WFJLCqCLNVuu39UqA0xCYnaNEQ/6HqGK
fBbhOWhrdJnQeViB9v/1QrmDfTHoI9KebXSohV774yahE78ImJkvmXE9mqEf
tkyI9BsvBJQBc59VA63QY1UjrtDSCoDX5JR2u6ADuu+HmUobBge4CmozTxv1
QDc7GfFljSwHbK8nv/vkLYI+rLg9mZiRD/bkmPK0O/uh07mq7BxSPqAv1j8o
+ozqUL6lbR1ROR+QVeIIpUqof6bqhm90nWQDO33eZZoB6p96TuuHDTrY4Er0
Nmv6LlTnda+UbjnUsYGnqpHyvP47dK6XZGI2lbMBbcbvVuF+1FdDLx1h2vDZ
4I/n274etEX3Tgj1KZ5ZwgYvX7j9XG71HvrC+EEZj2I26Oeo7B3ai87dxIxQ
XWnF8xplY+nbJ1BerlsmO6x4W2JXRjAO3YPx1X30eS4bfBkkm+yXRn1b6bjt
fOQBNqiKyWaIp5AH5hrpPnLMA5Q0ihedi/qAYMAneoM4F4QRvTfzyajPn4t7
FpvDvQ9+CxA6zbYiZ2fjv70Hyrz+9x74D/WkcjY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKpBiaUtRKM8kjhkleonjR0NY5NqMsmbrFWDtCtmLdFD
9MJar0YY9NAY1sQ0cjHeYkReifGMyGg8ok5Y/XNvZ+8595/Puef87v1+v/d7
f5ru9ONeq6WkpKgrU3plGl41Wh4BAYdslr+NKSwl+duoxyQVlHvGRqmY2b4c
e4U3yGNPtx/MSszBFpRnwqd+RS7FblY9E5yHyQ0lRQSmi6EnKEUWba3Ix9ST
Fg37IiehHyjxFpMGORh5eJ8X2+QD9A0xz25mfCnA/AnSlu9Z49DV1bjVqYH/
YoyWMZ7lxzHoWtUP8TRXLrYwfWJrqcEodM2pUb9K+RKMI2tc4n92BPrNP6tk
l/z4WGi4PP91wxD0HJwMw+swwGw1rUad8gehp78jBviIKjB11wGa01rkhdGS
livXqzC5EvvbHt0D0G07ya479tVic7jH1iFGaL19jXJtM3flHCcc4vAy6Ltt
s1u4N7obMUbQ+jDyqWHoXTlXtapdmjD1xiZf3QW0f/1ISxzeuxn7265ISyRB
57Xu3O258XMzViYaUR12R3Fjbsw5Z7JGiLni85jOeBT/XAk5fguzGRPzLZKe
ZqI8PvzLs9BR2ITpGwoMd2pIoKfUpWxeTnuJMWrslIbcpqGLWsyqPo03YLKL
pWtoCTMo72fn90t71GGyq9S1g6pnUf2QQgZnlqswqua1IgPhHPTiWuc7pZJy
7JS7+tum5E/QJ7xxguSuYuyReFeAouE8dNmYM10h09lY9DVffMY/yIvDPd/y
KmOA0rDKPKcW+dqF8HhvdiFocLlgbvSdd/RPkC+aVoBtNszYnPvImwgVsncT
6oA4yaLBmvrdek2RmUyNECTYJzdQptE+Ty7f5EgntAEKjz7yhIr86rG00TFx
B+ji2yi1R6DzDj6ajAnM7QZH75NWcy+j+OzUrZ6O7+8B+sn42/U6KJ5HC1p5
mx/0gh3EidByN5SXSEnCAIXTBzCBB7iTie6dkZHDbIGqCPQ5vnmcRET1ELIu
1vbQfB84v27pYs9rVFe4sOLxKVofyNH+ieHVieo5h/oxwNGhF3Qd8RPXu72F
Ll96KIre2gNYcpVurr+3Q/d3/AFnK/8G2Oudj1TTEUJXENET3e90AGbW0qpR
qxfQdcpm5l59fQ2iHodpLRsUQn/iwyuMy2wDdTG0bH4WC/qRXrVGvHcrEL+/
ltuWEA99N3FOEOf4CmT6tk4GqoZDpxDzLxmHtYCFsQBVh2Y6dD7dtLLbdyWP
uUzf4F7kc17HuizqmsAuSlqVSCoYepaomhWq9xJkE7hKGQ8ioBM0NUp3pzQA
R41pbdLADejSJ2UEEQr1IEg/6DNx0z3oLskkrcu/1ACxGcWDNZoGfcs9NydJ
pAAsWggVVfNzoZs9IQRsJVSADA0nc3pJAXSxRsv1u5plgEWKz6ox4EHfI1SW
yyQ9B22NThNaDyvQ/r9eKLezLQZ9ZMazjXa10Gt/3CR04BcBE9MlE65bM/TD
5nHhPuOFgDZg6rVqoBV6tErYFUZKAfCYnCK0Czqge3+YqbRicoCzoDbjtEEP
dJOTYV/WyHDA9nrqu0+eIujDCtsTyen5YE+2MY/Q2Q89lavCzqbkg9TF+gdF
n1EdyrW0rSMr5QOqcgypVBH1z2Tt0I3Ok2xgo8u7zNBD/VPHYf2wXgcbXInc
Zpm6C9V53SvFW3Z1bOCuYqA0r/sO3eslXNSmcjZgzPjcKtyP+mrwpSMsKz4b
/PF829eD1ujdCaI/JbJK2ODlC5efyy3eQ18YP4hzK2aDfo7y3qG96N5NzAjV
FFc8r1EmOnX7BMrLdfNEuxVvi+9KD8SjdzC2ui91nssGXwapRvulUd9WPG49
H36ADaqispjiKeT+uQbaj+zzAC2F5pHKRX1AMOAVuUGcC0LInpv5VNTnz8U8
i87m3ge/+QkdZluRs7OI3/4Hyjz+9z/wH+1Od6Y=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDUosbSFiPJI4pBVqiuxo2FsUk0kb7JWDdKumLVED9EL
azEaeY0eGsOa0MjFeIuRySsxnhEZeUWdsPrn3s7ec+4/n3PP+d3f9/u933vV
3KnHvVaLiYlRVqb4ytS/arA8DAMOWS9/G5PAyPDbEICpCvI9QwM6MNnHtJN9
gz32dNvBzEQmWFCYCZ/8FbsYq1npTHAukB5MighMEyFPkI8s3FqRB1SSFvV7
IyeQHyj2FhEH2IA0tM+LZfQB+YaYZzfTv+QDf3Vx8/dZY8hVlDnV9MB/Aa1l
tMT84yhyjeqHBEdXDliYPrG1VG8EudrkiF+lTDFgSxkW+58dRn7zzyqpJT8u
CA2X4b5uGETOlJCkeR2GwEbNcsQpbwB52juLAB9hBVBx7Xd0Wou9IHqq5cr1
KiBdbHfbo6sfuU0HyXXHvlowJ/HYKsQAr7erUaht5tQDlRP2cQRJ/F3B7BbO
ja5GQAtaH0Y6NYS8k3lVo9qlCag0NvlqL+D960aaSxC8m8HftoUawin8v1Yd
uz03fm4GZcJhpSF3HDfGRuY5ozV84ErIZTgTcPxzpkjxWxjNQMQ1S3qagfP4
8C/PAgd+E9DV5+nvVJ1CnlKXsnk59SWg1djKD7pNIxe2mFR9GmsAUoulaxwT
ZnDez87vF/eoA1KrVDSDqmdx/RBDBmaWqwBF7VqhHn8OeVGt853SqXJwyl3l
bVPyJ+Tj3hK85M4i8Ei0K0BOfx65VMyZzpDpbBB9zZeQ/g/2onDPtyWVMVB+
SHGeXYt97UJ4vDerADa4XDA1+M7b+8ZJF40r4DZrRizzPvYm9Qqpuwl1UJRk
1mBF+W69mtBEsoYPE+ySG8jTeJ8nl2+yxRMEkFxCHX5CwX71WOrIqKgddnKt
5dsi8P8OPJqICczpgkfvE1dzLuP47NSuno7v64a6yYTb9Vo4nkfzW0s2P+iB
OyzGQ8vdcF4ipxL6yexeCHge8E4GPncGBvaz+UpC2Ovw5nGSBa6HkHWxNofm
e+H5dUsXu1/jupIIKxqbdOyFTM2faF4duJ6ZlI8BDvY9sPOIn6je7S1ymdJD
UdTWbpglXenm+nsbcn+HHyRsZN5AO53zkcpafOSyQmqi+512yMhcWjVi+QK5
VtnM3Kuvr2HU4zCNZb0C5E98SgriMgSwLsYxm5uZhfxIj3IjwbsVit5fyxEk
xCPfbTHHi3N4BTN8WycClcKRky3yLhmGtcCF0QAl+2Yqci7VuLLLdyWPOQzf
4B7sc17HOs3qmuAucmqVUCwYeaawOitU5yXMVufIpz+IQK6uplq6O6UBOqhO
axL7byAXPynJi5Cth0G6QZ8tNt1D7pJM1Lj8Sw0UmZA9skZSkW+55+Y0FcmD
i2Z8OaW8HOQmT9QDtqpXwHRVJ1NqcT5ykWrL9btqZTCLGJ9Zo1eCfA9fQTqD
+BwKGp3GNR5W4P1/vVBua1MEe0m0Zxtta5HX/riJb88thEbGS0Yct2bkh03j
wn3GCqBjv7HXqv5W5NGKYVdoKfnQY2JSvY3Xjtz7w0ylJYMNnXm16af1upEb
nQz7skaSDbfXU9598hQiH5LdnkhKy4N7sg1L1Dv6kNM5iqxsch6kL9Y/KPyM
61C6RbCOJJ8HKQoxxFI53D+TNUM3Ok+woLV2yWWaDu6fWvbrh3TaWfBK5DZz
+i5c53Wv5G7Z1rGgu6Ke/Lz2O3yulySiNpWzIG3G51bBftxXgy8dybLksuAf
z7d9PWiF750g6lOLrGIWfPnC5edys/fIF8YOSrgVsWAfW2Hv4F587sZn+Mpy
K57bKBlN3z6O83LdNNF2xQXxnWmBBHwPxlb30uc5LPhlgGKwXxz3bbnjVvPh
B1iwKiqTIZrE7p+jp/nILhc6pjh60Dm4D/D6vSI3iHJgCMlzM5eC+/y5mGfR
2Zz78Dc/vv1sK3ZWpsW390CZx//eA/8Bju2rAQ==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKpBiaUtRKM8kjhkleonjR0NY5NqMsmbrFWDtCtmLdFD
9MJajEZeo4fGsCY0cjHeYkReifGMyGg8ok5Y/XNvZ+8595/Puef87u/7/d7v
vZru9ONeq6WkpKgrU3plGl41Wh4BAYdslr+NKSwl+dvoxiQVlHvGRkzMbB/b
XuEN8tjT7QczE9nYgvJM+NSvyKU4zapngnMxuaGkiMA0MfQEpcjCrRV5mHrS
omFf5CT0A8XeYtIgFyMP7/PimHyAviHm2c30L/mYP0Ha8n3WOHR1NV41M/Bf
jNEyVmL5cQy6VvVDPM2Vhy1Mn9haajAKXXNq1K9SvhjjyhoX+58dgX7zzyrZ
JT8+Fhouz3/dMASdjZNheB0GmK2m1ahT3iD0tHfEAB9RBabuOkBzWou8IFrS
cuV6FSZXbH/bo3sAum0n2XXHvlpsDvfYOsQIrbevUa5t5tVj6icc4vAy6Ltt
s1t4N7obMUbQ+jDyqWHoXeyrWtUuTZh6Y5Ov7gLav36kJQ7v3Yz9bVeoJZKg
/7Xu3O258XMzViYaUR12R3FjbWSfM1kjxFzxuSxnPIp/joQcv4XVjIn5FklP
M1AeH/7lWeAobML0DQWGOzUk0FPqUjYvp77EGDV2SkNu09BFLWZVn8YbMNnF
0jW0hBmU97Pz+6U96jDZVeraQdWzqH5IIYMzy1UYVfNaoYFwDnpRrfOdUkk5
dspd/W1T8ifoE944QXJXEfZIvCtA0XAeumzMma6Q6Wws+povPv0f5EXhnm9L
KmOA0rDKPLcW+dqF8HhvTgFocLlgbvSdd/RPkC+aVoBtNqxY9n3kTYQK2bsJ
dUCcZNFgTf1uvabITKZGCBLskxso02ifJ5dvcqUT2gClhD7yhIr86rHU0TFx
B+ji2yi1R6D/HXw0GROY0w2O3iet5l1G8dmpWz0d398D9JPxt+t1UDyP5reW
bH7QC3YQJ0LL3VBeIiUJAxRuH8AEHuBOBjp3RkYOs/mqItDn+OZxEhHVQ8i6
WNtD833g/Lqliz2vUV3hworGp2h9gK39E8OrE9Uzm/oxwNGhF3Qd8RPXu72F
Ll96KIre2gOy5CrdXH9vh+7v+APOVv4NsNc7H6mmI4SuIKInut/pAKzMpVWj
Vi+g65TNzL36+hpEPQ7TWjYogP7Ep6QgLqMN1MXQsvmZWdCP9Ko14r1bgfj9
tZy2hHjou4lzgjjHVyDDt3UyUDUcOoWYd8k4rAUsjAWoOjTTofPpppXdvit5
zGH5Bvcin/M61mVR1wR2UVKrRFLB0DNF1Vmhei9BNoGnlP4gAjpBU6N0d0oD
cNSY1iYN3IAufVJGEKFQD4L0gz4TN92D7pJM0rr8Sw0Qm1E8skZToW+55+Yk
iRSARQuhompeDnSzJ4SArYQKkK7hZE4vzocu1mi5flezDGSR4jNrDEqg7xEq
y2WQnoO2RqcJrYcVaP9fL5Tb2RaBPjLj2Ua7Wui1P24SOvALgYnpkgnPrRn6
YfO4cJ/xAkAbMPVaNdAKPVol7AojJR94TE4R2gUd0L0/zFRasbjAWVCbftqg
B7rJybAva2S4YHs99d0nTxH0YYXtieS0PLAn27iE0NkPnclT4WRT8gBzsf5B
4WdUh3ItbevISnmAqhxDKlVE/TNZO3Sj8yQH2OiWXGboof6p47B+WK+DA65E
brNk7kJ1XvdK8ZZdHQe4qxgozeu+Q+d6CRe1qZwDGDM+twr2o74afOlIlhWf
A/54vu3rQWt07wTRnxKzijng5QuXn8st3kNfGD+IcyvigH6u8t6hvejcTcwI
1RRXPLdRJpq5fQLl5bp5ot2Kt8V3pQXi0T0YW93HnOdxwJdBqtF+adS3FY9b
z4cf4ICqqEyWeAq5f46B9iP7XEBLoXkweagPCAa8IjeIc0AI2XMzn4r6/LmY
Z9HZvPvgNz+hw2wrck4m8dt7oMzjf++B/wDk+H0W
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHCtE9UgYmkL0SiPJA5ZpfpJY0fD2KSaSN5krRqkXTFriR6i
F9ZiNMIYPTSGNTGNXIy3GJFXYjwjMhqPqFOs9o97O3vPuf98zj3nd3/f7/d+
79X2oh71/U5KSoqyMqVXpvFlk+VREHzAbvnrmMak/hsDmKSSfMfUhI5Z7GE5
Kr1CnnCyY39OCgtbVJ2Nmv4FuRS7Rf1UWD4mP5waHZIphp6sElO8ubIA00z9
YtwfMwV9X6mfmDjEwUgje3zZZu+gr49/cj3rUyEWhJe2fsucgK6pwa2hh/yD
0VrHedbvx6Hr1NzHuXhwscWZY5vLjMaga0+PBVYplGIcOdPSoNOj0K//US23
FMjHIqIU+C8bh6GzZGRpvgcBZq9tM+ZaMAQ98w0h2F9UiWl6DLq4rkFeFCdp
vXS1GpMvdbzp3TMI3b6L5LFtTx02L/PQNtwErXesVa1r4TZgmsecEnGy6Lvt
c5u413qaMFroukjSiRHo3azLOjXuzZhmU3OA/iLav2GMtQzOrwX7y6FYRyRB
/2vbtdNH8WMLVi4aVR/xQnFjKLLOmK0WYh64fIYbDsU/T0JK2sRowcR8q9TH
2SiP9//0KXIWNmOGxgLj7VoS6On16RuXM55jtFoHlWHPGeiiVovqDxONmNyX
stUuybMo76cX9kp712NyqzR1Q2vmUP0Qw4dml6sxivaVYiPhPPSSOrdbZZIK
7ISX5uvmtA/QJ/1kBGndJdgD8Y5gZeMF6HLxp7rDZ3KxuCsBuKy/kZdE+bzm
VcUDlRG1BU4d8jWLUUl+7CLQ6H7O0uQb7xyYJJ03rwRb7BgJrLvIm/GVcreT
64E41arRlvLNem2RhWytECQ7pjWSZ9A+jy9f50gntwMyjzr6iIL88pGMsXFx
J+jm26l0RKP/HXowFR+S1wMO3yV+x72I4rNdv2YmaaAXGKbhbjbooXgeLmzj
bbzXB7YRJiMqPFFeYiTJg2ROP8AE3uBWNjp3JiZOc4XqItDv/OphKgHVQ/ja
BPsDC/3g7Nql870vUV3JRJZMTLv0A5bujzTfLlTPLMr7YGenPtB9KFDc4Pka
ukLZgVhqWy9gyld5evzWAT3I+XsZe4VXwNHgbIyGnhC6koia4nWrEzByllaN
2TyDrlc+O//i80sQ+zBSZ9moCPojf15RYnY7qI93yeXnMKEf6tNowvm1AfHb
K3ntyUnQdxLmBYnOL0B2QNtUiHoUdDKh4IJpZCtYHA9Wd2qhQudTzat6Alby
mMcICOtDPu97pNuqvhnsIGdUi6TCoOeIapgRBs9BLp6rknUvGjpeW6tsZ3oj
cNaa0SUOXoMufVxWEK3UAEINQz8SNtyB7p5G1Ln4cy0QW5C9mWMZ0Dfd8XSV
xAjAFyuhsnpBHnSLR/jgzfhKkKXlakktLYQu1mq9elu7HDCJSTm1Rjzou4Sq
8tnEp6C9yXVS534l2v/ncxUO9iWgn0R7ouhQB73uhw1CJ34xMDNfMuN6tkA/
aJkY5T9RBFwGzX1XDbZBj1OLvERLLwTeU9P4DkEndL93s1U2DA5wE9RlnTTq
hW52PPLTalkO2NpAefPBRwR9RGlrCimzAOzKNeXhuwag07lq7FxyAaB/abhX
/BHVoXxr+1qSSgGgqMYTy5RR/0zTjVB0m2IDO33eRZoB6p96TutGDDrZ4FLM
Fmv6DlTn9S+UbzjUs4GXmpHKgv4bdK6XZGI3VLABbdb/RtFe1FfDLhxi2vDZ
4PenWz7vt0X3Tij1MYFZygbPn7n/VGH1FvrixH4ZzxI2GOCo7h7ejc7d5KxQ
Q3nF85tk4+hbJ1FerlqmOKx4e1J3ZggO3YMJNf30BS4bfBqimOyVRn1b+ajt
QtQ+NqiOzWGIp5EH5RnpPnDMBy7pLt50LuoDgkHfmPXiPBBO8tnIp6A+fyb+
SVwu9y74NVDoNNeGnJ1D+PoeKPf+33vgX3oLRxc=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKpBiaUtRKM8kjhkleonsaNhbFJNJnmTtWqQdsWsJXqI
XliL0chr9NAY1sQ0cjHeYkReifGMyGg8ok5Y/XNvZ+8595/Puef87u/7/d7v
vZoetOPeq6WkpCgrU3plGl41Wh4BgYdsl7+NKczE+NsYwiQV5HvGRgzMbB/L
QeEN8rjT7QezkljYgvJMxNSvyKXYzapnQvIwuaHkyKB0MfREpaiirRX5mHry
omFf1CT0AyU+YuIgByMN7/Nmm3yAviH22c2MLwVYAEHa8n32OHR1NW41I+hf
jN4yxrP8OAZdq/ohnurGxRamT2wtNRiFrjk16l8pX4JxZI1LAs6OQL/5Z5Xs
kj8fC4uQ579uGILOwsnQvQ8DzE7TetQ5fxB6+jurQF9RBabuNkB1Xou8MEbS
cuV6FSZX4nDbs3sAul0nyW3HvlpsDvfYJtQIrXeoUa5t5tZj6icc4/Ey6Ltt
s1u4N7obMXrw+nDSqWHoXayrWtWuTZh6Y5Of7gLav36UJQ7v04z9bV+kJZKg
/7Xp3O218XMzViYaUR32QHFjbmSdM1kjxNzweUwXPIp/roSUsIXZjIn5FslP
M1EeH/7lVegkbML0DQWGOzUk0FPrUjcvp73E6DX2SkPu09BFLWZVn8YbMNnF
0jXUxBmU97Pz+6U96zDZVerawdWzqH6IoYMzy1UYRfNakYFwDnpxrcudUkk5
dspD/W1TyifoEz44QUpXMfZIvCtQ0XAeumzsma7Q6Rws5pofPuMf5MURXm95
lbFAaVhlnlOLfO1CRIIPuxA0uF4wN/rOO/onSBdNK8A2W2Yc6z7yJkKF7N3E
OiBOtmiwoXy3XlNkJlMjBIkOKQ3kabTPk8s3OdKJbYDMo408oSC/eixtdEzc
Abr4tkrtkeh/Bx9NxgbldoOj94mruZdRfHbqVk8n9PcA/RT87XodFM+jBa28
zQ96wQ6ribByd5SXKEniAJnTBzCBJ7iTic6dkZHjbIGqCPQ5vXmcbIXqIXRd
nN2h+T5wft3SxZ7XqK5w4cXjU9Q+wNL+ie7dieqZRfkY6OTYC7qO+Ivr3d9C
ly89FE1r7QHZcpXubr+3Qw9w+gFnJ/8GOOidj1LTEUJXENGSPO50AGbW0qpR
6xfQdcpm5l59fQ2iH4drLRsUQn/iyyuMz2wDdbHUHH5WNvQjvWqNeJ9WIH5/
LbctMQH6bqs5QbzTK5Dp1zoZpBoBnWyVf8k4vAUsjAWqOjbToPNpppXdfit5
zGX6hfQin/M+1mVR1wR2kdOqRFIh0LNE1dlhei9BDoGrlPEgEjpBU6N0d2oD
cNKY1iYO3IAufVJGEKlQD4L1gz9bbboH3TWFqHX5lxogNiN7Zo+mQd9yz91Z
EiUAixZCRdX8XOhmTwiBWwkVIEPD2ZxWUgBdrNFy/a5mGcgmJmTVGPCg7xEq
y2USn4O2RucJrYcVaP9fL5Tb2xWDPhL92Ub7Wui1P24SOvKLgInpkgnXvRn6
YfP4CN/xQkAdMPVeNdAKPUYl/Ao9tQB4Tk4R2gUd0H0+zFRaMznARVCbcdqg
B7rJyfAva2Q4YHs95d0nLxH0YYXtSaT0fLAnx5hH6OyHzuCqsHPI+YCxWP+g
6DOqQ7mWtnUkpXxAUY4lliqi/pmiHbbRZZINbHV5l+l6qH/qOK4f1utggytR
2ywZu1Cd171SvGVfxwYeKgZK87rv0LlewkVvKmcD+ozvrcL9qK+GXDqSbc1n
gz+eb/t60AbdO8G0p1bZJWzw8oXrz+UW76EvjB/EuRezQT9Hee/QXnTuJmaE
aoorntcoE8PYPoHyct08yX7F2xK60oPw6B6Mq+5jzHPZ4MsgxWi/NOrbisdt
5iMOsEFVdBZTPIU8INdA+5FDHqCmUj0ZXNQHBAPeURvEuSCU5LWZT0F9/lzs
s5gc7n3wm7/QcbYVOTvL6tt7oMzzf++B/wCGl7Bx
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCNMojiUNWqa7E0jA2qSaTvMla5ZF2xawleohe
WOvVyGv00BjWxDRyMd5iRF6J8SYy8oo6YfXPvZ2959x/Puee87u/7/d7v/eq
uvqe8FgrIiJCWZ2iq1P3mt7KMPQ/bLXybUyB857fxgiYLiff19dLAUb7GbYy
b7HHnGk7lJnAAIvys2FTv2IXYTYpng3KBZKDieEBaULk8XIRhdvK84By4pJu
b8Qk8oPFnkKLARYgDe33YBp8QL4p+vmt9C/5wI8oavo+axy5shK7KiXgX0Br
HuOYfhxDrlb1iEB1ZoPFmZPbSnRGkatOjfpUSBUDloR+sd+5YeS3/qyUWPbh
gpAwKe6b+kHkDDFxmscRCKxVzUcd8gaQp42Y+XsJyoGycz/VYT32gqjp5qs3
KoFkse0dt65+5NYdJOed+2vAvNgTy2A9vN62Wr6miV0HlE/axRLE8Xdb57ay
b3Y1AFrgxlDS6SHknYxralVOjUC5odFbcxHvXzvCVIzg2QT+tilUE0zj/7Xs
2OMu/bkJlAqGFYdccdzo0ozzBuv4wJmQS3ck4PjnTJPittKbgJBrkvgsA+fx
0V/uBfb8RqCty9PdpTKNPLk2ectK6itAq7aRG3SZQS5oNqr8NF4PJJZK1lHj
Z3Hezy0cEHWrBRJrlNUDq+Zw/VgED8yuVAKK6vVCHf488qIax7sl02XgtKvy
u8akT8gnPMV4SZ1F4LFwt7+s7gJyieizncEz2SDqujch/R/sRWHu7zgV0VBu
SGGBVYN9/WJYnCezANY7XTTW+87b+yZIlwzL4XYregzjAfZGYrnEvfhaKEw0
qbekfLdeVWAkXs2H8bZJ9eQZvM9TK7dYovGtkMzxHX5KwX7teOromLAddnKt
5NrC8f8OPJ6MDsjpgsceWKxlX8Hx2aVZNRPX1w21kwh36jRwPI/lt3C2POyB
O80mQspccF4ipuP7yaxeCHhu8G4GPnd6enZz+YoC2Gv/9kmiGa6H4A0x1ocX
euGFDcuXut/guhILLRqfovZChvpPNI8OXM8Mykd/e7se2HnUR1jn8g65VMnh
SN+WbpglWeHi/Hsbcj/7H8Sspd5CW60LEUoafOQyAt8E17vtkJ65vGbU/CVy
jdLZ+ddf38DIJ6FqKzoFyJ96cQpiM1phbTQ1m5uZhfxoj1IDwbMFCt9fz2mN
j0O+x2yeF2v/GmZ4t0wGKIYhJ5vlXdYPbYaLY/6Kdk2+yLm+hhVd3qt5zKF7
B/Vgn/c43mlS2wh3k1MrBSJByDMFVVkhWq9gNpEtl/4wHDlRVaVkT3I9tFeZ
Ubfov4lc9JQ4L1ymDgZqB34223wfuVOShdqVX6qh0IjsljWainzrfReH6Qge
XDLhyyrm5SA3ekr030Ysh+kqDsa+xfnIhSrNN+6plsIsi7jMah0O8r18eckM
ixewtcFhQu1ROd7/14tlNtZFsJdEey5tU4O85sfNfDtuITQwXDZguzQhP2Ic
G+Y1XgCp/YYea/pbkEcphF6lJedDt8kpYhuvHbnnh9kKczoLOvJq0s/odCM3
OBX6ZZ04C+6oo4x8chcgH5LZkUBKy4N7s/U5xI4+5ClsBWY2OQ+mLNU9LPyM
61CyuXUDSS4PUuSjLUpkcf9MUg+RdpxkQitNzhWaFu6fGnYbh7TamfBqxHbT
lN24zmtfy962qWVCVwUduQXNEXyul8UiN5cxIW3W63bBAdxXgy4fzTLnMuEf
L7Z/PWSJ751A32dmWcVM+Oql089lJu+RL44fEnMpYsI+lvy+wX343E3M8pVk
Vz23QTwqZccEzssN4wSbVW+N60wLIOB7MKaqN2WBzYRfBih6B0Rx35Y9YbkQ
dpAJKyMz6cIp7H45OuqPbXMhNZnqlsLGfYDX7xGxSZgDg0nuW7gU3OfPRz+P
ymY/gL/58O3mWrAzM82+vQdK3f73HvgPMaQZgw==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCNMojiUNWqa7E0nhsUk0meZO1yiPtillL9BC9
sNarkdfooTGsiWnkYrzFiLwS45lXRuMRdcLqn3s7e8+5/3zOPed3f9/v937v
VXXzO+G5VkREhLw6RVen7jW9lREYcNhq5duYBinJ38Y4EFbY3NfXSwVG++l2
Mm+xx55pP5SVSAeL8rPh079iF2E0K54NzgOSQ0kRgekC5AlykUXbKvKBctKS
bl/kFPKDJV4Ci0EmIA3v92QYfEC+Keb5rYwvBcCfKGo6nj2BXFmJVZ0a+C+g
toyxTT+OIVerfkSguLDA4szJbaU6o8hVp0d9K6VKAFNCv8T/3AjyW39WSSz7
ckBouBTnTcMQcrqYONXzCATWquajjvmDyNPfmwV48yuAsssAxXE99sJoYcvV
G1VAssTujnv3AHLrTpLLzv21YF7siWWIHl5vVyNf28yqB8on7eMI4vi7bXNb
WTe7GwE1aGMY6fQw8i76NbVq5yag3Njko7mI968daSpG8GoGf9sWqfGF+H8t
O/d4SH9uBmX8EcVhNxw3mjT9vME6HnAh5NGcCDj+uUJS/FZaMxBwTJKeZeI8
PvrLo9CB1wS0dbm6u1SEyFPqUraspL0C1BpbuSHXGeT8FqOqTxMNQGKpdB0l
YRbn/dzCAVH3OiCxRlk9qHoO149FyODsShUgq14v0uHNIy+udbpbKiwHp92U
3zUlf0I+6SXGTe4qBo8FuwNkdReQS8Sc7QqZyQHR130IGf9gLw73eMeujIFy
wwoLzFrs6xfD470YhbDB+aKx3nfe0T9JumRYAbdb0WLpD7A3ESsk7iXUQUGS
SYMl+bv1qnwj8RoeTLBLbrCZwfs8tXKLKZrQBm3YfiNPydivHU8bHRN0wC6O
lVx7BP7fwcdTMYG53fDYA4u1rCs4Prs0q2fi+3ugdjLhTr0Gjuexglb2loe9
cKfZZGi5K85LpDBhwIbZBwHXHd7NxOdOT89+rkCRD/sc3j5JMsP1ELIh1vrw
Qh+8sGH5Us8bXFdiYcUT05Q+SFf/ierZieuZTv4Y4GDfC7uO+grqXd8hlyo9
HOXX2gOzJStdXX5vR+7v8IOYtdRbaKd1IVJJg4dchu+X6Ha3A9KylteMmr9E
rlE2O//66xsY9SRMbUWnEPlTb3ZhXGYbrIuh5HCyspEf7VVqJHi1QsH49dy2
hHjke8zmuXEOr2GmT+tUoGI4chuz/Mv6YS1wcSxA0b7ZDznHz7Cy22c1j7k0
n+Be7POex7tM6prgbpu0Kr5IMPIsfnV2qNYrmENkyWU8jEBOVFUp3ZPSAB1U
ZtQtBm4iFz0lzo2QqYdB2kGfzTbfR+6cbKF25ZcaKDCycc8eTUO+9b6rozCS
C5dMeLKK+bnIjZ4SA7YRK2CGiqOxX0kBcoFKy417qmUw2yI+q0aHjXwvT14y
0+IFbGt0nFR7VIH3//Viua11MewjUZ9L29Yir/1xM8+eUwQNDJcNWK7NyI8Y
x4V7TxRCyoCh55qBVuTRCmFXqSkF0H1qmtjO7UDu9WG20pzGhE7c2owzOj3I
DU6FfVknzoQ76snvP3nwkQ/L7EgkpefDvTn6bGJnP/JUlgIjxyYfpi7VPyz6
jOtQsqVtA0kuH5LlYyxKZXH/TFYPlXaaYkArTfYVqhbunxr2G4e1OhjwauR2
09TduM7rXsvetq1jQDcFHbkFzff4XC+LRW0uZ0DqrPftwgO4rwZfPpptzmHA
P15s/3rIEt87QX7PzLJLGPDVS+efy03GkS9OHBJzLWbAfqb8vqF9+NxNzvKU
ZFc9r1E8OnXHJM7LDeNE21Vvi+9KDyTgezC2ui91gcWAXwbJegdEcd+WPWG5
EH6QAauismiCaez+uTrqj+3yICWF4p7Kwn2AO+AZuUmQC0NIHls4ZNznz8c8
j85hPYC/+fLs51qxM7LMvr0Hytz/9x74D9yigoY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCRHkkccgq1ZXGjoaxSTWRvMla5ZF2xawleohe
WOvVCGP00HisCY1cjPdrRF6J8YzIaDyiTlj9c29n7zn3n8+55/zu7/v93u+9
qq6+JzzWioiIUFen6OrUu6a/Mgr9D1uufBvToLnp2/gAhBWU+wb6KcB4P9NG
5g32mDMdhzITmGBRfjZs+lfsIqwWxbNBOUByODE8IE2APF4uonBbRS5QTlzS
64+YQn6w2FNAGsoD5JH9HizDD8g3RT+/lf4lH/ipiZq9Z0wgV1ZiV6cE/Ato
reMlZh/HkatXPyLYO7PB4szJbaW6Y8hVp8d8KqWKQZ6EQbHfuVHkt/6sklj2
4YCQMCnO64Zh5EwxcZrHEQisVM3HHHKHkKe9I/p78SuAsvOgvcN67AVRwtar
N6qAZLHNHbeeQeRWXWTnnftrwbzYE4tgfbzepka+toVdD5RP2sYSxPF32+e2
sm/2NAJa4MZQ8ukR5N3Ma+rVTs1AubHZW2sR718nwkyM4NkC/rYuVOcL8f9a
dO1xl/7cAsr4o4ojrjhudGnmecN1POBMyKE7EnD8s4XkuK30FiDgmCY+y8B5
fPSXe4Edrxno6HH1dqkIkSfXJW9ZSW0CtBpruWGXGeT8VuOqTxMNQGKpdJ19
/CzO+7mFA6JudUBijbJGYPUcrh9S8NDsShWgql4v1OXNIy+qdbxbKiwHp12V
3zYnfUI+6SnGTeouAo8Fu/1l9RaQS0Sf7Q6eyQJR170J6f9gLwpzf1tSGQ3l
RhQW8mqxr18Mi/NkFcAGp4sm+t9558Ak+ZJRBdxuSY9hPsDerFYhcS++DgoS
TRssqN+tV+Ubi9fwYLxNUgNlBu/z1MqtPNH4dkgp8R19SsV+7Xjq2LigE3Zz
LOU6wvH/Dj2eig7I7oHHHpDWsq/g+OzSqp6JG+iFOkmEO/WaOJ7H8ttKtjzs
gzuJkyHlLjgvEcL4QUpePwRcN3g3A587fX3buXxFPuy3e/MkkYjrIXhDjNXh
hX54YcPypd7XuK7EQosmpu37IVPjJ5pHF65nJvWjv51tH+w+6iOod3mLXKr0
cKRvWy9kSFa6OP/egdzP7gcxK6k30Eb7QoSSJg+5DN83wfVuJ6RnLq8ZM3+J
XLNsdv7V19cw8kmo+opuAfKnXiUFsRntsC7aPouTyUB+tE+pkeDZBgXvr2e3
x8ch30Oc58bavYIZ3m1TAYphyCnE3MsGoa1wcdxf0bbFFznH16iyx3s1j9l0
76A+7PMex7tN65rhbkpqFV8kCHkmv5oRot0Es9TYcukPw5GrqaqU7klugHYq
MxqkwZvIRU+Jc8Nl6mGgTuBn4ub7yJ2SSOpXfqmBAmOKG2MsFfnW+y4Owggu
XDLlySrmZiM3fqrmv02tAqarOJj4FucjF6i03rinWgYZpLjMGt0S5Ht58pIZ
pBewvdFhUv1RBd7/14vl1lZFsJ9Mey5tXYu89sfNPFtOITQ0WjZku7QgP2IS
G+Y1UQDtB4081gy2IY9SCL1KS86HblPTah3cTuSeH2Yrzel50JFbm35Gtxe5
4anQL+vE8+COeuq7T+585CMyOxLIablwb5ZBiVrXAPIUtgIri5ILU5bqHxZ+
xnUo2dq+gSyXC6ny0aRSWdw/kzRCpB2nWNBSq+QKTRv3T03bjSPanSx4NWK7
WcpuXOd1r2RvW9exoKuCrtyC1jt8rpfFIjeXsyBt1ut2wQHcV4MuH2WYc1jw
jxfbvx6ywPdOoO8zIqOYBZteOv1cbvoe+eLEITGXIhYcyJPfN7wPn7vJWZ6S
7KrnNIpHpeyYxHm5YZJgvertcd1pAQR8D8ZU96cssFnwyxBV/4Ao7tuyJywW
wg6yYFVkJl0wjd0vW1fjsU0OtE+2d0th4z7AHfSI2CTIhsFk9y0cKu7z56Of
R2WxH8DffHi2c23YWZnEb++BMrf/vQf+A4ev64k=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHCtE9UgYmkL0SiPJA5ZPX/S2NEwNqkmkjdZqwZpV8xaGj1E
L6z1aoQxemgMa2IauRhvMSKvxHhGZDQeUSes9o97O3vPuf98zj3nd3/f7/d+
79X2pB7z+U5KSoqyMqVXpvEVk+UREHTQdvnrmMKk/hsfMEkF+a6pSRpmsYfl
oPQaedyp9gPZSSxsQXUmcuoX5FLsZvXToXmY/FByVHCGGHqiCr1oc0U+ppm8
aNxHn4S+v8RXTBzkYKThPT5ss/fQ18c+vZH5uQALxEtbvWOOQ9fU4FanBf+D
0VrGeFYfxqDrVD/AObtzsYXp45tLjUaha0+NBlQqlGAcOdOSwDMj0G/8USW3
FMDHwiMV+K8ahqCzZGRpPocAZqdtPeqSPwg94y0hyE9UgWm6Dzi7rEFeGCNp
uXytCpMvcbjl1T0A3a6T5L5tTy02J/PIJswErXeoUa1t5tZjmscd43Gy6Ltt
s5u417sbMVrIugjSyWHoXawrOtVuTZhmY5O//gLavyHdSgbn24z9ZV+kI5Kg
/7Xp3Omt+KkZKxONqA97orgxFFlnzVYLMXdcHsMVh+KfKyElbGI0Y2K+ZfKT
LJTHB396FzoJmzBDY4Hxdi0J9NS61I3L6S8wWo29ypDHNHRRi0XVx/EGTG6x
dLVz4gzK+5n5vdJedZjcKk3dkOpZVD/EsMGZ5SqMon21yEg4B7241vV2qaQc
O+mp+aYp5SP0CV8ZQUpXMfZQvCNI2Xgeulzs6a6w6Rws5qo/LvNv5MWR3m94
lbFAZVhtnlOLfM1CZIIvuxA0uJ3fZ/KNd/RPkC6YV4Attow41j3kTfgKuTuJ
dUCcbNlgQ/lmvbbIQrZGCBIdUhrI02ifJ5ZvcKQT2wCZRx15TEF+5Wj66Ji4
A3TxbVXao9D/Dj6cjA3O7QZH7hG/415C8dmuXz2d0N8DDFNwt+r1UDyPFLTy
Nt7vBdsIE+HlHigvdEniAJnTBzCBF7idhc6diYnjbIG6CPQ5vX6UTED1ELY2
zu7gfB84t3bpQs8rVFcyEcXjU859gKX7I82nE9Uzi/IhyMmxF3QdDhDXe7yB
rlB6MJra2gOY8pUe7r+1Qw90+l7GTuE1cDA4R9fQE0JXElGTPG93AEb20qpR
6+fQ9cpm5l5+eQWiH0XoLBsVQn/sxyuMz2oDdbHOOfxsJvTDvRqNON9WIH53
NbctMQH6TsKcIN7pJcjyb50MVo+ETibkXzSNaAELY0Hqjs1U6HyqeWW3/0oe
cxn+ob3I53yOdlnWNYEd5PQqkVQo9GxRNTPc4AXIwXNVMu9HQcdra5XuTG0A
TlrTusSB69ClT8gKopTqQYhhyCfChrvQ3VKIOpd+rgFiC7IXczQd+qa7Hi4S
ugAsWgqV1fNzoVs8xgdtxleATC2XfdSSAuhirZZrd7TLAJOYkF1jxIO+S6gq
n0V8BtoaXSZ0HlSg/X85X25vVwz6SLSniva10Gt/2CB05BcBM/MlM65HM/RD
++Ij/cYLgfOAuc+qgVboMWoRl2mpBcBrcgrfLuiA7vt+ptKawQGugtrMU0Y9
0M1ORHxeLcsBW+spbz96i6APK21NImXkg105pjx8Zz/0NK4aO4ecD9IW6+8X
fUJ1KN/Stpakkg8oqrHEUmXUP1N0wxVdJ9nAVp93iWaA+qee47phgw42uEzf
YpW2A9V53Uvlm/Z1bOCpZqQyr/8WneslmegN5WxAm/G7WbgX9dXQi4eZ1nw2
+P3Zli8HbNC9E0J9QmCWsMGL524/lVu+g74wfkDGo5gN+jmqu4d2o3M3MSPU
UF7xvEbZmLStEygv1/Yl2a94W0JXRjAO3YNx1X1p81w2+DxIMdkrjfq28jGb
+cj9bFAVnc0QTyEPzDXSfeiQB5xTnb3SuKgPCAZ86OvFuSCM5L2RT0F9/mzs
05gc7j3wa4DQcbYVOTub8PU9UOb1v/fAv3G1TIc=
            "]]},
          Annotation[#, "Charting`Private`Tag$5395#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& }], {195.75, -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJxc2nc01+//+HEZhazSoFREEUISKlxWaahUUiJNRCWrSMjKijLK3tkre3PZ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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQeUFFXThmd32Z2ZnRzMWRAwIKggBhQREBOKCCaCAuYAImZFkglREbOg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               "]],
              Annotation[#, "Charting`Private`Tag$5427#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJwsmnk0lO8bxkmlb2QNZUmlokhKZCl3smTfZasUUVGWiBQVIi1IIiHZUvZd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          "]], {}}, {GraphicsComplex3DBox[CompressedData["
1:eJx13Xm0n2V97/1IHaLggOhTjXWoUFCIA4iiHuIuivFxDI5wFI9GUIxDKXGq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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQe0FEXThm8A7u6d3ZkNJkARUAEDCpg/A4qKoqKioKKiohhJgpgwAWbM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               "]],
              Annotation[#, "Charting`Private`Tag$5448#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUVWUaxkG8oSQX0wFSwQwVmtERY3QVtlPHSlMLxUBlwkhEUqMBExmF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          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k01F/YAPB+diohlCKSrd1S9lzZotKKZE2IFiFCiYRURAhlXzOU7LLm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            "]], Line3DBox[CompressedData["
1:eJxd1Ws41FkcB3CX0IYIj7QtklzKohTqUZ2oyZQhlNp0EWEXG114PMVETFGu
O8ilZI2EosVoFu04M+QyLjOTzSCXGZcGJXet0Nh6c87zdJ7nvPm8OOf8/+d3
vj89ryBXHxkpKSmXr1P263wwcoc6fC18/2HJytcxCbIyv40q8GGh/JQymQaS
ay32lhVhV7Y5oh83XgDCS8w8smsnkJsZbRU5ddHAwkniURW3j8itVErm99y7
C3yz8xhFeR+Qf2EnznYHPYECeqqzYdgo8nujmtJmpgzIaRu70i0tRr5ztT3V
cpgJrafPSkpHh5D3q5mWPFZhQV5KnO0uNez188pWwgYWdHw/BjQdBpEHRCzL
aW9lw7kOX7osZQC50FNBML2LDY/IH2IscUXIjz/v/HJMwoKPHGYMgs2xq0dv
dklLZ8H0DLfjOwhC5MVhrWsitVgw23XDGZJXP17npV/dpdoaKJ1RImgq7UO+
r3Etda3dP9C48qKDvx12V7+fPfcSK2FRUjKhnoA95LCv9tnWcsgw7TQw4WBX
Ta97oX/hCYwY0nmVIcL7jrv01Iv5NCA/JWc4Qcbfe6o/ytRZngFcDNVG4i3x
f4sL/m+BZMoG6fcvbzfxfoecSdCgik83gHijxivdwhHkpS45b3vimsGJyJEX
cW3vkadWLHksxraB23KGxSEuuE4uX85ODgzigg3dlavJM1PI7Vf8IpbaW8FL
+i31kbQZ5IwCdt0ssQkw3S4ycj/NIp93EZS/X8UG63NUC22G5pDbSe00y3n4
DLit/uXTZ8955GqLK44KlkXQUUI44hSAfUej+cljz19Byg/UjYof8TqBfEoG
WeU1bNUO2sxbxPta68lrkkmdsF1oOBqfiM+Z2CzNcFjphYk3mbmKZPxdNNfl
+NYCEbTRX+ezUWkceazH7O0M2UGY9bopt7ML13kvVOP9encQTkwqZg2W4fsi
M0MmbloMwgfTUWfqqG+Ry4TeV+BKRLB98i8bR7N/kaefzbKNye+Du8q9mbtV
m5Efosv3XNftgsYEhegCLTZyTtmQxnJ4O3yRFhQhPsdA/iBdIKAPc2DSyQT3
wOhi5Lml2vTOAyzopBG8kiDKRR4zFnqj51AZ7B7eXE2ipCF3+uBQ9WYgBSYq
Fcr8WRSLfLvIL7LCJAmkFqYM+I9HIu+gCDj0sTzQxeuLbtK5hXxKMa3GN6AE
GBj6mB8NvIN8G3HObMaRDhYpKSWVpUnIR90eqbo3/Q3EB6ZilArweYgOtuft
17FAjjDb6oI8Dbnxw/61U6l1wEKSQGs6+BS5F+nxthphA6i2UJ/Q8SpHfr/v
2p5QCgfEWm8ZkjlViVyX+0wpjNMCYi039YbFQnzvz5slguE2YHVMR6+E+gp5
obr8TSMGF6hci6EbGTXiurLyn3vnywOOLGLj+TkOziuCptTcMg9sSwgd9gZt
yDvDD5PWWPABqyikr9+bj9znaqjMGxIf3MixJwTrtiO3XejYoXScD+yUn/64
fgjXz/VyX729BD6YKoyLomR3IH88HjpWp88HW4K94zKdOpHv9ueeqGvnASGj
2nqdajfOsc+KA5cseKDV71F9WDWuW8qmfeKJnDagYVI8MpaPc6zQw3Pp4+8t
wKuaebDFGeetGsk3Q4rbBEr3MX9aBfG7sN7fa0hqrQdiSSP9kxbOsafm3WdO
V7EB1/3Ly1raMPKrDea01MYqkLwo2yBwwu+uIqps+o8Lz4C//XjsaDDuRwKi
nXEZLQo6646KM9Nx/3IKmEx6tz4XOqcwXo/o4X4XsSrz3N34AijHcc/LJePc
02ox0PSryYOb+IsVjmm4n+Yn5H/rvzW/fdd//wezKB9J
            "]], 
           Line3DBox[CompressedData["
1:eJxd1WlQ00cUAHA0BaxcUVEk4cZRBAcjSOWSrVbAhmkrokEEaeUQZKYcglgQ
RUBarwKCiCQMckQOiYhaxBBgJZdyKDEcQiAlhMOGiogSECxJ6Zfdme7Mfvl9
2P/7v933nmVIzMHwlRoaGgeXN2F5D+bIG/LOJ3lkqdTLaxrQC/9bbSCUziDK
rUrB2Dq6CbEBu4PiD02drEpg1uQdM/T+HfKThvK7R9PuAFd745M/1U0hl1E/
XP6qgw7mR7dEhdq8RT775RaiVJoMiBkGiltFk8jHymyT11IuQ/mSomSnoQL5
Yv6JF7reTGhrscuIcHgCee2t6uNxFtVw333FdLXWOHJVaEiNpzELbqNK7GJl
o8hNFh3m2pzuQYmk54Z8To48yT+MBjtZMLKP9I7pjF0vIOWYw8Jd+PFofXoR
YwQ7IXlebVEFSQz673MU7JcvSRtVXCY0NbttlPVJhvN5zVKD5F4KxTLqOuo0
9tGcq441LkWwOrVV9oCIz+kM81A2ivKhfRq90CMIe6+XdbZn0RU4YcbxIY5g
l2V4pWYYBsKbO7acCSzG8V9KvN9qxC8BMy7shMjyMeSAe6Zco64eNGqNe2ue
fYPcKbQ+ciGqGQjOBy+1Hcf5z1anmXW4cYG4XJQ4celv5NU2881+g3xQVU2G
o3x879H3hm1s04RAf9VFjjP5PXKz+bbVEaNC4H5emxZzbgb5p6mwQdurApC4
YW3bbO8H5GEMskauFxfsKwjY9oPmLHJ5gO316FI2sJLV/0pcwB6+GUSOra8A
M9nav4hzlMhdO7vIDT7F0EFb2HFbhD3zjGR4mNcCozO3cspY2Jd8M/IDmR3Q
Ro8zabsBu+fxCzuuxnTDj/HhK+Wm+LusPT1Op3L6oaevcoc9G8fvZDYX22wn
hVNNSqu9TTgP9Baxj7aPDBqT4xN38nBdKAV7Ne8dHoHUBlPieDu+l6g7WeF+
D0ZgKo09ldeH71d/kz25L2gEcncRVL5GUuQD0MCYFyCDGp3KUn92L/JJKuvw
z5uk0FkRYLif/RL5jLlu0+6qfkg+FXwk8zMfudXJqTjrjT3wkXWMbu/RJuSb
1xMUFk5d8Eiot9o58iHysoXVriRSK9xjthhdvEhH7quf16P/vgHKZHchveYa
cjXtm62Pg+qgyZrwJ9MPL+D3D1f42RlUQDfHEzXEbeeQ96WdWBc8RoceN648
645OR15Pa4lOnM2AWqE7VcXgCvLne2b/indLBunuOpRiUi5yjndwYU57GQja
AOMnXhQjH/YTmV9fUQcO2lOtP6sr8P9SvvASH3gMCv103Pfn1SGP6FbFNCdw
gK9WjA8z/TFysfy1AMohYLSvddz8rBn5votLFIW6FTgeSyX483nI33TMRXFe
ckHvUIZleIgQOSEwwbz1Ag8cYjzcPubchvzFmCSOa8oHCs5w5cC1TuRzwOW7
p7l8wCoQlTUZiJAbxtomf1iu06+F3/MYXa9wPEuP7AQrBUCsy5W3MrqRd7no
CWXaAsCxp6ZEhOL3Y5X9fDX/LR/sDtj12sPmNfKcxR9JF2v4oP+fEVfaqgHk
G6OZfLI3H9CeqHvSJBLksUruSGYnD0xIZDey0oeQV1WZr+A580Aky42dZPkn
jt9nTWN1bSsYri2/6S7E/XNqqECn6jYEq/i5T92icF3IOyntA1QOOG0kfP5u
Bvf/vSmKuP0R9cAw7zSPz8TzgjZY41X8igUOuahMPoXgugse13WwY94Eb72e
HWg7hfuhKPFR/3hCAYy8Qznw225cv1K9pLTtDkwIHVNCUq7jfljiLuo7V1kJ
8wXflijYeG7WSo8ok8PKIOXN2Un/CjxnTbRV/83lFtb/5vK/GAYq2A==
            "]], 
           Line3DBox[CompressedData["
1:eJxV1Xk01FscAPDJ+g7JUji2phmV5UUbJQ1X6Vlb3qhe5dFgSE9OyVLKkj1j
mfBQEQ3KXiFjSdNlqFFkLJnINrYsrZacPOHpn3vfu+fcfz5/3N/9fe93Iblc
sHMTIRAIx1a26MoOeSNfGiDwMx1bWl5ZX4DBzp+rA9iZE40XP2WCvSqK4jd5
/3FZy497VfLAwd3GdhK62AuS3tK3NOWDd8ad681In5FvDuoU/0suFyxv5+p4
N39EztW2kdpbmQVuBA2yDzh+QF47kD/pcTgdNG7gZbm2TSBvznMgCTpSQNpR
0dRV5uPIzQK7qV5zScAk0CSmpeY98ifXQ/X1xpPA9+tFx7O3jiKXpMbOHCGl
ghm7Q8kUwTDyS5l/d13ZdgcwbRM+anQOIZ+PN+leHZ8NPPaMrOkmYSev27Gw
LzofaK0qd+BVDSK/W7T/sgzxEYgl0nIVCrEvBPAIRs1lYLPZMQvSFPbc20W2
1ZANZCus90fG4PPld5IouqJVQJcjoe3tjO/ppDHFOd1RDSws4ZyS/wjy8wen
68qCasDhlA/HbUfx/wYTu2hX5TmAbMr2DY4ZQ660bvLHRetaMOdWLForh+Of
HVarvuBUBwx1DbWlpvF7rWZmsdvPc0F+UpKlxBB+345lfdvdlvWgRX6WzAj9
ijyQbiW3MaYeUAXDLJ+EKeSKPcalXiL1gPVB3FTx+jTyCJtNzrvC6kAlO+ke
2WcGeUj0cU/LkxzwlbVQS6DN4nsqDwaoqLGB6dMqTeav35BHf/XJZU/fAzvS
NMe8m7AnG5WowVeRMCqOQg01mkPOGPjCuu9cCqP6M3rp7thf0HXa1Ql1MJJV
7uN6CntGM8PpTPorWNiqZUVfxOf7D/EjY4ntcP5Po1UEa+wajzzDNGkCKHr+
9zCKNb4/nxm0bXDDO2ijNs4d+ITjUPutT+mBSx8Uti3zXaVw3FQl2gwqSwbg
eGwzN+r+J+RRbe1TZcFCyHYzj1Oaw3XR/1omnpIrhIrk+CJHM5wnJTBPnXNM
CDW0PMvFVIXIJ8fnNkWoDcBZm6Yshf4u7D4Ml+6IXphf5Sm9ZNKO3FT4S7MN
tRuW6xNPmb58ifzkhYfG9usEME/FeapNWIfjYySebD/cDrNFHz+NZ1Qij0vJ
zAhObIIZKYyCiD4W/u6LB36zJTzIe7LDb4SfgFwPJEWnPm6AEuR/eEPnQpCz
HDaOagZyYbS785D5+CXkp7mV84nptfC3NadVIxauIv8esofl5cWBMxdHwvMi
w3EfCPBgqNZUw3NTAdH+F2KRqz8Ivm1YUQal36u5SdvdQq5z5JK3D6UAqtoo
mAzMZSM3tBqe4NxMg286XgDHh8XIVRQymd4SAbBlWSOmHJQjn5bc1VD/NgK4
ellXcdJrkC8Wi7ykOaeBUJEKa9vnXOTb7Fv5Mvo5wJyZma5FbUQu+8PgqFfD
fXD4s5+7dkkTzhODNQdme/NA+evweZFDfOQjR9e2P3MpAIu0ibEJzzbkXdQz
LYEhhSCn0paXYt6B3HGtwzB3VxFQFev0T1LrRJ4qaX/I+MaKf3LYJ/guQD7a
a35iOroIkHrWyjcu4bxiWivnpxOLACVZaruySA9y/VdZHZGehWBzhZ3szEAv
cocoGj3NpwDECQ1fGzzpR84ujWulMnPB2asnae4ncF/Nab029bQxG+j5MXL6
TXD/NA0+22Nx4w5QZ2dIE5dwXRz0eCfquSUBNBAmlB4N4zlilDnk61v9Bzil
ZzFlVYXrqzI8+3mYTCIsGwri3yqeRC5+l2wfKJcBu7ZOvFER4L46Y65wxffy
Pci1nbVkSeH65VZwJBYk8yHlGpl0Vg33VVruelt+Yx4k9nHveIrhOetET1Qe
rmJB95T1Y+412On2Oj/n+DOx5f/P8X8BzABtGw==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xk0lGsYAHCJFmtlqRsSJRWXtDgh884tEulE0SVdImWve5UtdC3DsW+R
3dgiGdsgIV4Kw2CunTEhI6Ky5GJs5dY/79u53znvP7/znfM93/M+i4zVvSu3
ubm4uIy/n83fT723U9/RUWeC8saPZxYkJf54mEA7cC4/Ry0FRNp7jS/2YHev
oTKqq3LAjPZVK20T7O//jlI6/SAfSO7K0Yz2mkFON7/V7iJSAKLdzw8pGE4j
f7Qv9VKjUQEIU37tc3DlE3K5YBM6X2sB6LWXnHe2/4h8S37DfaMjRWDgOqvT
om4Seeo6s/AcrRiQGSHKy0IfkO95YMnivKACvzqLdJrBOHLX5+6VExblYCqf
Xr/WPob8YtTtXr+olyAphgnaKtnIWwODfh13egVIcmI1NsLYj83YTb8LqwPy
gdyKNztGkfOGrZxyWXgN/igr9xYUwO8r85EuU040gqxdm05rVGFnfJ51dThM
A7H0qXzVfhzPL1kOr0dimgHpsQbrKxHHD8m8bEZUC7i/zi33ZW0Cua2xkKGk
Kh1IDyx4HpKbQn6zwt+U6koHbHlRXU4AzvOSsxLPE2s6cOM/wVYaxvfi3d80
6LOLDkR3K/DPyMwhd0p27BfzawGTNHPh3y59QV6SNGGc+D3Owp6XZRH35pGf
O9s8GbrSBLYR9hbmxv+L3Gem61RmQgOYfiui1Zm5gJy7VmpoyL8eFCoWWyd5
LCIn6beab5+tAklfZQPi5JeQxwrO1+8XLAa2knPE8lLsUXE+oVGxISBpZed7
XmEOch5y47U5wlNY7b22MajO+al+GMyOvEr4WTxSZu4nl3En2Gkda4AW/8RS
VkWxm0sd860uboVWZFldvmb83WmSJ4FvoBPSf+evqiBgH871eBqd1AtTLSw7
pJ3xfy0BWwkVOACPNpy3uuyI86BVdNGgz5oFX4W9EPDdg/Nmo9vVuS9yCBJ3
nDZM1sX53z7sTVXkDMMmf6Ue8g3cd5P3tNgRGSPQ+mLC6oFJXA/9d0R0DFJG
YE6Q+obQbVxXAfp1MYe/DUMVPQqv/g1cz/EPpy7c7RyCsvI7t0nZsZBrWiW7
ws1v4VGjDy8CYnqQf9IXKhAaZMJcM1clSUo7coKbhFR0aC8srS6NEC6uRq7a
rhoex9MFDY8v+hckZCE3nryTffNJB5w9WNY92hGDvDhIfZzSw4ARIa1pNsd9
kLc4XaeYrbZB8TX+wDd9f+E66W1x4FxphQ8/PtOLX3dG/q3Fj+Ge1gI3yHx5
Eke8kGc2vSoYnqXBrMmSgeRrJOSmZ3Ss1QyaoEEkTVsRhOE8C+fx1FY2QEVN
soOKyGPkm7fEmmmN1UPXhRTPA3fIyAvVa4ITRWthjFgFq2hHHs5bc5dCglYl
TGDYzhs7UHHfLS8PaoqVQzfeM8K2g5XI9fJM8/xVSuCjHbsVF5fqkW8S3UoK
sKdAfbttPAVxNBw/lTh1wzYXhuapkWozGcgPeHrs7BDIhscrbkUS17uQn0jM
Fk7uzoQTwY+dXUbx/a7uP9fdw8qAql3K4Z5dfXgujbrE8IlmwL0yGqKCnAHk
RmOBLZTwdEhjOxClZHH9NCvY1M9rpcNM7h5HX4Uh5GKm4ipiR9LhO8vGtIZT
I8gFw/+sqFZNh5ztq6Y85e+QJ6WXnoT26XD8LoE60Ibr9mqgHZW7Nh26Djbp
PHiL523z0ymTReUMSFoz1xGfwvP2q7RZIvNqJsxrT96/ux/3xabo7OA0rmzI
p2a5r2Qc75fUFIHrcGsOlHIkXrBvw/3FNvSq1ox7Bk+yTeI9nuN5q8s6u1VN
8zk8dND20UbRZ+SHnMwkNILzIbPzTEl4MZ7DhqY6y1qy+TBferJkPQT3te+w
ccObsVxYyCxJLCPi/Tv9KWh6qiYNulHIks5t2Fndvj/2e63e//b7fzfJYUc=

            "]], Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKrBEktb3pRXzXLIKtVPGjsaxibVRPIma9UgdcKsVVJ5
9MKx3vIuaQxrQuRijPGIkbfEeEZk5DnqhNX+cW9n7zn3n8+55/zu73u/3++9
qq60Ux6bRUREqBtTdGPqheuvjwO/o5br38YsJvLfGMLmaiiPDPSTMeODuTbS
b5FHn+s6khWfi63ILYTO/o5chNGqcP56ASYxmnDDP10APU42rGR3TSGmlLCq
Nxg2A/1wmaeANMLEyGMHPRiGH6FLRr2IzPhShPmqi5p9yJ6CrqTI4iT7/4PR
2ybLzT5NQtfgPMHbO7OwlfnTuysJE9DVZid8aiXLMKa4QZnvhXHokX/Wia/5
VGDBoZIVnU2j0LNxYnSPYwCzUjWfcCgcgZ7+nujnxa/BlJyH7R22Ii+OmGu7
eacOkyizue/WNwzdqofsvOcgF1vC5VsE6aP1NvVy3FZWI6Z02jYGL4a+27G4
i3W3rxmjB2wPIZ8dg96TG67BcWrBlJtbvLVX0P51w8xweM9WLN66RIM/h/6X
1LPfXepzK1bFH1cYc0VxS5XKvWi4hYc54wvSHPEo/nlz5Nhdaa3YbIVpwvNM
dI5P/nIvtuO1YPv02Hp7VeagJzUk7VxPeY3R661lR13mofPbjOuWp5ow8dXK
LfZxC+jcLwgPibo1YOKblDQDOIsof0hBIwvrdRhV9XYJgbcEvYzr+KByrho7
66r0riVxGfq0J46d2FuK5Qt0/WT0hNDFo873Bs3nYJG3vfEZfyMvC3V/V14b
BWTH5IVMLvKtK6Gxnoxi0Ox02UT/O+8emiZfMaoBypZp0bmpyFvUa8QfxjUA
QYJpkwX1u/WqfGOxeh6Is0lsosyjfZ5Zj2SKxnUASjlt/BkVefjJlIlJQTfo
rbCU7bqB/nfk6UyUf14fOJFK2swKRPHZq82Zjx3qB/sS8fcbtVA8TxS1l+98
PAD2EKeDq13QuYTNxQ1TmIMAY7uBB5mo7vT1bReLFPhg0O5tfgIR5UPQtmir
o8JBcGnb2pX+TpRXuJDSqVn7QZCr+Qvdowflcy71k5+d7QDoPe4jaHR5h+q0
8ugtWns/yJGodXG+1gXd1+5HnJXkW3BS51KYohYPujSfFu/6oBukZa1tmjB/
BV2ramHpzddOEJ4forFOKIb+zKu8OCazAzRG2edUZGVDPz6g2Iz3bAeCD7fz
OuJioe8nLrFj7N6ATO/2GX+FUOgUYuFVg5A2IJz0U7BtpUF/STOq7fPmgdi8
NO/rA8iXPU72mja0AF1KSh1f5Dr0TD4nO1jnNchRZ8lmPL6B+o+qSuX+pCZg
pzKvSRq+C33zGTH2DelGELAv4DNxxyPoTokkjcDf6sGsMcUteyIF+q5HLg5z
YWywasqTUSjMg278TN1vt3oNyFBxMKGVFUEXqLTdeahaBbJJsVn1hHLoBJ6c
RCbpJWhvdpjWeFKD9v/1crW1VSkYINNfSFlzoXN/2sGzrSgBBkZrhiyXVujH
TGJCvaaKgf2wkcem4XboEfIhN+lJRcBtZla9i90N3fPjQq15GhM4srkZ5wj9
0A3PhHzZIsYEao3U98vufOhj0mrx5PRC8HOOQbl6zxD0ZJY8I4dSCJJXGx+X
fEZ5KNHWsY0sWwioclGkShnUPxM1g6UcZxjAUrs8kK6D+qeW7fYxnW4GuBmm
bJasi/Kc+0bmnnUDA7jKE2SF2u9RXa/hbu2oZgD6gte94kOorwZePZ5tXsEA
114qfz1ige6dK7TnxOwyBnj9yunXatMP0FemjuBcShlgiCl3YPQAqrvpBZ6i
zIYXNItFJKtNQ8+6YxJvveGdsb3p/nh0D0ZzBpOFLAb4MkLVPySK+rbMKQth
6GEG4NzKShPMIvfNI2g+tSkA55Ps3ZJZqA+whz3CfhDkgUCy+84KKurzF6Ne
ROSwUsEfPjzbxXbkjCzit/dAldv/3gP/AnRbRxQ=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKpBiaUtRKM8kjhkleonsaNhbFJNJnmTtWqQdsWsJXqI
XliL0chr9NAY1sQ0cjHeYkReifGMyGg8ok5Y/XNvZ+8595/Puef87u/7/d7v
vZoetOPeq6WkpCgrU3plGl41Wh4BgYdsl7+NKczE+NsYwiQV5HvGRgzMbB/L
QeEN8rjT7QezkljYgvJMxNSvyKXYzapnQvIwuaHkyKB0MfREpaiirRX5mHry
omFf1CT0AyU+YuIgByMN7/Nmm3yAviH22c2MLwVYAEHa8n32OHR1NW41I+hf
jN4yxrP8OAZdq/ohnurGxRamT2wtNRiFrjk16l8pX4JxZI1LAs6OQL/5Z5Xs
kj8fC4uQ579uGILOwsnQvQ8DzE7TetQ5fxB6+jurQF9RBabuNkB1Xou8MEbS
cuV6FSZX4nDbs3sAul0nyW3HvlpsDvfYJtQIrXeoUa5t5tZj6icc4/Ey6Ltt
s1u4N7obMXrw+nDSqWHoXayrWtWuTZh6Y5Of7gLav36UJQ7v04z9bV+kJZKg
/7Xp3O218XMzViYaUR32QHFjbmSdM1kjxNzweUwXPIp/roSUsIXZjIn5FslP
M1EeH/7lVegkbML0DQWGOzUk0FPrUjcvp73E6DX2SkPu09BFLWZVn8YbMNnF
0jXUxBmU97Pz+6U96zDZVerawdWzqH6IoYMzy1UYRfNakYFwDnpxrcudUkk5
dspD/W1TyifoEz44QUpXMfZIvCtQ0XAeumzsma7Q6Rws5pofPuMf5MURXm95
lbFAaVhlnlOLfO1CRIIPuxA0uF4wN/rOO/onSBdNK8A2W2Yc6z7yJkKF7N3E
OiBOtmiwoXy3XlNkJlMjBIkOKQ3kabTPk8s3OdKJbYDMo408oSC/eixtdEzc
Abr4tkrtkeh/Bx9NxgbldoOj94mruZdRfHbqVk8n9PcA/RT87XodFM+jBa28
zQ96wQ6ribByd5SXKEniAJnTBzCBJ7iTic6dkZHjbIGqCPQ5vXmcbIXqIXRd
nN2h+T5wft3SxZ7XqK5w4cXjU9Q+wNL+ie7dieqZRfkY6OTYC7qO+Ivr3d9C
ly89FE1r7QHZcpXubr+3Qw9w+gFnJ/8GOOidj1LTEUJXENGSPO50AGbW0qpR
6xfQdcpm5l59fQ2iH4drLRsUQn/iyyuMz2wDdbHUHH5WNvQjvWqNeJ9WIH5/
LbctMQH6bqs5QbzTK5Dp1zoZpBoBnWyVf8k4vAUsjAWqOjbToPNpppXdfit5
zGX6hfQin/M+1mVR1wR2kdOqRFIh0LNE1dlhei9BDoGrlPEgEjpBU6N0d2oD
cNKY1iYO3IAufVJGEKlQD4L1gz9bbboH3TWFqHX5lxogNiN7Zo+mQd9yz91Z
EiUAixZCRdX8XOhmTwiBWwkVIEPD2ZxWUgBdrNFy/a5mGcgmJmTVGPCg7xEq
y2USn4O2RucJrYcVaP9fL5Tb2xWDPhL92Ub7Wui1P24SOvKLgInpkgnXvRn6
YfP4CN/xQkAdMPVeNdAKPUYl/Ao9tQB4Tk4R2gUd0H0+zFRaMznARVCbcdqg
B7rJyfAva2Q4YHs95d0nLxH0YYXtSaT0fLAnx5hH6OyHzuCqsHPI+YCxWP+g
6DOqQ7mWtnUkpXxAUY4lliqi/pmiHbbRZZINbHV5l+l6qH/qOK4f1utggytR
2ywZu1Cd171SvGVfxwYeKgZK87rv0LlewkVvKmcD+ozvrcL9qK+GXDqSbc1n
gz+eb/t60AbdO8G0p1bZJWzw8oXrz+UW76EvjB/EuRezQT9Hee/QXnTuJmaE
aoorntcoE8PYPoHyct08yX7F2xK60oPw6B6Mq+5jzHPZ4MsgxWi/NOrbisdt
5iMOsEFVdBZTPIU8INdA+5FDHqCmUj0ZXNQHBAPeURvEuSCU5LWZT0F9/lzs
s5gc7n3wm7/QcbYVOTvL6tt7oMzzf++B/wCGl7Bx
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCNMojiUNWqa7E0jA2qSaTvMla5ZF2xawleohe
WOvVyGv00BjWxDRyMd5iRF6J8SYy8oo6YfXPvZ2959x/Puee87u/7/d7v/eq
uvqe8FgrIiJCWZ2iq1P3mt7KMPQ/bLXybUyB857fxgiYLiff19dLAUb7GbYy
b7HHnGk7lJnAAIvys2FTv2IXYTYpng3KBZKDieEBaULk8XIRhdvK84By4pJu
b8Qk8oPFnkKLARYgDe33YBp8QL4p+vmt9C/5wI8oavo+axy5shK7KiXgX0Br
HuOYfhxDrlb1iEB1ZoPFmZPbSnRGkatOjfpUSBUDloR+sd+5YeS3/qyUWPbh
gpAwKe6b+kHkDDFxmscRCKxVzUcd8gaQp42Y+XsJyoGycz/VYT32gqjp5qs3
KoFkse0dt65+5NYdJOed+2vAvNgTy2A9vN62Wr6miV0HlE/axRLE8Xdb57ay
b3Y1AFrgxlDS6SHknYxralVOjUC5odFbcxHvXzvCVIzg2QT+tilUE0zj/7Xs
2OMu/bkJlAqGFYdccdzo0ozzBuv4wJmQS3ck4PjnTJPittKbgJBrkvgsA+fx
0V/uBfb8RqCty9PdpTKNPLk2ectK6itAq7aRG3SZQS5oNqr8NF4PJJZK1lHj
Z3Hezy0cEHWrBRJrlNUDq+Zw/VgED8yuVAKK6vVCHf488qIax7sl02XgtKvy
u8akT8gnPMV4SZ1F4LFwt7+s7gJyieizncEz2SDqujch/R/sRWHu7zgV0VBu
SGGBVYN9/WJYnCezANY7XTTW+87b+yZIlwzL4XYregzjAfZGYrnEvfhaKEw0
qbekfLdeVWAkXs2H8bZJ9eQZvM9TK7dYovGtkMzxHX5KwX7teOromLAddnKt
5NrC8f8OPJ6MDsjpgsceWKxlX8Hx2aVZNRPX1w21kwh36jRwPI/lt3C2POyB
O80mQspccF4ipuP7yaxeCHhu8G4GPnd6enZz+YoC2Gv/9kmiGa6H4A0x1ocX
euGFDcuXut/guhILLRqfovZChvpPNI8OXM8Mykd/e7se2HnUR1jn8g65VMnh
SN+WbpglWeHi/Hsbcj/7H8Sspd5CW60LEUoafOQyAt8E17vtkJ65vGbU/CVy
jdLZ+ddf38DIJ6FqKzoFyJ96cQpiM1phbTQ1m5uZhfxoj1IDwbMFCt9fz2mN
j0O+x2yeF2v/GmZ4t0wGKIYhJ5vlXdYPbYaLY/6Kdk2+yLm+hhVd3qt5zKF7
B/Vgn/c43mlS2wh3k1MrBSJByDMFVVkhWq9gNpEtl/4wHDlRVaVkT3I9tFeZ
Ubfov4lc9JQ4L1ymDgZqB34223wfuVOShdqVX6qh0IjsljWainzrfReH6Qge
XDLhyyrm5SA3ekr030Ysh+kqDsa+xfnIhSrNN+6plsIsi7jMah0O8r18eckM
ixewtcFhQu1ROd7/14tlNtZFsJdEey5tU4O85sfNfDtuITQwXDZguzQhP2Ic
G+Y1XgCp/YYea/pbkEcphF6lJedDt8kpYhuvHbnnh9kKczoLOvJq0s/odCM3
OBX6ZZ04C+6oo4x8chcgH5LZkUBKy4N7s/U5xI4+5ClsBWY2OQ+mLNU9LPyM
61CyuXUDSS4PUuSjLUpkcf9MUg+RdpxkQitNzhWaFu6fGnYbh7TamfBqxHbT
lN24zmtfy962qWVCVwUduQXNEXyul8UiN5cxIW3W63bBAdxXgy4fzTLnMuEf
L7Z/PWSJ751A32dmWcVM+Oql089lJu+RL44fEnMpYsI+lvy+wX343E3M8pVk
Vz23QTwqZccEzssN4wSbVW+N60wLIOB7MKaqN2WBzYRfBih6B0Rx35Y9YbkQ
dpAJKyMz6cIp7H45OuqPbXMhNZnqlsLGfYDX7xGxSZgDg0nuW7gU3OfPRz+P
ymY/gL/58O3mWrAzM82+vQdK3f73HvgPMaQZgw==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCNMojiUNWqa7E0nhsUk0meZO1yiPtillL9BC9
sNarkdfooTGsiWnkYrzFiLwS45lXRuMRdcLqn3s7e8+5/3zOPed3f9/v937v
VXXzO+G5VkREhLw6RVen7jW9lREYcNhq5duYBinJ38Y4EFbY3NfXSwVG++l2
Mm+xx55pP5SVSAeL8rPh079iF2E0K54NzgOSQ0kRgekC5AlykUXbKvKBctKS
bl/kFPKDJV4Ci0EmIA3v92QYfEC+Keb5rYwvBcCfKGo6nj2BXFmJVZ0a+C+g
toyxTT+OIVerfkSguLDA4szJbaU6o8hVp0d9K6VKAFNCv8T/3AjyW39WSSz7
ckBouBTnTcMQcrqYONXzCATWquajjvmDyNPfmwV48yuAsssAxXE99sJoYcvV
G1VAssTujnv3AHLrTpLLzv21YF7siWWIHl5vVyNf28yqB8on7eMI4vi7bXNb
WTe7GwE1aGMY6fQw8i76NbVq5yag3Njko7mI968daSpG8GoGf9sWqfGF+H8t
O/d4SH9uBmX8EcVhNxw3mjT9vME6HnAh5NGcCDj+uUJS/FZaMxBwTJKeZeI8
PvrLo9CB1wS0dbm6u1SEyFPqUraspL0C1BpbuSHXGeT8FqOqTxMNQGKpdB0l
YRbn/dzCAVH3OiCxRlk9qHoO149FyODsShUgq14v0uHNIy+udbpbKiwHp92U
3zUlf0I+6SXGTe4qBo8FuwNkdReQS8Sc7QqZyQHR130IGf9gLw73eMeujIFy
wwoLzFrs6xfD470YhbDB+aKx3nfe0T9JumRYAbdb0WLpD7A3ESsk7iXUQUGS
SYMl+bv1qnwj8RoeTLBLbrCZwfs8tXKLKZrQBm3YfiNPydivHU8bHRN0wC6O
lVx7BP7fwcdTMYG53fDYA4u1rCs4Prs0q2fi+3ugdjLhTr0Gjuexglb2loe9
cKfZZGi5K85LpDBhwIbZBwHXHd7NxOdOT89+rkCRD/sc3j5JMsP1ELIh1vrw
Qh+8sGH5Us8bXFdiYcUT05Q+SFf/ierZieuZTv4Y4GDfC7uO+grqXd8hlyo9
HOXX2gOzJStdXX5vR+7v8IOYtdRbaKd1IVJJg4dchu+X6Ha3A9KylteMmr9E
rlE2O//66xsY9SRMbUWnEPlTb3ZhXGYbrIuh5HCyspEf7VVqJHi1QsH49dy2
hHjke8zmuXEOr2GmT+tUoGI4chuz/Mv6YS1wcSxA0b7ZDznHz7Cy22c1j7k0
n+Be7POex7tM6prgbpu0Kr5IMPIsfnV2qNYrmENkyWU8jEBOVFUp3ZPSAB1U
ZtQtBm4iFz0lzo2QqYdB2kGfzTbfR+6cbKF25ZcaKDCycc8eTUO+9b6rozCS
C5dMeLKK+bnIjZ4SA7YRK2CGiqOxX0kBcoFKy417qmUw2yI+q0aHjXwvT14y
0+IFbGt0nFR7VIH3//Viua11MewjUZ9L29Yir/1xM8+eUwQNDJcNWK7NyI8Y
x4V7TxRCyoCh55qBVuTRCmFXqSkF0H1qmtjO7UDu9WG20pzGhE7c2owzOj3I
DU6FfVknzoQ76snvP3nwkQ/L7EgkpefDvTn6bGJnP/JUlgIjxyYfpi7VPyz6
jOtQsqVtA0kuH5LlYyxKZXH/TFYPlXaaYkArTfYVqhbunxr2G4e1OhjwauR2
09TduM7rXsvetq1jQDcFHbkFzff4XC+LRW0uZ0DqrPftwgO4rwZfPpptzmHA
P15s/3rIEt87QX7PzLJLGPDVS+efy03GkS9OHBJzLWbAfqb8vqF9+NxNzvKU
ZFc9r1E8OnXHJM7LDeNE21Vvi+9KDyTgezC2ui91gcWAXwbJegdEcd+WPWG5
EH6QAauismiCaez+uTrqj+3yICWF4p7Kwn2AO+AZuUmQC0NIHls4ZNznz8c8
j85hPYC/+fLs51qxM7LMvr0Hytz/9x74D9yigoY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlRDWIWNpCRHkkccgq1ZXGjoaxSTWRvMla5ZF2xawleohe
WOvVCGP00HisCY1cjPdrRF6J8YzIaDyiTlj9c29n7zn3n8+55/zu7/v93u+9
qq6+JzzWioiIUFen6OrUu6a/Mgr9D1uufBvToLnp2/gAhBWU+wb6KcB4P9NG
5g32mDMdhzITmGBRfjZs+lfsIqwWxbNBOUByODE8IE2APF4uonBbRS5QTlzS
64+YQn6w2FNAGsoD5JH9HizDD8g3RT+/lf4lH/ipiZq9Z0wgV1ZiV6cE/Ato
reMlZh/HkatXPyLYO7PB4szJbaW6Y8hVp8d8KqWKQZ6EQbHfuVHkt/6sklj2
4YCQMCnO64Zh5EwxcZrHEQisVM3HHHKHkKe9I/p78SuAsvOgvcN67AVRwtar
N6qAZLHNHbeeQeRWXWTnnftrwbzYE4tgfbzepka+toVdD5RP2sYSxPF32+e2
sm/2NAJa4MZQ8ukR5N3Ma+rVTs1AubHZW2sR718nwkyM4NkC/rYuVOcL8f9a
dO1xl/7cAsr4o4ojrjhudGnmecN1POBMyKE7EnD8s4XkuK30FiDgmCY+y8B5
fPSXe4Edrxno6HH1dqkIkSfXJW9ZSW0CtBpruWGXGeT8VuOqTxMNQGKpdJ19
/CzO+7mFA6JudUBijbJGYPUcrh9S8NDsShWgql4v1OXNIy+qdbxbKiwHp12V
3zYnfUI+6SnGTeouAo8Fu/1l9RaQS0Sf7Q6eyQJR170J6f9gLwpzf1tSGQ3l
RhQW8mqxr18Mi/NkFcAGp4sm+t9558Ak+ZJRBdxuSY9hPsDerFYhcS++DgoS
TRssqN+tV+Ubi9fwYLxNUgNlBu/z1MqtPNH4dkgp8R19SsV+7Xjq2LigE3Zz
LOU6wvH/Dj2eig7I7oHHHpDWsq/g+OzSqp6JG+iFOkmEO/WaOJ7H8ttKtjzs
gzuJkyHlLjgvEcL4QUpePwRcN3g3A587fX3buXxFPuy3e/MkkYjrIXhDjNXh
hX54YcPypd7XuK7EQosmpu37IVPjJ5pHF65nJvWjv51tH+w+6iOod3mLXKr0
cKRvWy9kSFa6OP/egdzP7gcxK6k30Eb7QoSSJg+5DN83wfVuJ6RnLq8ZM3+J
XLNsdv7V19cw8kmo+opuAfKnXiUFsRntsC7aPouTyUB+tE+pkeDZBgXvr2e3
x8ch30Oc58bavYIZ3m1TAYphyCnE3MsGoa1wcdxf0bbFFznH16iyx3s1j9l0
76A+7PMex7tN65rhbkpqFV8kCHkmv5oRot0Es9TYcukPw5GrqaqU7klugHYq
MxqkwZvIRU+Jc8Nl6mGgTuBn4ub7yJ2SSOpXfqmBAmOKG2MsFfnW+y4Owggu
XDLlySrmZiM3fqrmv02tAqarOJj4FucjF6i03rinWgYZpLjMGt0S5Ht58pIZ
pBewvdFhUv1RBd7/14vl1lZFsJ9Mey5tXYu89sfNPFtOITQ0WjZku7QgP2IS
G+Y1UQDtB4081gy2IY9SCL1KS86HblPTah3cTuSeH2Yrzel50JFbm35Gtxe5
4anQL+vE8+COeuq7T+585CMyOxLIablwb5ZBiVrXAPIUtgIri5ILU5bqHxZ+
xnUo2dq+gSyXC6ny0aRSWdw/kzRCpB2nWNBSq+QKTRv3T03bjSPanSx4NWK7
WcpuXOd1r2RvW9exoKuCrtyC1jt8rpfFIjeXsyBt1ut2wQHcV4MuH2WYc1jw
jxfbvx6ywPdOoO8zIqOYBZteOv1cbvoe+eLEITGXIhYcyJPfN7wPn7vJWZ6S
7KrnNIpHpeyYxHm5YZJgvertcd1pAQR8D8ZU96cssFnwyxBV/4Ao7tuyJywW
wg6yYFVkJl0wjd0vW1fjsU0OtE+2d0th4z7AHfSI2CTIhsFk9y0cKu7z56Of
R2WxH8DffHi2c23YWZnEb++BMrf/vQf+A4ev64k=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHCtE9UgYmkL0SiPJA5ZPX/S2NEwNqkmkjdZqwZpV8xaGj1E
L6z1aoQxemgMa2IauRhvMSKvxHhGZDQeUSes9o97O3vPuf98zj3nd3/f7/d+
79X2pB7z+U5KSoqyMqVXpvEVk+UREHTQdvnrmMKk/hsfMEkF+a6pSRpmsYfl
oPQaedyp9gPZSSxsQXUmcuoX5FLsZvXToXmY/FByVHCGGHqiCr1oc0U+ppm8
aNxHn4S+v8RXTBzkYKThPT5ss/fQ18c+vZH5uQALxEtbvWOOQ9fU4FanBf+D
0VrGeFYfxqDrVD/AObtzsYXp45tLjUaha0+NBlQqlGAcOdOSwDMj0G/8USW3
FMDHwiMV+K8ahqCzZGRpPocAZqdtPeqSPwg94y0hyE9UgWm6Dzi7rEFeGCNp
uXytCpMvcbjl1T0A3a6T5L5tTy02J/PIJswErXeoUa1t5tZjmscd43Gy6Ltt
s5u417sbMVrIugjSyWHoXawrOtVuTZhmY5O//gLavyHdSgbn24z9ZV+kI5Kg
/7Xp3Omt+KkZKxONqA97orgxFFlnzVYLMXdcHsMVh+KfKyElbGI0Y2K+ZfKT
LJTHB396FzoJmzBDY4Hxdi0J9NS61I3L6S8wWo29ypDHNHRRi0XVx/EGTG6x
dLVz4gzK+5n5vdJedZjcKk3dkOpZVD/EsMGZ5SqMon21yEg4B7241vV2qaQc
O+mp+aYp5SP0CV8ZQUpXMfZQvCNI2Xgeulzs6a6w6Rws5qo/LvNv5MWR3m94
lbFAZVhtnlOLfM1CZIIvuxA0uJ3fZ/KNd/RPkC6YV4Attow41j3kTfgKuTuJ
dUCcbNlgQ/lmvbbIQrZGCBIdUhrI02ifJ5ZvcKQT2wCZRx15TEF+5Wj66Ji4
A3TxbVXao9D/Dj6cjA3O7QZH7hG/415C8dmuXz2d0N8DDFNwt+r1UDyPFLTy
Nt7vBdsIE+HlHigvdEniAJnTBzCBF7idhc6diYnjbIG6CPQ5vX6UTED1ELY2
zu7gfB84t3bpQs8rVFcyEcXjU859gKX7I82nE9Uzi/IhyMmxF3QdDhDXe7yB
rlB6MJra2gOY8pUe7r+1Qw90+l7GTuE1cDA4R9fQE0JXElGTPG93AEb20qpR
6+fQ9cpm5l5+eQWiH0XoLBsVQn/sxyuMz2oDdbHOOfxsJvTDvRqNON9WIH53
NbctMQH6TsKcIN7pJcjyb50MVo+ETibkXzSNaAELY0Hqjs1U6HyqeWW3/0oe
cxn+ob3I53yOdlnWNYEd5PQqkVQo9GxRNTPc4AXIwXNVMu9HQcdra5XuTG0A
TlrTusSB69ClT8gKopTqQYhhyCfChrvQ3VKIOpd+rgFiC7IXczQd+qa7Hi4S
ugAsWgqV1fNzoVs8xgdtxleATC2XfdSSAuhirZZrd7TLAJOYkF1jxIO+S6gq
n0V8BtoaXSZ0HlSg/X85X25vVwz6SLSniva10Gt/2CB05BcBM/MlM65HM/RD
++Ij/cYLgfOAuc+qgVboMWoRl2mpBcBrcgrfLuiA7vt+ptKawQGugtrMU0Y9
0M1ORHxeLcsBW+spbz96i6APK21NImXkg105pjx8Zz/0NK4aO4ecD9IW6+8X
fUJ1KN/Stpakkg8oqrHEUmXUP1N0wxVdJ9nAVp93iWaA+qee47phgw42uEzf
YpW2A9V53Uvlm/Z1bOCpZqQyr/8WneslmegN5WxAm/G7WbgX9dXQi4eZ1nw2
+P3Zli8HbNC9E0J9QmCWsMGL524/lVu+g74wfkDGo5gN+jmqu4d2o3M3MSPU
UF7xvEbZmLStEygv1/Yl2a94W0JXRjAO3YNx1X1p81w2+DxIMdkrjfq28jGb
+cj9bFAVnc0QTyEPzDXSfeiQB5xTnb3SuKgPCAZ86OvFuSCM5L2RT0F9/mzs
05gc7j3wa4DQcbYVOTub8PU9UOb1v/fAv3G1TIc=
            "]]},
          Annotation[#, "Charting`Private`Tag$5469#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      SphericalRegion->True,
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& },
      ViewAngle->0.3915709384105045,
      ViewPoint->{1.7488541020523958`, -2.255415880209155, 
       1.8178582279800783`},
      ViewVertical->{0.025725609186045877`, -0.043846485746769075`, 
       0.9987070034397801}], {587.25, -189.}, ImageScaled[{0.5, 0.5}], {360., 360.},
     
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx03HlUTV//wPEUqRBRoiQZIoXMSZxMiQghIRqkiUyZmggpZSpDUjQQadQ8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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQXUFdX3hu+X3PvdmBvYCSomomIHISC2oCAGqISBgIiKLYKIgKIoKoKB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               "]],
              Annotation[#, "Charting`Private`Tag$5499#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJzs3GdQFG3XL3qCiIACioGkgJglKIKKCktFCYKISlARQZCgEkXJiiBJkiAi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          "]], {}}, {GraphicsComplex3DBox[CompressedData["
1:eJxc13c41e//wHFZoUioKIqohEoIFW6roaElktFEpEFCQlZClFFW9t7Zm5tj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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQeUFFXThmd32Z2ZnRzMWRAwIKggBhQREBOKCCaCAuYAImZFkglREbOg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               "]],
              Annotation[#, "Charting`Private`Tag$5520#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJw0mnk0lP/7h0nSIoS0KVqkQlTIUu5kzb4LFSEia2RLG1FRSpG1RIiQJTvj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          
          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k0VV+8AHBzQolClESUKEOS2RFSNEuUSDKUzCVjZgpFIfzMs0sp8xg2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            "]], Line3DBox[CompressedData["
1:eJxd1Xs01GkYB/DJJaTEhFWIkqiWRDa5vZqkWq1iJdGNyWSU2LQb2tHsONkt
15TUqJVGEUKYDF1expCMNIbGKJdMRsa1GmHWZld/7Pues79z3n8+53d5f895
3u+zIjjCJ0SJQCB4zy3luWX1lktdk0FzXTv7z9w1DpjXv15VQDdQReoxjwXe
y9UFGbnYp7NXV7C080FkV4qbvHQMOVEx9HFdew5QS9g739p2FPnyyANl7nk0
IKaNBE9FDiOf8GK5EplF0HnmPqHUbRC5zgPpQfeGahh5zyRBTyJFnhv+/NTd
6VqYa7RUVTz8DvnhxXEE/dA6KFIzZbKMsF9dtiXFL4IHeSaqZSt8JMjtxFbG
zWb1cHuQrJtwtg/5rABoCWLqIaMgRZR27y3y9LXd/b30epit6GHvqe9FnhIx
cfOPnfVwtdXt84bbe5BTPey4wTIebHMpjXsj70J+5eQBQvQRHjz9qugyr/YN
cpXjGbFV1+tgzJdAUxLnNfKNP6XY6TC58Ae+m2KYiP0cl3S/K2quDkHUZebj
ncjdqGJVa90aSFEAX6o/vr9ws4Z3iuUTuMehMUruj7+b5+3poRlQDTmV0ek3
RvE+Hx9qfHrIkgOfZwWG5Ljj/z0cek1nOKESZqZq3lcyxnXTaLl23GmSA70Y
Tn2GXFznO+RwsZ70MeR87qNGs/qRD/YVKI1pcaF1W9OujLYB5OEXV77ZvvwZ
lCi+u3RjBvcDe+GshuexF/CxNF9F0DeE/Ncmh7GyKCE0z3BKyA8aQU6gHP65
47QIKq/ZRvQm4T5cdMnQxezVa6iRVJiefxG78Yx9NbOiFx7a37It0Qa7hZpp
eK6NBFrsHZKNWuH3B/zoM/1hRT+cpYtqGwrwfmRT6hTtCin8Ky0+u+kW3j+l
/6ZzhWgA0sofxpF6cD9vTK7MG97zHloGfxM7W4HrxoCFLI7Re6hbnKkR1I37
6qHLSeUn9gPQpsvDsi5UjNxEbr51gN0PScWuBoWdQuRZjSpTHckSWJDa0hVs
1Yx8i8qRs57f9kJFkZEs9lMdcr3EbLujZ8VQxnauqN35CPf/aJL3WR0hNCN2
F66llSE3VJeTiZPPoCuDbnHOMh+5JaR+CCm5A+PkfY4RtenIQ9erTaxbwADG
ZirMuPgE5GEhXpuDtuSBgnJ+TDSfjtzlDnNR6vQDQFEUtYfNPfefx9cwJqOk
D8HHqk+q7InfkRvQU0mMnEfAdp9093FJGvLPW/3/eb68BoSwxmQaSpnIyWnZ
RppUHvhyrDxCNJ+Fc2N9eseqeY1gYRfbWj2+ELmzmwU3eD8f6BmrCQeJ5chP
riq+4qHaAi5LbZgyjSrktg8SNwgtBKA0pp+ltawGn69bvgbyTa2g77I4iNbH
Q17F13TVy2kFfkPaSbtPPUM+MvVSYa9oBZyedt0ZpybkqmHS9TKSEGSdeU3P
jH+B83lEcrstSgio5CXnyecFOG+3Rer3XBSCS/XJnXIX3Cd39/F3L0wSAv13
Ine/2TbkjY4xXTNnhECQTFSrLH+Fc0CrJGLQSwg++udOgIMduP5FsZSSBUKw
4EiRieoSnEu+hsRGYkkr2HiBdNStGOdSWECW59VmARDVLb1V+Us38r+PVl/P
M38JOOts946b4RzOKPq+IcClGUwuJg/dpOH8qQprIlNljcCZbV+j34DPUcMg
faVyKA+QO1177N1w/mSF74gOMXkK+GyrzoNSfB43HXCgeNeWAl7GCfr4Enx+
d7U7Sih+ETDwxG8KB388v3wctblKrdnwqoG76c4pnA8b5l3404WRB63981dl
UfB89J3R2pFIyoUm2nwaPwXP04Ynkq/z9ynpf/P3XxPRE/E=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1X001FkYB/DBTiqtNBopNNqko5aYqHaKK1TslneSslvIS/KSlJeaPRNl
exntbGWE3QbjPUISlXUZM+M1mUkaGlOGKSOlljArtfXPvefsPef+8/nj9zv3
ee7zvasCoz0PqxMIBI8vW+PLNn/BCzdLp9ut+/T5yxoHWZlfVxtYuv8bxU41
Lng1Mb87PR/7DMf0DlenGMRIL9tPVL5FTlKNvl/fkws0U33mWVDfIF8Zc+C2
UxEdSOhjgdMxr5FPunLtSFllcNtsOaHSfgT5kipFgJPwPowpoaSS5Qrk+ZFt
sYUzTTDfcDlR8noIucccnaAX1gzJmsZZXEPsZ5OaTHyj+TCqi1O+ylOO3MRc
J751tQCaJs3dJZwaRG59M9OrOVEAdzS0uLJKXiAPyEkvaGIIYIxGpqWr4Dly
5sC/x/e4CGChVkKG3i4Zcv/5ugnOI3xYKBnNlk9Ike/rS5H0e/Ohe0eDist7
hrxUJlLRQ5vhQY/uZPf6fuQJxv2n9+ryYH8N03zOCLudWljqRHAjZM1cF14k
YucHrwo+H1kPH1A3eBEZ2MVh9rdk22vhjUHX89JM/F+FpeGx8uYq+OD0/dhA
3wHky2pFA//4FcPFxWYuL9/h8yZSK9i71DkwaHcxv7QA142Q7F47x0qHjh8q
4jqZuP4fJdPsrnPpUKgU5kYJcB/FZr0GU105cNNb/+nyUNx3/xWU6Pbkckgj
b/IhL8L3xI+5LiIiuA5S4lTq24/iezWVA74fbuHBSsdqCuEAvp8xjvmzPdfa
obHOlRN5Lu+Qb0wimssVItgn+XPkVBr2IY7EIN7nKRw6LnO0i8MO59ihDd1S
KOWRT5aO4e+7t/eqvep8AUPKrXKH3fD932X9hH/1mRz6ZeQxaFpjyPNG1lvb
pQ7DnweMOG/k+LyxEZdoUSkKKHm5lpK2CdeH8XG23V+ogKVG8izBIVzneNsG
w0JnBTy2r63q1UbcR8YSZSlnxTBkeYkZunU9eB7zT0hVlnLo28KauhDXhXzA
41fP1w9l8N2eDFOXNQLkOiEpO5heEvhDlWJ268F65BE8fX6bhhhaztCotW9u
4z76bF9sNt4CB5UFVu6ni5F7kko/RZYUQOD/vNXi/RXk17WhgQE5Gcg4Q1u2
VqTi/p5dQPR2KAKpeXSbgn4GctMh9mTJTBU4f9f6Tsu3ychpkynLTijugnbL
5aZ9k78h12f87pCc+wBQ9yrcIuQs5B8c/T63rWwEh7lvlQvUM5AHsTiGWuF8
MBdaHd07j4ucveHKUxO1VrBIWmMxP+Um8m32a3mB+zoA2UhTPEKqRh5lcuva
TmIXuKqwzFIuuIecWnXJSry2G1QmDnO1VzQir8/x1p/YLAKDVyWH6IN85Pc6
tOzIuSLgO6rDdIttQT42/UhloxKBOlnP0tmt7ciJRxQblA5ikB3fz8hIeYjz
eUye9/i4GIQH6Z4LOteN83ZHjJ7sohj8IUjrm7AVIy/c2+G2iCkGekO9Tr6f
HiNvpSVKZ+PFoDuNpFlb/QT5L9oV0SOuYvDeL38SBDzF9S9LCqlYKAYLD5ZR
iLp9yL0NSK2kChGwvuAQbH8L59IR/+yf2J3doLd5eU7tSZw/H4PvZxateQTq
1lN9xlfjHE4v+1Hob9sJphYHjf5Fx3Nx70h7ULiyFWyrsWnUE+KcF44wvtMI
44OgPjuZjf0w8uxI54TDlAbQUWPeF6DAc7f5wJYQj6ZKwE8/yhjXxXO6u4cm
D/GNhvuPnlFt8cO55EnT4amLOJCt72TsMo3n3Urtwg3b5CJo4Vdskh2C88F7
Vtv5kkM+pOh00Dsu4zwR/i3/+v42OPzv/f0PQZ4hyw==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Ws01GkcB/BBqFxWE45a5ZJWRblEapLHQValUeMSg1OZXCtExyU726xc
lpJayZFkGLmsO9lx2eYxGVJDMSQiuY0YtxW5rNvWm+c5Z59znjefN8//PP/v
8/1peARQPMUJBALl25b4tvf3v/Ddm0w327e2/m1NA6OD31c7UHTdILQWY4HP
sxtbk7OxL2b89IylkAcCe++az5ZOIScuiWZ0OjKBdIyj1AHDSeQ7A93KrXLp
oIs+4bEQOI58jswyIz4qhKbLRYRS81HkW8qE7laNNTAwXy1GaVCIPPvqq6Cc
RS7MVt0m2TU+hHx9hE5Q9qmH2lLqj1iq2OtNqFmOATx4tlM/T4MyiHzqmf9c
/a4GGO43EEOIGEBubV2aUhHeABWoszmJ+f3IL7i7WzxmNMCe1TXiqYZPyPMZ
MZQNJxrgqITLTYWf+5BXT5Hix0d4sD9S0Xt8thf7Kldw05oHOVaJqlX1PcjZ
O+K5XnvrYUfpRSkH7gfkpmY+PW+vcCHZQPJQgQ523USrTF1dDiQfV185ooH9
Q5wT+XQbG2qN3JNdLsXuExd0cudkCbS1jzmvIsLnxtNM3GipjyF1wkh1+P1H
5OJfmHKkHdFgxX54VeSB78ExJfiN0a+5YLZnJSKZjO8zmio/799cDtzY9pZO
scPImyjS9CMlbBAaeYbUpfMZ+Xgt2zW3uxqYbXx5R8dVhJwQsmebzZ4qMG+S
es0uFefHL6cp+fbuchDbvG6gZvMP8iUdtbB384+BntUne+3oGeQc1Qym/sUM
GFYYPnnG6QvyZ0Fu5jV+tVDl901RFC72a0XLqc2Lr2B/nvT1pDrs7jULRrKh
7bA8fdL1ozX2SsZ+wr9u3bDDJeFrtg8+d5+EnLdpcR+0JyvyZTTxd6r7pteO
5w9A+NS/dj19ArlXkZTnus0QnG45bZ5oh/NPkUu7v09tGCqTBdMFr3GeU5jF
yim7hqGqP/l5Xy7O2w3OGqmMOgQfRFVXX5Z+j9/F2kSwHmcAarf3RhRltSI3
os9XWbr0QWZhb3kUsxF5eMREiK1mF7x+tCo9uOo58uNC3T97v7TBxLuMgHdh
FcgPSQzIPBl5CWeiKhJEQ3nIwfX46vzttTBAsrjA61IGzkPiZqpc1lMY498z
eVA3CedZYlouQzMS6AexxE4JY5Cfn+RoMCxzAeFgB8F7koHcVum8MX+xDBgt
k1qmt0Qi9y3j/BIi/AvwOgNbJL/GIldhJFpEZtYCw3NCu8uD95B/tXRef7Wz
DniypsY2iacgp93LUJXx5YFV74qATikW8od6f7zXEmsCsr2VBzbeKsDv1Fz7
hYcLHyjtkBaMEvH9+GsVP7CWfAOShPqPxjZVIzcsu20g0G4FpeHDLPntdcj/
ZjqozJq0gYGkrov0AR7uDb6MmVJmG3ASKdyxC3qJfGLh7ZLxUhuo6utQXD76
Grmkn1BvzEIA0kI/MFJuteDenhjMag8WAF/a1mhaNM7D3PFA5b54AbjfkNA9
e0yAPOcc3072jgAoD3VaOa214/9ICu9dDhWA1gSiNLviHf5f8iUBo2QBmHHO
ngPuOIcqhTe8SjYLwOYLhWqSW7uRO/xIbCKWtAGjOItL5sW4r/yoaaceNreC
zvptTHYI7qWVSzWpubvfgiodQ8fpXbiXkgtPNlKPNYP5H2iidDru82q/1zTf
sSZgWmlcp9yI+6pxlKEp4cMDtG6zPmNz3FdpV23CPNU4gF+5v9tdiOeOidth
r7PcUsBLvsKY3orfqW0HadDLKQC6Xvlt6bAznmsUksIL8bYM+FDFSv3EAn7v
BmJxT45F5sIDznlaaV54bjosy9vctsiGagp8Ov8unrONzwe/z2WOxf/m8n85
VmIL
            "]], Line3DBox[CompressedData["
1:eJxd1Xs41FkYB/BxL2SF8aTUKDbJxmZ36FGcWdnSRXIJuWyhNGziUbGy0zOk
dltUdpL7usxEWuVWueagGSZTMUOMccvoJ+MuWYm09c85++x5nvPP54/znN/7
vr/v2egf6nJSnkQiuXzeCp/3tleNQSbJDNuty58+rymQnvZldQMdb0Vijxwb
vJld0ZbMwf4+e/MDtuYdENZ7jTZbMolca2F0xrQjF6hcOaJsZjGBfEOYT5l9
AQOIGeP+82FjyN8dYttqpRfBXYv3SCW0EeSrSwlf+6ZqGFZIuUKWEsg5IU/D
8983QI6+npJ4bAj5TAeDpEt/AgOVDNLZ+thLUiQ7joRy4WKcgL3RRYp8YKXz
oXpDHvS8NHeMFD2IPNpAtS8/igdFId9Qrhe+Qm7aTla4yOTBIpWqRAfeAPKC
yYQtTx14kC41S1Lb24+8sGQtTUhwYfl6p7i3s73IL9Jld6XWXJhqnRubwu1B
7pvURDOdb4TVip10f54EecxEuZHucD2UrHMOrrXEflf9uquXRi207nW6k22F
naLfnB+l+wBGUZhqKWLslW9eKUIKB2YuqZ+TM8X3mWfoSJ1IkcC7NGKpkIbv
P2BnbKgH7gEDL0HoqipcB/qpzayzl2tAXWoay6YL11M5ThZFNX8CnLfyO5Vd
cL/Ix3u6QtKaQVwENfyFI+5vIDXJRJHfAvYYeljZT+F5EC1PHqgSCsBB11Qq
vxDPW7WeI6Vnbwuo1N5S6pE4g/vVTT3mU8cDZ9dlGLjKzyIf3bfq0SlhLSBv
kXW3LGM/IJz/xOLkgPH0w4YXrr5DrjIZU616vgxqTy/rJGRiz3PNilN43gwT
3RTydm7Gzj5jqT1cJoIq09bEdzvx+bLo20a7P4phrJBds7sL37Na4h44VtYP
c1tf9tzNw9/FiZfMx0QPwlyXn4j1wlHkh/ePVT7jS2HFzRGlhse4nkdzls2Z
lkOw+DydHfOfvkh6G/KCoRQOmThu6iDEyCMkvked/Qbh8uTjFT80CZG3tujc
GPrQB1MdPaZd2puRh7u3/X7uQxfkWvoREy/qkOtXV+qbEkKYea5/zk9Wjnz8
sHnFg4FmeHNcnFJjVYg83vtXLR9yDTQenn5Lq8pGPi3dTydn3oZ7X4qjZ71Z
yH2k+dRr22LBzGRsjsrq35A7ql+YCLcvAH0br9SylpjIqa7e+sPvS4F7ZWPR
QXIscgMCZkUSj0CWY8qEyRw+Zw3zul1sbg2w8CCcfpbeQD632/PT0w314CR7
UrZSPgV5wI1sfbUgLvh4qjy0U5mN/Jb5n11Gcnyg3vvQbMWlv5Hvohk3+h8V
APJ6FdGIFq7PGaP7N/covQAs4tt02coq5Bal8dtFxm2gJOo1W2NtPfLaHLc1
s1ZCMMgS+zEGucirBGq25FwhcB/VTHAKx/0an29doC4IQWV/h87izhbkSsGE
ucxOBDIiJcyUS89xbo9L89rPikBQgPblgMttOId/DNPt/0MEkniJ3bM2IuT5
HgIn9QQR0B3qtHdfbkfOt47qXYwUgbZELZWK8pfIj2kUh44cEoEZT8474NuF
6190IbBYVQRUjxdRlLS7kbut0+JrFQvB91ftTtDu47wK9so4cOtZG+h8opdT
EdGHfOlEdVrB162g0tTiyJQhnv/kov1NXjbPwD9fBYxmMXCeVwW3BATJ+GDX
Q2q9bhPOq6YR5iYFOhcEdNv2U2mvkWeEOPxyklIHBA+3dfsS+L+z8tkR6NxQ
ArjJp5lT2jjHDnZYSwPdQ6H36ZiFHZ44x1ysNRvlhdnw1hp7g33z48i3y139
yya2AJp53jHKCMTvptuihkO8HQdSNAUMwTWcD02PpV/e5Tq7/73L/wLPfC75

            "]], Line3DBox[CompressedData["
1:eJxd1Xs4lFkcB/ChHdfWyoiEsJRnt0dF65LbmUezsrooi6ZilVvYMMtGqimX
sjty2ywVbYjNZWlEyi1HzIwpqplxF2KYchm3hoZVbO0f5+yz7/Ocfz7P+5z3
vOec3/dn4BPm6i9LIBBcP441H4fJUFPQVxl0+69XVj8+M4Dw7zME1I99JnKU
yQdvJAq8jALsizlb7uerFgFafwpZUj6NXG1pYm5rRx6QT3CX22Y2hXwTzbOC
UkgHPXSxj5Q2iXz+QL69WlYptF0uI5STx5CvuyfyonBqIa1YL2G9UIS8IORJ
+J3Fx7BAR4vYMzmCXPk5naAR2Ax1ifpZ+TrYV66nqLqHsWAlU/e2gasQ+dTG
S+MNhmyoUqB5iHBuGLlxGZVwO5oNmZUukynFQ8hPBwefDo9hwz3q5Gt72K+Q
a17Zn1rhxIYcijpTcc8g8uCLr0/5i1gwcGTeZkHSj5z0eI4YYcGC9RLnbjHr
JfLzoi2eyyNNcLwoVnGG04d8NLnaPreiEZZxj2e9s8besTvHxh/UQW5bXY0J
GXu/tm5ic3EF1LrYYFL9Brt3R2naDzY5UG1KerNtN16P/1sjLeHgVZBsvyzP
DMTrryw0YpzYWQmccpUWJL14H85rH9y3zG4ETZ8nudCU8T6vsW1/JS/mAKv6
ibjwHHxeMazYIpJmG7C61TmQWo/P96A4lBipyAPOpqaatxhi5OKh5OyfJnig
YLpigb9rFnkLo/7IrhAeuMtX6UlTfIucrMTJu1DSBlIM3PZOpkuQX/9A9bAI
YgNGp1/iVO48vg+/Rsm9WawCBh7DPz+wXEA+sV/hXFRJJnxyc1j3qOt//PQE
P5fYBB3LCrvdB/A88QGrxrbGPFhKCY0LmsLf9ShMioC8Lujdzg+gXMDrvO8j
8/zQdD8sdlaKeu2H/2uMS1uwaR2C7JGX0Vs5uC5EK5Pv5RyFUL85Yc7n/Gvk
iaEebbMvhXBzmNNmDQd8bxuMzjpoXxLCcouQ0LSbvcgjFUgRPXbDULPdzT3X
XIDfl5Xu7O4agBaAeTLeiYu8+s5qrO1kN3wn1vfctwsiT6Bb68y+4sNzqTe8
vNXvI59uMRlVHWiBpQnSCHi4GHmn/6ML7qQ6aMr4e1NJbw5yT2kf99mNP+GI
KTVqR2g6ckqLo1+daRxgxMkeqzf4BfnDyL6SF5RCQOcmXfWWjcX1fkbiM7t4
Dxh+33IxQyMOOag1XHtG9ABEz62rtVzA82yISXWIy6sDZodFLj8K05Av7Kau
PtnUCPzzp8cVZa8h903L0VEOYoEPJyvDuuTykWduv9ptJMMFa/urtinE/4Xc
lmzc5HOkFazXlReMqVUiDzW6+7sj8TlIF+3IGlesQW5274qpwJgHyqNH81U2
NiKvz3XbILHkg+H0nhP0YRbymlZl+/V5fOAxoZrkEt6C60X6Ysl8iQ+qBzvU
l22eIicGi7aPOwhAdlRfzLX4Zzi3xcLb7RECEORLuux7mYdz+FuaxmCiAPzG
Tu6V2OF7cudwq8vaJAHQGOmieKy0I+daR/cvRwkAL1lN/mFlJ84ZFWbY2AEB
mKMWzAOvbrz/pWcDmEoCoHS8VI9IwvfTTVuNq8bkg28YDn7kuzivgo9m781s
44GuZq3ch5EDyN/71d4o3PwCVG81c58xxLmUUerMOWrXBt594TvxBx3XRU3w
U9+gcS6wrTJv1ODg/OeMxXy5JpAFfHvtB83Jo8izQ5zO+Os1gNYqk14vEc4x
S0+rgEOPywEr41TMDAnn2L4Oa2GARxg8dip2yYqK69fVWrVJlp8DMzdQ9L+T
4nwzlWHcsosrhNuoRUbZAbhvui2rOF1xKIB6qq301hTcZzmPhJ/6coPD//ry
P71ZCys=
            "]], Line3DBox[CompressedData["
1:eJxd1Xs01FkcAHCRx0Z55Oi1FLZRWZRCHdWNGpQZj0pteqBkd7RRm45tGYkp
2jFYjzxOskZ5JK0xmpUad8ZzxmuGrdHkzcSQvGuFxuqfe8/Ze87953N+597f
vff7MD4ffPSispKSkufSVFmamUN3kmTXwvc7KRaXxjjYtfPrGAAjs6UnV1KZ
ILHKei+rELuW/WFT+mg+CC+29MmqGkNuaba11+0NE8yecDmi7fUB+W7t4o97
fr8LArJyOYW575HP8eOnpcF5UMJO8SCEyZHHyg2WWVpwoLB5+Kp02SDy7RrO
STYyLrSbPKMokQ8g79SzKH6ozYOiZLrDLj3sNR9X2vbU8SB5ZBgYuPYjp9xc
UDXcyoczrwPYKrQ+5N1+6pLJXXx4WO0QZ76lF7nn0/Yv7goezHad2hxihV03
2sQzNY0H09O9ju0g9iAvCmtaEbl26fuj606TzncjJ7+gVF+uqoQq6cUSQUkX
crv6VUmrHF/CbeUXXAMdsZMo3/vtdSmHjxMSibVE7FecAgzPNJXCcov2zeZC
7Bpp1c9MffPgrQGjmvRevO+UZ0ftoJgJNCZUCWNUfN5T3VEWHmoccIygNxRn
g+8tLuTfWZIFH2Tcu7Ld3P8d8pdE/aTBU3WAYVZ/VdozhLzEM/ttB70BHI8c
ekZvHkGeXDbvMxfbDG6rEp5c98RxEnQlKzEouAWsk5ZrUKcmkBMXKTfn25rA
C/at1UOpU8jL8vnV0y4CwPW6wMn5NI182lNSOrKcDwyydQrsB2aQ2yrttMy+
XwSOa/zw6bPfR+Tr5xbJ6jaFkKwgHna7hH1nvdUJ96c1MPqbpA2aH/A6wWJa
OlW7FTYZBpuI5vC+dsZqBlRSO2ztIcjj4vF/xjcs47gudkJGBDdHk4rPxTy6
ENeU3wvtTXUvbtAaxXHuM307XaUfZrYKctrf4DjvhHqiH+/2w7Fxzcx+Fn4v
Kvf6WIR1P7w/GXW6OuktcuXQe+otil7YNv6XPdnyH+RpZzIdYh51QdtSf+5u
nQZ8z2y1jhsb38AtRPXo/LV85A2sAf2F8DbISQ2+OXiWgzwrTSJhy4Qw8QTD
Oyj6CfLcEkN2+wEedNcPWWT05iCnD4f+1nGIBd/KTCpItFTkvu9dn7/qS4bx
WgXKfxbG4rjtpUSWmSeAlILkvsDRSOSNNImQPZwL2kVd0QKjW8jlmqmVAZeK
gSnhotWRoDvICS4zllNkNpilJReXlyQgl3k90PEW/A1kByZitPLx/zi5Opxz
1uWBrJ4sW181Jl7nfveqiZRqsF3BYAoOPkbuR3q4rbKnDlRYrx4zOl+KPLXr
2p5QmhDE2n03oHyyHLlhS5FWmLARxNhs6gyLhcjvPG1QSGTNwM7dyLg4qQZ5
3mq1CDNOC9C+FsM2M6vH+WgbOPMuQATIPJf6czNCHCdEA6WZBRHYxgiV+YNm
5JJwJ9IKazHgFV7v6vYXI/f/JVT5FUkMbmQ7E0M2tiE/MPt6h9YxMXBc+Xj9
mgEcP7+WBhjvJYrBRAE9ipb1Gr/7aOhwtakYmIT40zPc2nFeBLYcr24TgW5O
hZ2ujhS522fNvsvWItBEeVAbVoHjNmrTvsGx7Gagb/5kaPgRrmN5Pn7zH35u
BBcquAcbPXC91SEFpCu1CABrH/fb5RDnhe3+TgKpqRbIFfXsT2txHSuwkp4+
9ZwPRN5fXlQxZbh+1lkxU+qfg8Q5lTqJG847VhRr8g/fIhDoPBorD8H9SOri
uIXFjIIeG+WDGWm4f7lfGk94tyYHeiRzWoeMcb+LWJ5x9m5cPlQVeufmUHHd
W9O42YBSmQs3iefKyKm4nz5kPPrafyt/+l///Q+R8Gpp
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs01FkcAPCJpIMySaw36ZToaEJF5G4v2nF2C4ukbN6PPQ0iNlGG7FZa
z6SGozDeU0lJ0ww3M2PyquSVhsnMeNTYJDJEy6z+ufecvefcfz5/3Pv93e/v
+/2a+Ee4BSkQCAS35a24vAcyJfU5F845pi/Jl9ckCAn+vsZAAC2fKNlYBEbW
0/SJ9ditpI+UVNPLgSHbOWLw8yfkv2tKqo5TS8EeS52wUzUTyMfI01d2tdPA
3PCW8ACzj8g1VLYQhcJ4QExRl94sGEfeVWwer0G6AiWL0js2mlLkM7nBL9Sc
6dDceLe2oscY8vKblX5RxpXw4H3pZOWqUeSzAf7Vh3QYcBtZYBEpGsb3LljN
tu68CwWCnuuSWQnySK9AT9jBgKF9up/ottgVvBNOWs1XwS/H65IL8sXICYrx
c3LjCqibT/t7loQ98bLw6RKHDg0Mb2unfxUh97pmQtB1KIJdIvJ68iT2lsw0
62q7Alh1sUn0gIjPqQ10lD3tzIWWVNotxxPYi51MMw4VXIUfDFkuRDH2U8lO
F1M0fWDeji1xPoU4/qzY+03avDtg2o4ZE1oygnwfJ66EUFMH2KtGnZXOv0e+
K6AudD68AbRc8F1s9cPvnyGnGrbbc0BXSWfs2OV/kFeazTW4D/BAVaUeHObh
vFPuDpmZU/lAffUllq3eZ+T6c60qIcN84HBB2TMicQrnayJwwDytGcRpabTO
9E4j98/XI2Q7ccDBPO9tR5RmkAu9zbMoRUxgKqr7kziP/dhmEDqyoQxMZSj/
0ZUpQ36k45VevUshtFLmt9/uxJ4WJxga4jZCSupWVjEDu9w1JdeH3g7N1rDG
zbWwO/kl7UiL6IZfooMUJAb4Xsa+np1nMvvhIVfZDksmjt/GcDaywUIIJ9iy
jfvZ+B1uNXa5KLuIoI5edKwNF9eFrHm/0l0PMSTXGxBH23BewkrTg9wfiGGS
J3Mipw/nd+0mS72+E2LI3a245KotRN4P1XW43iJI6JAVeTF7kY+TGR6nNwmh
rdRb8zDzJfIpIzX23op+qH/G91jqNx5y07CJKNMfeuAj0wi13uNs5Js3KEqN
d76C3gHOctvQWuT0eZU9urpN8IDhAqVwgYbcc21Oz9rP9VAsqoK06mvIFb0O
bH18ogbqrwt6MlmbhLwXrnC3UC+D9tbB1cRticjfU4PX+47QoOP1q8+7Kcn4
ez0bKbEzKXBlgM1SIbiKPGnfzIdo+3hAdVAlFepmI3/g7Hsrs60Y+GjB6LEX
hcgF7p1GWStqgJsl2fSbvAy5CWmlU9fRx+Cmu6rD4Zwa5H7dSxENMSzguirC
hZ78GPkLyZtmKIGA1qZhvfl5A667S4skqbwJWJ28qOjF4yIfaZ8NZ73kgN7B
FJMgfz7uMz4xRk1JXOCRX7t9xLYVeduIIIpjwAPjrKHyt9c6kH8Bdj8/y+YB
Rl5nMVu9E/m6SPP46eU6/ZH/Czf/1Wscz+JDi2aFZtClxpE05Xcj77Bbwxcp
NwO2JTkhJAD/P8YZLSq8jzzg6L37jaPZG+TpC7/pXqrmgf5/xXs8V79FrkWh
8/ScecDzibyHKhAgPy3jiFM7uGBMILqenjyIvLTCaAXXlgvCGPbMcybvcN92
Wfe08l4TGLpXcsOBj/undDBPteI2BKt52c/sw3FdvOsgtb0ls8BZbX7Lpync
/x0TpFGHQ+qAZs5ZLo+O54XbQLVT4WsG+NVuSf+rP647j1E1Kwv6DfDR6fnR
1jO4H/bEPuwfjcmDoaWko3/txfU7tOYcdbsVHULrBP+ELNwPixw6+xLLy2Fu
8093pEw8N+8Jj8niA4sh6f35ca8yPGf1lZe+z+VGxv/m8n+9YM6x
            "]], 
           Line3DBox[CompressedData["
1:eJxV1Xk01FscAPDJ+g7JUji25s2oLC9aHiUNV03P2vJG9SqPBkN6ckqWUpbs
GVvMQ0U0KHuFjCVNl6EosmYi29iylGqQkyc8/XPve/ec+8/nj/u7v+/9LiTn
C7auIgQC4djqFl3dwW/kS/z5vqbjyyur6zNIvf1jTQJbKtF4aToD7FVRFL/Z
8B+Xtfi4VyUXHNxtbCuhiz2f9ZaxtSkPvDPu2mhG+oR8S2CX+F9yOWBlB0/H
q/kjcp62tdTeikxwI3CIc8DhA/Kawbwp98NpoPHnhkyX9knkzbn2JH5nMkg9
KpqyhjqB3Cygh+Y5zwImASbRLdXvkT+5HqKvN8EC364XHs/aNoZckhYze4SU
AmZtDyVR+CPIL2X83X1l+x0Qb5PwUaNrGPlCnEnP2rgs4L5ndF0PCTt5w87F
fVF5QGtNmX1D5RDyu4X7L8sQH4EYIj1HoQD7on8Dwai5FGwxO2ZOEmLPuV1o
UwU5QLbcan9END5f/lcSRVe0EuhyJbS9nPA9HTWE3NOdVcDcAs4r+Y0iP39w
prY0sBocTv5w3GYM/28QsZt+VZ4LyKYcn6DoceRKG6a+X7SqAfOuRaI1cjj+
WaE16ouOtcBQ11Bbaga/19r4TE7HeR7IY7EsJIbx+3au6NvstqgDLfJzZGbI
F+QBDEu5TdF1gMYfYXsnCJEr9hqXeIrUAfYHcVPF6zPIw603O+0KrQUVHNY9
svcs8uCo4x4WJ7ngC3uxhkCfw/dUHvJXUeMA06eVmvG/fEUe9cU7hzNzD+xM
1Rz3asKeZFSsBl9FwMhYCi3EaB45c/Az+75TCYwcSO9juGF/wdDpUCfUwgh2
mbfLKezpzUzHM2mvYEGbliVjCZ/vN9waEUPsgAt/Gq0hWGHXeOQRqknnQ9Hz
v4dSrPD9W+MDtw/9/A5aq03wBqdxHGq+9is9cO6HgvaVVhcpHDdViXaDiuJB
OBHTzIu8P408sr1DWBokgBxXaqzSPK6LgdcycZQcAVQkxxU6mOE8KYa56txj
Aqih5VEmpipAPjUxvzlcbRDOWTdlKgx0Y/dmOveE98G8Sg/pZZMO5KaCn5qt
aT2wTJ94yvTlS+QnLzw0ttvAh7kqTsJ2QS2Oj5F4kt1IB8wSffw0jlmBPDY5
Iz0osQmmJzPzw/vZ+LsvHvjOFTfAhic7fUdbE5DrAVZUyuN6KEH+p2H4XDBy
tv2mMc0AHoxycxqmTlxCfppXsZCYVgN/W3daNXzxKvJvwXvYnp5cOHtxNCw3
Igz3AX93pmp1FTwn9I/yuxCDXP1B0G3D8lIo/V7NVdr2FnKdI5e8vCn5UNVa
wWRwPgu5oeXIJPdmKnzT+QI4PCxCrqKQEe8l4Q9bVjSiy0AZ8hnJXfV1b8OB
i6dVJTetGvlSkchLulMqCBEpt7J5zkO+3a6tVUY/G1DjM9K0aI3IZb8bHPWs
vw8Of/J10y5uwnlisO7AXF8uKHsdtiByqBX56NH1Hc+c88ESfXJ80qMdeTft
TEtAcAHIrrBpSKZ2IndYbz/C21UIVMW6/FhqXchTJO0OGd9Y9Wn7ffxvfORj
fdQTM1GFgNS7Xr5xGedVvJVyXhqxEFCSpHYoi/Qi13+V2RnhUQC2lNvKzg72
IbePpDNSvfNBrMDwtcGTAeScktg2WnwOOHv1JN3tBO6r2W3XhE8bs4CeLzN7
wAT3T9Ogs73mN+4AdU66NHEZ18VB93eiHlsTQD1hUunRCJ4jRhnDPj5Vf4BT
euZCy0pcXxVhWc9DZRJh6XBg662iKeTid8l2AXLpsHvb5BsVPu6rs1SFKz6X
70GezZwFWwrXL6+cK7EomQcp18iks2q4r9JzNtq0NuZCYj/vjocYnrOOjETl
kUo2dEveOO5WjZ1hp/Njjj8TW/n/HP8Xubo9Mg==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xk0lGsYAPASLdbKUjckSiouaXFCvHNrJNKJoku6RMpe9ypb6FqGY98i
u7FFk7ENEuKlrIO59m1CRjRTtlw75dY/79u53znvP7/znfM93/M+i7Tl/at3
uDZt2mT0/Wz5fmq9HHuPjTppKm38eGZAW+uPZxJoBczmZqsmgwg7z/GFbuxu
VTRGZUU2mNa6ZqlljP3D35GKZx7mAond2RpRntPI6Wa325yF80CU24UheYMp
5I/3p1yuN8wDoUpvvA+tfEYuG2RM523JAz12EnNOdp+Qb82te2B4tAD032B2
mNewkaesD+SfbywEZEaw0rLgR+R7H1owl17SgG+NeVqj/jhylxdu5RPmpYCT
S69daxtDfinyTo9v5CuQGD0AWstZyFsCAn8dd3wNSLKiVdZC2I9P2069D60B
cgFcCrfaR5HzhK6cdp5/A/4oKfUS4MfvK/GSrlBP1oPM3ZvPqFdgZ0zOuNgf
aQQxdE6uSh+O55dM+zcj0U2A9ESd+ZWA44dkHhYjshk8WOeS/bI2gdzGSNBA
QoUOpPrnPQ7LcpDfKvMzobnQAUtORGfJH+d50UmR+6kVHbjynWQpDuN78epr
GPTeTQcie+T5pqVnkTsmOfSJ+jYDdqOZ0G+XvyAvSpwwSvgeZ373q5Lw+3PI
z59rYoesNIDtmvvyc+L+Re493Xk6I74OTL0TJnZkzCPnqpYcGvKrBfkKhVaJ
7gvISXotZjtmKkDiVxn/WLlF5DECc7UHBAqBjcQsobQYe2Ssd0hkTDBIXNn1
gUdoCTk3uf76rOYzWOm1tjGotvRT/TAG2inlcFIsQnr2J5d207QlHq+D5v/E
UFdFsJtJHvepLGyBlmQZHd4m/N0pkocmb38HpP/OV1GmiX04x/1ZVGIPTDG3
aJdywv+1CGzElWE/PFZ3wfKKA84DseCSfq8VE74OfcnvsxfnzVqns2N/xBAk
7DxjkKSD879j2IumsDQMG/wUu8k3cd+x7xNZ4ekj0OpS/OpBNq6HvrvC2vrJ
IzA7UG1D8A6uK3+9mugj34ahsi6VR+8mrue4R5yL9zqGoIzcru2StkzkGpZJ
LnDLO3jM8ONL/+hu5J/1BPMEBwdgjqmLogS1Dbmmq7hkVEgPLK4sDhcqrESu
0qYSFsvdCQ1OLPjlxWciN2Lfzbr1tB3OHCrpGm2PRl4YqDZO7WbA8OCWVOsT
3sibHW9QTVdbodgaX8Db3r9wnfQ02y9dbYGPPj3XjVt3Qv6t2ZfhltoMN8i8
FPGjnsgzGl7nDc80wkx2UX/SdRJyk7PaVqr6DVA/olFLAYTiPAtRuKvL66CC
BtleWfgJ8i1bY0yJY7XQZT7Z4+BdMvJ8taqgBJFqGC1axizYScF5a+qUjyeW
w3iGzZyRPQ333fLyoIZoKXTlOStkM1iOXJdiQvFTLoKPd+5RWFisRb5ZZBvJ
344K9Wy3c+fFNuL4aQTOTZscGEJRJVVnMJAf9HDf1c6fBU+U3Y4grHciP5mQ
JZTUlQEngp44OY/i+109cL6rm5kOVTqVwjw6e/FcGnWO5hVJh/uk1UUElvqR
G44FNFPD0mAjy54gKYPrp0neunaOmAYzuLodfOSHkIuaiCmLHk2D7y3qU+tO
jyAXCPuzrFIlDS7tWDXhLn2PPDGt+BS0S4Pj9zRp/a24bq8F2NK4qtOgy2CD
9sN3eN42PeMYLyilQ9KambYYB8/br1KmCQPXMiClLenAnj7cF5ujsoJSN2VB
XlWL/UXjeL+kJPPfgNuyoaQD4aJdK+4vloFnpUbsc3iKZRzn/gLPWx3muW2q
Gi/g4UM2jzcKJpEfdjQVVw/KhQMdZ4vCCvEcNjDRXibK5MJcKXbRejDua59h
o7q3Yzkwf6AooYSA9+/U58ApTlUqdKWSJZxasTO7fH7s92rd/+33/wBxq80w

            "]], Line3DBox[CompressedData["
1:eJxd1ns01FkcAHDlNKrBEktb3pRXzXLIKtVPGjsaxibVRPIma5VH6oRZq6Ty
6IVjveVd0nisiWnkYozxiJG3xHhGZCZvdcJq/7i3s/ec+8/n3HN+9/e93+/3
XlVX31Mem0VERKgbU3Rj6kXor48D/6OW69+GEBP5b3zCZmsojwz0UzDjg3k2
0m+Rx5zrOpKdkIetyM2HCX9HLkJvVTh/vRCTGE28EZAhgB4vG162u6YIU0pc
1RsMn4F+uMJTQBopxshjBz3ohh+hS0a/iMr8UoL5qYuafciZgq6kyOCkBPyD
0dommWafJqFrcJ7g7Z0Z2Mrc6d2VhAnoasIJn1rJCqxY3KDC78I49Kg/68TX
fFhYSJgkq7NpFHoOTozmcQxgVqrmEw5FI9Az3hP9vfg1mJLzsL3DVuSlkbNt
N+/UYRIVNvfd+oahW/WQnfcc5GKLuAKLYH203qZejtvKaMSUTtvG4sXQdzsW
djHu9jVjtMDtoeSzY9B78iI0OE4tmHJzi7f2Ctq/brgZDu/ZiiVYl2nwZ9H/
knr2u0t9bsWq+OMKY64obmlSeRcNt/AwZ3xhuiMexT9/lhy3K70VE7JME59n
oXN88pd7qR2vBdunx9bbqzILPbkheed66muMVm8tO+oyB53fZly3NNWEia9W
brGPn0fnfmH5kKhbAya+SUkzkLOA8ocUPDK/XodRVW+XEXiL0Cu4jg8qZ6ux
s65K71qSlqBPe+LYSb3lWIFA119Gbxm6ePT53uC5XCzqtjc+82/kFWHu75i1
0UB2TH65mIt860pYnCe9FDQ7XTbR/867h6bJV4xqgLJlekxeGvIW9Rrxh/EN
QJBo2mRB/W69Kt9YrJ4H4m2SmihzaJ9n1qOKReM7AIXpO/6MijziZOrEpKAb
9LIsZbtuoP8deToTHZDfB06kkTYzglB89mpz5uKG+sG+JPz9Ri0UzxMl7cyd
jwfAHuJ0SLULOpfw2fhhSvEgwNhu4EEWqjt9fduFEgU+GLR7W5BIRPkQvC3G
6ujyILi0be1KfyfKK1xo+ZTQfhDkaf5C8+hB+ZxH/eRvZzsAeo/7CBpd3qE6
rTx6y7e9H+RK1Lo4X+uC7mf3I85K8i04qXMpXFGLB12a75vg+qAbpGevbZow
fwVdq2p+8c3XThBREKqxTiiF/syLWRqb1QEao+1zWdk50I8PKDbjPduB4MPt
/I74OOj7iYvsWLs3IMu7fSZAIQw6hVh01SC0DSxP+ivYtvpCf+lrVNvnzQNx
+ene1weQL3mc7DVtaAG6lNQ6vsh16Fl8Tk6IzmuQq86QzXx8A/UfVZXK/clN
wE5lTpM0fBf65jNi7BvSjSBwX+Bn4o5H0J2SSBpBv9UDoTHFLWciFfquRy4O
s+FssGrKk1Eoyodu/Ezdf7d6DchUcTDxrSiBLlBpu/NQtQrkkOKy6wlM6ASe
nEQW6SVob3aY1nhSg/b/9XK1tVU5GCDTXkhZc6Fzf9rBs2WVAQOjNUOGSyv0
YyaxYV5TpcB+2Mhj03A79Ej50Ju05BLgNiNU72J3Q/f8OF9rnl4MHNnczHOE
fuiGZ0K/bBErBmqN1PdL7nzoY9JqCeSMIvBzrgFTvWcIegpDnp5LKQIpq42P
yz6jPJRo69hGli0CVLloUqUM6p9JmiFSjjN0YKnNDKLpoP6pZbt9TKebDm6G
K5ul6KI8576RuWfdQAeu8gTZZe33qK7XcLd2VNMBbd7rXukh1FeDrh7PMWfR
wbWXyl+PWKB754rvc2JOBR28fuX0a7XpB+grU0dwLuV0MFQsd2D0AKq76Xme
osyGFzaLRaaoTUPPvmOSYL3hnXG9GQF4dA/GcAZTlhl08GWEqn9IFPVtmVMW
y2GH6YBzKztdIETul0/QfGpTCM4n27ulMFAfYA97hP8gyAdBZPedLCrq8xej
X0TmMtLAHz4824V25PRs4rf3QJXb/94D/wJsBUyE
            "]]},
          Annotation[#, "Charting`Private`Tag$5541#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      SphericalRegion->True,
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& },
      ViewAngle->0.40603978838238247`,
      ViewPoint->{0.8618128142024905, -1.8694405203534539`, 
       2.6856043666439384`},
      ViewVertical->{-0.17568517878038734`, 0.15245895842422288`, 
       0.9725692694883509}], {978.75, -189.}, ImageScaled[{0.5, 0.5}], {360., 360.},
     
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx0nHlYzV33/+NOxlIhc+Z5CpGIlaRCZpE5swwhRYoMIVPKVIikUVQ0z+3m
8TScU5EkFU0yRIYQ/U5te5+v1e95/nmu63Wta+213+uVm9P5fAZt3rdsW1sp
KaljvaSk/hP//8yBo1f+9+fcLPKzSfy/j+BRS6bo2CybNf7KLJcdKregR8Cs
+C7n33E+zPrY0d3bQ4j/t2GnFfSrON/eZpX1sLgk8lBa+13l0Decj+1SEz7i
SCZxSEiYapldxvmXqH6drvfKJaPHLOwVOuoV5yuORMVmxQuJifX9z6e2FHE+
Qunni4ajIjLCfaBlcEA+5yv/ezet6ZiQvD73okG1MZNzmcyzq24+zSRGm942
HN0ezfmCbg1eHkviye2ga8unOHpzvqGrQp/ZU3zIeqImGj3Rh3O7FfGyjxOv
QK+OvcsXVIRzvrF+55KVHb2gi9fSwdrXEjlvnBnpZf3pOljPe3Q51zSV8zaz
Wjg5hfgR2ocooT4iei4Zhs6dSOeElWhONXovOIXu1ZjRkgMYohzW0NzgLcpt
Is0ZJqCc19G9gCnay989wlC0x9F072CH9r6LegKeyJNZ1CtwQ155ObR4SDoh
DxXcTjR7G/sMeYt99l9eZhbpfQWwz4xjnxnHPjOOfWYc+8w49pnxDxMMS+rE
Pi+sKsuKEOfMuN6geTmLxT67du70Qvl3JufrXUJcnudmkjBl6e/u+6I5P7Hj
0+Cpc+KJ66xjcjL53pxvHuDQMLnkAWla8WvK2QQfzj1dz09ROH8Vvimv2N1p
ZwTn3cqmT41b5QUVxtv6TfmQyHm+8cjcgLE3wHd7ScrxwlTOCyknTxAfTfuQ
d6hPJT2XtB3w77lT6ZzQgOY0ofeCc+hey2gO8BjloE9zA2+UWwPNGQxQzthn
tEfuM78X8plx7DPj2GfGsc+MY58Zxz5LDU4tjfC+38pnxrHPjGOfGcc+M459
Zhz7zHja3P2/C8U+K4wfEZEuzpnxXM8O9+dYCYljO6PE502ZnH8o+BjkTzLJ
gS2xh35fiOa8rPHeW8W+8WTuBw3v2EsPOPde7FunUORN5lmqf3tt9ojz9vUR
slVPr8Oq+MNWMR8iOZ8u6GKpqOUNX+V7Sn3/ncS5ZmHi5Vsvb8BABbch6zqk
cz6XcjIEcQPah/xBfRbSc8lWdO5ROidooTlz6L1gHLrXa5oDGKMc8mlucBfl
lkdzhl4oZ+wz2iP3mXHsM+PYZ8axz4xjnxnHPjOOfR51u7+to9XDVj4zjn1m
HPvMOPaZcewz49hnxjfufH8iQOxz256jurwR58x4lv2evNLDQlI3WOXEemkB
54b9vvVf4J5JpA912qwWHs15RmSweVBhHDHxMg9SjfXhvN/TPYlVY7yI0d3n
m8bO8ef8Ys5NHR2vm6BhTvbnmsVwnu48Ks8u+QFsCYoauYakcN5d/8j7wW2d
oJuqt2fBnwzOe1JOeiP+mvYhe1GfHHouWYDO/VDQMicYojlD6b1gJbqXPs0B
Gs3/zUFIc4PvKLddNGfoiHLGPqM9cp8Zxz7z/shnxrHPjGOfGcc+M97K546R
jhHeAa19/stb+fyXt/L5L2/l81/eyue/vJXPf/m398teWYp9vruz4nCHwHzO
bUO7OEw8KCT6Hx+fvtNJwHnJ+0MK0kczyeq+q36lf4vm/MDIhB8lR+NI7+jp
2/O2PuLcaH7EmbhCdyJtqyk6ohjA+XTP03tJ7V1wyJ7Wy/BIHOd6xQp63i8f
Qsr8+Jze49I5T9WuqXnleBOsRXEqHUKzOE+mnJxE3Ij2IULU5xg9lzihcyfR
OaEtmnM9vRe0RffKpznAUpTDJZobLEe5tfnQkjN4oJxb+fzvHiU+/+WtfP7L
W/n8l7fy+S9v5fNf3srnvxz7PGtuRY23QmgrnxnHPjOOfWYc+8w49plx7DPj
f2JvRk8R+3xzUhf7qeKcGY8xW1k5Z6+QPP7kpnBaUcD5s8RlBxbPzyTtYhvM
fsyN4fyDwsruPh3iiMu0sMVeVn6cv7+96phjlSvZ+/TE2Xm2QZyft/UcELfA
Df6L3/Wpzj+B8xfpf3J7nPaD9VXPi2tBcm5uJzei4HQbZEuH3K28mst5JuWk
K+JfaB+yE/XxpeeSLujcGDon7EZzPqf3ggvoXhk0B/gd828O8TQ3CEG5dSAt
OcM9lDP2Ge2R+8w49plx7DPj2GfGsc+MY58Zxz4vOyk/09EqspXPjGOfGcc+
M459Zhz7zDj2mXGZKVBdbiUi1a91U/eKc2Z83qHV90dtF5J7H132NvYVcH5w
ZsaeBLlMEtUzf2ihRwznuzufHPDyZyxRS5imsbPxMeeTbq7YeDThNgmXj2vr
ZREq6TN05tX4+V5QNCZw8pUVyZz36ep429TwCeypy01x/JDDudmjHsPDGu9A
xp/0AW/vizg3oZxkIT6S9iFWqI8TPZdUonMLnVrmhDA051x6LxiM7rWT5gDB
KIeFNDfwQrkp0JzhI8oZ+4z2yH1mHPvMOPaZcewz49hnPifymXHs8/aYGQ6n
K2Jb+cw49plx7DPj2GfGsc+MY58ZH7O0dI2N2Occq2JLP3HOjAuWGCk2rBf/
/fmQ5tia4QLOtdWiSdeMDNLg9HjhPMVYznPem990i4ghHWp/t83cF8B5gEr3
BCfXq6TKfPzoyJcRnO/1vOZRUSn++2DBdgXdzWmcGysN+6ozLhD6DXtyX6an
iHOP9nYrXeLuQf9X9i9L2xRwfpNyMgDxg7QPGYr6XKXnkino3CV0TqhBc3rT
e0HT23/vpU5zgM8oh1yaG3xHuU2hOcMzlDP2Ge2R+8w49plx7DPj2GfGsc+M
Y58Zxz7HHA06EOEd38pnxrHPjGOfGcc+M459Zhz7zPhwp7mTe4l9Fn2/+faL
OGfGJ6l8zU1dISSx34/YjJos4PxC0OTb7Y5lkDm3s82l7WI5d/6xK2j70mji
6OfioCUXxLmDW6+lOf/ZkAtytg4GvjGcR8rWDx/T8QmIXB6tqs7O5Hx9zrRn
HWYEQ9c+hyJSLSTzJFc1LZ259z789yG4/8NHzziPoZzIIL6b9iG9UB8BPZeU
onNf3G+ZE86hOc3pveASutdxmgNooBym0twgGeWmQnOGIpQz9hntkfvMOPaZ
cewz49hnxrHPjGOfGcc+p/aZ5/ykOLGVz4xjnxnHPjOOfWYc+8w49pnxs/qd
g9wsReTqqB6ac4LyOd97T/FA8Hwh2bflt99NTQHnup72Uy6OzCC++4Sat7oR
zp82Nt7fnBJJPKJMc2LzgzmPq9NUHWMH4n9XmdqeeRfH+eUVGaGpJYGwfd6M
unEOOZzbHzGac9kqFMzOL7i6s8czzreOaRNoPdAdjssOcdR1ksy/mnJig7gz
7UOOoT6u9Fxihs6V6jC7eU6yAc3pT+8Fd9C9ptMcwAvlcIDmBodQbldoznAb
5Yx9RnvkPjOOfWYc+8w49plx7DPj2GfGsc/C8JIkb4WUVj4zjn1mHPvMOPaZ
cewz49hnxvdNfjF9qNhn/elTHJzEOTP+9Mt6lWIQksufbq6WWyzgvOrPGWWX
rHRSqLUg/qAH4dz81qGfav0jSB/dl49qY0I5z2oalG9qcxbiH9+y9RmTyHn5
YQv/lNoQULEZtN44S8h5xMTsV92rwyE/uWajYsVzzqGs7ceGLx5gMqaX8deo
l5xPopwcRDyZ9iGvUJ+v9FwyHZ3rIDW4eU6ShOZcSO8F3dG9imkOIEI5FNHc
4AbKzZLmDCtQzthntEfuM+PYZ8axz4xjnxnHPjOOfWYc+/xipdkHF520Vj4z
jn1mHPvMOPaZcewz49hnxrsoztdxOSIil5fUvqwT58x4Vc4W542qQnI4a8bA
jRsEnCt8GKqxeG86GZF+8XadchznUz6bCMvXhJGgxXpfuiSFc67zKWKm4QNH
cE55dK3wUjLnr9cpSkmNiACfuCL/NZ/yOO84Kx5WHomCjndWjDJ4Vcz5krPn
v42r8ALvb1Xqg8+Vcg6Uk4eI96B9SA/U5xs9lwShc93onOQOmlOW3gv80L1k
aA4wDOVQS3MDa5SbEs0ZHFHO2Ge0R+4z49hnxrHPjGOfGcc+8/0inxnHPld8
6djL0Sqjlc+MY58Zxz4zjn1mHPvMOPaZ8Qv7tu5QFPs8XXFC/0XB+ZyfUKwa
s2mkkDwyU+u03kTAeeL82DukQzo5qt/PvtO+OM5P52QlPjwdQga6R9p3LYuU
nLvljPc73fvwJM1+3ocOaZzPH32oJO5sNHSbn7baetxTzq9tWBVxd0QsvFsd
3nf2L8n886w6HNWvfQD9Bt1Z3HduOedTKCcDEXelfchP1MeInksGoHNt6Zwk
GM25ht4L+qF7hdIc4AjOgeYGgSi3GzRn0EI5Y5/RHrnPjGOfGcc+M459Zhz7
zDj2mXHs88er92bbPRG08plx7DPj2GfGsc+MY58Zxz4z/rPs++xTFiIyt+/g
qf7inBn/7+KOMul+QvI7b2qvQmsB5zU3Vin2v59G3AceWeEUH8e57O5+yt1c
g0jkDq0IZ7kYzgVJMQ2au7xBbmraefObGZx3WXhxj5lUHOyWrR49wKqQ88R2
yon7zONgn8xJ/zgnyb0mz8s1md3mEZjtLjLx7yrJoS/l5BDiabQPOYT6KNFz
iQU6t5HOSRTRnOW7Wu4FIehexTQHcEU5tKe5gXT+v7m1K2/JGfRRzthntEfu
M+PYZ8axz4xjnxnHPjOOfWYc+/xDZcru0xXZrXxmHPvMOPaZcewz49hnxrHP
jGcpep/9eFhEwn+u6iAfks/5jldKBfu6CslguYV5LvYCzv22ZzxwUUsjDmGH
RtzrEc/53SOBSzICA4j/VauOI3UI52qTXevIAz8IurTneezkLM7v7N898HRy
PITMe3BgeZ5kni+xFWY7X8bDrR2FMhrqrzlX1DeakjHQD4pF32ZalVdw/nVB
CyevEP9B+5D7qI8XPZckoHN30TlJBJrzAL0X+KJ7udIc4DLKYTfNDUah3J7R
nCEO5Yx9RnvkPjOOfebzI58Zxz7zHJDPjGOfGcc+n9qxLWOmXW4rnxnHPjOO
fWYc+8w49plx7DPjTvDs/Vqxz8XFaiam4pwZXyJ1IiO1rZC8u7S7zNpVwHnJ
IFWpk1mpRHmARt6wXfGcBxkLkyaeeUxW2NpeOBsXx7lR15hPBg0BkJk+7+B3
UQ7nUY0bYsAuEfZVbSEKE15yvn5FzwsndBNB+WD11XEvJff9ZrLlsO2cx6Dn
ZhDUIVySTxHlRB/xTbQPGYH6pNBziTU69yidk+SgOdfQe8FydC8hzQH6ohyW
09ygHuXmRnOGNyhn7DPaI/eZcewz49hnxrHPjGOfGcc+M459tp2qsjHCW9jK
Z8axz4xjnxnHPjOOfWYc+8z4rv1nJ6UfEpEl0Xs188U5Mx68YkLspG+5RCH1
5J25AQLO3T57Obbdmko6hap7jYuN5zz77O9Rrg8fkZx+HoH6xRJ+W8d/742e
IaAuf3jTQDUh5wsHwoHFy5IhashQGR1byZz2sq9mHHmcBHr5UPvAupLz2vAf
yucCnkBAR9NTBRdqOC+mnIQgfp32IUtRH0N6LklH5wbTOYkGmtOC3guy0b1u
0BygI8ohjOYGvVBuZjRnWIVyxj6jPXKfGcc+8z0inxnHPjOOfWYc+8w49vlS
u1/1qgmiVj4zjn1mHPvMOPaZcewz49hnxovKe8uqi31ek2y0WjU0n/OpWY8P
Pq3JJZuHn3wYFy/gPG2mZhejxhQy8YLj7kj5BM4rYm6X7C/zJn2adqQq1kv4
ssPzHcnIcKjQudbmjbWI84mG9iZbuqaCbf393QfflnLefuvSwX0UUiDO703n
9F7VnJfeW3/zVHQAtF/x5P5Og1rOsyknXRDvTPuQDNRHg55LHNC5e+icpAbN
aUfvBX3RvaJoDqCCcphOc4NdKLcKmjNsRjljn9Eeuc+MY58Zxz4zjn1mHPvM
OPaZcezzlfzkc0+K81r5zDj2mXHsM+PYZ8axz4xjnxk31FQd72cuIjK2Hjev
iHNmPKfrZOnCl7nEMevo9VihgPMjt5/vyXVKIWdlRxjlGyVwftLCMFFqigcR
jRzU43qbJM59fV2K7g2Ogs+6Z4o/ROdxXjkr/uUckgYzw3vNPtOhnHN9s36v
Zu5MheBLSu2IVw3n6/v0f3GFBIK19dawTYrvOZ9POTmJ+FLah8SgPnX0XKKL
zk2lc5KvaM6R9F6A77WH5gCnUQ55NDdwQbltoTmDHMoZ+4z2yH1mHPvMOPaZ
cewz49hnxrHPjGOfHd0d+o/9nt/KZ8axz4xjnxnHPjOOfWYc+8z4V2V39RFi
n/Xurql8K86Z8dK30/atFeWSEz4D1nYtE3Duft7iwkm1FDJ7imyfi34JnP8Z
Ne/AyieuZIDfyggP6WTO29ecs9dtjIGNyy9vPvte0n/nxMtnS9dlwK+VX2uO
9XnNudnPHvYlT9Ig63umcemQWs7f7Cnd4BsWBPs2xmmcj/7AeQ7lxAxxS9qH
PEd9DtJzifSqf88dROckm9GcHvRegO/lSHMATZTDG5ob2KLcmmjOsATljH1G
e+Q+M459Zhz7zDj2mXHsM+PYZ8axz86mawO9FZ628plx7DPj2GfGsc+MY58Z
xz4zXtLuYPwDMxFp6285FcLyOZ+veXq8TWoucVGLkjnzUcC59muTg9eLk8kz
5flrGr4mcG6dYqHdNvo2Kfx8ccSMH8mctzPbs/H6yjiQ7+m2uZfsU87l52xr
a/Q6E6bpHO43or/kXuef6r8cVJUOv3o4Lwm5KMlHpLvpWM39YJh0uH+3/SPq
OI+inKgifon2IR2U/u3Th55LtNC53eicpBuaMyO55V7wHN1LjeYAT1EOC2lu
4Ilyq6Y5QyeUM/YZ7ZH7zDj2mXHsM+PYZ8axz4xjnxnHPrvOHq47ZOyzVj4z
jn1mHPvMOPaZcewz49hnxmdFTZs9WexzwqtvF+3EOTN++vH97H0xuWSJ+6yJ
XxoFnEsVZMj1OZdMLp0XO6GeKJkzL+7PJ/vrpPzHV50jxSmcP1Du9dbJMR5c
dqgnzO31jHPLyiXzxy/KghIV51MWshWcuz8yura1fSY8zmoX067oPeduNZvG
XbAKAcWmaQdWlddxfoFy0gNxb9qHRKE+tvRcUo3ODadzEjc0p4+o5V7wGt3r
c35LDnAR5XCO5garUG7zaM6QgXLGPqM9cp8Zxz4zjn3m+0U+M459Zhz7zDj2
2VP+0wsXncJWPjOOfWYc+8w49plx7DPj2GfG1du49E47KCLJa4N+5YtzZvzt
5al2EJxL+g+1OKfaMYtznaVaNV1nJJOATi+Wux5K5HxGu9EF0iV2ZMTaFNmQ
R6mcX+8z7/3eyARItstxfte5kPNGG0+zTreyQW/L2HzX6grO+53bdXqunABG
plXrVXaS5ObsHKvZRisUMrW04tMvfeLchnKShfhA2oeooj4yp1vOJcvQuffp
nCQdzZn+X8u9YBS61zSaAzxBOXygucEwlJs2zRmyUM7YZ7RH7jPj2GfGsc+M
Y58Zxz4zjn1mHPv88FXU/j6bnrfymXHsM+PYZ8axz4xjnxnHPjO+oT9c2in2
2a9e93H38HzO9xrP/CPrm0v2PeqtO6h7Fuc9F6hqrP+WRHIz9KoN/RI5X9JL
eEcl34YMGKh24sTWNM5tR3w68TA2EbqNeOQ5saKQc42hM450i8uBu3a3Fsj5
VnKe3Dkw4HGDAJYslvmySbaOcx/T4i6/PodCeWTQ/tShnzm/TDl5jXg67UMM
UB89ei55gM69TuckPdGcIqWWe8FgdK+ONAfAORygucEhlJsxzRlCUM7YZ7RH
7jPj2GfGsc+MY58Zxz4zjn1mHPv82P9sO0erolY+M459Zhz7zDj2mXHsM+PY
Z97/WkVYD7HPvz1sqhaIc2b8xy7NiHqPXLLRp4f7rf5ZnIckPVLLjUwivoen
aqYVJ3L+xKfOS372IXLm1KpfT6TTOZ9hte66pmsSeH2NTDp3/znn0Wfq3tZs
zAWDnWPWHTKQ3PelUcyF14lZYKoyd6maTR3nojVHtm+9FAYOWuuXnnvwmfNQ
yslVxF/RPuQw6hNPzyXr0bl6dE7ig+Ys9mq5F9iie3nRHOARyuE3zQ22o9wO
0JxB2vPfnLHPaI/cZ8axz4xjnxnHPvP5kc+MY58Zxz4HH1t6W8HxRSufGcc+
M459Zhz7zDj2mXHsM+MmW8fcyDUVkQaTh3+OiHNmfMKoC11l7uWShEcdVE4O
y+Lc97atU9/zSaTNvPa/N0oncT5na1jF4poNxPt+aMi2C+mc964yU7q4LhmO
d8wMiJ4lOXfNuy4Nnhm58PHN4avF5ZL7at5pGHt8bzZIa1dfvVJRx/myS1Uv
9ncJh7kDL38+oVTPuRrlRBfxubQP6YT6bKTnkl/o3OF0TnIGzXnFsOVe4IPu
dZfmADiHSTQ3SEe5WdCcoQnljH1Ge+Q+M459Zhz7zDj2mXHsM+PYZ8axzxH6
/SbYPSlu5TPj2GfGsc+MY58Zxz4zjn1mvN1bh/pbYp+vxW3f5SLOmfG3i0cL
Vt7OJcrivwbGjcnifPKeDhfzNyWRR85+83yGJHE+2GHIiOI2i0Chasdm2S/p
nHfIKKtY8SkZbnwfcPtrpOTcYB+rC7+VhfBhlMmFm8uqOd/kO+nCmfps+PQt
zXbe5E+cn7rwX1/XA+GgsOLTnB176znfSjnpjjntQ76hPpH0XPINnduDzklu
oznTvFvuRbqjew2lOYAvyuE9zQ2Gody60pzBGeWMfUZ75D4zjn1mHPvMOPaZ
cewz49hnxrHPsX2rEjtkvmzlM+PYZ8axz4xjnxnHPjOOfWb8The5w6Zin0/7
7IwJF+fMeKX65T/1jrnE4obhpzkqWZL6QLmv++cmkW8ey0FnehLnmrtuaa/o
tRP69ThUsUszg/NdDyYeeLUuBb7/uuYd2/0F50edOlrXrxXCroE9a9a4V3Ou
XXrEaOuKHICLL9+Z7/7E+aGqJ6YJkeGwv2Gi2VTfes4NKScHEdejfchc1OcU
PZeYo3OP0DlJE5pz+v6We5GB6F52NAfAObylucFxlJsXzRkuoZyxz2iP3GfG
sc88Z+Qz49hnPg/ymXHsM+PY58S3AYanK0pa+cw49plx7DPj2GfGsc+MY58Z
PzR4uOMasc96dX4P0sQ5M24SuzC36nou2Wvv//zPpCzOx73V66SjmkSWpao0
fdZN4lyqo+XYK/IHQKaNV+dbJhmcr7kzur7qbgq4xTlv7LTgBefudy69yD0h
hJDrfRdMzK/mvOtak08Nl3NgYNzyUSZ2nzhXTFy1ubEyHMjejKaJonrJfRNa
OIlHvBvtQ4ajPj70XBKHzjWmcxIvNGe7Li33Ih3QvQbQHADnYEpzA3OU20ma
MyxGOWOf0R65z4xjnxnHPjOOfWYc+8w49plx7HNGxNH3TU2vWvnMOPaZcewz
49hnxrHPjGOfGZ+pcfrmMrHPJqr7GrPEOTNuVPxw+zSxz2MUX0ZVT87i3Cbm
8FLb8Unkj+dM67P6SZzrnVrstynWFNK2GE2Xtc7gfE3hhRmPglJg1eTuginr
X0juNajjn+F24j1+1+p3/k0158eelu+65pYDd6c56glufuK846Kgselfw2Gb
MLeyqqSe89qFLZzsQPwk7UPcUZ899Fxijc7dSecka9GcBmda7kUy0L3MaA6A
c9hKc4NJKDc9mjOYo5yxz2iP3GfGsc+MY58Zxz4zjn1mHPvM+AH1gKPtHINJ
W4crVkd0fEHVe3Hck+IgcA00Lrn3aStUhmr5jLgXwfn6Isc2vWcHkeITD2Zd
//wY9F5bdrunEw7fRq73yHS1gbVex1M018VwPu+MtoXFej+Qq5p9UdUonXM9
2geSUZ+K2OnGS9cnk6OmDbmpD4Nh3QCv7XZPoqEozfhX9ZMAYrhsoYnsoEDO
NS8l+uVpXQVZ1V2/i1/Fcb5fOr/xRvAT+CXS7mZcJOD8Ea0nPVF9Eu0Pi1D/
jIfqm02rk8h4nVnT9lwIgXC/6uKZdnGwYc+cLgvzH5MO8yvuyV0P5nybXeel
Q4qdIcmz/sHkDYmcyw48Gy/bJgji1OWmtNmRy3kBrSe5qH4y7Q9N8/7tH0Dn
gf5onpNa0zNqtycRk9Bz6bqnQiFhgbXMlIQEqH48Xn7hm0ekaLBhQf38MM7t
CrpEJIA7bG8ffOrBoBTO73yZbDDTLgS+eCtMvOok4jyB1hNTVB9L+0M26r+T
zgPr0DzSlQs2axUlkv2vrJ1N7cNAUNNNZez3JDh8uHqz+11vcsevzx6nmZGc
j9DX6n1WxgdWD89RrRuUzrkR5WQn4vNpH7iG+tRWtJwLRujcTitEq/ppJ5JL
T6/mJPmHw1Nbn9VDxqbCsN+DTwyTdSfXdZ0PDNwSw/nW+z0s2018DGqOd150
WCng/A7lRAfxxsaWPnAO9alb3nIuWKNzI2qMl2p4JZDG6LBOpcURUDoMbPps
Soe7jU31XU7eISKfmzflVsdxLrTPvL3xaSDMibWQMwjO4fwd5WQl4vq0DwhQ
Hxd6LtShc/dprxx+tG0CsV7rekVdKQreJub7KjhmwtXQgaFrL10lhyZopyyW
T+B80geV98qTQ6Hptt/6dbeEnGvSejiA6lfQ/mCK+huLVi5JXRNPZrYd/3bo
qmj4smnX0w6ZWZCg7/dwYvAJsvF1xNZxokTOXTw2zPPxiAC3zPlk7ZY8zgfS
eliN6hfR/qCK+pcm243sERBHZH1GlJc4x8Cf5j8um3JAcEthRQ/TjSA6+mLm
plvJnHfTVSp+MDAGGg/ly2ZMKuBc/l5LPRGg+iTaH6RR/1URSVJb2seR0sWD
im6WxoJ0TsZ1qz5CWBUU0BTqcA70lH4r3TBK5Tz1y3a1FYviYNXgDeumtX3G
eR2tJ4Dqp9P+UIj6u16+YLCOxJIlVqt6J8jHQSeXG6O+q4qgpMbNyMXSESZl
mIaYDk7nfDutB31U31l7S9OLwzHEISOz2MQvDuT2GsWaLs6D+p6zc7zVXCF/
sfLroOcZnIvmtNTDZVS/e9/Vz301okn6zA2WR7XjobvGmOUfjPNBhXJIRdxi
wb2XOV2jyEr1ndeH5cdDr87fqoxPF8Cs6elNxq+9Yfam30Kthg/QKazH3Sjv
k6A0u/NNKVcXojVLs9tG/xrO8d/r/lc9e4/xqUHrT8/SFpEgTdudlo+f8Xq9
lyU/pPREZI2N5XsHUyHnf15PfCIn5hdHzUm3FXPWZ+5JuYtpUrnkgubI80nP
k3j9Nn0IGtsml9j2X/DfdDFn9Sl+i/QX56aQqckLnr14E8Drz/WouHpHlEKG
eE1TMysN4PW1Kh3trVaEkUv63dT2hHjw+v2bm47vXx9GKp+abIq448Hr5/fc
eXrY7nNk4Lw/nkq1kv7TR4ed+pR5jqwzX3zmk1DSf/JlMmO40A0WON/sNX1x
HK/3v/WxbUOEG5htP3l64Yw4Xp9ueOk/E283OJG3Q6O+Zwqvd3BfFK19yw3e
DcyZtqspmddLtfzvosYh6wM5vTqk8XrKz2t0fXiscMcHyfu6c2h/ch71Z30u
/vT0G1uQBs8y1fo6Wd0GJ3ou+YrOXUzvRZajewnovYgVutcppZbcYDTKbf+o
ltxgG8rtGd0LHEF7WUv3AnloL4/p3mEw2vt+uneQQ3vXoV7B1f+/V3AZebWU
egsbkLft37R4C/bIWzvqP8Qi/2vpzwuoop+v+fTnkcxFP4+Y/6/3h7N6/HPN
9oh/Thn31NE90fxzqntMc3fznIxLh/Y9c01XRGzvNlY8F9+Lce1pK/ss+5VD
2vvs1VUqSeLc9q3Q4mNMCinM7PtLukMg5wXpJbsau4QR6Wexp69ZenJ+dv5/
cpbbz5CCzc562UGS+rw7Q60mXHAHJd81Zdof4jgvXdN1s0Uvd/j2Zl6o4EUK
5xlSUornDt2AbhWdJyxfJfG2itaT36j+E+1P+qH+kfNa5oESNE8cnR8+Pf13
/v30vpCI7qtD8wE5lI8szRMuojyf0PxhKcofe8I49oFxvPfuGz5PfqDg1Wrv
jI/LH2HRvHen9If7m89lfObQQW8idEQk7E/Dr10HhZy7v19eXvkhh4w8/Vng
W5nEeXzXLw3bb6WQ5xmh4e8XBnLe19MrJt86lMCCxYZX23pz3lhenbZVYE0U
Ftzo9lormHMHqT4qjx+FkF/vZ4/N1fOBWU/1ik5X+MMh6bVXlH56wNCJlvLH
Rifw+g77ZF/N/WRMPN91mOl9LZTX7z7dUaj+wx3iNy0UTN6Uxuvpn2+XNcKN
9J+/25PB+T5aT9JR/TV6LhmDzt1a1jI/9EHzy9D7wlh034c0H0hC+XjQPEEF
5TmX5g9RKP9pdF9wH+0Le8I49oRx7AnLDXvC+LwxPfc0e/L8TYhF87l8L2OU
PQ7NFZHKHz+ttMyEnGef6xFsVpxDbocNW25Sn8T5nz4/TYdsSSHyIQdnJoUE
ch7f3tmo2i+OpPyMGznc5iHnkwpDztgreZKF05xTh3R8wrnRofuGv0aGkPap
z7ZPD3jI3/sqGnta72I/b0iRfnV5nJTk3LjyabWZP2aRhG7bF9xoG87rixbf
iemq6wn6GvLxTu4ZvJ56ckVjeNwqmysZAs5f0npigOo/0XNJDj53d4ufEIj8
tKSeQw3yvJLmA43B/+aTQ/MEN5SnNc0f3qL8V9B9wWu0L+wJ49gTxrEn7PMN
7AnjY0+pr2v25P3DeTbN5zJ+OX+OfdYcEXk6We3VenMh54Znbr6blJRD3is3
OahKJ3Pu3NMkKbVvChmdfLhsyawgzm1eGHeLnhtHnvbZ8+3qZsnnMGfj5u0w
PuhG3tyN6SbUCOTcYMnMbzPqg4iy3w3l9e39+ftUg8hBm2G1PnC93UuvfOMU
Xr9k8ar6pWoW8HqY24WRO6Mk75uNWzRR/o8XLDxs46JyJ4vXt2hy4qpG7ibF
t1JVOZxn03piiOrz6bnkDjq3OqTlcyTyBX2OtIZ+7gQf7f/93OkUzQd6onz+
5glfUJ6ONH8oQvmr0X3Bd7Qv7Anj2BPGsSfscyrsCePrDsfqNXuStU7Hoflc
xi11t91PnC0i6lUD8yIOCSWfgw3yX73LK4dMlKkel9UrmfNHVxb2Hp2UTBZI
9c35URHEuWHO/gDvi4Solhlvmf7Yn3Oiofjq6tVk8uPaoAGvtIMl703tVStV
vseFpBjESNfWBfN6uRq3TYNPBJJbI4e0WfVfAK+33HSgv3CqB8x3ue2u9iWR
16teUtw+OuUifL5mVdhwhPB6O4XFV3r09oH0HkppHe/n8nr654yjxrRx+1aY
Fkvu60DrSQ6q30U/JyR90OeE8aNaPlcku9Hniu3ovSAR3au9XcucpN31f+e8
RvOEaSjPv/nDNJT/KbovmIn2tYPuF56h/WKvGMdeMY69Yp83Yq8YTz9VOrHZ
q6Km0/eaz2U851rbHxtARAyCN89ZZiHkvPshi41mNuL/Ttk+Nfypksy5nOn4
syffZxCZKq1vwucxnH91KBqzcWMsuSD/tKBPwBPO54R3CLEbmkxeZORv2NEz
RPI+1T4m4dEiR9Lt+tM1K/qH8/qbQ+cbd8h/QsztE4odlwbxesPX0+Tbnn0A
y2y7yn3NTuH1Xq+zDxq+c4Q532sfVfVI4PUTEroqZF95BF7WG/OGJ4t4PfXq
tsb6k8tfbe6Tz/k4Wk8eofqT9HNg0iHv38+Breg8ZB2aR5XeC/C9ur9pmZMs
QnMK6OfVsBt9Xn2S5gB7UA496F7gPtpLId0jrEZ7zKd7hzdo79g3xrFvjGPf
2OfG2DfGl+i86dnsW4Ho2ZPmcxlv7FKb5KUhItPk+m8fbCnk3FOk/C5ibQ6Z
NPfpyYP6yZwvMi4NtfXIIF6+QUndFsVyXmF0u3BIpxgyLbbSPEQ9kHOj/e2u
jfVJItJtFzUd/y+Uv7dTV+DQZ+eGS8TuRvvYs+FRvP7IybNlFVV+5Nwkzeun
qkJ4fdqha73dd/uBSd9+Ww1lM3i92/ANXmDrCoMSL+7PCEvi9fMyy32yjfzh
SY3RmraqBbye+nZXQ9TnoJWT11PO9Wg9CUP1yvRzfpKGPuevo/MQSzSPTWbL
veAyulchnZOMQ3PG0txABeW2mOYAx1AOXnQvoI72okNzhi9t/s1ZWrZlv6CB
9ruW+gCvkA/YQ8axh4xjD9nvBbCHjEeSnr9mij1Uf9Ypqflcxq1W+493VxeR
12fmZgw9KpT0cSrRCJyQQ+67CydX7krm3Hr80u7eyzPIoNH9lN9lx3L+e1h9
6Vf7KDJINy1c9C6I88kp9qllg5LIDIMhW7fKhPH3bZb6LrJ8ut+UnJDZu+Jx
GOH1lV9uxLXL9CH6jxWOrYoJ5/WLF3bPPbEnAOSlDq329Mzi9V9EU1/Z9xD/
e/S+xvDY26m8/k3cssf5sU/ARC29blGl5L7Uw/saRPmX164jzzkvo/XkMKr3
p7/HIY3o9zib6TxEGc1j8qjlXmCD7jU6r2VOsgDNmU9zg14ot0iaA8xGOfzd
C/igvfSmOcMYlLMN3S9Uof2mUB9gDvIBe8g49pBx7CH7fRD2kHH/DcIXzR7O
3vumsPlcxvfX9NNaP1VEbuT+2rHcWsh5QtYoi7KmbKJSItvl+8Vkzu01/NeJ
fqUTO79t+oVrCOf1lk3LtL9GkBINJ3/D5BDOe9kabJ7jkEj8Ej3PdBb/94i9
JzO2zPBPh+GHYc8w/Xs72ifw+kId1RNp6z2J6pT4Ptcyonh9U+ywuceXhkOY
bKKMQUM+rzdLvNp2v7wvhDRe/NgrNIPXP5pgoG2zLxD0fM6QL3lFvJ566KER
4hdZu/lCMedetJ4sQfUKpOVcEofOFemvEdZsCCbyCxLLz6Xkcq7/uuVeZB+6
1yM6J0lBc2bQ3KAQ5faI5gBjUA6JdC8wDe2l6WxLzuCCcrag+4VbaL+R1AdY
gHzAHvLfSyIPGccest8DYg8Zn9VmX2Szh2VSwz82n8t4+tpBopJJIrL6tHug
9wkh51Vu7QY9E2QTnVEHBVqPkzkvviwaq+CSTvwv9V2jWkc4t7rxU/RqVjj5
4jFnYExMGOcn6vYekPmWQORL2stO1I7g77fM7jskMbbcAe57TBDsM0zi9fO1
5m097OdKsg+s8+kiQ3j9D5mveWfmRsH7aNHN4ack83efvN/326QAuFLS3ctW
KpvXt7Nr2G80Mxhc1/XNGfXlJa+n/z710jB+brVIP/cV538utdQTH1TfpX3L
ueQbOndb+1cLVU+HkaKRBW3rX4g4n9Cv5V7EDd1rAp2TuKM5l9Hc4D3KbRDN
ARJQDtV0L7AQ7WU7zRnaopxFdL+wHu13HvUBapEP2EO+F+Qh9wp5yH7/iz1k
fGzRCqdmD28mX5KxEp/L+IzF2msnTRCRLWqXfPvYCDlXHr1451inbNLzkfGZ
jfnJnM+s6VZzdEY6iRu5r+mejuT30av8PUa8OxBKRn0YpqKUK/l9dOB9x7If
KxJI1MWzgzdaSN7DuXXvYgOVy3egYXXneY2pKbw+Ufd0+/kOTuR0R8uFHSbH
8/ru7x9VHDSKhXqPTfY7xxXxevNeHrdOnQwGW8Ht2u7huby+cL5WY5shoXBz
0BLVFJdSXk899NFINlH67uNaJvm9PK0nLqh+BD2XNKFzPz9+qP9RFEn8XXp1
z+1SwHk8vRf5he61hP6enXRy/vf37ONobjAE5baH5gDHUQ4D6F5gANqLE80Z
/FHO2nS/sAPtV436AG7IB+wh49hDxrGH7F7YQ8ZVtd+ZNntYbS1Sbj6X8a/9
J7/ZPEZEqtq+/+VxRpJPnXq90amN2eTsgqy8lz+TOQ+wCNo/syCNVKTsqVO4
Gce5Z8bgrNxrweRUP5/eY79Jvp+wwz5Tvs3jePLsz7DchpAo/j7J0nhbnZ0r
PCAu0sQxZlE6r18mODOhy+cLZGd5ftGsugRebzG4d5aVIA7eRQRO6fW5mNe3
nTrh94eaMKhM2Ru86piI1zd8F6wK7RMOeyO73RuwvJzXUw99NT7N+EGuGr/m
/D2tJ2ao3oaeS36ic+UnJJiNmx1LlvjNi7q0TJJnt4SWe5EkdK9I+r0L4o++
d3GU5gbWKLeQzJYcYDPK4RPdC1xGe9GnOYMA5fyH7hdq0X6B+gCfkQ/YQ8ax
h4xjD9m9sIeMi864LWz2cNRyf7Xmcxkv+OldbDVCRLz3fZGCc0LOfVYe63di
eDaxl581Yf7gFM7buhV6ntmTRrp2jbKzqo3jfPcjr+iRDwNJpx9JRRdHxXL+
Xun0EDmZeLKp6elz7R/R/D2Qno7a3sNsH8LEN2suK1dk8vo/tXM2bXY2Jr1G
mcUcCEni9R2/9BwSZJoAxzsrnalMfcXrM969M2qzOQqMR4SmRM2XvA/z5Lf9
oTeUI2HoKzmb/xTf8Hr698PHGjP2ikacmVnBuTmtJ2NRfXd6LrmMzm2jYbBn
aXkc0b6q9H2l13POC+m9yBR0LxX6PRzS/vC/38OZTXMDGZSbUU1LDqCIcnhI
9wKOaC8imjMYopxf0v3CI7Tfl9QHmIx8wB4yjj1kHHvI7oU9ZHze+aoRzR5O
8CpY0nwu42sTlX6dGyIi7tcfviu9IOTc98GDkNx3WcTwfpn2+PkpnOtoH8+3
b5tGVu5efawc4jnXcLK7FRD5hKx84KabNTGOc5GZ07h+6+JI5DKLtxazYvn7
G62vy3xds/0JzBqzdvham2xe35TwsCjq7FG4lKsVu+RYCq/fWKMW9a5/EnSb
aHph5PIyXj9jX3TytZHRcPTPupuqTys4p74FaHwzKwiS7lnF+ThaT2xQ/W7a
n/RB/UOnVnzY5JNAXHudvTmpTTHnjnR+MgfNL09zgBUoB72klnuRs+hef3OG
jSjnUJobBKLcttB9gTfa1wq6X1BH+8VeMY69Yhx7xb4Phr1iPP7S2LbNXqn+
aDRuPpfx0otnejsOEJF7EUaFp+yEnPv/zFs0KCiLDJp0Zo2iaQrn5yqH/Xf7
ZipxSf2+Z971eM4VZWremTn6kRH55ffzF0l4QMO9E8u2E6KzfNSXpJOEv0fR
9+UupSHng2BkxLhXmQ65vN6i99wEvR1XYFbPclcbrTReH16yavnw9GQwXrda
tD6hnNf/qGpfcGVSLDzt/8hv2+0qzqlXQRqBRwvhdF0159W0nrxE9Ym0PzmA
+hfQ7+mRLeh7ekl0fjIKzR/ZriUHGIZyGP+25ft4ZBT6Pt7fnGEkytmC5gaa
KLcaui9wR/sS0P0CoP1irxjHXjHe6nt3f+ds9b27v3xjdnmxhtirQ1mFp5rP
ZTxu50+Fx31FZOPwnS/7OQgl3z/suaHTAMssMvr71xDrWymcF3VdMK18QipJ
66rTKagqnvO7qXWZQxN9yJ6E/adO70zgvF9+x1dGfWKJypY3Sx5vjOPvM/yd
c2xb7/YJ8HPZrxg1QSGv/2MpE3jJ2hmU6zTGRzal8/r5T1b6rN+XCqrtOv/U
HveG18+uL7g1rW8cXNbyujJvteS+1KtgjUa/AO9DSW85V6f15AaqX0n7kxmo
f5fcljlJh+X/zjlaLz3lpFsoeZ01ZG3jC0lu2jQH2I1y6N2r5fuZRIC+n7mD
5gwTUc7leS25wTiUWxrdF2xB+9pF9wsn0H5bfU/sL2/1PbG/HHvF5sRe8fmn
WYY3e5VyVtm5+VzGLdVqbr/qKSKvP6WN9b4q5Fx9RNv/zLWyyC2n1dK/SQrn
i+69JW7pKeS935xfQ9UTOJ8p9V7pg4wXubl60mF7q0TOT0xdS3QLo4lMpPva
lB9xkvdhHn8idyQkEZ5d3nPd+GIRr59WfMvmXud0eGw/OeuOfQXnwnnOqYo9
42HzC+NGN9lazqk/oRqjrK7v32j3jvMUWk92o/o5tD8JR/016DykEs0TtzAi
f5RPBNG1LmizfkAe56+b3jXfF/B9p9PcwBXlpk1zAGmUwymaP1Sh/E3pviAX
7Qt7wjj2hPFW3xP7+z3hVt8T+8sNFIxuNHtydMGZwOZzGX83usvQyd1F5L1H
wPA+N4Sc7/dfMD+jSxbZ1XtJTO+KFM79fow5KrcjhayU98x6aJvAuUBpa4GO
tCeUGNRoTTop4Dy2xOHYjhXJ8MqtyM9+ejHnOovNLyndyoDg/6zSZlZUch41
UtPudccE8F00dt6KwHecUx/CNKb/3qP5eq7kvk9oPQlG9ctofxKN+gvoPOQD
mqeezk+eovmdJ86Ok9nrBpOthzRFnU7C+YApymcG/Z42GKDvaX+hOcMnlLMR
3QvYor20+j7YX97q+2B/OfaBnYt9YPxN0O+DzT70f5WS1nwu4zp35YOD5UUk
wHD1ARMnIec3bEbUk+cCcnxryLFtHVI5b1ywRH9hxxRS2XQ831CUwHm3K6PC
k677QIGbT/K3btmcdwpONmj/KgXS1sxucyf/Jeea9cV5vbsJQP/FqSvDR1dz
vuPZlSEi8b+fDUZ+zzXRktyL+hChIX8t69Oz6o+cr6H1ZD2q16f9yUrUvxed
hxShedTp/CQbzb8uy+SElZQLaAT+UPtwIplzR5oP2KJ8FtE8IQTl+ZHmDyNQ
/njvjOO9/6/v/ysXxR2tcHnaau+MFy4LW9G892Hmri+bz2V8xrjjqSayIrLF
vWvXu7eEnM+ONB3/0UdAut77ZHBoVCrnVlcTZI99iyCFC7f8jlyTwPml9H3b
TF74wfTqTlf07HI4D1TIGxe+JA3mvl1URFa84tyssCBzunkWTLi8ttF2jWTO
TLluJqPSE0F7k0H47IiPnNO9R2ro+il1ehhex3ksrScLUf1J2p+oo/4JdB5i
iOYJpvOTSWj+WfS+8AzdV4vmA0oonzk0T9iB8nxN84cJKH+8d8bx3vk8aO+D
fS4qbIp41mrvjM8RvFVr3vu5I3l1zecyHnlEa+LuTiIi13fawXvOQs4DrScd
rzomINa/37Wv0U3lvDY+8eW++nDy/UyHlAdPEzhvMydBJaziCSwdXX5jvVku
5zsLvhwY6pkOF+2chsxcWyo5N8H3xrKobNCdu94y1/StpD56Tl8jhyRQTEpq
o3q+jnO2dy3/hvwNez9xvoHWEyVUn077k2Wo/xE6D7mB5lGi85OFaH4/el/A
9/2bD5xF+STQPEER5bmI5g9XUf5474zjvTOO9z7SYqVXcV5hq70znm7/oX/z
3k/rD297VHwu45WfR/8ObC8in8w+39h3V8i51ovCzuNWCohS1DuVzVtSOQ+5
FZ8T0DGc5Ox79MNSJ5FzX4NOXkd8A2HWSL3y/gqSPpcL1m9fVJgBP2qOZIt+
lnJ+PredxeWyHNg1rltu6L5azgOsLWYP1E6GAuUzr98O/cQ53Xu0hut1qcbd
8p85d6f15Dmqd6L9iTnqf5fOQ9q+/XceQucn6mj+w/S+kIvuq03zAWWUzwea
J3xFeRbQ/OEyyh/vnXG8d8bx3sfqDpph+OF5q70zruYs37557w4ftyo0n8u4
BqStWNRORGS1VGU63BNy3lXFXUFtsvi/7xov1tpbpXI+/IvzPimNMFIz8vbP
sgeJnE/coebroxEM4XtkQuWcJX1szXIH3anMhImnpL/Oti3jPMxwgu9M01zY
Xt3t85xF7zgvfLhz06LyZOhyZNXwz36fOKef80dp+PhEKFff+8x5Jq0nCqg+
jvYnpqi/I52HzEDzaNH5SRCav7q+5b7wFt1XnuYDtigfbZonKKA8tWj+4Izy
x3tnHO+dcbz3SUrvcvI6vGi1d8Z3ONyonyHe+/77m5Sbz2V8ZGDNdu3/RGTf
1/4/t7gKOW/KDLc26SEgSUOSGkY4pHKuV72md/KlUGKZsvtAaGMi53NSlo5w
vBIC+fON5a6K/17DuL7rnXXlAgEMHOjbq+JPGee7DqR3OleaC8kDx9W+6Pye
885kZ0RX4xS4bn/ptP/gz5zTn/cYjZiR1xyH9qnnvDG2pZ7cRvWmtD8Rov4b
6DxkNJpnFZ2f5KD5O9L7Ar6vlKAlH8hE+ajQPMEM5WlK8wcrlD/eO+N474zj
vU+tCN26eEhxq70zPq8q7HXz3k/v+Dqy+VzGNdd2XebcRkQ2Tliz/vh9Iefn
0maEjf2dSZQu3p36wTWVc5syrWjZPyHkTPbexEbNJM632kUWgXcodIfl03T3
izgXHb1av/dcFuxcPXm4gVE55ylbRixbO10IDa5jA+Z6vedcZ63B05ynKfD1
23TX+JOfOac/7zEan4/usgk8Vs/5NFpPfqL6bNqftLv/b/9SOg8xRfMcpPOT
rmh+bXpfsEX3PU/zgf4oHz2aJ2xFea6g+cNllD/eO+N474zjvWsEn/yRMfNl
q70zvm2W97PmvaeekprYfC7jRzZ3UTSUEhH70eternQTch605fe5yLeZ5Hxs
bvRjv1TOf35f9OSs+OfCfY6gXbVZEuefJuru3GYZBnuuCT/LRYg4V7m8vm2X
ntngnLXp0d6H5ZyLznWp8bEWQllBcm5AX8n8g+Usl84dnQo6y/KU5TI+c073
HqtRWv2o1470es670XqyANUX0f7kHeo/i85DPNE8UpNa5ic70PxR9L7gge4b
TPMBB5TPSZonXEN57qf5gxDlj/fOON47nx/tXdNG/7KOYUmrvTP+PtM2p3nv
Sjm7pjafy3hArsIB6yYhIRcN66vEczKu2PvXksUlmeThLQMtndBUzk20rj0x
1wshgxNvbS12SuL84crjPew6hMOX+3Oy5N6KOI+z+nZU/nA2uHeK115SXM55
ikFeppevEIaH2RWTXZL5z96c5me+ORVK46+1ifr5mXP65zzR8AoZqLyxsZ7z
Q7SevPn/1Z8gGqPnVt1qo/RF7FHPIQmmryCbnksmonOz6ZzED80ZRe9F6tC9
xtMcYCjKoRvNDQJQbhE0Z0hEOf+ge4FBaC/YB8axD4xjH9h9sQ+M43r+fiT0
vP//6sPq5T8dyGz26mHnoerN87P6vT6LGuXFXr3zLKpVcRdy/qL2Q0ZzvcVW
q5Z61kewSNVAvjCTDG/rLHUzMpXXh7n9mvufuE9Uk4L8dHEfVv8h6lbH0CEh
xCzl5Lf9Pkm83i5cJK33LJOMHmZxdnBUKq9PivFR77IkHLS7/QgNapvH6/e8
23O074AQ8tvgYorHI8l7jezT1qmu9c6GF37d1Xd8Lef1uh/vjW6zOhwa7vsp
ZLTL4/V3vpP61EQhrJ0Re/nUVUn+0RGzv+zwy4Zl50a/vNhQzutlVz/XDrdO
BXnpXJWp3ep5/dhvzyP9UoTg0CEp6JiTZC8w4rFuj8/hsPuUKC/ihaR+bcoD
R61TqbClz5ylukqS90H9MWzpT7qj/uznKIwkh6v1/sLr3en8ZCuafwHtT3ag
/i40H/IG5aNK5yfOaP48mj+ZhfIX0HzIBpTPY7pfOIT2u4bmT+pR/n/9gXHI
n7F0v9CE9mtO/YQ65Odl6g9MRP70pZ5DMPKcUD+BID8rqedggzzHP9esD/65
ZhzX/6/3Vv2vPvy9WOjnnb1PAL+fjb1P4KHOxOJvR0XEctzSnJCAfM6Vz2uu
zDsmJDZPdx3d15jJebRr160jCzJJm4DU4ak7ozk/L91hq97CeHJ228Xdvp7e
nFc6TQk/MsCHVCy6YnPOwIfztlEGr+W/XgGrgZ6+bWQiON+iPdXqSz8v2Oeu
5iP9MJHzwc8zpi+SugFL4+8On30plfMRlJOViLP3Xby2nbWul0Ea+C8vM4v0
vgJHaX9igfrPofOQC2ieKDo/lKD5D9P7wj5030CaD/x88m8+g2mecAHlGUzz
h1Mof+wD2yN+vxmrx/tl7w2QufahslK836s/RaZx4v6Mz5ZLlzE/KiRNQztd
0fqTybn3rXNzHqdnEu8lplpyVtGc52YFHDSfFE9UrG6ZDBj0gPOtfQ1LXA88
IH2u6CuKDj/kXOPg8nLN49dgfg/Vk/06R3J+x3jmWrsIL3iw5rOu20bJ+xOy
6XseiBJ6z0MorSdPUP0J2p8Yov5T6TygiOaJofNDLzT/HXpfuIfuO5fmAzLD
/s1HgeYJt1GeeC+M472w5/SnXl88NlW8F1OPqlsF4j6ML/262ib6iJC8rdPT
fN1GwHn/6HumrwIzySSXl3e23Yvm3CLrh9LA33HkYLBx9VUlH847P1/zu6Gn
NxkpZ1f0O9xX8l6I60Ylsf1DiTyk750n9wBG3e5v62j1EJZvdfdtY+8I4LJz
r5aipL/G1TOrf9w6RNLHnJA+sDyE13eb4Nm1ps4bHB8O2hSdlszrj4zIKru5
yRFy5h8N6VGbzvlRykke4mNoH3IP9blB5yEL0DwlhS33Ev+74d97bac5wDqU
gyLNDcag3AxozvAJ5axJ9wKWaC94v4zj/bLn631m2Xe+Kd7v8HOK7b6K+zCu
0f7AtwBzIZF5nu+l017y/gHDKfE7fztkkqpBOkOMCqI5XySsfT+4rzO4dP1v
/voeRPJegnsWvTYRH3j3cNbInmWpnE/zchxGYp0gIHVqhUBL0l+dchKKeCfX
lj7kO+pzlZ5L/NG50vS9DbAAvbfBj77nAZ6g9zwspPeCUnQvTZoDyKIcgmlu
MA7lhvNnHOfPn7vXH6i4Rpz/0lHtVyoH5nMe4Kl8ctN+8b+D2t28uU5OIHmu
v7D8mcnWTLK74/S8tf1iJO89qIw0aLrgCsqr960LOBPP+Uqrz7vPD/CFmiHm
wp1uGZw7GNvUlZ+/BWVd26fuX5WDOalE/ADtQ76gPovouWQkPpe+DwHK0fsQ
9tP3J0Acen9CAr0XbEX3CqE5QArK4TPNDVaj3HD+jOP8+fPgIdI/ZcX5e0xL
kl8q7sP42XUuSi+MheSHwhxh154Czt8EzLeKGJdJ3Ac8d7U5KHnO/U308WjN
To9BJV39wB7pbM6v5wZMdYtxBumUzHFl9v/n+XrKSXvEm2gfMgv1uUOf9ycr
0PP+k+l7BkAZvWfgOZ0TnNGcF+i9oAnd6yvNAXxRDjhPxnGe7PnlKdvveQdb
iYhyYvu7lwIlz30/cT6sP2mzkOzeOUhVZ5Dk+e5Pqtc+bp4RAHv2N2w/9ieX
851dZn41Wu4CB7YV+E1Oy+N8HeXEHPHftA8xQ32y6PPycBI9L9+WPl8PTZX/
Pl8fTOcEUzQn0HvBMHQvnA/jOB/2XK1qqsyIxc35jOullyvuw5/b1QsdYL1a
SCaesuhTNlbAefCPTh2NxwXBs6Jre7pr5nE+3nP+af/7ruDkZDZMZpHkeeeR
lJPbiMfTPqQU9dGmz32DK3ru24jOA9PQPLPo/DAczY9z4HOiHNhznYuVSx+U
WIpI2N1inb5B+Zw32Nc+LlwsJEZZZx/HqAs4PzFc6+1agxDw1DSPnBJXwPkh
w9zIzVpukDzn+IyU3pLnbfdSTjIQt6N9iD/qY0qfO4a+6LnjRjoP7EDzrKHz
QyyaH+fAOM6BPVfoNCnLeqs4h0kOs8L3BEmeu6xUTKnbMFdIspXlVofoCjgn
9HlMaI+ex+zn6/YjwTcMzIe972J0uJDzufml+97KeMBEZeuQrkMkz4FOo5xM
RXwU7UOOoT6n6fOwcA49D/uWzgkFaE43ei9QR/fC+TCO82HPuxl/OtSz/IiI
LNme5Z0o7sO4R8TY5SrThWR47YQxLv/nPa7L6HOCIETPCY5ebK7iNDYSaga1
+bxn/QvOcy6PMfle4wlEeoF3spHk+cQ4ykkC4mq0D6lHfXLpc5rgg57TfEDn
hHFozoP0XmCI7oXzYRznw57DsqzX/Gkozud21zvyA4LzOd/Ztmy7yXghGXgB
ti/YLuC8hD6/Bh7o+bXdgbsmGWZFw0sVZ/AxLpE85/W7sOJVhTccOHqq0nGr
5Lm5sZQTM8QP0z6kFvW5Rp/XI1fR83oq9LlCiEHPFe6h88MINP8Zel9wQ/fF
uTGOc+PPDaUHJmRYiEjCmCWlx8R9GJ/YJslcY7CQdC+T/213SMB54/iW561A
Gz1vFXxtsXCwLYHpmh1vHk4v5Xx57Zfdj7/4wKZh90tkRkme85pFOdmCeBzt
Q2ajPsr0+TLyGT1f5kmfg4PX6Dm4KXR+6Ivm16P3hQx0X5wb4zg39pzLinyP
vuri3IKPrP5ZIu7D+Nnt73qTHkLSsFpl8BRbAeffZrQ8HwRq6PkgOVffdW9G
xoPU2VW1pTvKOb83M+n5NHlfUOtRl7W1QfL8kS3lZAbi3Wkf0gH1qabPQxFz
9DzU1/stz22BLHpu6wKdH5rQ/BvpfSEK3RfnxjjOjT3HMWkURHoeFpGMWt0Z
s0PyOX+xLzOnb0chsV24rkjupoDzR/Q5F7iCnnPxPm993Oyq+L8/e0sFqp3f
cH7q5aanIyeJ/z003athdlYl5zsoJzcQ96N9yBbUR50+TwQr0PNEr+iccBnN
OZPeC0ToXjgfxnE+7HkEeevnhorifMrWTz3qLu7DuMqRh2csGnNJj9nnrlY/
EHC+aaL5AdP9SVDn8lVdbl0J59oHl7hJNyZC+Apj/3P+FZwHxx437jL6CXzY
uG7IADfJcyKelJPPiM+jfUgc6rObnksa0blp9HkWMg09z2JFn6OBO+g5GlV6
L+iH7tWH5gA1KAecJ3/eBH9e+vd7+MPPZwacOCQiokfgKB2az/mZEtGoXx9z
yc8I7zD7CAHn8vR5BChDzyO8MDAeMm5SCnyaXTb93apSzo/MM3BctSkZjt0O
a/NZv0pSv2PHQKFaACQvfqR47IDkuYlMykkG4sdoH3IO9amk55IGdK6+Vcvz
HaQ3er5DQJ8rgRT0XMl5el9oE/nvfSfSfKAI5dPqc8u/HOfMvsf+dsNMy8/m
IvIztX7bFnEf/jzCy5Bp6a9zyXv5I4tE6QLOH9Dv7YM2+t7+rh7mavo1qTA7
/cjlDMsyzvtHplZoxKbAPK36H9fLqjmv2mD+ehoEQnBDeqf3UyTz5FFOwhEf
RPuQ5aiPGT2XzEfnzqbPU8A79DzFMnov+Iru9YXmAG3T/s0B58l4q88b/34P
/JdR+/XG4jy1DyRkx4r7MN5t+C799oW5pOrxufPHn0u+315Pv99OVNH322U3
a6vLXBf/+9JwjuaQVZI+T2qKQn0c0mHM6b491a+VS77nvzth+125NEieFzcw
aMdbzpWV9AeMmxkEqZ+9+g96+57zTpSTTMQTaB+SjfpE03OJKjp3OJ2T1KM5
XelzCmCAnlNQ6HjpZZZ7FExNXTFgtV08OLo79B/7PR+UaD7wEeUjs6klT9BH
ebb6nPAvx3th39POGhDwtdJMRLboLo3tEZbPuVCQ618oyCVw9OHandUCzntk
t3zPnODvmb+6PWKNgfjfD7a9QlZ6Hy/g/LtO/6+LhmSC3MGhIz7cfc25VsyY
U7aL0qFRd/61iKJazjcfPOASND4YOm+3U2o8J/n+vD7lRBZxHdqHtNf7t09b
3ZZziRI69yedk1xEc36gzwtABXpeoIDmALooh2c0N9iNcsP5M47zZ9+X7qHq
krlHnH+JetCEHeI+/Hvjix993JCQS/yyJrYz+ibgXHaN33WLgGRyN96jdlGv
RM7LB7nqhdxwIv3GlU2auDeF86qOzx+U/YgD1xpYuu/GU84DdOLMbe4IwOHm
SK10pzecK0oVd5xhmQHbp5+NXjT1veT73gE/LL7Lh4CbcYpx7lnJ99snU048
Ee9J+5ADqE80PZfcQud+oXMSdzTnCHovwPdqWt2SA9xBOSTQ3CAE5TaA5gwV
KGe8L8bxvtj3nFUuHl7YeFBEDj08PD5Q3IfxtU6lxyP+H13nHc31/8Xx9qBd
SlvSlNJeciUtLWkPtLQVKlGSKGkoqdAglJU9snnZm88wyswWKaOh3e/D6/t+
Ob/b8VfnPM4993Vfz3vfn/C5977D+KRYUumxQvcsxpeOH9dity+J7O6ySzJy
ZwLjsKD78d/e94h18+ZcsqqjT1vF2c9g+Yx4KFpZYLD4YUc/9ou72iOKWrMg
ZPDly8WXqhk3sD1/Yd6dDFj/weCglkFHP3bDTYUHm8tfgfewtadjF3f0pedT
TvwQN6Z+yA7kJ5CeS+LQueo0TlKG4jSb334vsEH3mkl1AKyDFtUNqrBuVGcw
QTrjfDH/KF9cf/KshtJMW1G+zg+zLPgi8sPxXirjt/T055Pnc+xMXw/IYtx4
OF/acUQSmX7w3t8im47+6i4NPZZI+VuSw2t2y/QXT2VcuGPY7UClBFhq4Tqw
l/Ebxs3mRe1aMZsHZEG3bec21DBeYDj3+kLR7yFXXVRqpts1Mn7i8ZBHag4h
sLBcvv/8oo6+cXXKyWLES6gfYoX83KHnklR0bhmNkwCK81Z9+73gKLrXKaoD
YB3EqG7wEum2hOoMJkhnnC+O43xxfcVGT40uLBPlq8kxQ3t2WG5HX7f5N8u9
HqLfF26cq+w/Motxt/wgucOvE0nJqlXTuyd39EWHNruOCntiQva9Of41IzSV
cavWifNb5yZCdp6sttTqAsYviS3MuC4t+nlS75mfTI9axiVlSng7D2TBgnnh
iu6qTYxrHXu1JlY5FIasneuz9lhHH/hqyskwxMdRP0QB+TGn55J+6Fx7GifJ
QXFmfGy/FxxA97KnOkAx0mEe1Q3GIN2uUp3hG9IZ54vjOF9cP7BxT80Dzfqi
n+t8LaUOifxwvNcSw3H5znyy8aHUmLgJWYxH+Y0W+Dslkm8CicF2zR39zLs+
fLTcv0yHtK59Kfiimsa4c4+CjfO7J0FywonyyZ8LGK8tkOvRzZ4PG5SPL09+
Vsv4pbNdXvQamw1vUwMCa0OaGJ/Qffkof14o2O1MeruloqNPuzfl5DHiV6gf
Uo38fKDnkh3oXH8aJ8lCcZrWtt8LfqB7+VIdAOvQl+oG25Fu16nOsA7pjPPF
cZwvro83cmjj0SBRvk5vuqRnJfLD8YtvJnlee8onfeIr+7+emsX4nC3LlKTP
JpKIpIF1wyQ6+pB7tIyr1rNZTH4OlugpiE9j3ErsbP4frySQ0zg7b8iVQsbt
jXrF+rXy4VnIykaLce8Y3/a+NGzQq2z4Y/emdvDAZsa/zv3Vz0i57fuxv3ve
qXT0XRdRTpwQ3039kJ72/+/HkZ5LvNC5j2icZDaKMySx/V7wG91LhuoA4UgH
E6obDES6JVGd4TzSGeeL4zhfXP/tzJiZa66K8iU916PYW+SH44frFcZcFNXh
xJenzy6ZmcX4qUzNBUrqieRhb5UZQ+Q7+oc/3u2/59mTfWBdOT3vy9h0xpNU
NebtmpEMxjf6nljaUMj40S6jc/WUBJDZo0C13uQd43dShkb6TuWB+KIopbHq
zYx73P/oEP8oDJYEfF3+9m5Hv/RNyokC4veoHzII+TlJzyX56Fw+jZNcQXGm
Pmy/F7mP7qVFdYAHSIdjVDeQRbotpjrDdKQzzhfLC8oX1x+rSe5aHRLlq1tJ
VPd4kR+OnxNk2cc/5JOBBr4Ti2ZnMV758Zy27tJEssfXqGCZckd/r4tr/xtf
m3SgrNkxSH1POuO7nzydkWCWDGMfDa7aN6+I8Qt/SZmOngDeP9TqwyPvGG8I
k/O4ZsCDPtIV5kqXmxnfWlIusMgNg+boRJsd8R19zgsoJ58R5/o5fz3f4LG/
32f2PtZG6p8MRP4v03jIVxTPERo/mYjiv+3Vfl9She6bR/WB3UgfI6onDEd6
HqX6gxjSH+eR9VejPHL9jRHiG+y3ivI46qWie6bID8ftt29fe+gBn9xK3LDI
d25WR39p7UeV1lmJRO7PxiP713X0kSq93LCpQF0fNpw/cHaW6Pcqjpv8GHpw
sW8yHO5aJ/FyZxHjfwr9ygbdFIDF2eYD+mXvGFcwm1Xm5cCDRsPwhZ8fNjM+
gfbrEh3Ur6tE7clXZN+jqN0/sUb+b9F4yDEUzySf9vjJJhR/DL0v4Ps+pfqA
DdInieoJ0khPnJfO+sa5/kncH85xy7O5Zm370nf3tTrWtoeT4z/eLCp/vVpI
FlsobvHWFzAuviojctFfHlHtdSbwYFFiB3+9dN6xtGQy77rx4YEtAYy7Zdhf
eL44lFjrqY7X//uC8UUCtRNia6+TH4qrRp5ZEMi4k+JQ/WfDn4N3vW5u081Y
xrV/uM96K3ABa/9vWRf3JzN+nHJij3gU9UMCkR9dfvu50B3+/9x7NE4wQXF+
zm+/F4xD9+pHdQB1pEP3gnbdQAHpdp/qDIeQzrhflOO4T5jjOL9dpFPKwt2d
/8kvx9XMQo3b8nt5m5NO27kcPze5WHKeKL/31I3NR54RML7/5+PxZV94RDfi
5vLC8kTGCzb+Cq33SSY/Dn8d4T05kPHYNbtq3bNDyNMDq1rOTHZjvOxYa3Jp
ohmpGvZjSPqBIMZfww3ry7IvwO6pg+d7wzjGZz+Otutx8TmEZ8aMuWmRwjjX
D/zovKzdl+tpjC+i9iQO2X+l/okj8j+IxgMfUTzeNH6wRPHH0ftCNbrvAaoP
GCJ9LlE94SHScw/VH24i/XHeOY7zznGcd66fE+ed4309n+i35b3HPY2zbedy
/OFEX+VJq4RE4LlySLYoTo4/8e317EQNjwjvuKjebEhkfGHwwudnTJNJ1g25
g96XAhlPOjBDY9cXV7jQsD32TLcExg0XLFgbbvMCJqgm3J90Io1xmse7CrUT
NlocNs9g3ITak+nIvpL6J2bIv5N1e18r5KK+1uG0PxZ+K/5/f+w4Gj+Eofj/
uy8UoPs6Un0gD+kzjOoJA5CeOI8cx3nk+D95/O+9V//k8T+eCs8Otb8/5Yr/
pfZzufdq9ba+5SvinoP9ylPOChiPmNv6tK+AR26nVYRv+ZnI+Or+g0/cXp5M
oozyp4p/DWQ8WfHGy+xTHjBGNuXre+kkxvsoL0h8JeEGoyYtDn3WN5Nxmkcb
BbGoc5MMl2czLk7tiTSyr6b+iQzy/ze1/f1fkI3e/6VK3yMGn5P//z1is2j8
4IHi/+++cB/dt5DqAz5In1yqJ1QhPf/JIxcPzuN//J/3tf33Xqp/3tf2H/dR
alBvy2OD7KUb7e//+o+PlZ2+M1dZSCb8aOnew0DAuNq6hlU/XvFIvpZQTmxA
EuOKQ2YWNTcnkZ6zb0tr3QliPKN11VJ9ay/QafwyqSUnhfHZ33vc1v3rDvf2
bJ05ZjePcZrHhwpju85wbS3mMz6X2pMnyP499U8MkP+vau3v5yIt6P1cQN/z
BeLoPV+TaPzQIv//8W+m94VSdN/JVB+YhPQJo3pCK9Lzn/ep/cf/eZ8apyfK
I/feJZxHjlemhy5ry+PYSU52bedyPMI8auFTJSE5OEwh0eS8gPGGII3cOw95
JL3qpvE5mSTGHd+d71eq5gemyw1V9ftnMO5jI5kkq/oSflbekNvq2eGH5stO
YccuQ2/5ZiHjvtSedKv6f/s46p/cQf6/v2t/fxbcQe/PcqPv4YIa9B6u/+IH
IYo/gd4XjqD7fqT6wFSkD84Lx3FeOI7zwr2HCOeF4wvNl09qy4v134/ubedy
nP/5VE4/RSHZNi4pYK6RgHF/zW82U3V5RFC6dq+6YhLjg2LPJR0RBsCQ1A0J
MUnZjDf5vdTt1egt+jf9sfenHMY/UE4+Iz6B+iFjkZ+p9L1UkI7eSxVA44EC
FE8BjR92oviV6X3hMbov1pnjWGeOY5259+lgnTneP0/Yt03nbmmLItrO5biP
2ZZCuaVCEkdm+Iy9KGA8+tD9+IWreCTugbbclj1JHe/3ISf8XkAwHP40xC/f
sMN+19oxQwbX+EHJPG/LhdfyGd9BOalCPIz6ITrITww9F1LRua9onJCM4pSk
94J+6F5YT45jPTmO9WTvkUF6crzn8Jj3bftpAxxWZbedy3EJne31vReJfk4z
zGtdcEnA+COVtSpLJHnkidzqSqmLSYz/rJ43r+RdCBx///Hk3vgcxi8VSMbO
uR8An/0tdWF7AeNGlJNfiPerafdD9JGfx/RceI7OHUvjhHwU5yB6L4hC98J6
chzryXGsJ/d+E6wnxyvuaGS06TluQ3Fl27kcP3hkv8GLeULiYDxxpdFlAePP
73lIRdRkE5VK3757HZIY7xM3PmpYcjjMV1Ffdn9RPuOzdm3LktoSBBo5jxXV
NIsZn045OYz4GOqHKCI/L+i5sB6de4LGCc4ozg/0XjAV3QvryXGsJ8exntx7
OrCeHL9xcohnm56+A8J/tJ3L8ddWfz37zxYStbBDWSVXBIw/7X28bl1gNhko
NafSIS6J8SeqKk6B2VGgrXXp2YjcN4zrrOilaiP3Cg5ayQWoPXjL+GHKyUnE
fakfchr5caDnwnB07lsaJ2xFcT6g94JwdC+sJ8exnhzHenJ9vFhPju97uuJa
m55SKvZD2vaGsfdZLHitulFOxNdMP6BxVcB4ke71n7cvZpNsDzsHo9okxmvq
jVqffCdw6G/TmOFWRYy/lCla2jomFO6GpeRsPF/OuAvl5CHiv6gfoof8FNNz
IR+dO4XGCTIozhP0XjAd3QvryXGsJ8exnlx/L9aT47vt9u5r09No9RzZtnM5
vn3RNnu9aULivirfvMlCwPiukA9uE1Zkk35bztpfGpDMuLBC6py7YxyUS91J
PrCnlHE7eUGy6ehwcHpy7Pr92ZWM36acuCFeQv2Qj8jPHnouDEXnatI44SWK
U5veC8zRvbCeHMd6chzryfX9Yj05fmp85pI2PYcrL1NpO5fj78Lrp5lPEpLH
K8ca3r0hYNzMY8vyoL6i5/3v3Ih5C5IZj+rGd/i7WvT/j9qzkjVPyhj/OYD3
ZM7ESBh9PVks5VMV4x8oJ9KIp1A/5CryY07PheHo3CYaJziiOI3ovUAK3Qvr
yXGsJ8exntzee6wnx2U+dZNo03O12CmNtnM5npWpnHlngpB4VS7cP+e2gPFc
j9/TPvKyiMuKu7wpmh17+Pc6ww61tzFwJ7ll65tR+Yz34D97U/ApEbwHr1zY
R7yi4/0FPM/Gz3LRUHbu0ySXsBrGT1NOahAfRP2QIOTnIj2XPEXn5tE4wRPF
mU/vBf7oXvJUB9iMdMD6cxzrz3GsP9dXjPXn+KKL+o1te/OqexgZtJ3L8X0b
32g4jRWSZxUm2wR3BIz/fnww8bJtFnnRuLG59Fpyh39vE40A2TgYPGXpEYV3
HX4aGzd2neOQDOGbHQKeGVYyXuHjnug2n8Ce/WqeeRfeMc6nnOxH/Cf1Q2KR
Hxl6LpFC5/6hcYI3ivMovRe8QPdaQXWARqQD1p/jWH+OY/25fmOsP8fnGtxK
b9Nfsc/Qu23nctxObbtXwkghmVQ+/fyhewLGjcvSTg/TzCLlj2QbKryTGS9Y
onK39m08nJowQP6yTwHj60sCL4hDKhhUnOiV/LaK8dri7CmSj2PhuErL3lHz
6xkvpZzoIb6T+iGXkZ939Fxigs79L06oQ3E+o/eC6eheilQHWIN0wPqz/fxI
f+YH6c/tJ8f6c7yvW5Rbm/5+y1rc2s7l+Ntvcut7DBeSr7pN4lX3BYxHrq29
sm1KFnGWvucWI0xmvH7PzXD7Fy4QE9tnSpRfBuO35EqvyV1PBD8TxzVq2kWM
n/HZMNk0Nw0MAietXKlQw/j1DeFO6ffiYO2CiW+UKt4zzu2Hnxx1q6nryQ+M
G1N7shnZm1L/xBT5f0zjIbEonmF72+MnoSj+KHpf8ET3raX6wA+kzzCqJ4Qj
PXEeOY7zyHGcR9a3jPLI8QBzvatteYS/2dFt53J8y/jMyzpDhMTTe/aDNbYC
xoOJh2ptSyY5qTXMtEtrMuPrab80WYT6pS/tO5dXt9UdxLS2fzTckMX4Elu9
ottjksGhseL5dbESxhVatCR5OzNgoNJSg943axl3jR+s1f1yPGy4f3Lw8ksf
GOf2vX8/cjFJa1Qj44+oPdmB7FWpfyKJ/K+h8RBfFM8LGj/pjuJ/RXWAM0iH
PVQ38EG6RVGdYS3SGeeXxYnyy3Gc3yf6ewLdB/+7x5vjVr8GHWrLr7fvoZy2
cznuPPK1uNhAITnrf7n8pr2A8eh+faYcicskwySM3ZaOTGF81K0RQ++ZRhDd
PxL+3pLxjJsPeC0xJd4L/k6YGT08N5vx7TZrqlSepMAOh5t95tuXMh6vta34
eEom6DecLJVOese4STd/7R+aCWDy4pzh2q6NjHP729fJD9DcubOJcT1qTyyR
PY/6J8bI/2EaDzmK4vGk8ZOvKP7Sm+33hdPovjFUHxiD9PGkeoIh0tOe6g8h
SH+cd47jvHMc591p+eTVE2f8u8eb4xbLfq1sy/tec/3atnM53rdH4egqcSG5
emzqjBePBYw/aoj2OHY/kzT5aOztuziF8dgFM4x/6oWTfh6mFeMexzM+6knK
gt5v/UBeN8PedDyf8ZPRJi1v/qTCXIsAvdc9yhj/0BI+rveYbDB4tzu6uq4j
ztq9868MnJUIq5tnh9TMa2Kc7vGLULC9F+spKdHMeAG1J+uQ/S/qn5gi/yY0
HrIMxbOaxk/kUPxm9L6A7/uY6gOtSJ/BVE+wRHreo/rDYaQ/zjvHcd45jvPu
Oqi5yHHVv3u8Ob7nrtX0trxnrY/63nYux6vvxUj37CskzWLWU+48FTDu3rLz
jeGxTFJ60EhObHsK4z/dJi1afDGMOK2IniM7KIHxwwH1Qx/xAuDLm5cWPxP5
jDsdf5o1dkU6TDcqkFbzKWM8tCX4vqs6DyY1DTpU/rmecaWEe9OEDYlwRf2l
3tqCJsbp8x6p8GvpV+Ulcc2Mz6X25BqyT6L+ySzk35fGQ+aheIxo/KQZxR9N
7wv4vh5UH6hB+nygesIXpOdhqj+8QfrjvHMc553jOO8v30bqjtr/7x5vjvut
HjGkLe9KU8TF2vbOcfxnN72Yc72EpHLYSIkVjgLGTzh8sh2ikklqNBb1rz2d
wngXxyFVM5+FkiFvbdVPGyUwXn5uRb+gi0HgE2hz6dbODj9bx72av+pQBpj0
SGq5uaKc8Q0NHt/5c/mQvnmV2WfRz1cct1E1yO1jmwSm137cfnuiuePc//a3
u2iGWobtbmHcnNqTa8h+K/VP8pD/QzQeYoni+UzjJ54o/niH9vvCUHTfk1Qf
+ID06d69XU+oRXpGUP1BFemP885xnHeO47z7+Vr0tL1Y+E/eOV4jqPjVtldT
T2qmZNu5HLff091xWQ/R70GzDuRFPxMw3quXtoz7xExSWNG0R90ihfHunwrf
65aFkFvW5Wp+uQmMTy0pccr8GAzyKX0en3vT4efp7YvrP2pmgtIc01+JSeWM
HxXjnSn14oNazeFbWwMaGG+Rj3QJnZoM/c/YDGmub2ac2+fsf/ZmevLbFsYr
qT0ZjOxPU/9kD/L/ksZDVFE8i2j8RBbFn9jSfl+wQvftTfWBCqSPE9UTpiE9
m6n+cBHpj/POcZx3juO8B1/a/Hiw7b/72zmeLpz1vn2Pd/qPiW3ncrzKxOH4
wW5C4jDCrfW7k4Bxh7G7s+36ZJJJRmW8Po9SGG/8NSxz6fIQMvtk1IYCqUTG
53VX7n5bJgRazLs0L14hZNyyUjx+knwWXA0+cuj8nIoOHldTPWSQAA7azRlh
q/GB8chS362TnydDccE55y7bWhjn8m4QPdkvb+Mnxn2oPSlD9tbUPzmF/NvT
eMhdFM8qGj/5iOL3p/eFOei+jlQfmIH0aaB6gjPSM4/qD3eQ/jjvHMd55zjO
e/j6MbOs/P/d387xG8fmlrTlfXfkBrm2czkudfByUEMXITl3eWDKJ2cB41Eu
qpnzP2WQt0FSIHRPYXygX8oenYRXZGqVtX8fjUTGu0zoemPTyFBo2So9yN5O
yPjLMxVuhnmivOupfNhjWcF4Hw2bu8u1BNDfPVsmuPoD407lp85Ud0+BpQ+r
qnkeLR3+/+tbjvQXr7Rz+8S4NbUngOwHUf9kBPIfRuMhd1A8g2n85AOKn+/b
fl+Yju4bTfWBGqTPVKonGCE9H1D94RDSH+ed4zjvHMd5jxldm9An49/97RxX
th6R05b30q9i89rO5fjyfZtLSv4KSHD+m20eLgLGv2wLWRdXmUGULBetMQtM
YTzDSHHO5aOviM25GfmWlomMP8z7fm9ReiiY+tsQm1wh48HR11K/rs+GffPO
ZegmVzB+OG5ymrHo95yeP42nD1/TEX9gn6xnwrUp8E4maevB6hbGuf3tPXs1
delV84lxF2pPGpD9KeqfDEb+E2k85CSKx5PGTy6h+G/S+8IDdN+vVB9Yg/RZ
S/WEcKTnBqo/vEP647xzHOed4zjvXN8+zjvHxRx/ZLblvfuKcYvazuV4pM/n
YUtEee//fLiFxHMB4+vFLfyOFmaQwwpqr7+FpTB++BhZbDb7FTmnXTfztUsi
4xd3Lp40b34YPJ/Z8l3/u5DxGVszzBY/zIZxfl4vf76vYPzOlS+ZkpECuDIl
9e0D8474XXWF30efTQGddw7jeop9YtyWcqKH+EPqh9xGfhTouWQqOvcujZM4
ojgn03vBeXSv/3QAHaRDAtUNhiDdJKjOMADpjPPLcZxfjq8aLqttecEVYpMd
BPklH2DurJMr7C/eBM+V4WdfnxASWU1H2euL8xlPc/+wsa5VQPZIbjgfacxj
XLY4caSfWDaZlDd6Tp/jcYyPsuxSrSaRSMaIr+6/19Kb8UvG/vVaaQGkaNUx
4+Ytbox/dnnXat1fDzLOtkyqN3jFuCKvZrzfeVdQ3Pwkx0I+nvGXN+ReTJVx
hJ+eF3LvDUphXCd0z7vNc12JhL/tiM9jkxifPvPKaYsrDsTi+7GCob2iGedH
fbqnMssR8psnHi+U9WX84oVVtc/rouDpHXWx84tdGT+sEa5Xop0GMjPM4+e9
CmH8uNil/u9z+WC8Rzxh+fFUxj+Ove7joi+EkmvLI++NzGFcicc/MGjnegh+
eTft0Mj3jCelTh/naupMJn71ecQPa2Qc56uh98FT16odoaSun0yuKF8aTw7v
vyHKF8crtpmG1nwVkCXy85YPM+Exri5+6H3F3yySLrNr+ze9OMaNEkbGrv+e
QEx7vpLs98ebcafXk4fkageQPS5yNzZfcWdc4eXV4zoxhnDkW1XSaLsQxuMv
7g+32uQGizarmJ3plcB4Xou0983fjtDwtbjHfbFUxs3DLo42VLQgzl6nd3r1
SWP8wGCXY74lrsRaVV7+jVgy49lKc1pDDj4judnffhXrxnTwjQ41p/Y9BY/T
q21HFPgxHrxUPkv7SRRs/Wr92+SPK+M9BNfHXtqSBjO7VS5VyOuI/+ToHt9A
yIfT8w0Cc3U64ix86vpRW5THhxZmSyJEeeQ4ziPHcb7G/bqu8WyVB3htr1yQ
LcrXNI/XW61E+eL42T7OpyW/CMh5uz7OxqY8xh9se6DzsCGLrD4dIzvNNI5x
yw3j5i5MSSCy0kscT/N9GI9JG//tnMAdtHzmupRfTWS8HwxOGLrcCS72GTTh
Sloa42bNa2KV114nb2THWmkL0hn/Wvrs49IB7iTKIbpkq+j/HY77b33RvXif
M8k2iL8TbBzbca7x9ge9Jz2C4wf1Py88GcB4wNedihYDo6BqZPKbcE13xk+V
joXnc9JAfpTaVpMBoYwffzA890IWH+LX+aotOpvK+GKxG9u/6wlh27v6Z91G
5TCO9ec41l9mSWNXRSt/mDq6F0kS6Z/Pk/hhI9Kf4ztbUyvMWwSkeWfO3g/m
PMZTH9y520WQRcTu543SfRDH+Ea5hdZulxOI2cfwaQN/+zK+eZ3J0/JvnrD3
zq6D29yTGa/XqTgWtt0ZRg81jx+3JpNx8dObDh2N8yBD4mSHnxmYzvgm1WcL
Q1OfE8n0HwUD1sczbrh0S0ucxQPoWXBgsr51EOPrH6qLea6OhDGtirq9tnsy
buViczqwexpIDb80e9O+UMZbx2W0eCbzYf5sB91dl1I7eMB4WU2RzjMmzh5y
XKQzx7HOHMc6LzYYtW1GazCUJL7NixDpHKQ5S+mxSGeO93hwjSffKCChc+Qm
7LXkMV486d7I8z5ZRNInYrW1bxzjU8w3u+hNTCDmp6IXz1HyZzw5LtNlF/GG
tN8nvA4fSWO8dy+zn3pRLhB8fOjsRpMO/90ezfIZ2fKSxOSu8Ro1Oovxpisv
fOdVuJE7BWv9BjgnMr7+lGXJ58lWMKMmvCVTPYTxInm7AZNXRYDDCZWZJqVe
jKeaRd9bmJIKBu6LVMLTQhk//mBKWnk0Hx6PDPQacyOV8X0DpBVFP3NAzZLC
3Y0inTmOdeY41nlD4EqPUfvDYZ7drKc+Ip0nXto0+LlIZ45PnbFEftp7ASk5
ouAUacVjXG/Z8eCDZlmkl3jSmqXZcYw/LtmQpzLAHy6MOqOWG5XJeGbPmdkD
Tr2Ad0Z1OpMDBYwH5x1qjnrkQ65EV6UPPcxnvBdpKOz14iUx8LukGCz6OYvj
O5rHzew2IBy6HW9ItWjyZTz98F7Zd6L6O/JDd5rp2jDGbZIiAhWC+LBNanyw
pl0q4/U/n9Y+Py2Em09L6qxH5zCOdeM41m3/R92ffTKiYYWy+2JHkW6Jr/6q
+4h047hQWW6sUY2AbPrsEv7zPo/xBfN2eq5WyyKb7rwdPORTHON33Q5enNE9
EG4WPjidvZHPuFz3wjNGh92AP8Zq8oqvOYw/uZ08Q26nP+FprgmMvyVkvL4q
7EtNNz/SUtz0yDwmnfGZYitUnKamwoxrGVoypWGMX7MzdSl044N+X17MZ/dU
xoti3/25cUoIdQnbCteP6TgX68NxrM8SiY3uF0fFQQE5U3xbpI/4gfM1YSJ9
OH7TbKnHzHIB6aFa/bLvEx7jnx910QwfkUVuTsoe7DYmnnHT3k80ri4KBumV
JzYPuCxkfNAKpV8pzzzgS91l5y7XOvzPtLhuvH14IFlh2Kw49Vsu4xu8M04U
fQsgii9V5RzPZjMeW/U7vsyeD80Ged19IlIZn91LWrhORwj+D2d9kxqbwzjW
geNYB5WgSr7+pgQ4FhUYZiTSocvAbx5JIh04PlPBIXBXkYCYqIet5rvwGHcL
ELt3oCCTHJjSx+SCajzj6eDt6+UeAva9FVXt3+Uyvjk5IXjDUC94G3Y6LmB7
AeOtPgPUxncLJl4zdh/58/w1401SYbK5/sHkpM+OmU0rBYzbNgX1MrrBB/6w
N1s28VIZL9+lOObDCSFUa6Qki43LYRzrwHGsw8bNRj+OXU0CoWx+b22RDhGJ
88/miHTgeJ38smjxPAEpDLFavMiLx/jISR57/zzMJKtur0jraRzfwc2yxm1d
Gw4brilXzbz6mnFfvRJ5v3AfkHkdZFB2oJhxcblWpwSJEOI77Fe40vVCxhvL
h5fMcw4l9eujjLoa5zBusnjJS4EhH0as9491qE5lfHeXwu96x4Xw4JGWZe/x
HfZYB45jHXY2DpDZH54CJ9629t4k0sGzNW1chUgHjlsGzQrekS0gGkHPVk4N
5jH+q3fPnjs2ZpLxFeuVgvzjGY+YIJ9mJxEFMrbr9P+sLWR8eY8Ls4xX+oPG
fD2ZI05vGb8/9Vxq73VhZOwGfR2VRyWMl+bxt8vGRRCXUQP/vs3LYzzH0tBz
zBE+8Pau27HtdyrjsX5lxaVHheAms2fVMKkcxrEOHMc6HLB6sWHnxzQokB7/
c6FIh1fpfsbNIh04LpVd+2pzioDYLHlpfy2ax/hTx3mPVnTPJN/Lt6ZW1cYz
/iZD792gHgSqjK2sgmeXMD5Uw3vubhIA0YmbxZLNyhmPbD4/b92TCHLu+cfZ
x46WMW5xIMdhe+8Yorlqt9ql9W8Y3xXvPO3uVj44/n78bubwNMb/Ki64vOiI
EIxHSRfKTchhHOvAcazDSdkl5zdNzITRdy9MlhLpME8uVavrknzGTcpy8wfE
Csgw6VMj5qXwGF/3NUzH9VUGSZI2DP8slcB4xIhT1773jIO+5iXX148sY3zs
hXKL7quCYFiB+taBKpWMH1kXsO7p3ygScjPi2IQhFYxrXXxxrTk4lkxyXRh+
9k0h43dDAwr2LefDl6NL376dlcb41i3Xc821hfAo1ParmnQO41gHjmMdDNJ4
Tqt2ZoPVYWtBb5EOy9Ycsh8s0oHjNp/GVrwIE5CNQf2Chgt4jM9/vMBQ+3AG
WePdxFu4J4HxwvjD0UPa9tlqKo/PdS5nXGfo3ReVuaKf71I2tqYPqGb8S2S2
SpYuIdonn0tlJVYybm1kUr3ldDzxvm5+eoJ+CeP9o9evy5DjQ+PjDeNHq6Yx
vuTZyZ9JB0W/XxT+nn1hYg7jWAeOYx1ig+ZUO67iw/i6IysbjwtJ8ZPcLxNE
OnD8r+siyekBAjJUVzF2YBGP8e/zlR/oDc8gnlPGzvz7MIHxJQ9ap77QiIOw
sX+vFw4tYDwnvvsqvwmJELqmtSFfrpLxsgMN+zYcCQG5aV2k7EtqGP/4Q7Yg
8VMsMTh3L3LLxWrG10YGervIJZLp9nPjC/uUMf7V/pSV3JgwMvh1nsWeM0LG
nzl8Xdl3FB+qK6o/3DuUxvj0jf1n9jgghFfaywa5yeQwjnXjONYt2ey30aj9
Ahg8yTcjX6Sb9bifq+aIdON4fXephmBPAZm5RkutazWP8RsBF8LDk9PJzqrt
xx7zExj3HR92qmpiAgjGlbekTili3MX1e/R4/yQojpmo6R9WxfjJPyNaLL+F
wscDMkl9vd4x/uXRiuULZsaTF0lH+t+Tr2V8pkytukt9EpGtOO3hsaOc8UP5
1ufO6EeSCbc1tl36m8O4n5n78O29+DBxxs6SzyZpjG+OPBW4Yp8QnqRs7i+Y
1GGPdeM41i1jc+oA24tC6Jn/xidGpJu9R+luZZFuHC+M+kT2uAjIyl8qt7I+
8hi/p7dRVs4wneSdP/1kl1gi45sW9lO4WJkIBuONoH5uCeP+OXZrwhalQM/0
k3vJshrGjQNHj6wwD4erP4ybQvTqGTebclNS/FACKX27I+nQ23eMH4h5tGy0
cwo59j38lpVzBeNzrGN7zYmKIQtUZ5TxruUxLnB2iiwQ5Vs1+WnkZ/s0xq1v
OKXf0BTCaMUi99bJOYxj3TiOdeNL3X8+2DYHxtevnecu0u1607Ku6iLdOG7Z
nOY874mA7BUX9tnxjcf47qMlL0Nl08mmZCf9u8qJjJv0633KvSYASgNsVlev
4zM+IniY/DS7ZKjT91AfOect48beXe6XhqTC2R35c86G1TLuo7FRKaRHJHw1
sv2pOqOB8cWvpp91vpdIZuU7CuLM6hlvkEk4WrcujSicl1D1qqhkPLXo6umk
1liSoD7LnXR9zfjM7akLDz86AUErU/KHtSYzbrA1LXJgLA9cZLuZrghMY7yn
4+cXRXuFYCj//MTwqTmMY505jnXOa9RYZOWfC/XKBq7WIp3/akmJ7xfpzPHs
pZf6bnsgIJenPX0Q24XPuOT6g0GKFWnkwvuYxfcNExnvNnPEyCrbQPLD+tqf
GwbxjIe4pcj0vB0MaV8UliusFzA+bpyHh3BxKljvPmUgd6eM8cA+MS9GTE6H
dK0LipoydYyTsKBDZgZRoJJnf/dhXkf82eKuU3SDkshZexPLaIkGxtVcfXPF
a9IJf12vUYojqhlPdYs8rnclnkSGK21/c+oN446Wr1YmGZ0hY5rLGpevSmXc
4vgfeyL6PaqrxoH5D9PTGA/frb9ecY8QuvT58XPatBzGsf4cx/oXxkzN6pOR
ByMUh6y8KNK/vP/BdadF+nP8kcMye4GVgLgs05sv2ZPPuKLXuTTHp2mkf5iN
MN4rkfG/aVu9HsoFEPWcXQHL5yUwbrV26q66/qGw/ILzuckgZPzkqm4j7ian
gW51S/Z5g3LG5ayXqkuYZUBu45/liy/VM35lwCOnplzR78Hrxyx6fLSR8S09
kr3rwl6Q2bGvRmwd3cS4rf3d/YOTk4ml3Kdjjvc77ntWNvxm0PFMYjNG8bX7
0hrGd305e+Ty1wSy3zBwojC1gHEy4mbpgCs3iKW31Ppy8zTG5XcMteYXxcF8
2dbtTxriGPf/vEttuxEP1MrHlDqVd9hPSwp6FLJL9P/gieyxs6bnMI7zxXGc
r7dWn/Zfrc6HENNVW46I8pW5QMnOWJQvjidEuBZGXxeQ2dOvaE7qy2fcXGJa
tceeNHK0u87Tq0WJHfZqU0q+hvmRsmPRb1ZUJzB+cM9Uk6xD4RB7cJEgXfRz
L8d75E+JDF2UAYuPvTCbs6mC8QVx6VMTkjOhunfm3B8x7xn325w+s3o0gXGn
pH026TYxrpoj2XffI1fiEqUefa6ogw+OXFq6PjmFnL1TsKG+9SPj3y9Uiqvn
ZZHbTetLL6yvZbzCfnP4XfUkYmEx3dNRvIhx+W+Rd06OfkBcDhxzXOydzrje
xznblXXiIPNs34Wf18czfloretrSXTz4Pn3apgmtaYxf77VbZu1OIZx/qBUn
LduhA84Xx3G+qvbGfP379zUUHm4U3ybKl5YDL9lSlC+Ou8wdMGCGmYC0zKyp
KerHZ3yT4O2f8VJpZI+O4vK1vZMY77o9YeOQTT7EyXyX/KXriYz/vPZbwvtG
JEhfCx5xpTmH8TVXkh99uZUJsmYvJHIkKhn3lTzqo96UBfsX2Owrqm5g/Fqg
h1bSxFgYmvN0tuOYZsYHHzv/fvgRN3Jk8pUFt2518C5fnO5NCEglozV+1S0e
38R4zKea324TeKTbhpjtV1e9Y1zslN8rq3vJpLFWadC5ucWMnw9Zdqp/wWOS
2HuGgSAyg/GBu/b0bOotytfnlb+UXOMZ7xecdyV7KQ/OvfX7myeWzviqDyrz
f2wXwgY3HfFuMzp0wPli9ihfdbI3bl0cVQB2u+pcVdo+D9VMXt0X5Yvj9Ut4
dTMuCUh8boSn/CA+4+W3xySH1KcSS/eMg1Yzkxg3cpw6O0rGi+wK08vpNbKD
e+t2TZIwiAaJIW4lBV65jD/T8DLbGJUFiwvS9/VMrWQ8NcE0bdXPbDgxOiT6
yMeOOMdd1fw182UsnOgWfGVuaDPjOcM3174Y706iLVf3vDqthfEHhVZe2eZp
ZOSoTIOggCbGw3XKDGom8cl4YWxm3uQ6xnefGf4p0i+FmNtsO1WiUMK4rbD1
iJ2+E3k3t8nbyC+T8aEX6kP7+sSCxXsTZ8PP8Yx3raj0ODqBB88bItPNx6Qz
Dtkh4VnbhOCunamRLsoXx3G+OI7z9fHHFqnWeYXwaPJJ9QWifJXpGys7iPLF
8dGvhunwDAVkvflt95FD+Yxf0Zp/o39UKlk69NO0IrUkxmUGGa45q+RJjusr
tMjad/Ammx4uKjIEyoptX7tuzGP8zdHQLrOTs2FP9/d3Ag9WMZ5869QKkyoe
rHd0XXst7yPjT1KCuj4dHwf2dTruoNjC+LcdM4eUxbqTO2Zd+lgEdXCpvgOL
ipamk8aDV+Rezm5mfLFYsKm0B59k9LT8nVVfx3iX8gQz4plKKgIt5CJlShl3
vKo4Mm/4c3LBtOrz9qtZjGttu6vkpBELN/WGHvJZnMB45Rifgp1iPCgdFuP0
RTad8TWatxambBXCOn9FLSO5HMZxvjiO8/Upbdwr/U1FcHP1eYXponxB4PjN
rqJ8cTzWoChA6pyAWO7QkLkjwWd8Q7T8Vv8HqeTHzkOOGTpJjB+9FCLxzt2d
KP2pbzrVPZnxA3N7J9mujgWhgv/RX6/zGN+9yGTgZTcenP894EDv2irGr512
vOe4lQ995rXsNrFvZHxK062/XmZxUJs7cZOcfwvj04tmm1Wt8SB9zmn3+TTl
E+O54hAm9TqdvDBT+O3g0My4dM/0iC7DBSRnaJcoKet6xhODXLq9NE4jYmmW
B7e/K2W8r7fRJPXNrsTGOeVE/cJsxvWf67c6j4qFqPM3rQaeTWDcqNB3XdXX
bJg5LXvy70XpjOdUvoiv2yKEj13Nu/WfmcM4zhfHcb6+2det/XisGGxz1Syl
RPlauHVxmpcoXxw3DXdMktUXkL6yRXEWI/iMvzulu17iXCrZs+NFde9rSYyv
uLghs1zLjTTt7VZutSuZcfu8ROfVBbFgvU9BY/mqDv/lo+ZHrpPjg/ahXB8j
tWrGBX7xZx4/50N0zvjyq6OaGE9esf75fGEcuA4Tt3QT/8S4nMrlHyNDPEjA
xHhbnWsd/NgUUMzYkkFGmAmqVD83M961XvzQwlMCUuYqnV8y7D3jDgqGx7pN
Tiff+Tt/HLz2tiN+sREbNUe7k1mmpyRHpmYzLiMeUuKXRuBT9p+KRpcExgdO
3XdwZa0oX18zlp9Zkc64j7Hfp4WifGk2X7xtLsoXx3G+OI7z9ftIcOmxqyVw
0VVyy0hRvj6natr5i/LF8Y1ZspbfTwtI3thLD39L8hmfPl5y4xMNUb6ao5VV
bZMY9zZJbF580pVIg91qi0fJjFd/CnG+vDIO6kU/a06z7/C/v8gjf6YuH34d
vvg107Ga8RfLy8NWlvJBU2tTjsfWJsbnPFk6T7V/PORXmyTbb/rE+BkD0+BF
vT2J+bdo6ZL0Ds4vfbdc2z+DbPuuQLzntTB++7l7eLSfgOieWFJjcP4942Gj
S/Qzn6cTe4t1Nv1+vGVc1fdS9uPTHiRG5qTCnLk8xiN4WrNSjAj8kewfFJeU
0MGLGrt5FWWDqlrMrUXr0hlfM3t7WZC6EJwnHnhUJMoXx3G+OI7z1W3h5TPV
jqWQU6sbOEyUr4EtE32CRPniuLrtX2trUR0aK69c8nEkn/EfyTt4lhtTiefG
e+80nZMYPz3mjTCD94IESY+cZB+fzHjjuL6t32/GQV2LawTJ7PB/ZuHhkVJP
+NDinjp5uKCacR9dD9Wm7gJ4P7HU/JdRE+OxXbrsWzQ3HhJ2dR+z6OInxjXn
CnPfvM8gOj1PqXXTbGHc5XLwYF6BgISZPPuTEPKe8fqJUQ/ufE4nj+2O9jCS
LmNcY7PCBTFVT/JIperw5/M8xr+HFIcbrSJgNmGk8ZjiBMblXlj9XpibDVLf
BwbOV0tnXHJxVwktUV5OjGuSGjYrh3GcF6aPhc2EKF8PCJjDK771MwlWDPM3
mTgjFOQ/ujUE7PEFsu16Ue8uGYw3xLR/fw2n0ffXTuIF85y0vCCt0V8rWjOA
2c//feNwgH84bA57rF+43YfxGcmWNi/jPMG2oaG4v30g8/Px+Czdp7HesLtr
w7OT4mmwQ61IMNg2Eob0nlW/uksALNu/UtzkaTbjPPq9MNSh74UlU4QXlLt7
wN9RZ1d/qAti9nNe1FjZaIbBui/z06Zs82e89GrGiMfB/pAh8fV84O1MWLDK
fEiXLrGwUmOftPzwIAi6UE92aAkYV6Lft8IC9H0rUVabu6o+Dt6GPT38VRDI
7HUt5dOzvqdA15V9NWNnhTN+2ED4c8WGIBAklMw4uYQPSlWSCq3z4mFRvyey
m469Ao/XBiNH+eQwXk6/34Qj6PvNOvp3acB/lwZ1jeDlqeGQZXB9VfHiHFgx
2t6vOIcPacpjrVSWx4PhKt0PR8YVMr6b/p0WpNHfaeV3tf99jESiv4+tWOxZ
vlE9nqRd0bDccS2u4+88mSd0pgyPJ2YZBmUJ4XGwY0dCt4xleZBf+vO+4dsA
Enp+QmJBfjzji+nfE8gC9PeEp7TfDyRRv59pdHs9kzjUH1hJ+wlJDuonPEz7
D4k+6j88TfsVySTUr2hH+xuJH+pv/EP7IUkp6of8KtfePwkmqH9yC+23hMGo
39KX9meS7i//vz/Tn/b7wTPU77eP9nmStajP0/RFe18oKUJ9oTtpHynkoj7S
brTvFL6J/X/fqTTtU4WxqE+VT/taQQv1tQbRPliQR32w4+jnPAlHfbP48z/+
br9Uj8G2/+SxM87pMPZ0nFT+CSEpsVsxwFJ0Lmf/fnDfnTdFeTdapPTZWZR3
jq97BWFXWgXEd8/Nhysv8Rjn0X5Fcgv1K+rceH+8IIdPZp0Zusr/RCqzt9zz
KmtPr2zSbYQsLNCJY/wY7YckB1E/ZH8LhxZTzTRi9/6AZt/4EGa/bPA64Qix
RGLzZckP01BvxgfQfksyC/VbelX2GbE+PYo0uz95ecjSldlXyF84fNk5gGjO
qnPzynRjXED7OclR1M/5oP9Tz+JzDuTU5JuDs177Mnsl3y52KtJnYUEvu7t7
618x/ov2i5JA1C+qETp2rp+yI/x0qPA/YhfN7GvtxrpOzXaFx34zKhdZxDP+
iPajQhbqRz3X9ftN6/Ou8MksSavAOInZ37Lz2bvsoiNYx0k2hIr+f+G4Ku13
hZuo33XyoAVROm4PIcD9jra9Z4f+d6kf8gj5uUPPJT/QuQW0/5Z8Qv23fe3b
70Xc0L3uUR1ID8f/16GS9veSFai/N9GvXWeyGul8lOYFDqO8ZHq19w8TA9Q/
HE3zDttR3q1pnUAJqpMLtD8Z1FF/8iRah3Aa1WE3Wrdgi+p2H+1/Bk3U/2xC
nwv4Mfz/nws9+hzBEvQcraH91ZCA+qvV6XMKgeg5/UKfazBHz3Ud7d8GRdS/
PZV+PkAF+nyopX3gcAj1geOfizh7/DnWGe+sn1ksdq9YQPHzfz7HOuNcX+65
gJGmAtHn27fYPjK3RHFy9pEjg2/PF31erZibfbFQpAPHN5kMjZP8KiC/X4x6
O/kyj/FZtB+YrEP9wB46S96N5/NJrzHaJ310U5n9zu5fNq5tzSKbzv6pUjWM
Y/ww7TcmYajf2Od70cJClTTy7NeFppiPIcze59td1V8VCYRvrqybuseHcUPa
z0xmo37mSTbTlg/TiCLbpxhv1XnixuxzCvMibw4PIErXb1/ao+fB+JjM548z
Gh+TJ6+KDhjb+TO+L3DHqoelJlDav+sQN+NQxrdHfdlVoecESxaJn+XfI4xP
G7Rj7qWfbtAl1+VIvn8C43a0fxvSUP+21xbHfE1tN3Ct3FB3LSWZ2dcn8CN8
Xz6Dxn0K9oGCDj1LaX84vEL94SG0nxxeo37yBuqHtCI/ifRc4o3O/a9fnZij
fvW19F6kH7rXaaoDUUE6lNF+eHIC9cNXBbXrSZqQni0Z7fqDLdJ/7xXFLYPB
nLi4pIzY9Diso05oHmEJyqMYzTsoo7xv/ODSUBrkD37rYlZKPPVkfh7SugIf
VFcutA7BAdWhLu3/hz6o/38jrXNYjerciz4XMAg9FzfpfAEoofmC7fS5g26u
///cJdPnFDag5/QinV+Ai2h+4TJ93uEPet5f0TkIkEdzEPjzirPHn0ud8c76
/+ctCvK38vf+53OpM871t+8xK1dNF31eBc+f2XJXFCdnvz17t1GA6PPHQjvY
co7o84fjY22czGs+CYjtTU2LYWY8xhtoXz2RRn31l1Z3C1NP5xNpgx0h+oap
zP5R0FM13lvR59UASWWrG3GMf6Z9+0QW9+0X+ZdVj0kjwdZ21gfmhTL7G+Ef
tgxxSyCO/WzFXop+3+W4LZ0LINJoLuCVZU4vCRMX2Bl46ML6LR3nhjuu2/ua
7wF/5Md//3IlifGFdE4BhqE5hTWzV1Ynv3YHWwfPqAfpHfdyJZOcPeOc4Ex9
4S2V5vSOe51qn4MAMTQH4UbtiTGy30/9E0fk/x2dsyAyaM6ikMZPxGf/f/zZ
9L5EE91Xl85xkONojuNz3fPBvhnXyXPpxTuUGsOZ/agc400Xu9rB4Ntu8eOO
BzKuVFmkGTLYigzpeSvL6EIk8zPEsTlylKLo8yV+vo1jFy9mP0fpa5evgZFg
GK5fJVjt0aFP/MNZcif84Ef3uy/fO3gzP3o0v2CM8vuB1gMEoXpYQOdW4ACa
W7lL6w3WoHozpfUJM1B9xtC5GOiO5mJkaP3DY1T/++nzAtboedlH527gC5q7
0abPHUSg524und+BYjS/gz83OHv8+dAZ72yeZeabq7Lz4wP/+XzojHPzGkcG
RtrGij43vF+vPm4ripOzlz+i/fKvrpB82eozxFOkA8dLcg/aNTeJPjdm747r
acFjfBudEyHFaE5kzcfCFebxfDJxxTbBO7NUZj9fu3jNvNgs4t9v5400pzjG
j9A5FHIXzaFIKo58M7o2lUiD6dKJNqHMvovR/bhBWxPIjuuf0icF+zEupHMu
5Dyac/Hwq1BLB1e48+NjhdLhBGY/3llHJ2SNF2T/2Wo78XMK42/o3A3cQHM3
Ds9W/tZN94SZjzZ//3k5g9m/t2+f34EQNL/zitqTeci+G50DItFoDkiRxkNK
UDyxNH7yAMVfTeeMyBs0Z7SgbLbSY4t7ZOjuQ6+ES6KZvfptvmRYyD3I8qoZ
u600mPGYos8KecUPyGqbV9o/ZpKOOaOghh76833h91vbBcn6vsy+ztq9oTEr
Aj7NHWB32/Il4zN1u91qKPIG8UbPobWKHfNQtYbt+YIFKF8DaH5BCuV3AJ2r
grNorkqW1g94oPpZR+sNZqB6E9K5LRiE5raqaD3DY1TPS2j9w19U//3oXBhE
orkwPfocQSB6jmrpfBmEofky/DnA2ePnvTPe2bwV93dd/Lx3xtnck3yyabDo
c6DfiPeGjqI4OfvIBpP50qLn2t6t+ZXC6BzGzWynFyt/EJCBhT8jPt7kMV5G
556IKZp7GppV9Cs1jE/0dmjvaLqbyuy7Jrwe+to+i5xST/sdHh3HuDWdqyKq
aK5q+u1fd8a+SCXX1526U9srjNmrDasM/vAhnuwqyq+w9/dn/OTLnvpXF3pD
wZ3p5x+/zWb8KZ0LAxM0F3aV2pNyZJ9M58vIRzRfton+fZ5ko7/Pi11v/3s+
CUV/z/ek82vEEs2v7dp7NETshj25KqHsHvUyltkfagiam6poATo9Gr/ENYQy
vpDeF1TRfaWoPmCB9NngpT/VJygeanXGXGiZHsDO/Rrfrj8cQfoPp/kCY5Sv
w3QuD/6K/f9c3k1aDzAU1UMSrR94jupnFp37g3I097ef1iEMQXWoSOcHYTqa
H8TPEWePn5fOeGfzd9z3Efh56Yxz33fs+r1Gzk30HIktruvpIYqTs0803hI0
WvRcLGs+GPpepAPHgwbpalW/E5CJC5+FxFrzGBfQ+TjyFs3HXT2uJLHch0+8
Lx+RO/Asldm7PGzKlzueRaRjmhJ6l8Uxbkbn78gxNH/35JCYfPgIP0g6dXy4
x2kBs79L5/4gHc39BVN7kobsZej8IHmN5gel6fdEZD36nqjPifbvlcg+9L2S
I51PJPfRfKJzU0hE0dl4OL3ppFSlbwCz1zniPCJ4ayrc2WE3dPO9MMYrTo+y
85gdD2fjpyb0VghkfuyoPjAa6XOd6gmhSM8ZdI4S1qA5ygiaL5iK8sWj+YXV
KL+FdE4TtqA5zYO0TmAQqpMNdN4T0tG8J65zzh7Xc2e8szlK7vsvXM+dce77
teFNyikPRXVu1WD3OVAUJ2cfrZG0sFFHSOz84/sGi+qW4z9HzF5aUykgCWZr
FI7b8RifTOcfiRuafzS5kjJ1gBOfFN0+821gQCqzn79ZzjFxnuj3zW+Xatb1
jmc8is5Xkho0X3nud2nGgtkBEHLAc+2d8I54JtL5TVBE85tXqD2JRPY96Bwo
+YnmQLfR7yVJNPpe8j39HpPkou8x79I5UyKL5kyn03vBGnQvM6oDVCMd6ukc
K5ijOdZuku06QyrSOZXmBZxRXmzonCz0QXOyUjS/YIPyW0nnbWEQmrfF9cnZ
4zrsjHc238p934rrsDPOfQ+7JP/9ZXNRfY7fMkWGiOLk7I1V/Nc4nRQSnTj+
lvtjO77PLbR+dGprqYCo3B6y4bUjj/HXdC6VFKG51CyvnNwd9/hkx/IfHomJ
qcy+a/+q0KXfM4nygU23Bs2NZ/w+nXslSWjuVV3Pc05ZryBQiKjd5ryqI856
OlcLL9BcrSa1J8rIfgWdzyU1aD53Df3+mgSh76/P0u+7ST76vruQzv+SF2j+
90u/9nvBUnQvPtUB9iMdntD5YtiL5osrqM6wBul8neYFzqO8LKDzy2CO5pdV
aH5hMsrvWToHDb3QHDSuT84e12FnvLO5Y1UzX+2PxxL/qcPOODe3WyApded0
288Jxj10M0VxcvaF17bnzBHxme/3t1qI6o3jPXy7Bii9EZAD2nOeNbvxGFej
88LkJpoXnrH/2nLVK3zS5VavUSsLU5m9ynm7nJVhmcTRZ9o24YF4xi/SeWTS
D80j60pM+WMqHQLJJ34uGbJXyOzXngp/87IlFLJ6D/79RL4j/jI67wxVaN75
z4z2+WhwR/PRT+k8NZmB5ql3Uf+kEPm/TOMhmSieaXRem+xG89qL6X3BDt1X
nuoDYkifAXQeHJTQPLg41R+OIP2rab5gEcpXM503h7do3ryS5h0GobyX0Ll1
iEVz67huOXtcn53xzubEt0qp3K12TP6nPjvj3Jx1r2FRcrtF9dkwbbV/oShO
zl61yU7K65iQVG5cMPK2qA45zhsYD9ECAfGwKi5z8uMxHkLnu8kTNN+tPHmu
g4Qun2waGBev1pzK7E/ke9a56meS2Rd+f+hqG9/hn86Pk0Q0Px4xQeE4XzYc
VPufeFX9IpfZK10Knuv2MgLeThnVQ73iDePZdD4dnqL59Gt0nh0k0Dz7fDr/
To6i+fcN1D9pQP7TaDxEDcWTTufryRw0X69F7wvT0X1XUn1gN9Knic7vwyg0
v59P9QcfpP82mi/4iPJ1l+4HgP1oP8BgmndoQXk/R/cMgD/aM4DrlrPH9dkZ
72yuXzOmIKw4J/Wf+uyMc3PxwpPvHFeI6lb70bSIOlGcnP0fb4nU/qI6PDHZ
yvOZqA45LrH7nHtJuoCsy1PumhHGY/wznccn+mgef21A1q0PGnziqzTB0KVv
GrOfGjGrZca0TLL72ehXPTPjGd9O5/3JfTTvbyI9VFliXxScDlm/TXzAa2b/
cv6sHZI3ouHmogOjJ0cUMW5A9wnAdrRPwJvuHwBdtH+gF91XQBLQvoJw6p88
Rf7v0HiIIYqnlu5DIF/RPoQx9L6wDd13A9UHwpE+1nTfAnxG+xbGUP1BDenf
16c9X2CA8jWF7nMAO7TPoZjmHY6jvFfSvRAQgfZC4Lrl7HF9dsY728NwdO/p
ipw+Gf/UZ2ec22Pw3nTXpBmiut1abrnvuyhOzv5M3DEXrcNCkiq5TSdGVIcc
T7yz7kZIgujnhCqeydZ4HuNr6f4EchftT3gqVnGrzzo+6eVmodAsncbsW/xj
9EKLM0jeh/W3l/ZIYPw23c9A3qP9DNaN2vYBrwgMDewuXGVdwOyfneliEKgc
C0e2zE+961fK+Ha6/wFGo/0Pu+m+CAhA+yIG0v0SZCTaL+FG/RND5N+ZxkPG
oHhi6f4KMgTtr6im9wUeuu8zqg8MQvoo0v0YEIv2Y2RQ/eEI0t+E5guEKF/X
6P4NGIn2b3yheYfdKO+T6R4PWIL2eOC65exxfXbGO9ubof+jR7+MZVn/1Gdn
nNs78Xb21d7DRHW798TJs31FcXL2gXefRLgeEpK1d0t7V4vqkONBq8draEQJ
iJH9q3CpTB7js+i+C7IO7bvIeyO25dlCPpmhlDGqWSGN2X/XtamcfieDbLmi
HfNjWQLjYnSfBqlC+zR+36sO2XwvDmzK7OwHyRQze19nxy7rMuKgJPhgRX5x
GePX6b4OcEH7Omrofg/Yh/Z7aNB9IKQf2gfyivontch/L5v2eMhjFE8Z3TdC
DqJ9I2vo/g2SjvZvfKA6wAakQwHVDRYg3abSPSewAu05iaB5AROUlyiaR9iC
8viI7lGBLWiPSh2tBziA6sGO7mMBZbSPBdczZ4/rtjPe2f4TY/vH8+P1ef/U
bWec01Ogk271U/R71qCPNkkjRXFy9gW/filWHxCSWc0tPQbJ5DDu6Npr9rtg
AXmom792SD6PcSm6h4R4oT0k1dGRExsm8snxG8vEtu5IY/a3GtL7nFHMIN0U
n31/aJjA+BO654QUoj0nZT9GamzemAB3zg7S9o4rZfbGVx8YRu5KgK6y1lv8
j1Qwrkz3q8BktF+lju5jAV20jyWT7m8hc9H+FjPqn4gj/3U0HmKL4nlD98OQ
WLQfJu7v2ht7RieQw/5hO+Xtixk3oTrAr2X/r0Md1Q3OId3e03018ALtq3Gl
eYFHKC+VNI+wGOWxl1v7PhyQRPtwimg9wHBUD9PoXh2oQHt1cD1z9rhuO+Od
7aXh5gX++b6vE87NERxscu5aKapnv+XdJ04XxcnmEbwc9CbuF/2cYDyncumk
jjkF8Z0Tjuj4CMguuT47xMt4jK+m+2GINdoPY+ioPW76ID7ZL8h7k66Xxuw3
WubLXP6YTg6EZ+zQCEpg3JvunyEj0f6ZxwobZZz6JcHTAT8UnPzLmP25q7O7
7qxLBE2JlROCPlUyPpnuvYHJaO/NB7onB56iPTk76V4d8gXt1blI/ZNjyP8L
Gg9xRvG40709pBbt7Smk8x3kNprv2EjnQQieB4mie4FIDdoLpER1Aw2k2wWq
M5xAOhvTvUOwBe0dGkzzCJooj7k07/AI5b2Z7jWCuWivkQ6tHwhG9TOG7kcC
W7Qf6Z/v6f6z/+d7uk54Z/uF1tQfUNn5UfBPnXfGuX07eSmh3umi+g/b+2zP
ElGcnL1fq5m9tpbo541nj8ZpT85hfPyJ4/rd3QTkfoxby4c6HuPX6J4fMhjt
+alf3VVq2nce2dX9nWSv22nMftGMrbPgWTqpVlY55fQhgfF0ukeIANoj9NJe
O91sZDRsKTux4WVCLrMfXDjOpaBHIqg2flJfMKuY8Ul0TxHMR3uKMpZMvdot
JRne/h1vb/C7nNnbzpq+WO9cMvg3eYYtMa5mfCfdgwSH0B6ki3RvErxGe5MO
0T1L5Bbas/SY+icRyH8ujYdUoXhe0T1OZBDa4yRF70s00X2DqT5EHemjSfdE
kdtoT5Qv3YNEqtEepOk0L1CG8tJE8wjaKI/mdD8VCNB+qkm0TsAe1UkErSvR
78X/X1dldP8VqKL9V29pfUIMqs9BdI8WOKI9Wvj54uzxc9QZ72wP1YZwuYKc
Pjn/9o10wtleqXlD3wS2zWuTUEVVUZycfY9+uR/8NYTkiMKApZZTchi/dGnH
/VhHAZFwO6739BOP8R8O7fudyCm032nHnAmmmUIeCThlOTDUNY3Z15q/6e68
OZ34mx/R8p+cyLgu3R9FbNH+qCEnMg8+nxEL4xaMXrl3ZUectiMNBkmTJOjf
s/WL1PxSxhPo3ipIRHuranpURqwxTAUVvzvr9VdUMvtD+7VUD3xPgdWvYr97
/6phvIruxYIFaC/WHLpHC6ahPVo2dO8W+Y32bh2l/skW5L+JxkPWongu071e
xBTt9XKj9yUy6L6SVB8yFukzme4NI3/Q3rAHRaYL8w5HkASL4atvnurI1xua
F/BGedGkeYQolMf1dI8ZrEN7zK7SOoFRqE4G0roCfVRXd+meNNiP9qRNoPUJ
Cqg+p9F9a3Ab7Vv7Z2/zf/b/9JN0wjvbP6Zu+U1n08Tcf56jzjg313nt/JKM
J6LnS9nG4ekuUZyc/Yon06zFRM/Lsjl52c6i54XjEvYDH0bYCYiq3LnE7794
jPvS/V3ka+//3991yPWMaYAPj1wZ+MbJOiaN2V8f1cfeqlc6uWl+urZcI/F/
dJ13XM7v98dDsrKTyt4RiRCiY4Rsyih7JMkeJamMEiKzkJEkKS2052nvcZcU
SQolWZVERv363tfnfd0/pwf/eDyej/M417nOua73ffe+r+t1OD/C9MGwbs3f
+mCm+40H9luchIdP3LaJuC7RQ+tf/uOs/nQdiJO5tOy2azL383ugrJvO1ICm
70Eb+57PFHGuclKsSwaDiS7ZgZ+3XMqjY8FerfDCjvACbh/+QNPws0kyZD2J
fdi+RwnncUz3DMKJ7tnk+Ybr1vVKg36zxn2LsX7L7fdNkCp02ZMKHp4b25za
U8H5bKarBmlEVy2J6bDBTqLD5s5023A+0W0zY/4xgPjXZvHgUBJPCNOFw2dE
Fy6NzRcLyXwtWH6Q5keV6c7hTaI7N2qQOP+YSPKvWiOuF0aQelUwXTvMIbp2
5mydgB1ZJyZsXcEZsq7aMj09MCN6erFMzw2WET233mw9wxKynhey9Q86ZP3n
MR0/OE50/C6wfQQ6ZB/VMj1AkNnwtx4gfQ4I9nS//4v/SwdPuH/d7LzZP7iQ
h74qa9JPND0HxiaOmWPcFKdg7zVPbf/BVbm4OEp01q9pXws8UKnlWZmLOVju
OLOitqWI875MFw69iS5cR+0q6zn22Tix/34NnfxUbm/yx3BaeXQqbn5uvu78
pQTJuEx3DucQ3Tmzfl90sSYRZ0890XnJ2zjOHe+HziqNOgYrEj7qHH2Xwv2s
2bT1ZmlOEPSOX3fRITmH86FMBw8uER08t+H6+EQrHtbGrrY63Pc5t785qsJt
cqtUcBl0U1pJupTzFUxnDzYTnb2xs6bfMPBOh9/eLzUeepdx+5l2Y/xj8tOg
2xijrN1P3nO+g+n4wVmi46f+Um7YC60kGL8x+8b1go/c/jzTA4QjRA/wMdMP
BKofqMn84FTiZzPTIcQaokM4h8WJ/UmcU9i8sJXP3/NSYzqH+JroHPqwvKE3
yZsnyzPSPFswHUW0JDqKDqyOOITUcbmnuO64hNQ9guk04lyi07h14EVF11U3
YZd8ZL1zVCLnq9g6hA1kHcqxdQszybodzXQjoR3RjQxn+wLek30RwPYRGJB9
5Mp0KeEe0aVUZvsRJpL9OIDpW0IF0bdsdq5P2I/0XN8/+L90GtcMPXd1tn5+
s+fGvzjXG7x+ROl/50k+WuzuZtYUp2A/sDp9yW/9XGz4YbzIu+n5IPDdnd2u
hNrnoNwc1VLlNiLOLZluIe4kuoXFT38n/jDOxiMr57tf+ZjK7Yv3tJQ9fjgV
52gFeiklJHBuzHQR8QvRRbSZo6BgdjcWJ9/xig7pE8ftt2/8Uh1z7CHKr6lw
O3wunvPDTHcRM4nu4iKnB27zj16AWdekHb4opXH7NirdOo6GUFDc176/7+Nc
zgu+i3UdwYvoOh56ucm88n4CVG/ZtHHNzkJu73df2mCqTRq4jPlTW/W2lPMi
phsJJ4hu5MN7VV9PD8qEsF/nX4YmlXN7k2Ez3jkOy4CPu417aQ6Q1LGa6VKC
HdGljOx9erGvTjKMX94/UXPuZ27fnulbwg6ib+nH9DCB6mEmMj+oRfycY7qa
OJDoau5mceJPEmc4mxfGkHlNZLqdWEt0O6NZ3tCH5O0IyzPSPHdnuqA4m+iC
TmZ1xEGkjt6s7jiV1N2R6Y5iGtEdVWHrCpTIurJg6xDoOpzBdE2hjOiaZrF1
Dtpknb9l+wLsyb7Yx3RTwYjoppqyfQc9yb4byfYptK3/e5+mMl1WGE90WS+y
/Q41ZL/HMH1XyCX6rvR5JdjT59K/+L90Sjd+0x8Zt6+g+bn6f3BBP7Pn1ei6
tf/TyRxWlXe8KU7BPle74vqtlbmoHivVx6np+SPw7qmt7ryxzUHd9KujZTuI
ONdkup04k+h22n8yXjh8Xjau+7awdmKLNG5/7pQsqExNxf7TPvf4Up3AeWum
C4omRBe0fp7Tn7WTYnF9q69zRlnEcfvnC2eaHbf0w/Xmr5QNJkr8KDDdUaS6
oy7Hf7UZf/4q4C3Hrboa6dz+rv3psRVW4XAhzk5x5FnJfLsxXVNII7qmV1P1
23z5lgjT948ZMvDuC25vPH/MD9PydGiPFn4fA19z3orppgLVTW1ZUq5ndyQL
Xg/btu10xjtufzE+7bzy+kwYkZPTU2rFR84DmC4r/Frwty6r28MFYRe1UmC7
/7LnQ29/4fY/asX6rqBA9F0PMT1YMCJ6sF7MD+4hfg4wXVmUJ7qyTixOnEDi
lGXzwnIyr8dMtxZ3Ed1ac5Y37EHydpPlGbVInlcxXVzUILq4eayO6EzqWM/q
jsGk7mPtxLq7OIro7uqzdQWGZF1VsXUI68g6tFwu1vUFD6Lre4Stc+hL1vkF
ti9gG9kXwHSDQZ/oBiuyfQfLyL57yfYpTCX71IvpEsM3oks8gO13KCf7/S3T
NwZDom/crJ/Uf/bN7kf8g/9Lp9coYVDsVIdnzZ5L/+KCfqyv3BnnBU3PK+W8
rcbnmuIU7JXtB+xa3/T8+XmpcPK2puePwNPbdhvpfCQHR9ZNVL7cScT5OKZb
i7eIbm3jyc3nxqtmY/GmZZOqu6dx+/mfA7/elE7FVQVFPWx6JXL+s1Ssi4vX
iC7uqgKdM32ex2BInuGvTllx3N7sznU8NcYH8627Hz+Qm8B5b6a7iyeJ7q75
5x8uVnW3IFv57gK9SRncfoHTAYUlJyMhXO9VoNXSPM53MV1fqCG6vi8sUt/X
DU6GSx7qHVQii7i99JHNq8KVM0E9UP3bzb1vOF/JdIPhBNENrrJct2ByRDaM
vwGduoRXcPv2B8qP5h3KAjOZqLb9d0nqG8h0iUGR6BLvGDVqo0efVOjukpft
Y1LF7c8wfWOQI/rGU3qK9ZAhkugh72d+UIH46ch0lXE30VXuxOJEWxLnTzYv
nELmlcF0m9GC6DbLsbzhNJK3EpZnpHl+yHShcTbRhT7K6ogJpI5PWN0xidS9
iOlOY1+iO13rKl5X8IKsq6VsHUIwWYf1t8S61rCO6FpPYesc9Mk6lzkl3hdQ
QfZFDtPNhhNENzuH7TsYTfbdWLZPQfry3/u0mulyQyLR5Q5h+x1UyX6/w/S9
oZzoe9PnlWBPn0v/4v/Sqd5++fPysPvPmz2X/sUF/eQobKkxtel5lSKr8OBa
U5yCveLinSdmNT1/DMJ1VYaMesK5Wb/Wiu8tcnDLlI/jArqKONdius04neg2
v1X5snNvj2z8NV9a++TgNG7frcyt4mhuCrqv+l5sMC2R85dMFxqfEF1otBjt
/tQmBpWULslvVIjn9qKASRZmwx9gby/noY2rJH6Mme40Ut3pgB3GnmY5d0Be
bsmrD30yub36niLR3OXR4PdyTuhSqaecH2C61mBLdK3n9O7ncmBMCtytML+i
EvSS21f5ZUyfOTsL5H+tNUtXeMv57xKxbja8IbrZ4+JPDT+0TQSXjXqX2Zx9
z+1t9Kv1dA5kQy9fk5G6Rp85H8d0uSGR6HLP09KIWPim6e8IO9/TCrVV3H7K
2Pb6vd/FwKHustaz/lRzrsB0v+ED0f3epC/WCQcHohOuwvygFfGjx8bFbWTc
00yHHG8RHfKTbF44nMxrIssDXiN5SGM657iK6JxL+YvzjINJnuezuqArqUsF
01FHY6KjvoXVHUNI3UvYOkFZsk4GXxbrtOMHotO+gK1DGEDWYTBbt6BI1q1r
Z7EOPOwhOvAt2b4AN7IvKtk+gtYL/t5H+5jOPEwiOvOWbJ+CMdmng9i+BkOy
rwcwHXtYTHTsk9nzAbLI88Gd6eFDOdHDp883wZ4+x/7F/6XrvmdTWOW4uMJm
z7F/cUFvXO6S7p/RTc+3SSoTD99pilOwvzulQlWv6Xn1p9eK8KSmPAjcOSTs
UKlZDv7I31+7SU7EeSrTOce3ROd8/Lke04dJZWOQ7t4FqWPTuL3H78M2O++n
4KXQFiXSGxI538d01HEw0VGPWZc11W5yDF6aqXpaWz+e26cvi75kaOKJecqp
s9eLJH4OM512jCI67ZEf9LdFT3cHv+4/W+96ncnt1WcpZpq8Ruh865rJjStP
OX/hLdaBB2eiA68wfOPCGQr/Oz+qt2vimWJuX/GszD9EMxv25kvvOO75lvMY
pjMPVGc+P63r7oBSEciuea+zc3olt99zpmZEWtP3Lp0DPk6+ml8478N07CGD
6NgfdNA+O8EhDVRv/Bk62aSa26uODTproxcLLtKG6tWHaiR5Yzr54Ep08m8y
XX1oQ3T1ezE/eJf4sWbjojoZtwfT7cdKotu/l80LV5J5FbE8YDeSh5OsLwD2
JH0B6lme8SjJcz9WF6R12cH6DuAp0nfAhNUde5G6f2TrBD3IOrFifQ2wmPQ1
mMnWIbwg6zCErVug67bUUtw3AXRI34QrbF/ABbIvNNk+ghiyj6ayvgzwg/Rl
uM32Kfwi+9SP7Wto0/vvfZ3E+j7AWdL3oS97PoAWeT44sv4RMJv0j6DPN8Ge
Psf+xf/VB8F0jO2Rh0Uvmj3H/sUFff4UzZFyQ5qeb/LhS2M9m+IU7GWdK6ef
aXpehag3tlzQ9LwS+KxlZkbn9ufgi3jXFdflRZy7sb4AqEf6Aigdyvp05XMW
KmranTyrlcbtwx2sO761ScHbueWyQywSOW/H+g7gINJ3oN6qBuV/I06VPXup
/mw8tx/lM+zFhXoPNDOc5DxuTBLnGqyvAdaSvga3A7M3JGh7gGjP4W9nbLO4
/fyDj863doqBZRPHhF/tJsnDTtY3ASaSvgnu7Z5M9c5PhciobQOyNV9xe/nV
6ea9WolAQbn9kW79yji/xvoywA/SlyF9b02fN9o58KHfVC3f/EpuD6siVZyt
RTC4y6N3jz584fzne3HfB3hG+j58u2pZvEkxHdyn3lH0T6/m9uMV+lRX+8TC
xc4TpqeX1HC+nvWVgK6kr8Q0B83TX457QuXPP1l3DL5ye9FZMUfKr7O+FeBP
+lYMZOOiExm3gcWJ90mcQawvBnqTvhjTWB5QneRBxPKG1SRvT1jfDUwifTf6
srrgUFIXT1ZHpHWsZH090JT09djC1gmuJ+skg60rTCbr6jHrG4I3Sd8QT2/x
ugUrsm7L2TqHKWSdR1qI+5JAHelL8oDtI7hF9lF/tu9gMNl3z1nfEzAgfU/m
s30NxWRf92TPAYglzwE71lcFZElflVz2PIHe5HniyvqzgBbpz0Kfh4I9fe79
i/+rz4iF1GK5kd+Lmj33/sV5/wupxTd7Nz0P40rPG/k1xSnYp007Jl+lm4vn
d80yDWjKg8CHz3R5Xr8nB68NtgvUVRBxPpX13cCrpO/GuHMaKt9KstChv+l9
3zlp3P5LhvnoxcYpuLnuz6/t5xI5D2B9PXAa6esxQaao/3gXxPH2A1u8Dorn
9jNUzixe9OIenl2paLnGMonzLNY3BBtJ3xCTg0Up1nn3oa+nQa/1LbO5/Xir
PuHD5WJhzeJ0u9x9kjz0Zn1JIJH0Jcnc271mv0kaDHpR5vsy4RW3Hzpb+c7D
pSLY6hj3tOfhMsm8WN8TcCZ9T46K9toWX8yB6HEdcmzmSeq1b4SOq128CNS1
/2wfNrmK85OsrwoYk74qvw9X/Bpllw5dWvqX6Pas4fafN+cora6JhbI9ht9c
1L5ynsr6tsBS0rfF/7e5ydTXnjD/5QvL8d4S+8mM4wLC37G+MHCc9IV5wcbF
SjKutKU4TuxO4uzH+s7gC9p3huUBJ5M82LK8YQLJmwfra4NbSF+b0awuaErq
ksvqiLSOJqxvDspu/btvzhK2TtCYrJNrbF1hD7KupGrFfXnwB+nLEzFCvG7h
Mlm3g9g6B7rOh7C+P6BC+v4Us30EG8k+0mT7Dq6RfafE+grBKtJXaDTb13CD
7Os89hwAZ/IcWMb6FsEz0rdoCXueQAp5ntix/kfwk/Q/os9DwZ4+9/7F/9XH
50i2otf9rsXNnnv/4kLfme47h/jLNz0Pz32WWvW4KU7BfrifobVN0/Ntsci3
8FdTHgQe8S36osruHJygv+etnaKI806s3w1uJP1u1I6ueWNSkIWvJ/jO6roo
jdur9fR61GJ5Cr6atjnn5s1EzoexfjrYg/TTaT+greGxNYgT5A062uTGc3tb
vVu9fnS7h8EuFmu/PUziXDZE3K8HbUi/nr0tzpRP/egJLauH5u5clc3tF+x7
tWDwzlg4abi2YUSwJA+qrB8QuJF+QJ0WrCkqyUkD6fjeawy7lXD7Y8MUzPxP
ieDB+wawjijjvIz1GwJn0m+orcZ+p+jkHHAK7b3c6YakXmq1/Tzjv4ogePSv
0d+2VXF+i/Uzgsekn9H6L8PWLs1NhwM+G8xmLKjh9suWdw3+PDAOej6pDLU0
/sr5CtYvCYxJv6SqeT7dqwZ7wVKHvfEL3krszRlHPcKnMf/Yi/jfyuJBcxKP
N+vfhCmkf9NYNl+MJvPtxPKDN0l+/Fh/KKwh/aHsWf4xnORfntULab0Os/5T
2NLz7/5Txmw94GWyHtzZ+sGfVX+vn/b9xP2tsJb0t/qhK16fEE3W5/f+4vUM
dD2X9RL3z4Jw0j+rP9svUEz2ywS2v+Aj2V/vWX8u8CD9ueLY/oVJZP+OY/sd
DMh+N2D9v+AI6f/Vlz03wJE8N16yPmIgR/qI0eeeYE+fb//igh/ah8jW5e3U
QSNfNXseCpw+9wQ+p+uhdd2bnnuxKqnnA5viFHiPUTY4u+k51ibns8HgpueY
wPPuLv2pvCsHh77dPFddScT5eDeTULncLHzSRWG8+9I0zlfO1rEZPy8FT1xw
/XbWPVESZ9t7ETEaiFNatEuzex3P+Y9pLU+9c3PHpX1WbNiYlcR5qyMhSuGn
vKDGvi7L/0w255HagydVusTCjy/fGvNfSOLPVUy+GNEhHV7/LFadOKqEc9er
r9/tuy+CfpP/7Ld9Vcb5OJ3Pt0rLcmDa5XOHPqdI8hM3d/Fh7JQDwYtFiY9t
qzgvPnHIquJ3OiS+2l9fvK2G88Mtu3xX0oqDoN7fiyNPfuXcmHEMJ/wd84Op
xE8CGxejybiTWJyoQ+L0ZPPC0WReBSwPSPOQz/KGrav+zttYlmd8T/K8m9UF
DEhdxrE6giap42xWd7Ahdddk6wSKyTopZOsKhpN11Z+tQ+hK1qEuW7eQRNYt
3V8Cp/tI4IlsH+Egso9UL2q5bFVzhh6PtGJlT3/kfaNkTu317DE3FsfVODo0
hN7nfImcw0ptaS/sd8lY/ftxL85ltxeGmo33gMsOAxbsTYrnfBjjeIPwQcwP
KBA/306Kx4XeZFyPC+I4sT2Jk8Yv9IXpnDtq99VhsVjnU/dkoJ4n5/KBz0+M
VfHEA31fle749IDzJefr7jX88IBon7krJ3glcD6S9TnCYNLnaDuzxyRi/y5A
7B92EP+/csTxQDGJh85L4HReQv+I0ttb/tiv8IQviY0yN7SSOL8xIdhZz+8K
jIqw+16yS9Lf5DbjOJbwX8wP1hM/ap1vj84/dxX1V6bnh0RESvrX1Pt1GXLf
A/rdXizabCrp6xG2edPWkA8x8DBkl+kjI0nfEDovgdN5Cfr2t95/ud1y3gNw
8re6XXxM0j8iiHG8TXj+wgPbFc1v4ss5Zno2v5Hznle6e3pauoNtedCNO6cf
cr7indzs4VdioFNGwpbdVQ8kfRxInAKncQr62/ek5MztM33AuuPhMxN2pHMe
zTieJjwiuv2bxi13sHBUZHasfBznXfPkbaY+vgN9zj1QUih+zLmt/8Unn4bF
wKKLNqXRH3w4p3EKnMYp6Bt3WazX8epzf9j1aUH069oszoczjocIv9ZnX85t
bYQKxRIdX11/zum4AqfjCnqzbzfcdjz2+BG02uHw6+6pHM6rGccOhFP/Aqf+
Bb3Q89OH3nN6HABG2irpJwsl+rE3GMddhFP/Aqf+Bb3Hh8vap8q8CwKHTd90
h26T6ElGMY5OhFP/Aqf+BV2+Vlbn302YGwpJ761yc0c+57wL4yginPoXOPUv
6KcdftXhRkNOOHR/8WbB9D5FnJ9mHPsTTv0LnPoXdK7myTt7xR2KgqzxD3ff
HvOK8xWM40vCqX+BU/+CHpHT/KAds3rHQBvjvXYr1Uo5v8E4diKc+hc49S/o
w6wcNvCzrE0sbMLVH/eIXkt0exjHbYRT/wKn/gW9jhCmZwL6RM9EWX9Q61af
4iB9VlUHzQNvOR/FOOYSTscVOB1X0EnQqvIfuqxehAZuKl0VfTM413b7pXOl
NAG6aPunVVUXc/782ocl75cngFppl9pU+XLOixnHSYQvYn6wL/EznY0LG8i4
NH6B0/iFe+gmoenK5R9FuP+qTJh3VAbnic//uA+7kwSBBaZ/dt0p4byX7i5X
27BEmCEduGV8wDuJbgDjuIBwEfODkcTPLjYuHCbj0vgFTuMX7vmqS4U9zSgR
YTeHflaZmRmcW7L70RBD7kdXrE5eIFqWAp8K5g9vGVfKuarxznte3ZMhv1r/
3H3t95J74oxjCeE1zA/WET8TWDygSOKh8+LjknkJ9xanRntbjXwqQv/zdjUL
X2ZwbtUjZ6Gawx2svblLt2+i5P5me7MZzmvmRoHe1itK+W55nGfP6eF34Hsq
KM0zTVtc8JrzhZ2fH5y7IQXe144+sz2pknNdxrGW8ELmBwcTP4PZuLiCjDud
xQ/BJH6aB4HTPAj3rQaei2ytnCbC4UP2XGr4kMG53CDxPTXcTe6pbZXfMflG
yxh4/ULu8u+kp5L7jzLb5460TYchF/te7Vn8hvOnw77GW91oei62ND79S10y
7nPGcTLhLswPqhI/e9m4+JaMa8zuY4I2uY85hM0L1Mi8aH4ETvMj3O/IUR91
pARFWFnzfFZAfQbnAxWtfM/fTMTWNRFYpyy5F9NNat+JW52uoEwX13l77iVJ
7kOZSg/u2fT9/8CNNgUXCiT3UMY0zNm5pC4Drk5sXaT95C3npab3rR1j06D8
vaZBp9OS+yZljGMN4ZrMD7oSP5FsXDxExl3TuPd/cUJbEqccmxfQeeWxPEA1
yQPNp8BpPoXz553nDE84ECzCa6qv3s+QyZTcv7g66NWlhYmooa9+qnRrPOcP
t59QgrkXcKx9773vDyVzHj327KBFB+Jg7B6DtA05BZJ7JYuLVOznZsGhvfci
vgeUSc69O37/rZSdDv7qLea7x37mfAHjGEa4D/ODNsRPFhsXNci4X03EccI4
Eue3K+J5wQQyr24sD3Cb5IHmU+A0n8L52AfvRvZq4SfCVN/R6Se7ZnJ+ZUll
fZBMIlrYXb6k5xrPudfVhipfDTtccOdgyMmJKZx/f7RdJfpoPGw5UHTP+tEz
zi9bqy2siMmA8z9uju5e+IVzZ8bxBuGtHov94DbiZ+YV8bhAxz3J4oRDJE5f
Ni8QkXnR/Aic5kc4XxdhNOy1i4cI10pr9NzQS3Ku9dDJ2b6ZKQl4Rqql6d0c
ybnZ9YZGNyNXWqCtp6ZU51cpnMP+wsdDHTNBz2mkz6mtVZzPZBwNCD+8UewH
ThI/29m4QMeNZnGCIYmTzlfgdL7CeRun6/ozDF1FeEHOdbrfoEzOtRfFJV92
TEC/I9dVp/6SnKMbfvWAY4GyEbazX3n4zPZUzhM6flReMzsLhh46E/4qq4rz
FMZxJOHTLor9QEfiZzwbF+i411iccJXESecrcDpf4ff0thsyP22+IULXTdJr
DUZkcg51i9vdM0nAI2vuvbnbO4HzDV4BcQcyxsKfx1OPryxK5fxp6xDR3qdZ
MK6Dq/OzAZJzJi8YxymEP3wu9oMNxM8YNi5Yk3FlWZzgSeKk8xU4nS///bFy
xjufqyJs2xi5ZeHoTM7TdzxZcGR+Ap5bvWLZ/vEJnIsUH54efs4QOg7cfrq/
muR3+cnjQCMcskEzI326xfpqzst7frZX9g6Fn3EvDEUukt9z0xjHP4RrMT84
g/gp7CceF7uScSNZnEDjjGbzgs5kXjQ/Aqf5Ed6rT1ykuHyekwg3WtRaHR6b
ybnPhS2djmokoF0f/3YbZyVwfkYl8dSIfntgytyjCh+2SH6nk7k/fF2dTTZc
ibcP7XCyWvL7HePoQvgFVbEfBOLnJhsX6LiaLE4wJnHS+f7r94I4K+tPUff3
Nvu9QOD09wKBe8kW2X9RSkCD74tCY/b4cF517m3g8vpI3Fb+dUN113ucV7v3
nbDgVyQGFz/43ih7D9w/4PjZNrpaDdvn+658+QhXLXr10KqnB7e3uLR+a6+z
LuiosiIq5qkv535Xh7wPueqCA34YNP5K8+V+9Ad2CMnsfwvOK7peWRQVye3n
a7gqbFpwD2xtfH1utY7j/JKbQcyQpviebZ3lvPtzAueB22/dftUU3w6Zz2rW
FQnc/46kzuUOP25B1+p91duLk7h9bd9+zvPPnICXoskvvzxN5vzC4OUDHE6e
gIGTM9qdzE7mfjKYPRYT+73MPyoR/9a9HZMVv97CkvKTS4Y+S+J+vFn8WEzi
38Hmi+fIfJ1vbXz8ffY9dBo1PQGk4rifRSzPYE/y/IzVBZaQugy+7iJV8OoR
6E37POhzZw/uJ4/VHZaRul9k6wTGkXXy7an6obu9mvgjpdcZO324n2Z9z/+z
b9b3/B9c8EPf5wv2dL8L/dMdY558eqAZi8l95F5E1d3nPDYgN2axryfqPNG5
OVzuAecTHi20SbPxAI1Fvm46AxI4P6lmdaZV2QlwbGejc3K3pL/8WsbRifDp
7gbnqhc6YZv6IzU3ukq4LvOP04h/JxYPzCDxHGPxw0MSP30OCJzmQejL7Loy
ECplY/FIuHHPikxJX+wfjtqrFlnfx2k7lEr6dPLhfNjOVUk/PJxg6NfE1hfM
IzjfYvm9b4TjfZBtd08/b20i59ltVa4tD7KDXrqy65TzUjl3YRz7EG4rnz2q
Re8rmBSp53J2v4QfZf5RnvjfyeLBcSSeDBY/TCLxn2fzBSMyX5o3gdO8CX1p
F7H+v+hA+v9OZP2CsQvpF6zD+g5jD9J3WJX1KYZzpE+xRouBFn2eOkPSJlOL
bVOjOa8arxBWNNULNLq2ul46L5nzrzmjj4rqT8LdH5VR7o3pkv6/jOM9wrvF
P+z/fc1VDN12NPTZdQlvP0HsH2cS/5YsHswn8Xh0HjtJ3+MeaEtLfVQb6M/5
r6rPT3omxMADs77jZPs8kNiTPPM8kDwLfT9lLor7q2KbcX/3V73J+rGiVMnf
/ViPsr6umEv6uua+EveBhd8Gf/eB9TlgPTLb9DaYTh6eV/grhnMteW19dQtv
CL1z/5Ln61TO9RnHeMJrmB+0Jn5C7vx8+23EXUgb6xN26e4jzlMTNDU7bYqB
A0ohi6eUeHNO88P7yZL88L6ff04bPXoYhkah1/cVrvDlvLrD83Gu670x7cvD
9VHrHnGOrJ8m7if9NL+uFvffhIOk/2ZY9uoKuSl3IWLeLdWBi+I5X3bUXq3d
TD9YGOPSemOfTM53MY4rCX/J/GA88aPRJXTT9e6u0OPJ00uzJgZy3iZl2bZ3
2QjnXIdOUe3mxznNj8BpfoQ+gOGsfyJakf6JC93LHS6tC8UV38anDlv+kHPj
5FyLGa08sUHpwJxP7wM4d5174M0UCxOsPBFQM/FsBOfPVhnqdd7hCr+j4tbv
VYznfL96dvXFzfehe13K0Mudkji3Hu68uUXKQ1iWMCfPx1zE+RnGcTXh7VeL
/WP76L/9L9ARxwNvSTwLPygHKD65Bvtf/Gyxb04I5ytW/zqw0y8awtfd8B+y
QjJfmk+B03wKfeuez1iiPrsyFj+F3jSqy3nMuYuyxXj7F8F4Z2H0BPMpEt6l
Jq337hHuGLNo8volT4I5Nz4xVNPrlBloqslsL3yEnI/J+F63b9Q9UFdac3by
60TOK8xCk8sH+8DWm8f3fxiXyrl8Q3vpm96PQW7RkVv2XrmS/oaMYy/CjZh/
1Cb+Ve3E8aAGiSeqWhw/xJP4j7P5whUy3w1PDu3ovjkKPp5dOmXTk0ec0zzz
cUmehf5ril/1Dx12TMaWs45XGJSEcT5cO6Rz5uJY3P4xr8c2+UDOO4U5/xkw
MghfX51Zfn+1hD+eNL1wc+xt1MkbcWh4t3DOBzrt2Txu3HmoLvRvdV1Z0s9O
+9C+vSYWD6Deas2zyN+Sfna6xdKl5aEPofZIq5rgkAzO30z2lvJKCgT30nbH
gpWecl7FOPoRbs78o6z13/4tWDxI45Fl8cMiEn9NqHi+8JzMtzPLD2yg+WH5
BCmSz7W7j/06b5wG81I/md70jeac1kvgtF5C37FV9ubwaUgyqj3z8OxwJ5xz
g4AV1XA/Bs8o3jTcaR7E+c8/EUHGywNQXvqpvb5PMOdLa6bNfrLlCs6zsHsX
fjOK8yyjWzE3La7D5O+3O6n7JXCet1r6mN2Ah9DbYeD9++szOD+XGa08+lYA
vOyU3XLCbBHnOsEtRq5sEwTyloF9JnV+zvkyxrEP4TIF3c3yu4Vgn0eP+hcl
FHD+hY2LY8m4f1icOInE+aBaPC9YSub1iuUBOpA8aLG8wTGStyUszzCa5Lnt
ts4rNnRLa/qcXZ3/fgJyTusocFpHoQ/XYs/Xn3b5J2E7lcJZl3dHcP6w5YcD
Y8oQJ7topxV9Debcvvts1TdrHmGVxbKZV4eFcf470/K9beQplJt9tmhMYAzn
AZ/U9ey63oVTB2y8hm5K5ny3T+jaxskBsHjNdVtjKRHn8vNN1rsEB8PXmwNu
Jurlcl6YnX/buelzT9PjVsnP9kWclzGOMwjv2VanE5wOwwfpA/r8vl0oiZ+N
i6vJuGksTjxJ4vTIEM8LFMm8drM8QBnJwyGWNxhD8jab5Rlontv1uGInFZwK
m9yGfu6WhpJxSR0FTuso9KVaPeSHsuHYJOyp2K3Udm4k5590ouHD1mjMs67f
r20byrlLlf6S7xf8EHNOmlYnRnAu9xpvhJ1dgxWZJdmvAiX9vPwUO0+bMNEL
9s7waKM/JY1zi6OvFukeDYYTLll9H1TmcF4yUGbgu19hMP/YgeIN1nmcS1ml
y2jsCYO4EWsX1ai94rwT45hJ+LIV/QKsB0ZiTk62vO3dl5xfYePiZTJuPIsT
95E4DQvE84IvZF47WB4gkOQhhOUNMknelrI8gzzJ84hTWRknlqXCjSvz2/iP
jeGc1lHgtI5Cn6bi11FTtB8m4uTfCwx0R0ZxXrui840hLyLRvDHBpWZwOOcO
/lOVS6Y8QMcfx5TPHInmXMla0ei66XHY5e13wTAtgfOtxneq3rn4g4Oej5PG
uEzO21pUTfB7Fwa11X/GPK+Q9KsaNMx578Smz/fIY/0nnERJX6rt12SjN6dH
wKMzpur5mqWcWzCOwYSbH+8TlZIfjYfzZceN21zC+WA2LkrX/D2uJYsTaZz7
jojnhaZkXmtZHuAkyUMUyxvsJXnLY3mGSTTPLvXhcl9S4Fe3FhcsbWI4p3UU
OK2j0J+o1t402GlEImqueV6n2yOa8zPhRzadnBmBLV2t/KRzIjg3Sejka512
Dw3OeCzs5RHDuVsPh4WHzjjChw1j860/J3HectfR02MVA+DFO/flu/qLOF/o
dS3nhVEU3Khxsv5Z+5TzHulZjqP2xkDPT2uMDnR5zvnpAOcdHTWi4eO9LR+8
Kl9zfo1xrCH8qEVXv8asGLxQ73/vdmMp5zvYuOhLxu3M4sQiEudaefG8sI7M
awLLAywjedBjeYPG23/nrZLlGSaTPLvUxiW/tEuB2hOrzh7Jl/ihdRQ4raPQ
l+es9k7Re7cEnF5vYpTeAjmvn67RWHAvDLOSFheY2kRxvv+o2kWVOXdQ3sfW
OKlrHOcX0neuu9PKFbqptLgUqyTpW7Tb222v+e5gqLw5cvAFnxzOFUrOqvod
ioGArwffV7R9xrnrzqPLjDXiIOOo3rNxJi84TzM37PtjeVN96zSnvrv9lvMc
xrEv4aoRz+vLNOLwm6PIQdXtDefKbFxMIuMeZnEijfMDmxf2IfOazvIAnUke
YlneIJ3kzZblGaaRPFvv3Rep2CcFDiqsy48eEcs5rSOfF31v8F9/GfW+Ctq3
G0UY2bnufaB7BufJdglRBUoJ+GJYu4/fPiPnR5797lwtE4oj1r4epaoh4aIR
3vFvjzrjzahthjbWkr48zjJHujxPvAeluvsn3ddJ5/ze7E3y32Ieg2hr4zbN
qSLOfeufKdc3xEO2tJ55eOJLzqN7DF++4mIsKDcOf7ZzRTnnSYzjaMIbPxR2
KboTj+t6bfH9MauM83DmH4uJ/z8sTvxC4tzK5gVXyLxmsjwAzUM0yxsUkryl
9xrUXiYgGTI3hV+aeiSWcw2Wf4gn+W/2fuM/Tuso9DHp3vnOa7mvInw3qHL7
zqAMSX+Zjdpvv1+OxzKTW6ta74zhPHGYZ6H/9mBMWL7nx6n9Eh50b0LTV58L
eGJBqX2HigTOjSvtu/U67A0+iWf07+3N5FzOdcK3cy+DwPp0vHri6RxJP5fN
SjGn4hLB8OW06h8dSziXzgrJ+ZwaBwUl3c4rtqvgXJZxLCI8NnnOpbttEzFs
3+Lu3crLOa9k/nEH8Z/M4sRQEudSNi+wIvM6xfIAiSQPqSxv8JbkbXWWVNfS
uckwNvHhsIbcWM57svzDZ5J/WkeBNzuf/F+/jMoQ91sZ5SJMmVGWnJmYwXnx
+tvdXnWOx11bIhQGl8RwPivm5uPyZ4FYh612t50Ty/nWa9MSxvywxn795BMH
zEviXLWhKHvg6Yfga3hLfdp5Sd+QCcaVi2LfhwJUm1WaZudyLprvnplumQxD
usZmfxhbyvkLi2Vre/6OB8WU4qScx+85f8M49idc7ZTagzbGSfgCK0qdrSo4
L2T+UZX438jixHASZ/4V8bxAgcyrDcsDfCd5yGN5gx0kbwbbQg3LXyeB+zzN
Ca2HxHH+meUfskn+m533FvJJ6ij0O9g4fqruh0IRPq1SLHB/msF5SeXBWMUL
caj4rczbanEs57f29j+6SC8A9zvoP77ePY7zb6F3Y/0X38WYwYPyT8+U9I8I
+hlw2KgoAuap9Wpv2T5P0p/CPeDTJeVUuLfa49rsRa853/VqefdJgxOhUVsu
7toiSb8GU8ZRZtbf/Oqgg4/eRySjxqdFX1PaVHI+mflHf+JfxOLBxSSetWxe
YEbmlc/yADQPaywWKc4/kgSTrh87u+aAxN6Q5ROKSD5pXXge6Hvg/3TjF5bv
93TMFuEX6ZxO8W8zOO836OCgyf2TcPWFhLbyMXGcz9k1QHuW72309zafPXNm
IucZXcH2nk80bLswpttQjaecL26xbnxhTBp83nDqWfCaN5xnLxt/ZqFUKuSV
HVOTOirRt3/KOL4ifBXzg9+Jn3I2Lu4i414t/nXZ/NUjiDg4IOF5viT+6Izt
O4fJx8HxdLOS+LBYzruy+cIqMt+lLD9QR/LT7P3wf5zmmeu9P5viWZkgwl07
lDr/qsngvPXhxQWipEQUhcsbLmoj0Q//7dil8MtgZ6x6OON8knoS5ye0n66U
8YqBjz1O3vi0VKLLbajSfdqzaRkQ59+npMvqt5z/qDh4fcuYNNgzfPae/FJJ
PA2MoyXhe5gfzCB+HNm4WEXG1WFxAo3zh4V4XpBF5vWI5QFMSR5oPgXe7P6I
oDvdVk+vY4QIfxf8HjFQKpPzwkN/zvc6kIgrHI8WjZ4bz3lB1ieHn4qXUafv
5dzp3ZI591v5ZOfy17Fw1uHex2MrCzgPG3nQQdY9E/av2aJjMLuM8zM120a6
zE8Hu4kqgUOGf5bofjOOFwiPY37wMPETwcbFc2Tc/ixOmEvizGDzguVkXm1Y
HkD62d95aHZf5j9O8ynohXb+PWyW0mMRXrt0pqKLbCbn04Kn2XcbnoiXB18M
rrWN53z9iZTQLlPP4JrPz5coFiVzfsF8qdflhjgY4qr8KUf7mUSXdY6Z9MLy
LBhWWl6W2auc89JNvuM852dA2OCfN3rqfuG8jHGMJ1xaR+wHxxA/N9m4OIKM
W2cjjhPWkTjV2bzgEplXN5YHuE3yQPMpcJpPQZ/wvlKbVSMfiPCg3KaDd+Ul
OpCtNmz5daU8Acfve3rufZhE1/HuCZ2OveyOoeq8jlO/nEvhfGgDfNz+Mx58
9imu6tHzOednwVPTRjUT/LLlTa+NlOhnXmIcAwlXZ37wEfEzyVY8Lowm49au
F8cJNM4HbF5whMyL5kfgND9c92/jwXWr74rQO2hA7/B+Eh25LXeW79zjm4Cn
Lk4/sPudRBfuYK0lmuvvQ90db/MfNH2eC1y5+48NdtWZ4Nth7y/fW1WcqzCO
AYRvrxb7gRXEzwo2Lpwk4yawOOExiZPOl+sKkvkK+kUPjmYmR9wSYWqp3/lJ
wzI5T+wXvHWedQK21ddM/CObwPmqipWRw7V10b1PXpD1/VTOPyi0WGl8KQtM
Qqp+/PhZxXkV47iH8PtFYj/gQfwEs3GBjuvL4gQRiZPOV+B0voI+iXJAgtk6
ZxGmf+28tMOoTM5n9+y+87FBAo7+7Jc6aEQC51pzjSrLj+tDhNv7MZ/bSXRa
Vnvfhdmds+H2AakdG2dWc16yuPbLZbtQGLU56PmWIxJdnQTGUY3w9cwPehA/
3ZaLx8VoMq4GixNonCPZvCCXzIvmR+A0P4KOwSqvfNslV0RYLPWjos+YTM5n
aQ3TlZ+WgDP3rWttr5XAedugTsamk7bDrntzCnP+n56D1e4jy72MsiFR43uL
TmbVEv0Kg2VbHVJC4daW2g+dQiX6G+sYR1fCjzE/mE786EaIx8V9ZFwNFifM
IHGuZfOCcjIvmh+uo0Ly8y/dhrYy89puDHvV7NymwFfbVfa+4SjCsYVj+25R
z5ToLaRY9fq2MwcHD6h+uVxJxO311DRq48Yk4PA5plpf5yZI9BMOV8l20EnB
NysWOg32SOT2aYrWRccy9sIAuZIPq0wl9/QjVR2rdpx1xxkDHcfr5CVx+wvm
SUvOXM2GB5pr7hpdqub2Mb0n9h4ulwO72vlVdrav4vauLU8vh3leMEKlTmeK
dC23fxv+ZNG5mXHwpLv+jRbnvnL7UcweqX2c258upp9CUe9VY3pMgURXoWLP
zHERS73QR/nZWPf2tdyPE4sTH5M4e3awOLm/dQaK2mqdzt5dw+2ze4vzgINJ
Hl7e/xrUx9ML68ctmnTRKZvba7M8gzLJc8pWy4Mb1RBqJ38fElUWz+3XsTrC
JFLHkQvf+rXMyYINducjVuumcXu6rv6lYyDYd3U7uqJVw6nogp+NTf++QEG6
Rq+rh683sxfu11N7uXU16p5dPZrZC/fWqb1Wvk6hbZlfM3vh/ji1H3d/cczD
ooBm9vw+OLHXeWPR/fbs0Gb2wv1rar+mn4eRw8PIZvbCfWpqH+pbUTTVIaaZ
vXA/mtrHzbeWGR8X18xeuO9M7TPed1cb+T2hmb1wf5na55/0Mhg0MrmZvXAf
mdqXDAEbpY2pzeyF+8XUvjI+z6frlfRm9sJ9YWpfu9Ekv216ZjN74f4vtW/4
33+N2c3shXu71F46O83xsFJOM3vet53Yt3dxGv59XG4ze+FeKrXvtHND9L7F
T5rZC/c9m63/KSp6n7flNbMX7kVSe4UOde+22T5tZi/cE6T2fQtjLMtc8pvZ
C/fgqP1ArzNdN4YVNLMX7nlRe2XzFR5FT541sxfuPVH7kXMGaOp/ft7MXrg3
RO3Hyn/MftL2RTN74d4NtZ9QFmy4eFBRM3vh3gq1nxJ4rD5t6stm9sI9Dmo/
zWbBudn6xc3shXsQU/uP+J+9Fgr797/z4aFDS2y1tHOx7N1oYwv/An6e/PeQ
b32fbc/Fr30GhNtNyuf2nfLF59hRn5xjv+eb2d1hWyoGhnq0T/EL5va/Z6lO
bpebhHOt40eeK33E+Vx2rh7XkHP1c/5MV1ZfHYLHD/tsKndz5/bm7Dw/2JPz
/IP/LHoWj26Q1T+gXGdaDLc/zO4RwHNyj6DM8tqk7JtukLarXeLZ1pJ7B4bs
/gIOIvcXpMT/Tk75sanXlrxayf2FDHZvAveRexOfmX98QvyfYfc10Jnc15jB
4senJP6j7N4HKJB7H/nsXgm4kXslY1jeYDfJ2w1WF3hM6hLP6g5fSN1lhorr
Dj9J3em6EuznTU5t3PbmPs7a+Cdnxo/P3J6uN+Hzl36vEz5/m91f+O/cPvUj
fC5TP8LnMvUjnGOnfoTPa+pH+Lw2ctJt7zUnAtW+a+2RWeHF+bR4p9Gjtvvj
n1bnH3y45cO5u6ZeTaydI7Z7vmnovgsBnK/esKF6844g1H7j/V3/u8RP4sAP
HY+XBuLKzGmXl5pJzj9bvn6xLrirA/yRPpN5yCKC20u9iP6x9vg6fCcf8Gjl
rBDORUVOjZ8Nl4D2rt7Hp6SHcj80D8I5c5oH4XsIzYPwPaRO7WqnobPD8fF2
bVXrYm/OLfa0PPPxhQ/KfvHq/k7rIeeuu069rB3qgGrlYTUZusGcfzikk3N5
diB+jr7S/swAX87NXtld7HgzAE8atL6Y8F1yznnNi9opT4scYfSloC0/VZHb
6wR+OPhp1F4QrUqrU7UOl/Bb74d5Xz4Cq9teNqtYE8n90DwI+aF5EL5f0TwI
36+MvPcp+wbEYd3O3hY1Ix5xvr+6r2rLTmEob/Ixxa7Kj/M8ozUqFVYpaPxz
z/Cjc0M5P7j1Ts/AZSl4fuXV7ksvhvLzxm12Vv8yNE/EgWu1gr6bBXJumXTq
0oNYL3T8+LGo47XH3I/CzOxc9QNWuGfUUF0p7zDOa8Nnr9r9+jFOcG51Kuvw
Q85n7nA8q630GAu9RymknZecA++nEu1rfuomHJ9g1s4gP5bbDxst752oeQ80
npoM6HYngfPgRT9v5N4+CW6DW59uYRTNuVOwfNKJdhdg1JAR++rnx3D/62aI
44SdJM68BelhJ11vwrzXMmN6Pgri/ASLB8+TeH4z/ziO+Kf1FepO6yt8H6b1
Fb4P/96tdNVzTBwei1OObzPlMefBdZ7Ty91C8FoH0ekD0x9xPqn9TG1X5RQc
dSJ9/eDiUM4tT6mlZdb/79xyu3Uxo8P4Oecdub81K2QScXLZm+0DlwRx7t0l
bEDIEA80lDtfuVYviPtRe3D5VftdSyBgvOaRluejON/oB2aDtB+h1YzFUa1D
JHHKv28o8dnwEI28piffrQrg/rWf2tSuD3eDHrr9OnXfn8DtbZyWbHnxyAuC
X1qmXXJK5rxl+JfWjuccYW6h49wz5rESvSYv18n+q53BaGH0tbyQOO7fnPnH
wcR/f19x/OhP4l/N5gtbyXx3sXFRl4y7/oF4XNxHxr3O6gLnSV3ms/zAAZIf
KZYfWE3yQ9ePsK7o+hH+PqLrR/j76I32nuH/0xXclX3BVGtPAOexN973kmsX
jKEDPumZzZLw61fqctanJGPRMP+kdyfCOB/lm29tfCoBU9fpaanPCObnrlf9
er38XTc3bGtQvdLdOJTbHzj95zg02IJlC7cOl+tjOLfbaKTes9QP3xW8CgnV
DOI8cNLikncVPhicW/h1/lWJ/8d3F1jtjb8PIUNbDc/bksztj7dcOP1luB/Y
Vh2ftuVDGufxW+QPTtnpAs5D4m6XtU3g/OzGM4HBr+7AB3ytHWuSKDknz/xj
CvGfxOLHQyT+9my+0IHMd4SReFx0J+PGsnGxjozrwfIPviT/qaxesJHUaz3L
G7wkeTvJ8gbeJG8XWB2B1jGi/vmrMakJoKE1IXdSksSPHKsvhJH60nUorM9m
39v/+7ubrkP+d/f1/SFz1iXjkI/Tn+dqhUt0yba2WzTiTww2tDlyrD4+kPPd
G5ziDGYFoufIju2mWAdxXt8iOTpSOwHXPy+89ig+mPPGms+7NzbE45h0s3t6
80Ik5+fNK3pUjriBL6+/nuqaFcHtnYeoTtL+4gjyvadd7rslnvOrJ/TXzy58
gJM/GlnptwzlfJpU2YDoYE90Dh4fmnk4jPu/PLaxXm+JL6xbU98p/l4aty+3
2aVZMOgxaN29U2p3LYvz+at3XR9w3x2M517JXVuUxPmqtZfDU+zvg93lDnhv
TQr3n8r84z7iP5nFjz1I/L4HxfOFMjLf42xcNCXjXmTjoiMZdxnLP7iQ/J9l
9YKvpF7bWd5gDMmbHMsbOJC8tWHrAeh6KGH1hSWkvuWsvjCQ1JeuT2Hd0vUp
vOeh61N4z5Mu13/TlQ9JePXqfadwmQjOvyi3slq0KAajRLIwVT2Yc1nRnZat
1j5Gu7wpF5XKQjh/e6nQ6ExQPJ5a8mp+4FMJ9730eNlek3i8J4p/Y7IllJ+T
v7V8ql6g6UUsWHHRvO9hlOjmvY6V+tPLFaZtWbi6pGUS521cRsyvPOKBgdbD
J1xoKYnTbLrF4QMa7nj2hvJZC6dI7n+Xw8Rtoz2bPoccrUR9h2dxe7s1EX5H
Tz2A5TkXLM0rUzm3PyVn3d7FFwxjQdfbNl1yH4H5wYPEzywWJwKJs3aZeF7w
mswL2bhoSMaNYePiATJudbY4z2BJ8pzH6gKBpC5Ft8T5gQckPwtYfuAYyU8c
qztcIXVPY3UEC1LHy6yOcI3Uka5DYX3SdSi8P6TrUHh/+Liueyf3vUlorJ3a
MPtFBOc9sbRjsjLi7HsumyLCQjgv85E+k7r8IfovrjlUtC+c807lI1zm94lH
rf4bbTrUh3KetHrEmGVZcbjc/PSSYRfC+Dn/Exum35/uYIkqNTMHnn0Uy+1f
uzywedTLA8rtloxrSEvhfPlCjwvdmz7XesTtUV2nHs35jb5VoXLVLrj1U4Ke
9Avk/tUvXyxPfhYIom1fO/vViLj9KSVLD3vDhzDo4oIp7Udkcj7bskNH11aP
4X2HxU/0n2dxP0uYHywifn6yOLGMxClaK54XqJF5ubNxUZ2Mu4mNi7/JuOks
z+BO8vwmWlwXmErqMpLlB9qR/Mxj+YF1JD8PWN2B1r22TFxHUCN19GF1BB1S
R7oOhfVJ16HwXpquQ+G9dMixj5HF1YkYs7nvkJ9hkZzv2bPlherdKJw2Tef9
K90wzpU3Lzx8crsPfu9bea2gXxTnXermGSRZxWGWcemTBSPCORf56F0uVonD
zrO7L2qbLLnvYPts4/cJJjuhLsNYxSQqntvvKKraFW3oAzGHs9L7BqVznvBp
hfuCDtdR223L7quJMZzrXyxeadnFCQeXmnosuBMrufcR1PvcBrVQWC979LDb
u1xub73mdXxH7wBIGPfxppeOiHOFuzLPnAyCQMY75+RK5Rzu5wrzg7uIn+Ms
TqRx1r0UzwsbyLy+bRLnDT6SvE1keYbJJM8H2HxBi8y3LZsv9CXz9WF1BFrH
um/iukAcqUswqwtIk7rQdSWsN7quhN8v6LoSfr+IOTLnQ+LORMzRX3VHwzWK
8y9tVwVs6RKJ7nK784vrwzlfMWhynruMJ45I0Oso/RY5X9M2c33hs1j07BnW
6e2WCM6T/HPlftjGYkRCRIaxTCS/NyET7VijEeIAddstZFq/SOT2j729xw3a
9wj0ho2KOB6axbnUrxfdNkpfwKz+DXm/j8RxvuCF2wD7pyfwk0WLBKmN8dy/
7bh0k2r3CBg40Kavw6c8bq/WSrHFt44hYJn+ZFynDrmcT+7Rw/FNUiissFHZ
OqgqV3KPhvnBscRPNIsTaZzGKJ4XNpB5DWV5g74kb6Esz+BC8uz/UzxfSCHz
dSsUzxcqyHyDWR1BROo4g9UFbpK6PGB1gcekLnRdCeuNrivhdy66roTfuTJW
JXctL09AlDlrsuBMNOca+q2tB5uGo9Tmnc5xXpGci0oal/ayv4u/9wwYZb86
lvPGq9r+ZmqxeG5gWWMfT4l9Yr3FXacXMTjz7kZN+3mS+yCXhm7602/2dYgp
vjSklXQKt1eoCZhn2PT9WPWPhWHnchHnvhMuxtf0OYh93UZY+c9M4PxoRGTw
voyZOE7DO3XdsETuv9vmLMdeIxFq0mRsVzfkc/sJO9cckrcJh1VwV+lD/hPO
vT/qDZk2PRJyV8dKh0bncT9qzA9Kp//tZwiLE0eTOBcNE88L08i8brG8wXeS
t4aV4jxDw6a/87x1vHi+oEDn+0g8X1Al841jdYRoUse3rC5gS+rygNUFJpO6
0HUlrDe6roTfQ+m6En4PbXOrb+OTdQm4avyIKjNz5Dz8c9q5qfmhuKa+8YvF
2mjOj3+YOytBxgVtj8sMn5MSx/nPi66+jnYx+Mzv0yn1T1Gcx3zNvxMwJgYd
Rpsk3D4fze+VrFwU93BOmRucl2mdWTEmjdu3jrTX2z76EVzVU+48SSWb86OG
JVLOY/fB7rgOjzd3SOK8sEVmsPV2G7Bbebah25ck7j+A+ccbxH8fFj9YkfiP
svkCnW/MFvG4aELGPdVSPC4eJeP+vinOJxiQfBaz/ICI5Med5QfsSH5ofYW6
0/oKv1/T+gq/X7uukFdULohHtfcv/Q+OjeFc2ey4yrmJISjfZZtsXRsJP7fZ
oWNfKSeccfftzBr1BM6/hlw0NwxH3ORw+fuyMch5nMyt17e7IR6YfCXoeQ7y
+ya9zm8zHnnXE8JFT06prJPoUVu7tV4TviQQ3OSuGfd5K+K8bPp9s86PHSDc
OigkNieZcx3VdVF3ay5DwbNQj8THKdy/GfOPCcT/GBZ/0375O/5PpuL5Ap3v
FZYfoPmJZPOFVWS+9my+sIvMt9n78P/qSOslnB+g9RLODwQ1ZF46tLSpXoru
Dd89YjiPeV5T88U1CFdtmCXX+FLCHZXWqwZPOIVLxs77M+d6IudFUecPX90R
jTIyfSNWTZTYr1W58yU5JQrv104wD7WT3E/ZGO5leny+H4y3W5k163gWt7+e
sKElNlyDowrTn5peTOVcZsDzRefrb8GmlUtlVXamcT8JzA/OJH4yFMVxwlwS
53E2L1hN5uXN8gA0D+5sXtCKzGsQmxe4k3nRugj1onURzmnQugjnNCZFXvYw
yI7DOPvY8HUKsZwnvZu5aIRcIPr09x6+wk/CW6/vFpLV+x5G29n3fRcdL9EJ
X/8afIZF4ZuPryelP4nhfNP80i1RpyPxi8LB/gb9JPdTTjH/4Ef8j2bxAI0n
hPmHUuJ/GPMPn4j/Zuea/stbs99//zuXQvMjnEtJGNVT8e2Vx/DnwomG02Zx
nFP/wrjUv3COhfoXzrE0+73gv/sg1I9wvoX6Ec63UD/CPQjqRzj3Qv0I516a
ne/67/w/9SOch6F+hPMw1I9w7p36Ec7JUD/CORnqRzgfTv0I52eoH+H8DPXD
+30TP8K5GupHOFdD/Qjnmakf4bwN9SOct6F+eB9Y4kc4h0P9COdwqB/hfCy1
Twuz/NTY+Aq02PkKmP7f+QrhfOMiDbULk3VzsfTA4UMjRz/hfAg7P4nLyfnJ
/f11e1kUpKP1hZVvGsOTOX/OzmciPZ9pe6Zw1Iz+QfjhfWJ6T+8EzgPZ+U9o
Nf7v85/r94rPnYI3OXfamZ0vhQxyvrT1khXf1x9LhvuiiMbjPSTnXeu/jM99
oOsFNr9mLdzboZbngZ3DwSnX244dZqIg8Z/Nzs1iATk3W7tY7B+9if9Ydi4X
zci53AnsfC/MJed7Z7E8wEeSBx92fhhKyPnh//IMtiTPa9n5ZBhGzicbsDrC
B1LH91bhATKNObBQoSJJ427OP8+1Cpzqggqcns8ROD13LZznoetNOM/z9nlb
OU2vE/A+ct7I0e1SeL+tSMaxknD3ygs9srs54fDCsVva+SRzzup4asrdBqND
Y5RTCD89pX370HaJ5yS6oJl1+lp2nSPxh2LSs7B19/k5H9NPbh+LAx5i0Pzo
WT1uSvpMVVqucGwzxBl3b95Xq7HjEecxZ83f7FwSjO72oafsjkv8+MTZjc0p
D0K4HJMac0+iY3nlqJZeV7CBi27JPRdfD5X47yTuhwXzSD8shbXHdpuWWuAe
4/L1wxIDOZ+iu31CdN1e/DFBfd69T0Hc/2XWrwqySL+q7f5asyySTkGRluzv
lusyOVdhHIsJv2440dV42DV0Mq5yu1SXwbkz6zMFuaTP1Dx2rgNnkHMdrn1a
9o7tGA3XEvItW3aW/J5u0dE/Z5FWGoRoTBz1qSpa8jvjs2dLngwKgvm7fx35
rpPD39tv2HLyRNnbVHA9W/Rm7RHJ7xG6l0aVbFwWCs8PYWPBlif8/apcp4fn
806kwt4pY3YZd4jhvMvMBf2rvCPgRSf7iw43n/L3ZtfY+0PMIu8P1dn7Q+xG
3h8q9JutPWlgKsicPdj0x6XkPd7nbhs0zfojrDGzX7S/vEDy3om9R0I78h5J
n71HQkPyHkk+/M9VrYgUMO/a8kmSTwy399pfHZimFwsrRoaFPphSyP+OXsbe
J6AReZ+QzN4nYDF5n+Cx44WLom4KFO3/sfWklOQ9wFf5sx9bVyTD2Ohlg2WW
x/K/48xmiP9+wQDy98tV9vcLisjfL08ua5ZOt06GoCX6u2Z5xXL7kllv3+kY
hcD0vU+3Bo/K5d9vP7Lv4WhBvofrs+/huJp8D7d6L/25vXwy+MU/MtH5Hcvt
50ipFTk/TIJO07Z+7bEwjn8/nDzJq3SRbhykHFt7auWJWP79zXi/8cB+i5Pg
0InbNhHXJd/rKqpzfuz9EgHhMbP2DN8msbeoPpY31SACUqUmRko/ktz//fXR
W2Ohphc4Ddg9a+93Sf/ZE4wj5asOpO/zKQ5FM80VFp3SJVz4PArZ79JtZOva
v/nR6CmDnTxtG7pK7mtQXXHhOfzuYNH6mY4iHHhtllKheibnxpNQ941qAioP
bBg3dYHkc8cixnO+9d19kC7XMqqHleTz3Xb8sEMGd7Khf9BdTflr1ZyPkJZT
LqoNRfPnC/V7F0s+B08xexxK7BfHi/1jJvG/isUDw0g8lSx+GEHip7rW/7rH
8a/7PsLnUTP96v8+jzRfVp75nw6k/RfZud2v3+d8uE1kQ9ZoLzzZMM5vxmQv
znsbjX0XKHcLlJPuuo0LjOT+px5c2VOrkwdUxpadrr0Wz+3rDTXCxn5zhMa2
8S1HHZKc+21kHFu1+5sbMD/4jfj5fVwcD1iTeIaz+GEvib+ZfvV/vNn9i//4
ZKanDdJET/sI05GGOKIj3blarEuMMUSX+AnTMcZ5RMe4E9NJhgCik/yS6ffi
aaLf+47p/WIG0fsdxfRs0Y3o2Rox/VtUIPq31kyvFROIXqsn03dFM6Lv6sT0
ZrEP0Zs9zfRI8RvRI/1dPfKA8+4LOO6jzJ73yeGcyx4U66zifqKz6srsgdpv
Y/qZuIToZ+7xi86JqI7AecfmnV5mGcB50pDIVydWWuIoWDR1uL/E3pDpi2Kr
o3/ri+oOFtuDKrGfw/zDDOJfjulAoojoQPqWBY+MWBeOlge6qbRYINGTfGt3
2+PzF2NAl7NDo8xjOf+VL9a9BDmie+nKdDWxnOhqFp0W+8EY4seOjQtmZFx5
pnOIRkTnMPDuWNl0v1Dct9X30I8pIZzj1eV2aUpnoejk6Z7tY+M5l2W6juBC
dB2VmW4k/iK6kceuif1gMfFzlo0LO8i4E5iOH7oQHb+ahosFv8qDseiyaanR
XMnvwt0njEk7ftUZpOaejr4zPInzOUy3EBKIbuE3pouIK4gu4l7mB1sRP6ls
XCgg4zYynTpsIDp1yl6pN+7JBuHQlFfrh26P4Fwzaal0YYYb/NzfwWqudwrn
JkyXDw4QXT4NpvuHKUT3z4T5wT/ET4OneFwYQMZ9wHTYsI7osI17uraF/pAA
dNf2+i66ESX5PbFj597fvzd9jx5ld/iwVjrnh5juHJwmunP9ma4dDia6dpOZ
H5xB/LRn44IbGfcM0xnDQ0RnrOaP2Y3UCY+wax/Zsid5El2y6ufSo5wm+0N5
y3NTrV5kSvTTmK4afCS6ag+Ybhs+J7ptAwrFfvAD8ZPCxoWOZNwCpq+F2URf
a8J8XVsHBz+ctkXFJ7aNhNczfTBYTvTBYpguGT4humSv5on9gBbxY8z0oHAc
0YOK25G6YlrwA0zr/2zq1YFxnEcyPSvwJ3pWqkxHC48SHS0T5gdSiR8jpl+E
HkS/SO3ctU9jv3rgvv4/4p014jkfyfSXQET0l5Yy3SecQXSfChzEfoD6MWH6
PDiZ6PNcZnpBoEr0gq4x/SKIJfpFDjvFujrwiOjq0L/Hhfce9P2S8H1p2ftg
l887c/Dwhv5jVimJuH2J5+zAxDkpaOBse2GlRyLno9qN17h12h1j1QeotH6a
xPmvL43G+XI5MMox4n6EfRXnxex+MSwh94sHqt3NnaIdB0qmpovTzn3l9jbs
vQ3akvc2IgWvzidkMrChVifYYU8N5+VPtoa29/HCd2aulzOvZHOuaL1up+lo
hN3RClKDy+M5b+Oea1wiyoLh+W7++3TTOKfv0wS+Yo756+kzYnDVGlMLBbsy
aB/S41bE/WMwxNrKcrtREPrVDbHtuuAd5xuOb323Kd4X2z681Ph/dZ17kNdV
Gca9tIk247DiLUq8gbcYpUTHUfArCgRTyoia5CUUUPKS0oaIYhTCgIkUlC2K
DLgoLoOwLCuKC8gBBEHCdIFZFRBRAVPTFGuMtammPd/P2fqc6d9nnnnOc56z
ML/fOe/7/m68+U/pXqJy4y1dqyuait77d52/cduOxL/unuUrX1ndVFSNrdl3
/9BtCe9T8ZXLXj1sczGr5rkZ1x3xZtKxH/qh7AfcflKfsvzAtx9w+0HHfuir
sh9w+0l90PID337A7Qcd+6E/y37A7Sf1WcsPfPsBt5/0++DyQ5+U/YDbT+rj
lh/49gNuP+jYD/1K9gNuP6lPXH7g2w+4/aBjP/TX2A+4/aQ+dPmBbz/g9oOO
/dCvYT/g9pP63OUHvv2A2w869kPdvv2A20+6Z5Mf+PYDbj/o2A912vYDbj+p
T19+4NsPuP2gYz/U69oPuP2kOQDyA99+wO0HHfuhbtN+wO0nzRmQH/j2A24/
6ffT5Yd6P/sBt580x0B+4NsPuP2k+kD5oU7MfsDtJ81JkB/49gNuP+jYD/VF
9gNuP2kOg/zAtx9w+0HHfqiHsR9w+0lzHuQHvv2A2w862eefst4j+/xT4vaT
5kj480/Jzz7/lLj9oGM/1DnYD7j9pDkV8gPffsDtB53s809ZV5B9/ilx+0lz
MPz5p+Rnn39K3H7QsR/qEOwH3H7SnA35gW8/4PaDjv1Qz2A/4PaT5njID3z7
AbcfdOyHugj7AbefNCdEfuDbD7j9oGM/1FfYD7j9pDkk8gPffsDtBx37oU7D
fsDtJ805kR/49gNuP+jYD/Ue9gNuP2mOivzAtx9w+0HHfqgbsR9w+0lzWuQH
vv2A2w869kP9if2A20+aAyM/8O0H3H7QsR/qWOwH3H54/7If+PYDbj/ofC3q
hL763n1l1Al36Ht3j6gTqksd3keM8318QHwPCt/We9DuOK+mOFvzauwTfFDM
rRioe4YLY27FHN0z1MXcipZF/3vPkP1OcfmO45zBnQ/f950PeJZPqWOc+4Fs
vyXf+0Xf+wX3ftExzrrOgXcr5wDuHLhncA7g3i86xrmXcA7wnQP6zgHc+0XH
OOs6B97dnAO4c+B+wzmAe7/oGOc+5Jb3j+x7evWq0HnT2pvu/HR+wntXd5g3
774nw6S9zz5W86v6hDs39J0bfpwbuPNBxzjrOjfeH50buHPjHsa5gTsfdIxz
bzN90bQtH5+6KgybNv6dlR8tSHiPrUeP79lQE47/9fyOx+5sSLhzS7+7qtzw
49zAnQ86xlnXufEO69zAnRv3Rc4N3PmgY5z7pXBcVdPs3iG0fH1Xv4UDFyV8
/cf9Tmt+el3oc9PkUZOOXJLw7pe2zpMJ39M8mQcGtM6rCQ2aV+Oc8eOc8e+c
wZ0nOsZZ1znzTu2cwZ0z92DOGdx5omOce7P1se4r1Kjua9G4IT2u77UudB+3
a2mfXUsSXnXC1XPWrX44jOi6cXfnlra5N7VxnkxYrXkyR0Z+Yb7zx6fzZ1/O
H9w5o2OcdZ1/+t1S5Q/u/Ln3c/7gzhkd49wThmWzf7O7bkXYMGzYPYvnNCR8
a5wfEvppfsifv7PpodowKWwZ1bx32KIVCZ8b57SEqZrTcn7kF1vFfySuWwSt
63PBv8+F/fpcwJ0/OsZZ1+dCPYPPBdznwv2nzwXc+aNjnPvSibHuMbygusfz
Dp3e49Suy8OoouKAeYOX/Nc8jQXPvDH/hvDUGfOO2j5kVcL/HueThAGaT7Lr
n0//h1/Uit8+6hd3St/ngn+fC/v1uYA7f3SMs67PhfoNnwu4z4V7YJ8LuPNH
xzj3xrfF+tLwlOpLd28+4t3KBxtDS/9Hp9Vd1DanYnrjiDPHHzCuWHDOFafd
+siahHeO9avhCtWvXr+slR8Wir886hf7pO9zwb/Phf36XMCdPzrGWdfnQr2K
zwXc58J9uM8F3PmjY5z78xNiHW/4mep4Wy7vP3DyK0tD89W9q068qG2uQufG
YY09V/+u+OBvvzhv5WdrEz481gmH91QnPDHyw4fib4n6RZP0fS7497mwX58L
uPNHxzjr+lyoz/G5gPtceBfwuYA7f3SM847QJdY/h3aqf77+/ctWvPzls6Hq
hhnVBw5qm0vQ6eDJt2+ePLs4aOSGuzcOX5/wzrEeO+xVPfbYyA8V4neP+sVP
pO9zwb/Phf36XMCdf/pdWuGs63OhHsnnAu5z4X3E5wLu/NExznvKybFuPNyr
uvEOo5875JKOS8LawdvmfPX+FQlvrlz4waU75xbjLzlrz7c+fznhB3VorWMP
P1Yd+yFHtPLDRPE/vLtVv1gpfZ8L/n0u7NfnAu780THOuj4X6q98LuA+F96J
fC7gzh8d47wrNcR6+7BT9fbb2+0bMfPMhtDcfPZLi5e29cvXr72qdtwxC4q3
Ji4dXTy0KeHPxPr/MET1/+9GfnhP/MVRv9gifZ8L/n0u7NfnAu780THOuj4X
6s18LuA+F97LfC7gzh8d47yv/Sv2O4Tu6neY0O3J6Y9eWB9OujjM7HbPqoR3
iv37Yab696+O/OJE8Z0zfpwz/p0zuPNExzjrZt+7y/q67Ht3iTtn3gGdM3j2
vbvUMZ76PmI/SHhe/SBjG+4devTjC8I1dSM6NPy+DX849tGHJ9VHf0bkFz8U
P/veXfpxzvh3zuDZ9+5SxzjrOmfqCZ0zeHb/XL5vZvfPJe480THOe+iDsS8m
1KsvZuZhT5w5pmleeOT2qwYfUrcm4S2xHyf0UT/OJZFfmO+c8ZPdV5f+s/vq
Enee6BhP/j0/uayfzOqRStw5827rnMGz+6JSxzjvvFfGPqPQXn1G83/U2hdf
uC8+q3cq9Z0bfpwbeHb/U+oYZ13nRr2ocwPP7r3L9+Xs3rvEnQ86xnmP7nJU
06XdptQUf5t5x8BO69Ym3Pmgk92Hl+tm9+El7hzQMc662b1ZWTeb3ZuVuPPh
vdv5gGf3ZqWOcd7Hs/urku8c0HcO4Nn9ValjnHWdA3MDnAO4c+Cd3TmAe7/o
GOdd3jnAdw7oOwdw7zf9nqZw1s3meJdzD7I6wxJ3DrzvOwfw7L601DFOPUBW
l1jynQP6zgE8u7fk9yuFs65zYG6DcwB3DtQVOAdw7xcd49QhOAf4zgF95wDu
/aJjnHWdA3MnnAO4c6CewTmAe7/oGKf+wTnAdw7oOwdw7xcd46zrHJib4RzA
nQN1FM4B3PtFxzh1F84BvnNA3zmAe7/oGGdd58DcD+cA7hyo33AO4N4vOsap
93AO8J0D+s4B3PtFxzjrOgfmljgHcOdA3YhzAPd+0TFOnYlzgO8c0HcO4N4v
OsZZ1zkwd8U5gDsH6lWcA7j3i45x6lucA3zngL5zAPd+0THOuq7z6TvwmJPX
VL2d1fmAOx/6gJwPfOcD7hzQeSfOOQn9NefkwNjvEzqp36dr7A8K7g9aGvuJ
ik/VT9Qv9r8XI9X/vj72JRX71Zd0eOxvCserv+kfsU8qnKM+qSfatfZVFS+r
r+rV2IdVDFIfluujyMf1UeD+OyG3a2P/VzFW/V/++0HHfz/g/jtB3/Nk0J8V
57oUp2iuy6ahQ4Yv/WhV2LD0jrsW39w2j+X1/XXtu9Q+FbrMHvDa0LsWJryc
W1JM1dyS0XHeQnGX5i14DgDnmNVHlXVZ/junvuuLyaMu/qjX8rDv3IMvaBm0
t62/XucCf/jF4ZNrbm0qNlQc/svRc7f/X/26K94Zuax2WpHpl/VO1oef6Zd8
6x9w0vpdjbU1mT51RNaHb3341j99xnGTqsfMz/Spt7E+fOvDz/QPXVbdWLs4
06cuJdMv+daHn/WL9dnzQW3lc5k+9RhZX1jJtz586w8c175n9ZhlmT71BtaH
b3341r/5hQumTtizMtPn3dz68K0P3/ov3PfMTxtrV2f6vP9aH7714Vt/fcf+
j9XveDHT5x3T+vCtD9/6Tc/vXFtb+VKmz3uc9eFbH771t/9g5Cez+m7I9HlX
sj5868O3/p6/Hnps9ZiNmT7vI9aHb3341v/Lb2f3mlK/KdPnnt/68K0P3/r7
u51z24Q9f8z0ud+2Pnzrw7f+/cNv2thzymv5v9/yXtf68LN/vyXf+pPO7Ta4
sbYp0+c+0/rwrQ/f+g9VfPl59zWbM33u/awP3/rwrT9t67oH6ndsyfS5N7M+
fOvDt371E1OP6/rF1vz/t/I+yvrws//fSr71H6u6tqG2sjnT557H+vCtD9/6
j/c65bsnd3090+f+xPrwrQ/f+nPbf7Z9Vt83Mn3uJawP3/rwrT//7eUjOt74
ZqbP933rw7c+fOsvqptYUT1mW6bP92jrw7c+fOsv+fnlMyqrt2f6fD+1Pnzr
w7d+4/e/edaU+h2ZPt/7rA/f+vCtv/Ib77/Y7g9vZfp8n7I+fOvDt/6LHy4e
NGHPzkyfz9vWh299+P8GbsYKOA==
         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnXXYFdXXht+X8pyXk/OeQOwAbCwEG8EODOwCuxFFTAQLWxEURUQEBUEQ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               "]],
              Annotation[#, "Charting`Private`Tag$5571#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJzsvGk01u/7/hvNkyiaiIii0VRJcabJnFBoUEqGDA3KLEQolZCppCIzkSEz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          "]], {}}, {
        GraphicsComplex3DBox[CompressedData["
1:eJxcnHdYzu37xxskicgOWS07JEo6o2FTyRZKVnbILEWkrISkUtGeWpTW2d57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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQXYFNX7hr/gg91va2Z21kJRMQFBFMUWFUUMVFTC7g4M7O4WARsLu8Vu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               "]],
              Annotation[#, "Charting`Private`Tag$5592#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJwsnHc4lm8bx4syShFFexBlphIanJWMkBSSUZkhJYVQKVIhokQl2bJlk/G4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          
          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k0lF/cAHBLEiGJkqUUsstSEepmTRQSorKFrGUtUrIWUUrWKPvMWMu+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            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs4lFkcB/BBVJqVBy2VdpoiWVErJLfTqpXLug25tEiZhjBsxea6cslD
yU4tWpSws5ktzJgQHhy5DjMx87q0KpRVJiq5tCnJ6p9zejrPc/75/PG+5/2e
3/v7UY+F047Lkkgkt+Utt7y3Pm4+oZsdb/Xtx6XlNQXycj+tWmDjWV1hu1QM
KCEq5HI29t2D85p8EgfkzfE3V1W8Qt6alaVelVsEPg7tn50zeolcY8Byulgr
GtSY/8Akzkwi9++OU7x6uhzWSki07Z5S5Awd1RjhTD3kZaWqJKs9Q+7R1XBv
wboVpl2Rbf3LYQx5RuIzq8VEAeyXUa1LmhhFnkgorLTZJYKFrh32lOQnyGUy
S1bGbOiBlvVrL97UfYzcTzJKe8gVQwO/NJ7P3SHkw875CckcCeyqqhy63PEA
+Qevfn1vEgGJSA/7INtB5HKJe6Yf7Cfgb7W3Ur3593EOmvqVL8IIaGoZq6BO
HkC+896x14JYAq74exuQc+lDnnReuyLMj4DmA0t+N7wI5FbqnlILRQKeHyGf
M3cSI495WaB4JFEC9QxVOdYVIuQ0R/bIjRoxDB1OigjhC5BLyafWKO/ugdTx
tcXikFbkKRvJ8rVRIjieY7Ldn9mEvIQpmaMGdsLm8YMJfrJ1yLucxzR7Fdoh
WNWYx7tSiVz/KyXPilvN0LRgdoOXSQVyC4cdJlf8GyHbGUqNrLnIjXUUKOcb
quGrxeCZlBzslpyb52yiyuGRN7UqzjX4OeL9hjtZ6kUwbOFhfeNL/N7jBg7C
QWES9FhBTp12r0W+NTDhaFVfBlAMuHNmyQIij97Ef+24swjYsJ/lF803I//u
1Nv6NCEHeDGjdj9gtiMPTR0Xz02VgclLUnZefyfyk0l7XS0oPDArft77TxvO
/4gnszNWygXB1TnF4449yOHtIrKQWwoifn77KAzie5R79H1lk1oJGDwsNJ1k
SZCbxbteygKF4GnsyqaL6rgefPgjJ692soBGdjjFloF9n63K2Lq7pqBAx4/x
PgE7fYzxDW01C0a+t1X4Iwj7rpiZA75HC2FxBneiZB32ph2C9LTfS6DEgD4X
kozPYzBjFSTil8Idp7sposbP6lBSsSK3jQsf6fjQAmPw9555s9h7bRMP/uri
QDFuwPmoSYJfDLHKYP+ibmLkOZznbPS4tZ4hB/asYW+J1sT5K+nOj61nFEL+
gQmO1i18Xykj9uviujNgYZmKo8Zn9ztQY5Epfz8OFIdrktxEuB5s2gQTl/oK
gd27PyFHpgo5wWPVdRpygRHd7t22HFxvQ3blH8yvV4Ptq7hpe6/j+twTVXbW
pqUBMNbPCnS1sbvouViVeTcDiwyjkxGLPOTePj9K2263gbE4P7qSAa5bd0aE
ViClEwC3dKeWGHzOnNM6LIqlCNAKUhTvUPH/GKLmTp0XdQMnvYO+Pa0tyINH
tHq1YsUgd3ibycayDuSZ+tFD4QESQIzcuNwhg/OXP8Q6dYxEgMw1/zbVU/E9
PunvNtX1IMCEcX9uhDKuB5NI5fGhaAJom00nsV/1Itf2mVhNjyBAKV0if43X
jzyXSr/Q60QA3ujzSX1f3A/VS2MYXEUCKPqXUuRVcf9036giUOFKgFG6NX1f
Oe63IYfzHXJEYjDQsr7wzi+4Py/Q63JLtHtAjZ7hoamtuJ9nl9q3H17O7b+1
ARPX4nH/rw3uCjjxXAAsqoybvm7H86JDenaLXFArCBi0Gjbeh+dLPtM26jil
EQir9Ad9nz7FOfiYMlzv8kBrdujZKVU8v1z6zEYZHuHwp9DEd6ZeeN65mSk3
y0quwxyNA5vt3r5AbiiTXmCZVAINvDha+Qw8T90XlGwvWLMhRVkYL8zE87et
YfTTvG60/mJe/w8iaR1t
            "]], Line3DBox[CompressedData["
1:eJxd1Xs0lGkcB3BM2HDSGWy0QhdMWg7CysSTS+XSSuMuoaUpopuorDmRs+mK
lZLIFDnmjHvMrplm5nFr3EbM65JRbtOmokg3t2T1z/Ps2fec55/Pef943t/v
+/5+6387TjukICcn5718SMtn40hD5OabDAeTb0vLzxS4k/P9aQW7/P+qcl0q
APpHyWrlD7Bvlc7qPpRjgTufHhpwqiaRN2VlreHk3AffBp0/frJ6h1y7z366
YNM5UEvdGUOcmUAe9iRRJS+2HHIlcjSK/2vkdGONhPYPfFiZdZGcojmG3K9N
0LHg1AQvZSs0FXn8g/xa8pjDYnIL7JXX4F0YlyFPJpSUd5mL4b19ze76KaPI
5dOKlRPWdkJ7vvp19uYR5CESGe1ZRRc0C7lUGVw/iHxob+75FJYEtnFqBjOb
B5B/Deg1DZQjIBHn537EVYp8D7XQZ8CZgNWZq6YCHz5FXjflPud3jICioMP9
CWp9yB2rpXMbzxJwNuKp7UlaD3Kt3bnzDjQC9pcpmYnCCNwXk0y3xHcSaE7J
yKEf7EIes/tKTZaHBL6KkK5dmBUjl6VGgnMhXZBrRSgbb2lF/rEjdm+65hPo
5eo7oWr1GLkReyxdt6cN6jKyAqll9chJG0i7tTc1Q5K8TTOtR4D8VPYFDyfV
RhiabuLyC5WHfG7KwX9EKoCdM04n/9DkIrdd0Udu2caBSQljldfc8PuqinFb
mYxiWPu5+rCqjhB55hgsiuhPgd2OnS/ohg34e1lTsfkFt8BIaSErnCRC7iVl
eloosQFF1tQv5LUhr/S14zBE1UBpcOeZUF9cNy4leDyFzAW003qpcje6kcfX
tku2VfCBzCh6uR64X2on6iRuGULg6Tbz1WIG912Jyp4IuSsEzP1xB1/kP0d+
W3Ndg/oYH7ALK3zB8yHkSR9axcmGXJCZY1E5EopzaLZ4kaUlqQbM09FrKeo4
tzK9wowHGSVgem6J6p+IfXKYZ97tlgcWGk6eMuZhT5K8UWR1uoBhsX9DVQf2
mWl22qkVuTBbGFg3+Qh7h/Zb5vr2EjivpSXrTsDubTJameBSA1+tj0hduQJ7
L7Nc+QaFCz9+Tk/1+8/9daFe6v0qPmTMW0u1SMP4vyA7vxxlCqEwfIlDycb1
YSvIB3yJF8IrPvJ2K8txPY+t8n8fFM2HUVmJYZ6XcP1D3//qb15aCz9Y2jJ0
3HC/AFNALXhcDdXS8sXvfHB/jQxmwKxHCXxjruzZaN2O/BG9XjDunA2Tti9+
4evg/Njmt+V4RKcCYaz+0eQZnP8oFaM+hmUxyLSUzVmY4nwWcfMG4+JrwOif
wyGGSTjPZfmm3UHqAkDLOvJMTxvn359w5g8VNYCfy26ve0bC7+dfgavPdYhA
3PW4pfPH8f+lytHObrnWBpRWliySY/B9Iu9OetrldoC+52zTgbwm5FeDfijn
aXUBtXljq2LrFuRUWeDANooEOLr87sjzwvOhV7RXXzwqAYFR4bMGNv+ZJztt
LCxdCXB9wu5Tow6eP4n1hhVqcQS4H2zLGpjG9d9zZpf3iVgCbF+8cR5U9SJX
bKUpPPEkgGDdvTyLA3gerilNoFeoEEAlrFRfUQP33ecncgu5QgKsLjtF7CjH
8/ZoUK7HLXEX6GvUufd3PJ7PCxG8nGLDTlC7xdJ3aiPO4c1Sd1GQvRh8UQ8f
v8vAueVGtYVHvmkB2znWdT+K8L5ofp20gXSkCYRLHYasd+D9khvjevaQvhC0
c0ylB16+RG4TbEvfV18Jmm5GJ01p4P3l1WMno/sdh/ujk+dsA/C+87Zb3aAg
YcJb2i4GbjNvkVvKX863v1AMzQJYm3LpeJ/6LKxyver0AOqvbme0p+H9+1gg
+76vhU7/29f/AgN/Kcs=
            "]], Line3DBox[CompressedData["
1:eJxd1Xs0lGkcB/BBVHKQe2mXipKQdRkSHmcml6jcI7pYl2kUUU5ClFuW2uak
HVKWEMdwLJpGatQ8NGNmMGJel1LGrSVJTRLaFdb+8z579j3n/edz3vOc9/k9
39/v2Roa4xMhSyAQfFdfudV3+8jzyF15KY7GyyurjxRYWf779ACXgEcP3FbK
gN4ZNaXacuSWA9+2MAkMcPcrU7/hwSfceXS6dsOdUrAsIc9+tfqIu06/w0yZ
QSJ4vM85Grv4AfeQF8mKv8fVwidigo9RwCTulJ3qSR1fnsJ6epZahsYE7kfa
n3Uukngw+7Ysr8LjT9x/TZtwXEoTwj4ZdXb61BjuaZjCWhdzESzxFrjrZYzi
LkOrXJu0uQs6PFW5Ub1rBPcT4jGfN3Xd0OxEdv2xFgnuQ56FVzIYYtjewJLc
ErzG/Xtgn+lRAgaxC0fcqW4DuJcF6vw2QMZgUq9mbBDzJe5mqo3jRdEY7JW2
2c0r9eO+z3NPa1kcBr19ihXO+/fi3kX9qdNsdR3m9MJ892kMd7Utl1S+tInh
UtY9TZ3Ebtxd6eZl2uvFcHPVoqTUuxP36vvZ9XJDXZDfuHE8tLkN94MHS/ZF
MUXQuKR69PpuPu7fGBoG1iIhND06cq3Alov7aEbVyeOBPKh0OVnjlksL7gyt
COvRRxx488AcreVOM+7kG5kU1m0W9J0IMtU+hb5nV2WtwXruQ62kel2lJrT+
9+FvbKOsFKCQG2hX+laA+8ilafmK3GowsTsk4uU9tK+4FcVrOTaNoJ/tazRt
gOqTpSzXLkdoBrEizmC8MqpzSurB3FejXCAscLEuGULnOEZZS2M85gP7TaVh
9fIoD3dZ2HQSVQjaOE6SvNsoV7FXbVR++SAEnjurltSUxnGPp7Ne1JCFoM/Z
kpej+w7ln3kxQzOOD378+P2rZy/K+WBNYtUy4IK4bIH7dfIU7pMJio9mN3DA
5R/S/5B1R/2SfnNgtpPPAnQKEZuZQv5p/nVEjlMFeEhrhmn7p3F3MraqvWjv
CWrpSwzvEOQuEsfEAo9yyNseqaDsirz4Fm2H9ywLhtaFfG6aROvrW7xmlEAO
JJaCNSl7kb8LF/VeJnGh/Sv9z2zSf/5f3ovrSObDTPMZ0eIM2u9K1MrLS65C
OH3OkZCriepzWutQbcG0EC6bhHI29KC+bu2RjuseEkLCqZnBv4NR/bWKaoaj
M/nw5jbHs2vyh3FvCut0OTHKheHEqcT3EnS+gwsVO+knm+GbVybJW+JQHuyz
iswOURsheymW0mKD8hN8Mj/XLKEK7m9Q+ORzGOWNTHUzCrdJhVdT6uQSFlA+
BYsmc7bSUhB8fq+2qgwP5XNcOb2w6CFw3hhg7kJD+V+OkJdt5TwDhjahxYZF
qF/8lbwE/lIumCuQ+VC5C30fyd7x5ud4IchSObuZoYD6pfjcZLLnVhFw5S8b
jVe2ov22BVCheReoYDH3xAwJ0blsWMxcP9wN5EPL13kxRbhbvJUcXmoSA13Z
oAx/TzRPLnykEqVEDEi6uZ+dDVF9mkkVAToxGIhToI1hcz2435iy1CCfx8BT
eQ+/dcw+NA+JTcaCwxjwuxJkQjyO5qF2TRKlThEDiiE1evLqaH766aoJ1erE
wCqHFO5Ui87xTFChR76oG/RzN5U0xqP5vBjOvlNp2AUe77bwl25H/ZtX484P
chCBeZWwqaIUNP+fnG4Pi3wvBPYN1s1afJQrwWTqNjkqD4QNOA5ZO6EcFka7
JUTocUBHg+nA8XHU78RjthTvlnrAy4tKlaqjnHv12o1RjsTA4Ki0v2wDUb/4
2qk+lxXfg/k6+/UPLKC+s5DJKXZIr4RmgQyDQgq6T/0Wld2uk8qhnmpHSgcN
3b+tz8b+va85pP/d1/8A0h9srQ==
            "]], Line3DBox[CompressedData["
1:eJxd1Xs41FkYB/CZFDUia3ZC9ZCuKLpRKI6IZqd1v+6U3CeilBTr2dalkkpt
RBoahQpTxOQ6K8dlMJnJXFxySWslkUJND2mKrX/O6dnf85x/Pn+d33u+7/vq
+oe7BM0jEAiu347Ct7N6oCFEP/20pcHs3LdvAmQyv389wM6zopQ6lwt0QtUX
F9/Bvq3n0woOoQBkfuSsLC8dR85LS9MoZ+aA2X4b2Ufjd8g1uyze5675HVTt
tD0ijRpD7tv2B+nmiWJYLSG46HmOIGesJ8cIPtTAkrRE9TM/DyP3aH38VG7N
g0kZ83h39w0hT44ftvwaz4edRDI34c0g8nipopLdZiG87dxC0znzL3LilXyl
mGUiaFGz5DJbfwD5QcmgS99DMTQ6mFRyoL4f+QvHrNgzBRLYWl7Wn9rSi/yL
V6fhbwQplJ70oAVTe5C/VT871W0jhdlF0d10zjPkXS87DBYekUJ/lYrFdJUu
5PYm99q+hkuhnaojYcCzA7n/2vylc9ul0Ik32zQZIUWutani2JYiCcwVrTKw
SRYjNxtf/qt9uxh29dU70ZlPkQs1yccK9EWQouoXrW3Wiuupkhs7dk0A9xMn
DVpkzcgzd0wU31jfAgOBZc2JaB7yXaZ9pa6UBlh08YRp8qZG5NN3c1IhrIK6
l++/PBuKvbHJQSfQmA21ryV0G3o0IR/m5vTvDAiG4S9lZrZLniAPCprSNS8u
BMHCjNJzJBHy3enkLaOLuCDRbNTnUmQ78poFTre+lDeAsNSj9kZjuM4NlT5c
++IWcGxX9mvmUvyOQ2USinBaAM47OL724eA8DMoWKmlMtQF39narhT+9Qr6W
btGeaScGrys0bxgycD7H3437PdsvBn/mv3GxTcV55k2+XV6bIAKHY2XgnBnu
i+Rhg4jZMSEoSsroi9kxidzIrEIovMcHw2WWdr2675Er7zFNcNNvBF4RvHQ6
H7unX4LMPZwLaM5aGvWGH5BXXKY23SHcB6k2FikNQdhvh5L8WjtdwT/ryCsU
orCrD/mW6j0phClbRX5eh7CP+ym7bSvgwvNzV8a9N2JXzgu9uIHVCJ93VlFH
HuP7UD9ds6Sw+dChdeiR+w/3X/aeY1vIFsLhlJiIUzT8v2HynAFWkggWOYaS
u7fg+tQeZ24a9xNDsaemnEPF9dxdW2Lns1MM9xQn8hS0cP0VL1FS5+raYAYz
TtDEw3Mg8Jxn3t5pAUxcnMscKcXvW3KXEkjT4sMQd/2A0UycB5pudQhf0gAL
WYock/nduC+MezkfDlXDk39bHfW1wHlj5FEN27XYsKUjMtt6Hc6nwcar2iR7
dyiLDHPrjsJ5/kw3Ld0hywculONBWVk4/zPOHwuncisBzXHus3IS7pdbm7Me
HWLVA7WKKBvFNdifyzUGSc3NwDwmTWW+C+7Hm58T2CkTrUAU5T8zEYv7V7tO
W3ssqA1oih8Zyhn4Pul1ffHteWIQ2RxdaU3E84HozpIzWBIw7NvLrQ7A84To
LTb6pCcFcYn6+9KN8PxR+ours/ewFEzodSotmsH1KVtw1dvxuBQ4ZKu0sTmd
yFVfFObUO0iBP1et38wb96nGgxjGQ5IUkHwf6Cwg4/nptlydr/5QAowvWAda
FeN5G0rP2nddKAZdjVq3K0/hd5QHcpn5a0WgasNW94nVeJ6nP6A10y2EYGpJ
wBvWaZyH6sOtASGjfLCr3KRuaTPeFy0jcasUgnkgoMfyhYkVzlXWEWp0kE4t
EJQb9ni/wvNh+wFThnN9CeClh8VNkHE+nTrMBxke4XB/WPyMqRfOs6u5WsM8
yS14XXPPyl+m3yLfSryQbZGQD428CtZkMXBfuMlVqZes70AdNcFpwRW8f5se
D37f17XW/9vX/wHhQjOZ
            "]], Line3DBox[CompressedData["
1:eJxd1X00VGkcB/ChtloRS6doOeOlsq3VQWZXJh5UmkYoyms6icbLaElCKG9t
SyJtpmVFdlKIvJ1GzOLxMgYzMXOvl42WUCwqE1my3rbdP57nnL3n3H8+5557
7nN/v9/3p3Mm2OmsPIVCcf50r/l06w01BeziXLb8emX10yUDlP+uIWDrWlXB
WOUCKltVsTQf+56+j5qVlELwy2ylNq9iCrkgI2MrL+tXsDKw/8Os6Tvk6r0W
09ztl0A1/eA5MuIN8tOdMQp3L5TCGoLi9JXrOHKWvlqUeKYWlmdcU03cPIbc
RVTXsWgjgEk/ywse2L1GfiN+zHI5vg32yKnxEyZHkMeT69bbGj2DecdamdTE
YeRyaQXro7ZJoEWtcuqjXUPITxEjTi/KpHD3qaTyk40DyAcds2MTCwko4j0Z
+Km1H/mSW4+hO4WE5EUXpj+jD3mKJY//fD8JX466Ujwrf0fOKKhd6AwiYdBQ
iGGcUi9yb/vQ0KzvSZjqrHm7w60buQZBhLuakDB+6YbRxnASOb19aYrGJeCw
f24c57YUOdQxjW2sl8Kot3Pe8EkH8sXmpjuC151wgKuitc9PhNz0Zqp9zE4x
zKlSuGRj1YqcFFbKZNeEMP27ueN5MwLkRb/VROibNcKk5wtrnCabkftYl+YF
R1bBJsm0NS0WP1/b5XAmJTofPr1uf7i/V4h8i+LqkOHgD8CrNDPcU12MXFdy
K9FSoQJ4DopNpkbwuYwl7s4qE/WAo1v/Ns28B3mg0GUlOqgFSCKSGF1UXJex
7jSZZ44ICK44mhsLXyKPslytD90kATU60Vepzq+QS990akwoEWDUrlmRsYL7
bUxvS1lDNwFOuBskyeVOIhcdLKlU7SOAG4tTaK6C+1/c5nGqUI8AsVWLbvzI
98i1fiy6OeQrAQvO+o+si6eRV7D9Ny1ViUD/rjCrtUUzyJ8EKTycrxMAPlve
aPnkB+T5xn5aeZm1QKc7+d4ZEfYN3vMW700egxc3bMser5tFrv3NOGVH6AkQ
9sVKAE0De41Z2tHPR4rh7MLolPcG7LpTdBdaby2Ub/QYftWG36/2hm1TR2+B
hxa3GfGOYTeQG15N54vghCyjJ6wQf79WMq3tD00JrF5hCUmIzzsnZtKXdxKw
krUUkB6G/4/8nksFjGEC2jRqFbg04NyIif24EiYiINWvqUeXif+/VZcFbc8H
KVx6kHffoRjXi+IVyJ5UksAmtaXrOU64vpn0igyeohgOZ7YFHzHA8+5o6naX
k9wCXyjpJZnRcf9Yzo/VL1vWwzE7wdpXy3geLVKN30ttKuBfMe/6HWZwfypu
BNKGzTdhL5c/oJOG+5mZf75sXpMLpLy9e3v08Xwxvban5tvzgH4E4ejyAM+L
4ubcAyn8BqAcyHwYMornK89c/tCf2kJQ7u0eypHi569kaVu3R4lArqnmkYsk
nq9lg6aO8+qdwCpNZqiX3Y6cPcQuoqVKgdzd6oRAKs4HbjVHpfoWAaQXXpYk
svG5kiNz87l6JIhuZxbomeD8Kd6WrhbiT4KE8Gnl/X934Vzyu2g7E0KC3Mqw
gfFKPKfFDr5XoQMJ7gsmDtK9cB5uLYlilSmQQOF0CfUzNZyfx79UbVMtI4Bp
so2vVSmuC9sj2+7OMynobdbIexqO83nRl59VsEMCqg1MTsj0cH05JUyhh8Uz
MKfsM5lzGed/TaDIJ2CiDezj0Rq2CPG+aB2P013jLwA+fZaDNCu8X7LPMSLP
UuuBmGfY5zU6ivzbk2asY43lQMAJipOp4f11tNt8hOUSDD2D4hfM3PC+czZX
aZIn7sE76ge0D8+/RW4il5xrkVAAd7sVbs9m4Tw5vriJkWKTD6kq4sviNLx/
W+pG/t3X9Tb/29f/ALNNGNw=
            "]], Line3DBox[CompressedData["
1:eJxd1Xs0lGkcB3C3tpissyi1uzIquYS0Vq55qNzKqtVssuvOFIYoi5J0Gpda
19xFxMglgyyG0o6H1QyTYQaplI4xBpW1uUsurf55ns6+57z/fM573vM8v+f7
/H6qXkGOZAkxMbGT66/k+ps8HpcmCok0t177tP68Bz/qf35GgJFVFpcRQQPU
aVezp/ewz8oZdXcPlAGrNw4ejLZ/kacvc1Xy0mmAVCFOkHeeRB7gcyuRPxIH
gqvdA29WTSCnJkdzzW+Xw/hgYXRy3hvky/KGermND2BGTpHBqNUYcqb+CToz
uxU2MUBlFEmEXP2jqsof51iQ5iF70apbiPydo1deTmsHdCBuYErbDSNvLymq
u+3ZCR27hhiX6oeQt1AUQg/6d0Fb1l1JH6nXyHeWrGjydvKgXUGkxPT8AHIv
ymx93SMezKykEDIuvEC+IKY4ZqXEh5FJXj1nBp8hp6+tUHwN+TBRw2tzqGk/
ct3FuI3henxYclwmdyapD3kT+NBwsI8Hs9xsaH8xepDfyNLuF+V0w6UqqtpJ
yEM+lhqiN1jLhf7v11IvkbnIl27KLDJmOHCbT61OtB4HefCNmyPeG9iwv1y7
hqjORr6p3uC+v1krdPdb0IwVe4z8F8EWc8V7jdC6nJpF0G1DvmOCcCrbuwz6
F3YqeH2Nvxft3nNY7WdHECPtsmLNwv9PJyY5nY6+BwQD83ILVzqRK/Ef0ZTt
m8ALG5ft+W54v4f6+uf0i9qAb7DKTLw4rid3wshUcg8HBCkEJ/yp+Qrnttpv
kTbWBT7UqhN/iBUgp5WaSdnO88Hr48IssizOT0OAu52+fS84/3agY6RjHPl7
P/Y+67e94M7H8Jql8zi308a/5QS094J6E9Mk4TjOf1QFYchpqgc0ujLlVEVT
yPd6RxQT3fhgwOCJW5LiDPK7yn4rw+z1/b8TNTR9PYv8CmPVxDuOBR7KDhLS
m7HvPZ02sFbMBI/tywpcNeaQa+86ksc0rwa14W+2r3liL2zJD802OAUs46tc
IkKwf3p5IebOcCXMFi9qyPPGznKQ5c2OMKGlA48xuQd7nrIWOUuaDV8ZHTmd
V4fXU3VKi1r6pBMGqZfO6XyxfoaEeWz2es59gj0bxjTwfk3DOo4qzvXAjMYk
y+UhXJ99WilElb5eaFhSsPV1Nq7nBYtt8jRhL7z2zDr6qjKuP+1lMDnQoBcK
KB7/sH/H51W7ukWOMM+HBIVQlmAzPl/bfEHM0rFuyPtgOcjj4Tyk6Iy6dlhw
oH+2p6S7Nc7PCcpX+/c6tsHQ3WHDeq34ngLhfOzRa01QNnNORzMI5zNS6twN
HQYd2m6XoK2t4TyramefrZ8OgySzI6RwYjvyXJuVnwoVS8CDtFUbjhm+L/wT
EU6F9AYgmnElPfrifuVa6GjQ+1pAIcX88m4hdq8iLed4RxZITKMtVjSzcJ1f
8Hqcv+OA5wltXKF/B/KYyTl6qh0XuDup3SY/xeuktn3jSwntBhknvb91OY/7
Sap2jcz1Wh54GVWcdjkE73fTVtKgswYflJ2xCLPbj/tV3M5L4UxjPgj4O5ms
KnyKfOVJVOYxIh+YcIYS2Nfx/eUVHkq42sUDLaQJi0kz3D+3ELSdHHR5QFuU
Im84iPutKqFZ/mJ+F0j7tfmMeOMgco/C74vKKJ3gVlPI87PluJ8fsJ+qJnd1
AOn2uoFdh3H/N9FJSZbgskBToKN/UCmeF8tyU43GD1vBaK4xm2+D86Mp82r2
cvtDEFl5bF+BAp5HYOPyp6sedNBCraloc8LzSyrswBSLRoWkLL1i6RSc2wWH
QMG4UhF8R1/cr7QDz8f7IxxifGIZFFitjrpHfpH/iQRdv+ZiKNtuc0UtE8/f
u0kln+d1s+//5vV/lwx8fg==
            "]], Line3DBox[CompressedData["
1:eJxd1Xk01FscAPAJpbKUUNMiiievjiWPbHEtRcoWEXkSMkQLdUSLiSzPk8aE
Bnn27LIkVOQOv2FySJiZoiLyKDEVoZkKT//ce86759x/Pv/ce7/f7/1+t3mf
c/QVIZFILktbdGl30N/VJ1MvmdAWFpfWZ+BH+bXGQF2mU1aOYi44TQTY2Ndj
FxGwwxYvFIGqEV8+b/oT8h07Ex36txUA+dN0kax6PvLWotS2sq9p4EyZ2FEL
w0nkOXQn95jgU2BrH/vNeNNH5Nrp0UEleUmQHDXemWM3jtxRjjYZZ1UGM0Vk
mzXYY8gtycIfQt1a+Jw6aFkc+C9y3cK9iuPNj6GYRPmKo9HvkMuu2lNwIh7C
1WrEE0HVEHJruU2z3/OaYSuHR74tN4jfO3q/+JMkAbuow0bF8q+R53XSj6Tc
IyCLlNboHtKPPMZgreKUFgsOONgIFXpeIp9j6Hrr0FhQJPCKPsv8BfJIiw6R
g50s6Pb+oJdFORf52xsWCy6DLLgge8ePJs9Bvjsle92jPBas+P1ewsDlHuQr
1kUtpA8Q0MlMvyH+6nPkw1vK3eaOt8Cw+G8GJjKdyKuMnbuDdzChi7W1zsNv
T5FXN7HLzEmPoQOEPHHRNuQ0WeURR81q+KUszlXBikA+7yywHZHJgCGnwtLu
xTYjP/mzU6PWMAmohHuEbjfDblPJNQmMrgI8nUU+6X0L8heXzocL+xrAR/kf
JRap+Fy37/sL714jwHWXweq5v/D9r9xclWS+rx10SasXBub1IvdUSt2xPLEL
pCXOFYav7kMe4L7svdaFHjBhX/u6aXgAuXqhIoNuygH+RvTlKeq4TtZ/ZpTm
1nBBO6XcVWZ2FJ8bpxxIvckDPP4HS6fXuD7HBp9c13vCA4uyEhsn/sH1TytW
ij2nxwPe8zmuxrQvyLOj3iXoreSCRY6Gmv38FPIUuzd+mYpL7zk57Kiv9hXH
jZgvf0jrAnt8gw6JbZxB/jPCyICczAbKAX0U6SbsLRkWHvOaTBAqnB7x3zqL
fCd5hsYPrwKCwxXHpA9jHyIYHla6ruDiBN2zyxP7dNIa0RZqJdTuVX0Q5Ijd
bKDeS9aJCXe3lXUrKmD3Vs22jlR5Cp9Hek5+qMH3yUpWIYRJXTCYvPEalYzd
x8u4N2S6B9aI3S9ZNMLvbdfsXC8qxYX8CkJNR4jjY2oZ129uw4MGjn490hQc
T412yWYVJg9eruge7LfE8Z+DtlHikTx4tuOUj1E0zpdTESsptIYLv0tGyMfM
4PxmOO9qUKJw4BqLzLAoKq6HasHh0tjwHjgeaZjFXob7Q3Fx3Noa+y5o6lz0
I4KJ/zuZlt9GOdYOeQWxueJ1uD4dHnv/NiYkoN6ZZ0Nhqs+QU8c+wXVjjVBu
6M8FdSk2chLI6DHKr4as8fAYmV3439FW1uWMWjFgnpeSlq8D/l/7RltuSSWn
grfpQ2qjwdgzSg0vHD9QCX5mTpXmT+J/J3lL6g5zw0PgkD7t6WrXinxzaBCz
3x2C+T+MpdjBuD9kXhKc/abTAl7ya/0FTzuQc3OvksADAmy3yK8vJ+H+UxGg
2rI/jgWUT3CKlZRxv3ozHVCZ0M8CjQV5m+Mhjo9eWc4hKpcFcvopHV9ccT9U
1rIiQtNYoIlD8jktifun5UfNDi19FpDTfrvTuQ7HX0Nnw/ggkwB7jba3phjj
/jx7m1LUp0mAI9Bxitz8CudFiiuQLG0GzwTitpMrcH63pFzfYJUBQYjnsjqJ
UjwvTPrCTVsPNIBMhb8z6E64TuQv+lN9KLWAcd7s5SN3PI/swjorJrrLQWM0
lfEgAc+vE5xct5J8BojpUL57dBWuT7EIRpBESCqc6VXPubEVz81N3UrDetp3
YYJQjF8Rhevc3GF5ekRREQx9lZboUYvnsjk92/bKyTx4RveQf1sBnuMK4gu/
5n5T+f/m/n8sUAID
            "]], Line3DBox[CompressedData["
1:eJxV1ns0lGkcB3CXXHIrQkKn2NwSRZeV1FOxsS61WwaNcgZpV0rYJHSRUWrb
I0yL3EeTy9hxsIk048nQGpPcmmGmiBi5RbmNmYitf55n9z3n/edz3vOe9/29
3+f7vEYB548GycnIyHh/PeW/nsE8zYrYrsh9w0vLX4+PIPP+t2MUZAwZ6tkN
5YIrxAlVaRP2bGJwiJm4ENjO+N7StcJOf1JAve1aDCa9bNmxWyaRs/+4LxR2
0sACXLfZauQD8vVQd9SkNBdMTaWRr6eOI58OzRq5bUkBGWd2LEgsx5Dv92DV
v1K2BBOtMOXL6WHkJwsUyVev3YUUHrX0x1si5MRcmes5QVnQpmC2aNZ8ALko
i+A/VlgAPXYkVsmP9SFfVvSN45wshMu7DhTFa/UgN9Q9/lx9rhiWfWesaFwp
QB4lbSLz5kugk5f+q8SxLuTafozW1EI61BzyzXm6mY/ceYJq3jJLh8SYsNUv
k14hd50lqjiP0OF7N8U+0XwHcq4VQUnsRoflRDNS97l25BMDz3QCY4uh9Qsr
TifvJfLfJlnjrzxp0Lee+m44j4t8jZpFwR7NTKh/h6DfmNCE/M9VII7AugAJ
8y/16msbket95PxCUMoAh2bSVpB12Mh1WkQOO+XLweksaeSjCIj8ptOv+y1j
noIlVUla8CQTz9Psh6u91Q2gTkPevBaykP9Vnk3hVDSDn5mVS6LoeuRVBuMk
s7lWYGRjmBfo9w/yBe/KUsabDsCSzLLZ7fh9K0IMYoI28EBDM2OabstDnj8V
uFCk3AWO2g4ohCS9Rq4pO+qgHNMNOl3sYjXy+vH9z+g3NKUIwMYgf+4me5yf
LeEdjO89heCYXUR1z5ER5Dvqfj8SRxGCm0+F3M9ncJ7rHdzNVjkIgbZcS0uo
ySfkV3I80urtBWDNqGyG1fgU8ssR1sPpuV3AMCJpvNdnBvnO9567d7nxwIsv
zR3iy7PI/fla6zyW20HK64eJmwPmkF+62a5aasAFK/rWBwml2PM81eMz++sB
1f9I2O3DYuT2gW6P9m6tBH3bxIpJl7DL0NY7sRlEQGBKrn0gYzftA+4TJyqg
7SnmhqJo7CdGXHoTldgwOyv2ZJgH9oFOtZe0Oi5Mz3BsrP6En2efjWN+rWwH
DL/TQ2D4Y48pmLPo1+HBla5+5SuT8fuSDgvuVtK64OiCmku7J56PWvLh471E
AUw8pzvJYeN5snweS9pchfDxtTf2/GncS4JYql8TRQhfLC3C7avx97I+QRre
5CmErnK0/c7/+b5c2QjmpiIBLFnrLxhMxXmwbyD3ZcR1Qz61etKkAudnnrpd
t2qaD6kKhRdv2OG8kXfrGdaY8aBxevbAKlecz08K7+KS1Duhljmf/zelFc+5
wP5p8Nk2eFY/2tB7Due/l7M/lr+HC6tIpquZArxeOMzFAxv3NkIBcVHXWa4O
efCkhiQ8hAmnGqtEyT14Pe54+HltPrMCSqcUIo/14+vPszK17gTmQ/0nxS6N
kfj+cY5XE9K8XMDlixQm5SDuh1kVblRTXAaId9VKSHTEfZJJYNIYCQ/AVYnE
usYa94/NmBtHpa8IMIYexyfY4PWbc2NnhboKHTx3T4saM8D9pp86YxQuoIND
U7fqrAtxHwaIu15nSujAfYRxKtMb96fvct695DI6EK8dXHqggftWpKDE2q1N
Bzek6donynA/b1x8cFp1Wwkg+dpGP/LEfS56Jg3yCykE1WWabwfkcP+fXUdq
N6kpABucxBvyhHi/cDctCiNfywY/qbFKjCbeITfXndZ9aJIM5nJ9Lbwu4Py0
sIV8i7teoNe5uIZkjPcvxbdb6y9ppEALcvzBbtEoniftfoKyZg4kEq5U3gvA
+yOFNq2dEUWDPpLmQ5NtOM+CUNaginIxdAitAQdl8f57/dTnBB6nCPqZm5La
FrBXSFvqBmvy4TmaD/CsxeslkGjx7X+gTn75//8D/wJxM4Eq
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns01FkcAHCv0UsSJm2PTWybIj1WcWhceYQiVPKeUkSlYpoUh0pJdhUj
SuU1g4ydCVF5jebOmFB5JGWaZoZpvClsatqIbP1z7zn7O+f+8zm/c373d7+v
u/Lgyd3BKkpKSn4/luqPVRh7XLhWTrFeP/PzGQMtzT+fDyD9ZgZn/vosEGoy
uZTagZ1lO0H0phWCnFEK0dwfO2kwqL1RxAKli/nVs5JGkf81C97mpLHBRC1X
5x11BPkuj7ueRCoL9LXTtO6TPiA/OJE8u/RdEVgda2U/TzaM/J9WhuND20Lw
1WLjcsfBAeQtiqu6hjoFoCjbZvup3F7kBNfk2EuX8sANl7Qt6jI58uzsRn7F
Dgaot1OtlFd3IXd1+36G2k0HSukmdLMrUuRT1oIobhYdUEnmc3MoYuRVYo0l
0TF0kOhZNTKUJkIuVFsTtu4CHfzRSbY+LBAiFzhWhAw9oAMf+xefZySvkfu7
qwX06TNAQYZx+iDhFfLAIE+DjXwGaLS4QJomv0ROJixeyqPngcSdnZ0XU14g
17gVv/+jIh/YX+VGylOa8T4vf5WExxYC6/OniotKniF3f7roS00cG8Q77PSe
uN+A3OF+pGbyWBm4E/LctFQoQB5RaRE687wSbPNYzJlx4SNXyQVZ3/sh+Jbl
5LOg7THyh0ERWp4n60Euo6yhuLwaeVITq88uowmYaEydqpmsRC6RpK+UDbWB
s1VVQwN9+P1ryg5qlP5XgOPeL7q0m4fcWD1l+AJZCK6QOC4HNuD9E8t6Puke
EwHy6c4ggbgVeYh1hO95UzGooZ07HxXZgdz01pN02nkJiPOorgnIwHG/0e+a
YO4rBVoDvobEbzh/5lpe7lSXSUHqyLPShO4+5PRq472p2p0AuG2NSjTHeTv5
dldE02spGIaDTkdjcV1UldlFK2lJQX0yMW7A8iPyJRo68U9YYrDUmcCKInxC
nrOTcONMhQgED86oalA+43x+WTFdriEE/ibyegZNgXyLUUCExaF2kO65cRk1
7AvyCQ/NuQeMmsEJqyW8vRPYXZ5codyyFoA9mpmP0u3/Rd56JPt087UHYNW8
WsecEOw85iITSrE/SFouvWgTjl3fKjnpHLsctprZLo8JxW75a7QXI1QAr+p4
n82zw/63JK4s5W0zTJKTvQkf8X4q3Hg2vcHtkBLj9m76GHYjZUUkt60D+nSV
5Bvk4/8dnSX1YzwWQbtPtuvnnMDns+Seo7byazFcddzUbEg6jjxKzmLuNpJC
EXtTk54mPn/jwHMxgTIp9CGrmxetwPFqJSw49iO+0GKqhPZ+C45v3ex1j5wG
pPB9YC01Y1s/coNVPb6cACnU1fttq1izG3kB7zMhKkICw7a8oXWY43xTSvzQ
ectMDIeZpvtGaTg/E/PiuyVpIqgSQ9c15eB6VymZ5IynCaExN7VhfjfOf8PH
DRzXNa8hv7LQVa0R18vKPYO0L+teQneLuNY7DjXIV/tNRajoNcOwlZNAewrX
4z5nn6d15AYonF0gsd+K61EbnnT2N+LD36+VVp4qr0V+JCT8aJZ6NdTbw16n
kOHvLlhoo1txoBw+6Q1qN8zE/cS/Y2E8hXoPDpE8+ced8P59l3IWFtsyYZ5I
OrCJiPvVr4IBF3ZAATQ6sNevcLwJx33xBb/xN3nQW1V/qmwU17tb8yKHeAkD
7ggRJPyyGvfPnkvumX1rGLAreJNe3WA78qCDe4VfuXQ4MhoNtmfh/pwqqt5O
SaBDQ16DajMZ9/MGmVVbWzQd8oaNluV64f4fmGRkpZFJh8Mf7u4JCcTzoqmO
aXFXRodqi0Lzr5zGcTcb86vt3s6ACmqq6AQTzyP7iBElLjkPbq79JLa9g/sP
yynSy5VQAJmRhyxBIp53Yy2Ww9fnFMJl+pIVZzLxfLyuUfdg4EYRHGtSWB27
ifM2ye6k/DaJBZfN8jruq4Xnr67jBo+wP9lwwqzRLnw/ntdTY+G9vgZs2MWp
n3x7GNcF8eXm6ec9TKio5c9pMcP3AWUSn/P+cQ5s1fZfq3iOXfIq7ud9g+v8
v/vGf63MF6M=
            "]], Line3DBox[CompressedData["
1:eJxd1ns0lGkcB/BhNx271orooqkUoXZLhErbo4yWsrmkzSV2lyikXErLLmYX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            "]]},
          Annotation[#, "Charting`Private`Tag$5613#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& }], {1370.25, -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx03HdUzf8fwPHISIjIqKSsSFlZSbyzEiVkFNImZZWsppAQIpKWBpGmtvZt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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnXW8VNX3hm8QM3fiTFw7EBS7EMFuBAUDQeyiBAPEwFZKwEDFRBCkEVFR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               "]],
              Annotation[#, "Charting`Private`Tag$5643#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJzs3Hk0Vf//OPoMIWUumRoUSZkiRcUzUlRKKVNSUZEyS0KIkDmkDKUIGULm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          "]], {}}, {
        GraphicsComplex3DBox[CompressedData["
1:eJxc13c01f8fwHEhIaSoKBWRhCRZFd4ymiqViFApiSirlJCVkMooq+y99x5v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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnWeYFEUXhWd2WXZmZ6Znd2YMGD5FgigqggEDKiJBVCSomBARFFRQshFB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               "]],
              Annotation[#, "Charting`Private`Tag$5664#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJwsmnk0lO8bxlFS0SZKC7JWSiKRYm5tIkohspQiJUkhkmRNiSRFWSNky77v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          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k01N//OHCRnbKWLRGRyDsSUlxaZClbUUTJEoqiZF8jW5GtkpTdWFJI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            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs01FkcAPBBkh5H5KyIUhNDIUu1pbgTO17ppLFRO5REetBLjaaIGgyS
d0YiTWGqKTLyTG6YWRqlmV8ax5uhkUoP2V6WVv/cu2fvOfefz/md3+/8vs+l
AUfoQaokEmnb9FWbvuT+hgPmlyIdVkz9mD7vQc7ln6caOPtUlLr+uA6WHNKZ
W1yA3bbjq6GQdBPkjAuNy0vfIRdlZuqVX+aBqR6nT+OrR5EvlNt/vL6cBao2
0EKJ8DfI/VsjZueGFcNqGYlu5vMK+T7KgtMtY7XwXmacDltXidxb8vDphKMI
xnNVRYWbh5AnnVM6TJ5rhi9UFtScf61Afo6YqeFs/QRe29bkvoQ9gFwlma9x
2uAZtK/VunjbvB/5LpmC3lUihVa74u/51vcg7916JYp9UwYl5fd70ps6kf+z
44XlThIBiZPe7vtdO5BTj1pSe5wIqKP9JIYhbEeuPcSSLj1GwK/kPfKpeXLk
iyiaxokJBIygDz5WMNqQL1623yA0iYD+sWD9n9EEcgXV07ueSUCtOD+1VwIp
8lwTL9JeDwIWuQ0WPNJqRZ6lbhBTN5eAwtMzQ55MSJBHx/fQ95TKYLi/0vT7
cBPyRN3b7gmbZLCvpWpVsJ4YuTj9V+mpNVJICpHYyT0eIZfa86tyjVvhXaO+
7c30auRL1ylr39Ja4PZ2KX/vOyFygwOs0JPmzdBjbGVk3wcBcibnqjqwE0HK
QBbVg38d+VoLu7aDMghn6VRrBgZmIa/M1X1lmPkA0uKWlXGIVOThHMrwGvtK
aKhyyzL0Yjxyl7MVOXnjpdCAZbacr3EeeQctJMBcswjmJ3BPbP4UjVyXGXw4
IjkauizPYtQUxyHP35IaQPYvADmd7glKejpy87BvlcFHmsDexy+t7wj4yClB
32nbrAiQrTWjPj4fx4G3z9ljiNQBmJ5vbTlLanFf2OaUpFj3gdwWn1C3L43I
Ccv1bj2+CnCXTWhnxLUgzy6ddOE+GAIOFzZNfhvBddKw8bfyPV5KcP/YkZFr
JFyffwVNDsrMhkFru1VGUXgf8lsCRy+rLcMgJq5mlDqF++hp3g5pllwJZnIY
i0p6X+J6i9FjRz9/CQqjBBV+B3D/srlOO8krh8Af+mN58bzXyDM+tDj66CrA
qs+fJBcd3iKv17L+KG/qA02PyXUSSzw3hqJGqAfXd4HdgZ3K1gTs92Q9Gvqd
cvBFIFBhb8VeG2wYK35OgIKYZ4luZ/H7p04NZH0mtYK1NwnmVQ08f2hOmZcd
M5oAkzxs5GgyglwtWVx3qaEBFM1KWkixGEae0z2i7u9VB16r25Skm+A4jPKt
yizCpuPqcrXGRHsQ+Qleu9PKtErQyDuZZknF82feQJlm7N+VgK3HT4osxPFX
Jhir+rVVgxXhqfIUbzx/shmu3TMSakGX80bhM14XcoexQoOWJAgqhs3K+6Px
XDLiBd547lIPiLA5UUnjOO8fuGmJvZwG4KsWeydtLn5exjTarXqmERw9xPCp
uIJdPi+TEbRRBPQcwzVNY/F3Q4re1dp0ikDdIy+6q6Qbedub5MKnzmIgqjLN
F9n1Yh+R5U1EiQHVaE6KoAr/79h8Ugf5jBhEvd9uT76B5/Cm2Wqpq2zEwKma
LCwKwHETLl5U7HtFBFyMzydqUXB9mqjcoB1ObwSshl8SWSQc/9UpX/o9dRqA
rZTL7Ov9j9tEdJg2PwDZo0R3ZAnOI6Psvh+fVQJ+10+8CyZw3tdxzd0ooScg
h0eUTHri+km3k3z3srgGTftnB88fx/W2a4Z+2qVsPtxwYeHxC0F4P7ZlDTp7
0wqgt+I451Yy3qfSh4qf+7fO8X/7919EPAs+
            "]], 
           Line3DBox[CompressedData["
1:eJxd1X001FkYB/CRCE3HGk5pVqFa8lqJyljd2Yqwc04MSYkVFVZTGyWUkzHe
kigrLzXtkZWRymsmynSVmcV42ZlfXvM2ZoyUyJZaJdO2/9y7Z+8595/PH7+X
5z73+5gGn2AeWUQikby+bvWve63sabjF1fjtlqovX9cbcK3g39UKXPfxq9y+
FAHjCAq5vBj75v45o2pSKbg2W21SWzWNXJiTs6K24CZQDe18N2s/hdywx/mv
onWxoM7JhUWcmUQe1HlOhxtVDuulJOb6fRPIj5rrx7W9bYCVOSkUjsE4cl+x
oGN+hxCm5S0S3vpxDHkGe3z7ArsFdqvpP0x8JUfOJjSXuG5sh4VezR7GnFHk
apm8JXHUP6Fzg+6lMgsZ8kCpnDlQIYG2gWmVB58MIR/ec/08p1QKxbX3h7Kb
nyP/7Ndts59EQOK0r0eYWz9y+i829KGdBKTotSf5V/ci1xuLlZieJODc2kM9
qmU9yL811zZJv0DAc0xFq9y/C/nqNWFUVgYBg5KB44EEArmc7un7JJqAuikB
6hN3JMi533mTQhgELHFXFDfqdiLP1aAmPSYTsDpO81j7vBh5QtoQ81CVFJ4J
Gjf79KIZebpBmceFH6RwpK1uQ+gKEXJR9iZJjIMEko6JaT2MRuQSZ14d16QT
3ls1sreFWY/cdNt4w2uXNri3V8ILma5GTg2PZZ22aIGMt1bxIzN3kEen/qYB
aEJoPppLZ/CKkG+xpnX9LIVQi1KvffhwLvIHXIMJo5xH0CVlTU0qcRn5qsw+
7hbnB3Cyu1XBuZSGPNYvn1c3WwXDYUij1tJE5Ew6SLbXKYEWm5pvLqizkScN
czOuFiTAZX9EdK0eSEEOR3+18ztQDMocbbXp7GzkRK9t0euwZpB9IrTf8DMP
+YbdapZMEwIEjehb6lFqkCe7b6qc7+4DZ+5XqgzcBcjvllDUSMQw2Psh5Gip
Ja6/Tlekzxt1OdCq+bSwiN+BfPpYpxfLeAxoJ9BOLm7D/WMY36uuH6AEBVnJ
8nzlAPKK9tuR5BYl8Ai+8XxtA74XQ94v3HJOKcGcwM9VO0OJvMXRrXlZyhgY
ZjTpRSjwPT3cbVYo0VSA0AdOGlnt+F5HjSVtzeyTgfBWuk+7C84H+5MexeKM
QeBw6sI64QLOE76V8cv4iF5QG9V4jRw1g9yTtZr0jkmAxfM+1k5Z2Cmqy1bR
IW1gihF3q9obO6E22alztglcSV31gZqIn78xT6p6H1wPisP6GwAX55KAzI67
3lEOznsJom8B/P0xk0pCzb8ImE2pLQ95hv83izBd3uaQB9aXipSzQTiXFmZm
0gyf5QCyyiNm30sF8u/JnQ+Te2+ACJ/K5vcduM5a7NG2qakSEN7HMh6wxfnT
opMdSONWgixO5I1AMc6fXAObcHsjPogbDqCWvsTnSHw+sNUu4hHg+lvY9N7F
uXRWOWodY9oIpjWcZpVk7MBn152ej08Ah/p0z3ZD7KpWDj+D3gTmqRyjqELs
AqlA1GQlBGGmS4uPp+D3nu4v+CmnTwh8NJlx+8WDyL17ihhXXEXgI1+QB2nD
yIui9xQOnheB+YlXH0vrRpCrlwXWLj8rAjKHDVVrfsd1mLMvc7SyEwG+hoxT
EozrdnRs11v/60KQlFaeqGuOc/7g890ux7ObwMYPlPRYEq6/fdbfMk/KU7BZ
khc9MvwftzvXb9byCORPEYPxFbjP/WvuB/BiK8Culen3wPwL5NvyLNzNWadg
6k2iYsET90k2TfzJ27oQmsl0Qr+ZfY3nyOKVV67m86DTRcPIi0dw/3flKlx9
XYqhrzwy9XYm7k+JQP7v/H2843/z9x/4FBOk
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs41FkYB/BBFFkT2ZSyjEQKXVyyWh0rbIZdjG1aiZVbqdRmN8zkmjbj
0sUkCqGaDFJyH0oHO6JxaebnlsSMS2q7SvNIYlr9c07Pnuc5/3z++Z3n/b3v
96X4H6EFyZNIJNr8VZi/qyVNIcYXoretk32eP2+BhfmX0wWcdlWX7fh8Fege
1FC9xcFu3j+9qpxUCLKk5XpVZW+Q89PTtaouXQGywe3vpRavkS/vtX131YAB
eFsdQ4mIl8j9OqNUcv68BWtFJNraXc+RBxstZbZN3oW3009pJGiOI6cL6js+
2fMhK1Oef91lDHlq/Pi2ufhW2CO3tO7EixHk8YTSQqeN7TDfo4WqmzCMXO4M
dyFT+yG0vUs+XWwsQe4rGqENlAqhmS/r9p7GQeRDbtmxCYUiKKiqHGS3PEY+
+1uPqReJgMQxOnX/jn7kdn+Y2g1uJ6CGevtJ7/I+5OpjDCHlKAGnV+/tlX3T
i3ylkbJechIBo2ijD0a8u5F/p79fOzSVgH5/g+93xxHIR+zc6Y3hBCSf8lF4
fkOIPGeNJynAlYAFzqOcBnIn8gxF7ZP3VAlYzlQ61P5JgDyONUjbWyaCEX7j
hjPPWpAnaxZTk34UQXEbb8M+rWbkzexNwkhLISQdEtj0ujYgF9pyeTl6nfCm
jnhnK60WOcV6/O4rxza4s0/IDXhTjlw7hBF6zLgVuk6ujxZP3EAenpirCGz4
0Gg4w86VexW5lYlN9wERhIs0apUDAzOQ1+RoPl+Vfgc6ntKvSCTOITcRhUZv
sa2B7VvCpvJOs5D/EGit9VhaBtu2BFVakU8gt7glz4tZXAB3kGUd+cvjkbtm
AZ+fuXFQt2pqmUw9EbmHZaLEzJMDVC+fv5Rcx0ae4hzdVmBbB4QPUoq9K3KR
a3C2jv3r1wJ4Bue7438vRL7EPXWzIpkAChEuG67lVeB+WHZ/6l3+I9AZJ56R
8O4hV2N+LNLxGQKFVi8fZRTcR75NFkVWyBgGqmvbOhotcD9s8vDvC/IdBVTO
r92XdXAfysF+vTyTMVC3ykwniiFGHrkovPfz0jEgV3x0V5Alnq/uy7HuISaj
YPxD6mujSjynAQO1omtFw4DXzppLy32F/FiJoGOYIga6vRp1EbM4N+i8zo+7
mf1g4nrkjHrAO1znBjFFfU0XYE97MqvcJpG7C+eaGtYLAKdsWXA2xM6dSrU+
Sq0HK8b2rW1sxn7TzC0pcj6vjDY4txQFYhfPuqvpDmVCM0uHWXIu/q7h7lYv
h/1lsLgn5NyB4Ankkqw91Oy+GkhT0DxC6cc59j7vooPscS1UO6ifxhp6gTy2
RFEac4IHVWy3iwTjz5CLzmomKYkqYJhCYBpbiuvpIkqISXtaCNtFUT5W0Tiv
6g8Zs+g9Z6HB8Ebl6nycS8kux582DaSDBa6vFp/0GkLexSxnWtBLQA3fyjfc
/gnyb7O8KG/dqoG9GSnCbBTnVYxOfTA4WA/k3zPeyNZhb7ljGvQTtRG08JMi
Swyxk6uAAXW6CXC+izH9pQB76+rklZZafDDBdhAtYA0gpyo+3JjeyweGgbql
hwX4PV1ETaWTUzPwohzwq7X56v3KUo/q2GbwIo/Xep2H+1CSXxahdLwZdBdP
Kuhfw3XI8TQfXLO5GcwF36YW+OM8b1qspeKdzQeEVI5BNsL1nDHrczjM/gf4
O6glM0ijeN7PfpC4azQBc2FmuHjoK98c1W/YegdcfE08iS59ity7otKHyygF
DiuSb4JP+P9aZxo7G4X+BROvEKVz7nivsW0EM54m+dBQorJviRTPhe+CFWkX
LnLh1pTlYSlBeG92Z4w60R05kD4Sllh0Bs+LsH7ky16+Z/+/vfwfeNVdaQ==

            "]], Line3DBox[CompressedData["
1:eJxd1Wk4lFscAPCRsl330qRkCpEbKpGJq/GMo8Xckq0hieqxpOVGrm7RiJB9
igpZ4pYtS5sx9oxOaSaakWbeLFEMw0ULFXpSiltfzrnPPc9zvvw+nPe8//Nf
9HyDmP7zSCQS8/uW/75X9jcdMb4cYbN6du77egeuZP9Y3YCxu6Zi21wB0D1K
Vr1ThJ3aPb2cSyoFV6a4K6orxpHz09M1q7PzwWzvlsmpDWPIl3bSPxQYsECd
tV0gEfoGuXdbuEruX3dgvYTENNo9ivyg4aIw0QQPctLjyTEaw8jdhY1PZjbz
YWLmPP71HUPIz0cP23yLboEdcovunn0tQx5NKCgyzFph3s5me92YAeRyKSWK
YZSnkM5TS75h3I98v0TGfFEuhuv2J3L2PuhF3uecExlTKoHC6qre1OYe5F89
Okz2kAhInHS3P7ytG7ntnya2vVsISF7YGuvF7UK+cIgl1gsm4PRKn87ZnzuR
LzNUXsFOImA4c/CxzKsduY7+YUrgeQJ6x4GNnlEEcpmti/uDEAKqxe+TH70p
Rp77qyvJz4GAxdsHi+6rtSHPWECJvadKQG6YQkDrjBB5VGIv06dCAkO9h1d9
GWlGzta4YZ+0SQKlojrTQ5oC5ILU9eJTFmJIChDSOh3uIxfTS+pyV7TB29rS
XS3MeuR6VsO8t3YiuKtLXOI3zkVOOcIKPGncAh0m1kRI399EHpJwdQGg8aHh
QIatQ0kBcsu1tPY/JBAqkeuVDxzIQF6bqzG6PL0B2sXrVyYQF5E/69KhWtFr
YY5q2q2a5ETkQTYUg49TFVDrTJ5LFvks8lulHT1JqsVQUmMywzSORs6bd/L0
QW4UHHZvveBrk4DPeczm+DkWAe2vIVpDo6nIPf0WqoZZ3QWja+3zDRWuIb+r
FNx2zLMZjAg1IsbLS5EvMU9boiBHABHDK2sNuQr53DTHUznkOXg6VCg4JoPI
vcaCZ5Jne4G3zyfJx278XqFFNZTF9AFQD6QPWQ4S5Imq1AHrJhlYnO24rXT2
OfJdc6wgF8tB4KKt/xPNFNeFT5C+P61SBvzzQkerLXDdKTMMGE9dB4Cn6RrG
+024fnnjzEsW3D5wKfX9pGMh7g9KTq8UzyZ2g4n4nbHt5R+QWzN31ph1EODz
t2sdVItJ5FV5BtGe5GaQXqtT4mI6hTxSvc5fe5gLQmwF+U052IOcIlaX07Ph
+C3nAY2L2K0qb8c06DVAzeKxN1fUsdPHNLW3GglgoeWbimld/N0TPXv5f8sL
odQikNrAwfeMctT3LhOJoNf6182xk/i/KH4eAW5aIpjinJXCj3uL/Dc2lWIZ
2wJ/l3Yqmui/wvGJkE+uUeTDunp1Z37rPzg+igfTySk8eCK2Nm1WZRC5rlPL
lBWLA1tNdvgSX3FfGubcK22efxEe8WgjmE/6kOd3fzIy/HwVuO31eOTEfom8
rOgXG/d1XGBUQHpnoPYCOa24lpWo0wB04sr8PLbgPrbkVH8c4N0H4y8eLdtj
jp2uVHy6vbEJmLVdn1C5iZ0zUhmXpsAHm44/P+qYhM93tQp79rGdD3hl2l2R
QnwfZqPIS4UhACm6cnuqaPj+eRnBbpmRAlB8NItaWCdFPrFR3e1zmABs+CAK
1SvEcWCe6YnXMxeAoMqA5cW+OG9DJLZOnjl8oLZvXbCaIe7/ZkrhW4+lPgRa
p1TYLBKO84YLn/pdyE2AKs4Mkfb9x83Du1e1NICsMeJlRDl+L6/Kqn0lrHKw
VYt9G8yM4HzLNN5uGHgCJuQT5d9ccF2k0oRfXNfmwVX9KofUp3Ce7J+vdely
Vgm0Prf0+Dl/PDfbMwYZ7nZF0F12PKEsBeebuFH2Yy7f2/y/ufwvnyod5w==

            "]], Line3DBox[CompressedData["
1:eJxd1Xs0lGkYAPDRRZGOGnVyDRWT1qULxdjxusS6zC6mjSRWmKSoqIhY4y5F
a3ZcwinkrsIgFN6hsaZJzHzrkjQuI5ctUhpdKLbdP95vz77nvP/8znfe73mf
73ueR9P7LI2+gkAg0L7tld/29pE2f530SLNdS8vf1iwg/LtGgI3r/Wrb5QKg
fpood68Q930Dn1TZhFKQLWFr1FW/Qc5lsbbU3cgHSyKr9xLDGeSKfZR3BTvC
QIOpdSAW+hq5V1eEbO75e7BRSKDtdJ1CfoKkEP5krglWsRKIsZsmkLvwm58u
WnJhUuYKbpHDS+TXoifMvkbzYK+UwoOYV2Lk0Zj0GpvdnTDPucNePXYUuVRq
yZpw5W5IaZJPKdcZQe4pFNMGKwVQ3zOp6lirCPmQY05UbKkQ8utqRcyO58i/
HOnVcyNgELvoYn/SdgC5+Tk9c5EVBokbO+Pc2f3IN74ME2gGYfDT9uN9S+v7
kKuQZDSSr2Awgjb2WOzeg3zrtpPKgdcw6BUPTI4yMORicyeX1hAMyid4rJyq
ECDP1TpE8KFisNhurJAj34U8Y7VyXIscBtnh0gGdi3zkjCQR7Xi1EIZ6TWgv
THYgT95Ubn/FQgiHnzQY+G1pR97O3CO4ZCSAhAA+uY/KQS6glDTkanTBu2rD
h3m0RuSaxhNN09ZP4OF+QYnPGzZyZf+wwIs6PEid+y5y+G0F8pDEm6sBmQtJ
oxnm1JIC5Pt1yT2nhBCuJTbK+PpmIK/P3TSlynoIrRO21SRivyGf+z7+kjGl
HoZX/eIGU5KQc4i6YcuSanhg7eCcWCEGueG0zctZuWJInbVg1hhEI6eud6u+
fZ8Bt0cf83N1TET+qIalo+dQCC6XkZyzFpjIO1VEMoz9D0BLUSq3Q+sWcqs1
eVvmXTtAdAahtLirFPmd6z+H3F0UAo5999IrSi3yrIvOOUX0Z4AWtNNu3S48
z5IPIZfOPheBt69hmocjD3m60WlbNZVRsO3cNaZzvRB5U69JaXqCGHAuN8qe
uI//n7Vbb1SaPhODhbUrTZqb8LrwbZiyuKwrBm+CFR7SP+N1Z/74S739rRHw
zM7Aocx0GjkxnnMhZeYFoHSSyab0t8jbztgtStH7gdagz1Lw4TnkPheC9Pwc
BOCEUQ4PTL5Hzg6SmFMtW4F7/6h6zIQEebhaD00YlQWcq3ihBc7zyCvNev1z
pmqgsZR+rhbAvWXcO//pdS6criiP2lCLn2O4ax3BQ6kTnoz6qO1Vg7/3j/h+
by0nATy1OjhyQh+PszgmM2B+RgApsfbEdC/8XgG8c/NxFgKoPB/ZFUjC+9tM
HYG6e99TuLm+wrYw+y/kaYzS8pDxDvjjzG7GEXU8n/z6H8pij7bCgE/rorQt
xpBnh26gfDCrg4ofYm2kNPDvkk1hTrco34S/M86LUz8PIX93em+t0s508Ccj
RY5T9AJ/3os77pldBVrubG6bVR9EXh1vJF1OeQDu5TW6F1HxPpbPuGm3HM8B
ErW88q79uI/S9VUZJW1gctHR4Pkd3JkxHw+aELigK6t7ln8FPz+oNznFtYcL
/M3rfBP4eDxpOr0/vbduB6wpi0A2GY+/Z0D116tR7eCV+8YDBQ3DyFmu1o6S
8HagEmllqXkb78/1Ss1D6nvbgVk3R7bYG89PRGy09NEcLtghv+eMPAnv/4oH
3A6eYT4CDatkksMIeJ4Nr38ccSK2gX2CzJDhof/43ogBbd5DkDWDvYisHEfu
XlPrURJWCQ4qJd8Fi5PIjTN17EiBF2BiPlb51Qmfa0wyf+GQbh7UHpH12yDB
68VzlVJaelYJNL2qGHyVjs/NnowxGxfrQugiDk4sS8XnrKBZ/M9cbrH831z+
GyYhAjs=
            "]], Line3DBox[CompressedData["
1:eJxd1Xsw1GsYB/AtRLGlZEN0kkuqSXGoI/S6nDYjlSTVobARRdt20jlDbUIJ
1W5ukeSy0bqli9gGeXeFVWuzxy33y5LVkaXs0gUd/fO+M+edef/5zDu/eX/v
88z30aecdfNfSCAQDsxvhfnNkEQnDJ2/tJM892N+jQOLX3+uQXBw2+aK0jAW
cGzRHJ/Ix+5YOu7wtoMNiOp98rQaKXKytrr+3cT58/G1I55eY8gtiDs6Kgej
walDqZzi0lHk6QuLlPan58G+6ocX9MtGkGtH3Lz9hPMCfs657jZJH0YekU6k
d6fwoIFBbQyzeAi5CkOJIKTWwpe5pkx9MIg8ysQqzay6HlL3ZH1prRlA3uxZ
49JHEcB1JHf/Po9+5CKlRemMYCEsd/bMqpT1IF9EIrzsMW6EF5TvZPS2dCIn
ZtF7GrmNcEf7TLX57g7k0hRLwws6IjgRfT46K/cd8jW3A7S7gQiGk3xGjL62
IrdvY+pUHxBBPb2lR2PtW5D3VqwLJe4XQUMPd8OdlCbkH1IVjewsRXC6vUg1
9oYI+a6jkb5OKiJYNRPIVG0QIi/YveSiN6MR+mm+DFUtfYOcNvWhk9P2Fkp7
1/+g3ecj36M6PiyeFkJZrPqx4foa5JXKjUZXhwRQb6fPgmQpRK5mkrGLkfka
HvD/5qeS9QJ5yom1YdENddA1Fxg32T7D70bnE+mVryArY8/fxx8XIM95Dr2d
+BDqrvaaPVaQjdyHubraypsDCctCzmxbnozcLVjRasKuBM5tbQ5gJzCRt3YX
F0ZpFkNqa+Z659lo5HxBlu9a8QPItLxkkKAbgZy7MhE0x8TB8p7iXSRz7HI3
246SpCTwfrGGh2F/DHJB877CXvYTYJ+fqdA3l4T7Ofysu0MJBPr29O1dofj+
G85YP7oe+Bq0pnm6Xv63ELkNP1O7/U4T+NFxWKsorgz5PR/haEZ8O1DMJxdn
F/GQr1CVPxDn9YBBa1qZ9SpcRxfzulrr3n4guz6z1e4x7hPxjNSq20IMnjuX
K1KLcN9qpVu0XYkWg6krBWPTG8XIa8kES9ePA4Cv+9uSroMS5J9tzUpswvuB
5Hjm3pTwj8g3/XmDnDzXDeSX6Yre9AnkCvXyWHnbO+CnI/a1OfkZedGzui6q
2T9AwKJL2bJJ5Lsj48kLpl6BVhafdGVKhnyfaunI8pUFoKRyuoxyWo77OTBu
+cccNkwaryU/DcAetGmVNWsLF/Jc8h34k/g7Htau5oISPnTRbImLW4HdxU0a
JLvVABmzzI5QDr6neDFN7hjwFtoePmv4XPMT8jpDLxNusxC65dVcdBXj3AuW
6IibTgngSCIpTjsd59vNriCvpSZ8KJxg5dkcxfkW+vikXn4hD/qpjaWnpL5H
3qly0fsPAQdOro1wiLmEc4yx/f7eN+VsqNG77VagAOdYkE4OsaqcBSo0MoxX
b+5DvnRgRu2c5Cl4pLxZ8uI9zjEHI5H7li8cUK/w7VWYM/Y1Wl9jBpoqQNOd
1kS2NXYN0glCyJEqYGxGUY5MwJ6l3mlsrsQF64ciyIecenEdPYpi4xO5oH82
uyDGBt+HNql5N+c7FyR/EcanbMR5S4+XD/9iwQMhFiFOrNfYFampl6NMeYBy
bNBmHxX/79in78G6Yi5QvGd53mwd7ttlc2w1oSkX9NFGeG1y7O7nZk9TiFXg
xnHDKKUu/J4NaREUnioH3F11jfpGgN/f6oir1l8zeaBgdMRphwWul4x+6NkJ
6jXoN2UwmnIV1/f3Fg9JWkA2TDSbIdG08bwb2mDHETxkQ6bkU/i7MNwnjqYy
36e8B5DhT6fJkvA8fXIr9+f8rQr83/z9D4dTaO8=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs01GkYB3ApqUNRmVRyq1TI0IXc346kMmppKRvlGmkXSXYrhTTbmYYx
udQaJCbTGJfOkFAmL2bc7+G4tzOIMmlYg1231v7zvufse877z+f8znue877P
7/toewefuyIrIyPjtLJXr+zGx0MliRG3reOWv68sCfD3+2+NgsUOF48MzUwQ
IFXVLinBfnhTX9RSKBukPNdJUJn9hnyvTcG2D9oscH5e98sD/gRyu2qF3ZTp
ZPCU189hXviK/FhR87JXcABQOjKaemZuHLmK9YYujRcJUEBiEmpefUFuVK/X
rXcqF5KZ9tNL8WPIqXU5yz0mb2Agb6GOXPAJucDkKamT/w5a6p7+I3fnCPKT
Zpplr+MgLLy100l4fQi518SEFpVdCef1jSLNmoXI07vUixwJfOh6TanHMvwj
8tIwt4KWUj6M2C6X+qx8AHkGYbQkHQjgtrTFqvy5PuSW5s6uBRkCaK2Y77/O
thc5L2T1PathAcyKpV12IHcjHzPvWjuwphq60KVZ8VVdyI39kvYkrq2GUZGr
4miLHcjbE/ki0co57eYWmte2fEDuL3WoZKUIoM6njPB6kzbkxfnPZHYcFsCw
F9tn6nY0I2cNH1R14PCh522KXutCPb4HuoP7UUkVVPhsPnSmrwZ5SJyhYsbm
KsjQKTvkucBHLh3LflqsUAH1aH0x2cRy5LMc9wOZnDJIbDzlqNRUjJyzRDvO
0S+Gi1u/baIHc/H3/feXcxy4kHr2Rw3OFTbyG8LwPbpaTDg9OnbYY386cuHu
hqjY/TdhNdU3zoIRjzzNp/WqrzMZtG+4SFq3l4p8gdCUdCmPAShhnWzhSDTy
o6vtAqcIL8HggZTtRL17yNX7tddbDnJB4HCamovpfeSba7XkGgilgOgS/Cj0
n1jkNmJZE63eCvAgwUscaZeC+4Se0v9TWwvwtXdPXiNfiFxyRuK4xaAT0NMZ
Gzc85iF35Y5Pl6/pBdI8xU1lGdXIJ4bnzunuGwQxwqnhNxUtyE3jbnr2WAuB
1KM50NUU989tapLx2GURaNAtM441GkRu4mitRuGKQLJFZBiNNIzc5YewTCdb
EbikHM/JP/YZ+QmWj7KTvhBslQZPBh3E/3vMS58gff1B8FAsK47nTSIfNPoz
5/SqXrDV+qGqYcJfyN3pyq3ZMR3gnZNvQKWqFHknTXFyfF0jUHmraX5Zawa5
HMkmWm8PBBHA38wwF7tVlmVjVCETfE6jJHe3YxcD9rM5MRMG7aP7PEnBTnlS
6invXQp391DVuArYJ2kDsSqfKuGFTqC+Xh3Xw/UYvnXUrRoq0kreDElw/Vb2
6QZXm2rg67t2/aNFU8jJOgH2gbwa6DzS1n0gCN/DQp2RM9G0Gpa1hJ+2MMD5
SSFOle6IqoLdbjfp02/FyJneJ9pdfiuH2QWh1CO5OA8LL3LZtmYlkB06frCw
C+ehklvIJa7+Cxh9MZVnNoJzL/a93N1XhvbAdjxA4piHc89e9/iTCpsk8HFI
Rl50Q4RcsdWhWe16KvApNi+bUcW+/LrBR6CRCY5/DHleK8E5uXGm40QrKws8
ryicIs9hT86dn7WXzwaHxK/OXific5R3rTes4eaAJXLt7IdY7L+atcTNP8oD
vF3ng0IJuM6f7Qa9ba3yQcwjtV+We7H//vdAdIhJHmjUcLaZbMN9+7jW4+u3
RA6I9Pq+ECbC95B4J9/4HIkFlLzezwgJozg3Ds1lpS3RwZ0jd8h+9bjPPaMF
tjf8GHBt/8ZKrgKeX2GMpB7ZzCx4Vliffioc939WUcQDmSY2HNDO1mUU4vc9
qSogKQQwIXnqbn8gC89TA/nl/+Zved7/5u+/ZW3FOw==
            "]], 
           Line3DBox[CompressedData["
1:eJxV1Xk4FGgcB/Bx5CiKNnkaD3Is6XSUVMzrqkSprZmIYhCxq8iqTKJGlvJ4
KtE1o5VrmBmWjM0x9I6hVrLVuClmck8qRGPJsfrnfXff53n/+fzxHt/3fX+v
gX/Y4UB5AoFAXuwKiz2kRfNxdNs50tD8wmIbBYwH35sUnMyKMNs+8DsI89eC
1fXYxzVqio1kLCBK9Fpra4W9O2l2Mto1H0wEjs4vcfqMfIdGnnZ5Uw646VE1
LdL/hNzwx7VuOZzF8V11Z8lzI8hNDXbHc9engj3RB5br9n5ALihccW91mxkw
iXlVajk0jDxkikwuSb4JX7b3Qeb4IPJ/hgVRppFM+Mvwnjn65gHkcQG+U/vL
siBD7M9K3N2H99u8uI4rLCjJ9pWP932PnFplKU7dyoaxb0SnYgzEyC0yi+5L
93PgytGIrbuMu5GbZF6qb9TiQg1D5aRSw7fIm/adMRu4woWXigRQz74Tz+t9
wFPzLhf6F0QsI3q3Iw8mcDd+OMSFhHT9GeLlVuSukcmBzkWL8xbd7nTJa0au
kkbRrkhlQ7a/mDTzWIRcOUitpVUhH54rarmjkf4a+SuK2ztvQxaESWEjhaAR
55l0OI/emg3Hl5WEd6x+gVwuro359wQDVkioVylzQuRvSe4dQWEJcMHH5vq8
YhXyi7z+I1WiC4CtXKTy8Hop8nI1ObdVJkzQUNXV4RFcgNyemkkzKs4HfIpR
lD0lGzmxv+HxkAIPJFEteT619/C5zDcrX1hZCQQaGZqOGUnIHe2s+Rujq8G1
WLcVjLNXkeuvk7l+jhIAYftF7TF2NPKzu0Jm7sQIgdo3z9l46XnktdqRI3eH
6sCCZgZV3Z6OnOY7lHMF/gWMT59QtV2SgnxN5DbJDr+X4FnJzHpG0COcp2JK
QihsAir2Pm/Klpcht/k4FbXVqA2kKyqdZBFwns20TQFqqZ3g193H1WquNiAP
PS3n9SbhHfjm3DAjc2hCTn5gbc2e6AEUyQ0O16sDuY/HOdXwoxKgmNv903ET
CfLSaqKnWr4EvBd06jgV9yMvczJP40RKgCh7el9woBT5Ki2YvyFRDPZOmls4
quN3rbctluji3w0sfK8ZFS8dRy47eOz10ogu0KvUxKfXf0Fu3DjtqR7ZBngt
oT8YO00i73Po1+H0iUCMu2KqHvkrck5owBZDYQPYtHEY7v2GfW+uob2FsAbw
iT2DahQZ8sr+ksGhtyVAmXlCvy4Y+/pnhQI7t1tAxRKcYwHsn3qkKkqSLJib
EvCR0I7HJyveutHhWQqLD83z5HZiL+zyunjPpgreJ9YH0+l4/Q0k0efjkwK4
33acP1UwgXz2k5WE1CyELTXGuuXFOAeqXb0yL6EWngmhpvezcG5fafI2jt61
8AlpSwrMG0M+L14R0pgphAcDPJwUDuB6C5WD493Sa6AV/xHN/BiuqxZPJ08b
0QWwJ43LCYr4T10N79HK2lANbVqlYy9ZQ8iddCqS03h8GCu1TblAxPVzzSg/
pmtzJSSK1WUh1fieqKZxTfScy6ED00+1mo7r5/b5E5fut/0JExKPyKZu9SJv
dI4dAoMl0Jc/Xtc0ievqgCdJI5pcBIelQvelXOzPC+KCBp3ZUFTmqpRcgn3q
qMuoEjsbUog3vHhL8PgMju28odNDGNMrPJRahr3N3fxm2M93ITOOkUerw+vc
xA4hvtJNhS5rntWdV8D/AmOXKfHLk9twLuOFJPIszoFES7NKV7sDPaO5f3hM
4txkpnbkfAIDUg3EdS/o+L3kVLtYN+hkwg9sWZm8Gc4/nKuTmPI8F+bMOMgK
Sz4i/21M9t75YT4kMOPcd07ic1x3ufD13HQeHOn284ufwu8uqtJRqgIfQR2F
U+KGCnwfaF5m3//xpwoL///H/wUxQEu1
            "]], Line3DBox[CompressedData["
1:eJxd1Xk41GkcAPDRYsPIOmqorVa0XXZRUrle65jQoVyx5ciVMGHHsUKFUh5G
ri5iR6NhHVOEMHhHbiaRM2LKpGFJCJFr65/33Wff53n/+Ty/5/d7f9/3eyg6
+1i4rSEQCFZf93dfNzOM0r377R96qqvf1kfwnPttjYOSgRo/oup9cDuCNBXZ
jX3IO3fCIp4JHEkZFcWu2CuepI0X9eYA0ReWq7/kTCCP9xmcjk3KBZVVq2N1
1R+Q0xWC69jUHHDJlnDqZPs48h0zh+3Xv8kGKsKmrOq+MeQFJteciL8xQenF
BGvdxVHkJEbL2aR1mWCD30ZCwowA+Uab6Lyg4Adg3OusCJH4HvlSC3lRWiMD
DBJ5KwlTfOQdAWO0Q9V0MBctSdk3PITc7b32k1VvOigr0/5xsOst8sQFtXdL
WnRgqfU08HPXG/y88AWOy0462DR57a/lLB5yUcnmx1Z6dHDDVIHpGziA3Ntp
7IjqdTooKqGwIo37kVOOHRhLXqWDCL6v64zOK+Tr0052ZTzOAPKFsfy6Qz34
XpJ1IqNSHoAeuaKSKJMu5MOZ9NeXaxngT+modcecO5A/vPnueLJ2FnjZUBGQ
MN2KnCkiNdJSlQvGfcIU79s3It9vF308UbIAOIZK2L1QfYbzJMjAkMUvApKs
QlkZ43LkdlOble/IlIEblOVPjOJC5EVEas2IZhVQph943N6SjVxJMOGt9qwa
PBTZszVGgo7cyIoJaQO1wEjaeVzoTiLy6oApQjKpEZitvWJ59FEkcuEjORwr
RtPXeGYOz4qFIpdzDhnp29cCZknvSJuDqchVP267kLLIBdyKL61xfX7I0zVX
lJ6ttIICEk3zKDkcuQVx521BahtoTJRg8KWTkLMvmjjt/9QOzmX1p3uKM3A8
b3HSrKldYE1lrH7YT2xcF01mXiqifcDFdJtPXxCOP5ksLEYSeQ3MSTHSRbc7
ke85meQ1VDQAbEodBTX8PuSjTfvF5wg8ECfn4OnlgfOTyTfR2pHJAxEhLEZv
2zBy2l0zIdt7POB+x2JUy+If5OV8JRcr3iCgRgt1KkBcv2HnbQwG4wZAdYuk
ON90CnlrqcGkw/1+kLQ70M9/Zhp5Z7bh0cOtvSAj0jJO130GeXZDxuQWShdg
u54pWQqbRZ6XtSfknqAdzLJOGcjpzCEP97AKItpygWQj/eA+iJ37XPTw3aFa
8CTAUD9R6jOuIwtZfwd5NhicmRXhHsQevteeGlyTBSgesmrxOtjjLxfnLolE
wLAosrGaHHbNI1ViLyzzoKKhiqh+Hf5u/YIea4JWCvO6S1pJx7BT+ud7HPgc
yFVLoDxNwf91ocKCoXy6Fv4snXkr8SmOwyumYBIU1EPp6zuL18NPyKnwyq4K
80boGyriz8zF8Uynh68IbJtgb07bkEoMjn/8pvK18EsTrJ5ePC/mNIl83oBX
uHymGfq4uHqkqOF7nDfqFy0Laob3Km0u8fJxX5V66XtV16gZvmy/apZGxX2V
svmcijm7Cbr9bb8gdg731Rr9KI5uWSNMdDyteCMA55Vr9ghL5UADfOXurx8y
hPtqgrwT+4RxHfSM7FbmVOO+2h5K/uD1fQ1k0peteqWwF7YFxsZ0cCCF9yvn
h3aczynTGuLQshKue8Cynp3HHhfpm8WRKoO7Fme/lKfi9zSsPU2riy2GfQbN
7q7l+DzqdtrWk8uF0FzCZMPCFnx+zzyN1k7ZAug/KuQRw8bzYpf7idS9tEfw
yrVht92eI8hDt6oruCznQ3VPX8LcBlxHmR+XrPV+z4c928NqtOpxnJVoIxXq
W/IhmafCrT+E52BJsUZHXncuZJue6JaxwfclEBtP3bs1Gx6Ul5cgq+I5+5m8
nVnHTYcyN93NjJr/4x3h3+Z4len/5vi/6Uyxjw==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns4lFkcB3CMW2oVxpBkH7m2PUwNMZU6S2lFyGzKJa1mXEJCeJRbtJGk
FDNk5U5pYxiNW8pBIsJgZAqlVgyRTG5la632j3OeZ9/nOf98/jjve37n937P
0aQH0DwlxMTEjq4MwspQjNu2PAqD9tgsf38+ArH/nhnQncm5OKaTCWon1fpa
BrF/ssonBvjcBj2UzhuZYdgBdf3Czd57wPrC8zlmzzRyVarUM6EeG5x+QTPJ
X/6AXDbuOn2xgg3cBlvFrTdhH4eqdHo1G9Dmp3se7JhCLpORpKmy4kncdA2y
wyTyvawUI4sVX0pMYZV6vEfuyJNW8a1hA4rkbK2k+wRyH5ekwnV1bMD5OtQc
fnQcuRvp7EsaZIMqZQNSiJsQua72D8XUFjboWxs18Kf7GPIPlYzIr3w2aPZq
4GfZjCIXBUexGVNsUCJdU2Jl9A65zVa//ibFMnB7c1Frt/oIrk/Z02xfmzKQ
rRQzp0j4C3mVGbhyhFkGvBapu52+vEGudvaUkDBfBoqGnJLdBoeRFz2m//Q+
vRy4ytoH8GiDyIfJCS6iKA6Y1jMelTMQIB9jbZd0b6wASkPlWbO/8JE3CHOn
ugq4IMPfNZ7P6ULeucpVPm++CuTJGZMHSU+RVzN/vSfSegBCdzLi7d42Ije7
70u9PPMIkInROUsZtcgD5VWlXOQagV6lKuGdRAXyUZfzhQPMx0DRTLmU7XsH
uSE/t0Of3AKmGCwKkZmFnC7uydI3bgPGcVOeOlnXkXuwDmndrW8Ha1tzvnlu
SkC+pVksseRQB9gpsaAmko1FTmFQVCc7OkHecsO4zmgYcucDvTtItjzAO+HB
pTgFIufR9Ve1RXcDoWG4+4AgADnZ/UpIzakesEF6aYJthed/f3e/SOjbC3QF
XmrWA6nIjTImPFtT+WD/HZXPV9cUIi/VoU0enuwDM8oJubsgB3ma1bXx7Ih+
oA8eEH3YD5GncFvqdCgDgBj7c1/gEg/Xx+WCcSJ/EFiBEa2C8OfImdYHvH7c
9Qpod/PiKgZxn1BUcw1+d3sNZCOPeweMvEXu/fr8JY7YMIiZdXRSArj/bSvP
CcXXDwML8zBqeQn+79Q6k5ypOa9BQnZQvwwB50PqEU3iWM4rEBV9qE+aLkKu
rvgxmiY/BN76zPXtlppFrim8uWTHfQmIou3couA5nD/2gcFfWvqB5VaL0qWr
88h3yCgXaOTzgW9dfGzf4QW8XybTqcnbukFoFXWkXohdPoFW+tiiDTBJFoQD
9ovIFW42yzSKGkFzYq/PQjr2ptVb/X2kuSDZfVuS1hPsxRs2PqXmp4BwF7+j
9m3YX/xRvHwnLQ/W3OId4+RjLzsWPGD0NxcqWJ4K6LXFftzk4eUFnQZ4idIe
e7caf+dabpCKdUkz1MhkatuM4PX6fVSXOLPYCs+p6xk5f8D1SXviOEyKaIcO
qyUlFntxPWVIbzinbTugCUs7s6ngE3JTS6PPezI6YeQajb2HGXhfzFkRZLWE
LjhB0jDU/ob3UVShcDtXnAdjyglXKk1xbg/d2zR0UIIHLXNavxLqcD+IiAZB
dsld8Ma8bpynH87ba1KmeoyETniGY54SYIz76laEQsi1iWcwMUj7Ny8Gzs/x
f7xyTdvaILFrQ6b0OpyfAos0x5/tWuFqJ0NXZxOcn46RmVN6gmaY5e/wqWYI
93OHXK7GRkYTXDK476Iyh/3ifC+JIIDwuPdziuoNPM9A5cF3koV10KjnSHBi
FX7vGs2womq/GhiieZIQsRnnP38v2XJndyUMVuJ+EQjwukrr9ToL2u/DUO/6
S1vScR0cHlmTrXdXwGQzXuaMPa4b77xHCyRw4L56NV0rCXwOcmudGnSmyuB6
42iZE/64/u72jXBWoXSlT8zjz0Tg85dOVmo6aVAMY0JEqin78D62he4finiS
Bc0Ug4ySu7F3FOz7fh+oZ/zvPvAv/1YlHQ==
            "]]},
          Annotation[#, "Charting`Private`Tag$5685#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& }], {1761.75, -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJxc13c81+v/+HFFQqhoUISorCRZLZeiIZJKhNIyomVFWZkZqYzM7L2zN5e9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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnWeYFEUXhWd2WXZmZ6Znd2YMGD5FgigqggEDKiJBVCSomBARFFRQshFB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               "]],
              Annotation[#, "Charting`Private`Tag$5715#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJwsm3k0lO8bxmmjKFJaSEWRJEskS+ZWkVCRylKhREXarCXKUtJiTSpahOyy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          "]], {}}, {
        GraphicsComplex3DBox[CompressedData["
1:eJx13XnUnmV57v9ItUbAAYddduxgwTpAqBWwqCW+ohhXnYKKwnaoRlCMQymp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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQeUFFXThndZYGenZ7p3ZswRJaMoRjAnREQQcw6oBFEx4weoKGAAE2aC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               "]],
              Annotation[#, "Charting`Private`Tag$5736#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUlVUaxgGtRCDJMvGSF6z0kBRSaenYnhY1ecHbJKKmVJJEGkMeVg5E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          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k0VV+8AHApY8QvSlQoJClTiiTbUEKUVIRMIVOSkjJlHpJkSjJFhosy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            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs01GkYB/ApLCVFZVxiQ0O2TopDrVzeYpsclbCIpWQkKk2K2kONS2pC
ZXLLJbkMGrdVcpmSvEYYNSazbpH7JGNTM8Tohlb/vO+e/Z3z/vP54/d7f8/z
nO+jSznj7LeUQCA4LR6ZxcMQ0RNHgy9Zkxe+Lz4SkJH+43kMXLdveVIVxgS2
naqSySLstlUSm5e9LKCkPCTNaBQjJ2so66YnMYFNQtO4p9cH5NuUdvbWvqGD
E65p7LKqCeS5S0vlDmYWwqGGe+d1q8eRa0fduPWA/Qh+zL/mPE0bQx6dqUTr
T+VAvQ1NMYyyUeTL4+UIfGoTrC0wYuiCN8jphuYZxg0tkLov53NX4wjybs/G
/UMUHtQjuvgNuQ0j75D7KTM+kA9r7D1zamcGkCsQCU8HDNpgiPztrMHO18hX
5dAG2urboHnPXIPJ3l7kklQz0nlNARTTg+k5Ba+Qr7/lr9EPBDCceHRc/0sX
8t3dDM0GJwHU0l7pEbu7E/nQE71QpYMCSHJzIVlT2pG/S5PV32UmgLM9pYqx
1wW4/h6XfewUBLBuLoCh2MpHXrJ3+UXv+Dboq/o0VLHqBfLg2X9es7tfQvHg
xu9Bd7nIHRQlY8JPfDgdq3x4rKUROZRv078yyoM/Wx9dkiKGuA6GWXvis59D
J7+vxxRyHiG/46sTRm9tho4FwKDd6iFyFRpXiVb7DDKz9v155H4x8tJK6G3H
hVB7ndf84eJc5AGMdQ3m3mxIWBVyertKCnL3QFnzyV0VkGDc4c9KZCAf7i8r
iVYtg9Su7I3283TcX16Oj44wD94yu7QhUSsKuXhtEuiIiYM1A2V7iCbYh52t
eiuSk8HosjVupOEY5M0dDiWDrAfAuihbZmghGXlaxBkXmwoIdHbTdvSF4vtv
PG3x17WA56Ajw9Mx/F0JcktutkbP7XYw33tIvTSuGtftKH8iK6EHyBSRy3JL
ObhuitI8YeEAEFoEVVuo4T7uN2lushgcBtPX5rbtuo/nRDgnNu83FYJK+xpZ
aimeW7VM0+5IuhDMRhZ/+LRJiLyJTDBzfD8CWrR+Xd73uwj5tJVxhWXEMBg/
kn0gNeI98s3nrpNTFvqBNJwm602bRL60RRor7X4FjmkKfSyPf8T9fdjcRzX+
G7QyaWLWzDSe28sJ5CWzz0A3k0uMnJ1BvkexalxlbTGorP1UTTkpRc4OiFN5
n8+CyZImcrk/9sDNahbMrfWQs7/IhjuN3+Nu4WjCq+DCA6qdcXGrsTs4i0/N
3GyF8fOM3lA2vufosiCprf9LaHXoDKlSdQp5C8nLsL6DD50KGy86CnHunRZp
CttP8KAoiRinkYnz7UbfKa+VhlzIm2QWWnrgfAu9f1y7qIQDfVd8yExNe4u8
R+Gi9x88NpzSibKJufSfHNtx98CLGhZcPbj9ZgAP59gFzXyluhomeLwmy2Dd
liHka0fmVpwVlYNS+S2iR29xjtnpC1y2fmaDZpmvz8Lsseurf4kZaX8CBLe7
klgW2NWJvoQQ9zpAMqbIX07Enqf82sBErh4YjEaRXe0Gkdu7lcYmJNWDofnc
4hhLfJ9z06rp+d/qQcpnfkLqJpy3kQnSsfWmHBBiGmLHfI5dnpoWHm3EAZTD
bywdqPh/JVPfArWE9UD2jlmwsR6eW5UF1gq+0eJ3g8Y53VLsHmfnT1KU6kDc
EVK0XB+upyAjisJRZIN0tavUFzxcf2t3R/ULc4WgaGLcbqcp7peE5vrQl3oV
HpvdMJF6BffXttNNlOGfCxON54hBGnjfvf1lF5t3jwUZoqmIV2F4Tn4zmvEp
5+TBeD9a0Ewy3qflNwt+7N+6gP/t338BfL4c5Q==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xs0FFgcB3Ap0RmltiZFXi3VkEcveeW2yCnU0mJtlMfooV0k7BaVSbOt
18zk1ZohMYwxHu2YFUKux3iMvPI43nYGUZTHIrt57Oqfe/fsPef+8/njnt+5
93e/Pw0v//OXpaWkpBzW9vq13fhouDj+3m1z+uo/a2sasJiflwgsdzi5p6ml
A595RY3iYuxHtvVRVgK5gPVUK27HxynkWhYFu9o1OMD5E+ndg5oPyL+qJXwZ
MZcEHpf389jfvkcuV9i86unvAxSOjiWfXZxArmK+uUs1Iw4KbdnEumfvkBuK
tLu1T+dCKttmbiV2HHlMQ85qj+Fz6Fu+1EAteINcZPjYtrOmFJqRzvyau2cU
uZ2xWtnvdAgFt/Y4iG8MI/f+8EE9ilsFl3QMwoybxcjTu1QK7Yk10OW6Qo9Z
6BDy8mDXgpaSGhi2Wyb5ScUA8gziWHEqEEKllOXq/MU+5CdNHF0K0oTwpHz+
VTmrXuSVAevvnhgRQk4M7ZIdtRv5hEnXxoENtdCZMZ8ZW92F3OhKgmb8xloY
HraOTlvuQN4ZXyORrJ3TYWKqdn17O/Lv5+2qOCwh3PcmLVRk2Ia8NP+JlNIR
IfwxY/dCg1Izct7IIUU7Xg30uB2h3bokQs5m2Lkdn66GhLcmw2f76pAH0fXl
076ohkytssMeSzXIF8ezHxcRKqE2rS86W68C+QrP7WA6rwzqvTptr9BUhJy/
QrPk6RTB5Z1T2xj+fNyH/fdXc+z4MOrcN6q8y1zkFHGoJkmdDRfGxo+4H0hF
bqbZSIk5EATrorzppsxY5H7k1mvejlTQvvmCrdy+KOSjxKaEi3lMEBncyRWP
hiPXW2/tO0vMAkMHWbv1tO8i39WvsclskA98R1KUnYzuI99Sry7TSCwBuk7+
kYF/x+D+n5Q2VO+tBPfjPCfDrFnI0xis/u/aWgDZxi1pg6wA+fTZafvtup2A
nsrcsvlROXIX/sRcxYZeMJcnv60srRb51MjiedL+QRApnh15XtmC3Jge5NFj
Lgbz7s2+Lka4f0KiEo6NX5KARlLZsRiDQeTH7c2VI/gSkGQaFkyzHUHu/HVw
uoOVBFzcGsvLP/kW+SkOeauDjhjsnPef8TuE/3t0FtlPR2cQPJyUnowtn0E+
YPBHzpl1vWCn+UNF/bg/kbsxtrZmR3eAUgdvnyrFeeQdNPmZCblXgPhCzeSS
+gLydbYW4dqaENwDV431c7EbZpq9ogjYYDwlIqn7NfYFwH2yOMmG/vsZ5EQW
dlpiiYesVwnU7IlS5hOwz9IGYna8qYLOnUBlkwquR+A+cuu4ay0k0IqfD0/j
+s1tUnWvNdVBwR3r/rHCWeQ/a/nY+JbXQcfRtu6DfvgelhsMHPWMamFpS+gZ
U12cn7/ozZYoUaphp2sQY+7FJM4fr1OvnX6qgFkFgVFHc3Ee/naBz7UyLoZZ
gROHBF04D2VcAy7ydTJg+IXkcuNRnHuUSpk7z/RtgOWEz7R93n9yj2SZWGmR
AIaGpWQlNyXI97XaNSvfSAbkIpOyBUXshMJGslA1HVgOBTytn8Y5qbTQcaqV
kwlSKwWz1EXsmbmfPtrIZoPDk8/O3dDD5yjv3aRfx88BK9T6j+0x2CnGLfRP
kXng5V5nv0AirvOm9aCX1Yl8EB2p/MNqL3baXwPhAYZ5oFHV0WKmDfdtYr37
+6l4Hgjz/GcpWILvgRWSf+y8LQcoeL5cEBPH8LsfXsxMWWGAkKMh1Csi3Odu
4UKrm1eYULZ/SxWfgOdXEDOhRzo9E54Ti1JPh+L+zyi890CqiQsHNLJJTAF+
X2tFoS3Bhw2ps3f6fTl4nurKrn6evxV5/5u//wLdMxuy
            "]], 
           Line3DBox[CompressedData["
1:eJxV1Ws41FkcB/BxyaUo2pWn8SCXJaVyS7aY41aJsm3NRJRrRKslS5lEjSzl
8VSitEYrt2FmWDI2MXQYajV0GXeKGdchFaKxxLR6c86z/+c5bz4vzjn/7zm/
39ELCD8SJEsgEMgrQ25lnOlQfxjbFU0SS7+ufFPAyvLb1w5O5UWa7Br9E4QH
aMC6Zuwzag3lBhIGECR7bbK1xN6fsjQX61oMZoOmpKucPiLfrVak+bitANz0
qF0Q6H5AbvjDJrcC1sr8rtpL5OVJ5MZ6exPZW9LBvthDa7WH3iHvKV2XuaHL
BBjFvay0EI8jD5knkytSb8KW7mFInxlD/u94fYxxFB3+Mr5vmbZ9FHlCoO/8
wao8SBcGMJL3DuP/bV/ZxxUGHMz3lU30HUTuX2shTLdiwvjXgtNxekLkFrll
9yYOsuD6qUirPYb9yI1yLzW3arChmr5iSqX+G+RtB341Gb3ChpfK6qGOfS9e
1/uQp/pdNgwoiVxD9O5GfprANn13mA0J2bqLxMudyF2jUoOcy1bWLbvd61LU
jlwpg6JZnc6EzAAhafGhALlisEpHp1wxjC7ruKOW/Qr5C4rbW299BoQp4ZOl
oBV5aMqRIlpnPpxZUxHRs+E5cpmELvqL2SxYLfK7SlnmIe8jufcEhyfBrz42
16XytcgvckaO1gouAKZimdL965XIq1Rk3L43ogN+bV+PR0gJcnu/XKpBeTHg
Ugxi7Cn5yIkj/IdiOQ5I8bPg+DRmIveTtiteWF8D6tVy1B1zUpA72llzTWPr
wLV4t3VZ564i190scf0YUw8auy9qTjNjkZ/bE7p4J44HVL54LiVOnEfeqBk1
eVfcBKTqOX6q9jTkVF9xwRX4DzA8e1LZdlUa8o1RO0U/+reApxWLW7KCH+A8
5dOSwmAbULL3eV21tgq5zfv5GCuDLpAtr3CKQcB5tlO3Baqk94Lf9p5QabjK
Rx52VsbrddJb8MWZvyhxaENO/sPamjk7ACiiGyy2Vw9yH49o5YhjIiBf2P/z
CSMR8so6oqdKsQgM1vdqOZWP4HNxMstgRYmAIH/hQEjQBHINDVi8NVkI9s+Z
mTuq4rrW2RlPdAnoB+a+1wzKV88gl/x0/NXqyD4wpNDGpTV/wvXeuuCpGtUF
OB1h3xk6zSEfdhjRYg0LQJy7fLoO+TNyVljgDn0eH5iajsP9X7DvL9S3N+c1
AC5xYEyFIkFeM1IxJn5TARTpJ3WbQrBveVpab+d2CyhbgGgGwP5hYEJJQZQH
C9MC3xO68fxk+Vs3ejwrYflhKUdmN/bSPq+LmTa1MJPYHEKj4f3zSYKPJ+bq
4UHbGe58ySzypQ+WIlI7D3Y0GGo/Lsc5+No1K3KSGmF4qF/2CAPn9pkqa+Po
3QgfkXakwaJp5FLhutDWXB50D/RwkjuE+y1UDEl0y26AFtwHVLPjuK+aP5k7
a0CrhwMZbFZwJO6rmyMGNPK21kGbzonpFoYYuZNWdWoGhwvjJ2zTLhBx/9w4
xY3r214DiUJVSWgdvifKGWwjHefH0IHur1xHw/1zl/TkpXtdf8Ok5KOS+VtD
yFuc48VgrAL6cWea2uZwXx31JKnFksvg+ATPfTUb+7OShOAxZyZsq3JVSK3A
Pn/MZUqBmQ8pxBtenFV4/iyWrVTf6T6MG+IdTq/C3uVudjP8zF2YlZBVRG3C
+9zGDCW+1E6HLhufNp2Xw+9C1h5j4qdHt+FyznNR1DmcA4maYZmtcgd6xrL/
8pjDuUmM7cjFhCzopydsek7D9VJY52LN18qF75iSKlkTnH8EWys57VkhLFh0
kJRWvEf++7Rk0Pl+MSTQE9x3z+FzNL5c+mp5oQhO9vv7J87juoupcZxQgg+g
ltxpIb8a3weql8m3d/yJ/Nf/v+P/AQrte7k=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1Xk4lFscB/DRxQ0jTdRQt5W6JfeipLId1xbaZEuLJVvCWO5YrnALpTyW
GFoQdzQarmWKkGU4M1nCuCJLlpgy2S4JIbLd+uec57nnec4/n+d93ve833PO
77fT0dvcZQ2BQLD8Nn/4NpmhlE7F97/rKK9+H59ASvL30Q1K+qp9icoPwb1w
8lREJ/b3nrkT5vFMYE/OYBc7Y2c/Sxsv6soBoq8sVn/JmUB+x7t/OiYxF1RW
rY7Vcj8ip8sF1VZQc8CfNoSzZ1rHke+ZOWa78V02UBI2YXF7xpAXGt90IP7G
BKVXE6y0F0eRkxm8S4nrMsEm382EhJlh5Juto/ICgx6BcY9LIkTiEPIlntEi
SS0D9BP5KwlTAuRt/mOxR7l0MBclSTk4OIDcZUjz2aonHZSVaf7U3/EeOW1B
5cOSBh1YaDwP+NLxDj8v7MVx2ksHWyZv/rWcxUcuKtn41FKHDm6byDF9AvqQ
eziMHVe+RQdFJRRWhGEvcsrJw2NJq3QQLvBxntHqRr4x7UxHxtMMIFsYI6g9
+gb5QJJWRGTKI/BGpqgk0rgD+VAm/e21Ggb4gxS57qRjG/LHdz6cStLMAq9f
sv0TppuRM0WkRnhVuWDcO3TnQ9t65IfORZ2iSRYA+xCJc6+UXyAvDtTTZwmK
gCSrUHqDYTny81NbFe5vKAO3KcufGcWFyIuI1OoR9SqgQD/8tJWXjVx+eMJT
5QUXPBbZvz1ago7cwJIJY/tqgAHJcVzoPg0513+KkESuB6Zrr1uceBKBXPh4
DseS0fAtz8zBWbEQ5DKOwSM9B3lglvyBvDWIilz50y6vlMUm0MT+2hzX44s8
XX1F/sVKMyggx6qfMApDbk7ce284tQXU0yQYAlIi8oqrxg6HPreCy1m96e7i
DJznXU6aFbUDrKmM0Q3dUYE8vsHUQ0m0BziZ7PLuCcT5GxkJi5FF3oLT5GhS
0b125PvPJHoMFPUB61L74WpBD/LRhkPicwQ+iJOxc/dww+fzscBY4+dMPggP
ZjG6WgaRxz4wFbJJ5gPX++ajGub/Ii8XyDtZ8vsBNUqoXQ7i+xtyxVqvP64P
cHmS4gKTKeTNpXqTdg97QaJigK/fzDTy9mz9E8eau0BGhEWctusM8uyXGZPb
KB2g3PliyVLoLPK8rP3BycOtYI51Vk9Gaw55mJtlINGmCUjW048chNh5/4ge
ezBQA5756+vSpL4g9zSX9rOTrQD8mVmRpiPYww7YUoOqs4CXm7RKvBb2+GvF
uUsi4TAk0shQRQa7+vEqsVcWeXCHvpKobi3+bt2CDmsithTmdZY0k09ip/TO
v7ETcCBPJYHyPAX/lxfbnKFwoQbuIWXepT3HOXQxhydBQR0k3dpbvBF+Rk6F
1/exT9dDnxARP2YuzjOdHrYybNMAu3NaBpSicf7xW8rXwq8NkDu9eEXMYRL5
vB6/cPliI/R2cnZLUcH7OG/QK1oW2AiTK63/5Ofjurr+tc8NbYNG+Lr1hmka
FddVz62XlU5XNECXv20XxC7julqtG8nRLquHNPsLO2/743PlnD3CUjr8Ena7
+ukGD+C6SpN1qDAzrIXuEZ0KHC6uqy0hRh89fqyGTPqyZZcU9oKWgJjoNg70
5P/KWd+Kz3PytJo4tKiE6x6xrGbnscdF+GRxpMqg4uLs1/JU/J76tRdia2OK
YY9eo6tzOV6P6jlNq8nlQmgmYbxpYRtev3ueWnO7dAH0GxVyi67A/WKfq1nq
gdgn8PrNQRdF9xF8L7aryjkt50NVdx/C3CZ8jzI/LVnpnM+HnbtDqzXqcM7y
sSNs1W350JCv1FR3FPfBkmK1trzOXMg2MevcYI33a0hsPPXA9mx4RFZWwkgZ
99kvRruZtU3pkHTH1dSgEftcW9j3Pl5l+r8+/h+XKUbi
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns4lFkcB3CMW2rLZQxJ9hGi7dFoiKnoRGlFoVnKJa1mXEJCtFpC2khS
ihmykzuljWE0RMpBIsJgZApFKw2RTG5la632j3P22fM855/PH+c97+/83u97
tOlBNG8pCQmJQ0uTsDSV4zYvjsCQHXaL38YHIPHvGAKdbO75t3psUD2u0dPU
j/2jTR4xyO8m6KK0X2OHYwfU1XPXu+8A23PPZphdk8jVqTJPRfoccOI5zTRv
8T1y+bir9PlyDvDob5a0XYd9FKrT6fc4gDY72XV/6wRy2YwkbbUlT+Kla5EP
jCPfxUoxtlryhcQUVonXO+TOfFk1/yoOoEhPV0t7jiH3c0sqUKzhAO6XgcaI
Q6PIPUinX9AgB1SqGpLCPETI1+t+V0Rt4oCeVVF9f3i+Rf6+gnHmi4ADGn3q
BJl2I8jFoVEcxgQHFMtWFdsYv0G+zyigt0G5FNzcUNjcqTmMXK30SZa/XSnI
Ujk7o0z4E3mFObh0kFkKfOapFi6fh5CvPn1cRJgtBYUDLske/YPICx/Rf3iX
Xgbc5R2C+LR+5EPkBDdxFBdM6puMKBgKkY+wtkh71pcDlYGyzOkfBcjrRDkT
Hfk8kBHoHi/gdiBvX+a+Mne2EuQqmJD7SU+QVzF/uiPWuQ9ObWPE27+uR25+
1596ceohIBOjsxcyqpEHr1SXcVOoB/oV6oQ3UuV4P24xBX3MR0DZXLWE438L
uZEgp82A3AQmGCwKkZmJnC7pzTIwaQEmcRPeeplXkXuxHHVu17aCVc3ZX73X
JSDf2CiRWOzYBrZJzWmI5WORUxgU9fG2dpC7WDeqNxKO3HVv91bSfj7oOOrF
o7gEI+fTDZa1RHcC0aYIzz5hEHKy56WwquNdYI3swhjHBq//7vYesci/G+gL
fTRs+1KRG2eMeTenCoD1LbVPl1cUIC/Wo407jfeAKdWEnO2QizzN5spoVmQv
MAD3iX6cB8hTeE01epQ+QIzd2RO8wMf1cTtnkijoBzZgWCc/4hlypu1en++3
vwS6nfy48n7cJxT1HMPfPF4B+TNHfIOGXyP3fRVzgSsxCM5OO7uoANz/9hW/
iiRXDwIry3BqWTH+7jTak1yp2a9AQlZIrxwB50PqQW3i2+yXICrasUeWLkau
qfwhmrZyALz2m+mxkJlGri26vmDPewGI4i28wtAZnD8OwaGfm3qBtZFVycLl
WeRb5VTztfIEwK8mPrbHaQ6fl+lkavLmTvBLJXW4VoR9ZQKt5JFVC2CSrAh7
HeaRK11vlKsX14PGxG6/uXTsDcuNAv1keSDZc3OSzmPsRWvWPqHmpYAIt4BD
Di3Yn/9etHgrLRdW3+Af5uZhLz0c2mf8Fw8qWh8P6t6P3cP0wcU5vToYT2mN
vX0P71ORF6JmW9wItdhMXbth/L4BHzSlTs43wwhNfWPX97g+aY+dB0mRrfDA
cmmp+W5cTznSEPfE/jZoxtJlN+R/RG5mbfxpR0Y7jFqhtcuJgc/FkhVJ1kjo
gGMkrU26X/+T/+VKN3Mk+fBsGeFShRnO7f476wb2SfGhdXbzF0IN7ocpomGI
fXIHvDa7Ps47AOftFRkzfUZCOzzJtUwJMsF9dSNSKezK2FOYGKL7sw8D5+fo
3z45Zi0tkNixhi2riPNTaJXmvNO+GSq4bHJ3NcX56XSGPaEvbISZgQc+Vg3g
fm5XyNFay2iAC4Z33dRmsJ+f7SYRhBAe8X1GUb+G1+mr2PdGuqAGUroOhiZW
4ueu0A4vvBdQBcO0jxEiN+D8795Ftt7WWQFDVXifhUL8XsW1+u35rXfhKd/a
CxvTcR0cH9qSbS3KYbI5nz3lgOvGj/FqggQu3F2rsd5GCv8HedUudXoTpVDD
JFruaCCuv6dDPZxWKlnqE8v4k5H4/0snqzQcMyyCMWFi9ZTd+BxbT+0ZiHyc
CS2UQ4yTO7G35e/+dh+oZfzvPvAP/OQfqg==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BGi9mgyJiapuymtKGRVIq1mvOQtRKuQaCNJ
KUyy8k5qYxiNt5SLJiIMMzKbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8ePdjZW0ZKSurQ0iQsTdV408VhGLrdfvHb+ACoZt/GEOjOYl8YMcwCdePa
vS0i7B9tC4jBfrdBD6XzelYEdkDTmrvJvwfszj+fSe+ZRK5Jk3smNmKBE386
mxcsvkeuGH+NPl/JAh6iVmm7tdhHoSadXsMCzrOTPQ+2TCCXz0zW01jyZE6G
Lnn/OHJrZqqZ9ZIvJKUyy7zeIXfhyWv417IARXa6TtZzDLm/W3LRqnoWYH8Z
4EYeGkXuQTr9whmyQLW6CSncQ4x8ncF3d2gtLNC78mz/H54jyN9XMaK/CFiA
69MoyLYfRi4JO8tiTLBAqXxtqa3ZW+T2mwL6mlXLwe31xa3dOkO4PuVPc/zt
y0GOWuyMKuEv5NVW4PLB9HLgM0/b5vr5NXLt04Fiwmw5KB5wTfEQDSIvfkzf
8C6jArgrOgbznEXIB8mJbpKzbDBpRB1WMhEiH2FulvVsqgTEgYrs6Z8EyBvF
eRNdhRyQGeSeIGB3Ie9c5q6cP1sN8pWoZBHpKfKa9J/vSfQfgFOWjASHN03I
re770y5NPQJkYkzuQmYd8hBlTTk3pSZgVKVJeCtTiXzY7VxRf/pjoGalXsby
L0FOFuR1GJNbwASDSSGmZyOnS3szjaltgBo/4W2YfQ25F9NJ/25DO1jZmvvV
e20i8g1cqaRSpw5gKTOnLVGMQ05hUDTHOzpB/mLjqOFwBHLXPfwtpH080HXM
i0NxDUHOoxsva4vpBuKNkZ79wmD8nJ6Xw2sDe8Bq+YUxli1ef/zubonYnw+M
hD7adv1pyKmZY96taQJgU6Lx6cqKIuSlhs7jLuO9YEo9MW8rZCNn2l4dzYnq
A8bgAdGP9RB5Gqel3pDSD4hxP/aGLPCQM9zOU5MEImALhvQLI5/j6+32+Hy/
9SUw6ObFV4pwn5hq5pn85vEKKEYf9Q0eeoPc99W5i2ypQRA7fcBVDeD+d6g6
I5bWGgTWOyJoFaX4vdPqTD5My30FEnNC+xQIOB/SD+oRR3JfgugYp155ugS5
juqHGGflAfDGb6Z3m9w0cj3xzQUHzgtAlGzmFIfN4PxxDAn73NIHbDZZly1c
mUVuqaBeqFsgAH71CXG9LnP4vMwn01JMu8Gv1bShBjF25UTnssfWbSCdZE3Y
4ziPXOUmV6FJ0gS4SXy/uQzs3OWbgvzkOSDF0zRZ/wn2ktVrntIKUkGkW8Ah
xzbsfb/fWSy5kQ9rb/GOsAuwVxwJ6zf7mwNVbAKD+fuwHzV/eGnOsBFepLTH
3a3Bz7mSE6phV8qFulnpBvZDeL+BH3RkTs63wjM6RmaH3+P63HhyYJAU1Q73
L5eVmefjeiqQXrNP7OuA5kyDrObCj8gtbMw+bc/shNErdHe6MPC5WDOjyNqJ
XXCMpLvR4Ot/8r9S5XaeNA/GVhAuV1ng3BbdWzuwV4YHbXJbvxDqcT9MEU1C
HVK64PXZdfHeAThvr8hZGDESO+FJ9o7UYCruq1tRKuFXx57BpFCDX3wYOD9H
//HJs2hrg8Su1Vnyq3B+Cq1vHPjRoRUquW50P2yO89MlOmvCSMiF2UH7P9YO
4H7uVMrTXcNohgsm9900ZrBfmOWTCEIIPXyfUzSv43X6q/a+lS2qh5Seg2FJ
1fi+K/QiimsCamG43nFC1Hqc//ydZBvL7ioYpsb5LBTifZU2GHUWtt+Hp3wb
Lv6Qgevg9MiObLetEqZY8bKmHHHdeOe8WiCBDXc1aK+zlcHfQU6da6PhRDnU
osYoHAvC9fd0bILTKmVLfbIj4WQU/v7SyWrNx03uwNhwiWbqLnyO7ad2D0Q9
yYZWqqFmKd3YOwp3ffsfaGD873/gXwcniQE=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BGi9mgyxCR1tymtKGRVIq1mvOQtRKuQaCNJ
KUyyk3dSG8NovKVcJCIMMzKbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8ePdjZW0ZKSurQ0iQsTdV408VhGLrdfvHb+AB8fb6NEdDN4lwYMWSB2nHt
3hYR9o+2+cRgv9ugh9J5nRWBHVC15m7y7wG7889n0nsmkWtS5Z6JjdjgxJ/O
FvmL75Erxl+jz1ewgYeoVdpuLfZRqEmnV7OB8+xkz4MtE8jlM5P1NJY8mZuh
S94/jpzGTDWjLflCUiqz1OsdcheevIZ/DRtQZKdrZT3HkPu7JReuqmMDzpeB
5shDo8g9SKdfOEM2qFI3IYV7iJGvM/juDrWFDXpXnu3/w3ME+ftKRvQXARs0
+zQIsuyHkUvCzrIZE2xQIl9TYmv2Frn9poC+JtUycHt9UWu3zhCuT9nTbH/7
MpCtFjujSvgLeZU1uHwwvQz4zFO3uX5+jVz7dKCYMFsGigZcUzxEg8iLHtM3
vMsoB+6KjsE8ZxHyQXKim+QsB0wamQ8rmQiRjzA3y3o2VgDiQHnW9E8C5A3i
3ImuAi7IDHJPEHC6kHcuc1fOm60CeUrmZBHpKfLq9J/vSfQfgFNWjASHN43I
re/7Uy9NPQJkYkzOQmYt8hBlTTk3pUZgVKlJeCtTgXzY7Vxhf/pjoGatXsr2
L0ZOFuR2GJNbwASDSSGmZyGnS3szjc3bgHn8hLdh1jXkXkwn/bv17WBla85X
77WJyDc0SyWVOHUAK5k5bYliHHIKg6I53tEJ8hYbRg2HI5C77uFvIe3jga5j
XlyKawhyHt14WVtMNxBvjPTsFwbj5/S8HF4T2ANWyy+MsW3x+uN3d0vE/nxg
JPTRtutPQ26eOebdmiYANsUan66sKEReYug87jLeC6bUE3O3Qg5ypu3V0eyo
PmAMHhD92A+Rp3Fb6gwp/YAY92NvyAIPOcPtvHmSQARswZB+QeRzfL3dHp/v
t74EBt28+AoR7hNTzVyT3zxeAcXoo77BQ2+Q+746d5EjNQhipw+4qgHc/w6V
Z8TSWoOAtiOCWl6C3zutzuTD1JxXIDE7tE+BgPMh/aAecSTnJYiOceqVp0uQ
66h+iHFWHgBv/GZ6t8lNI9cT31xw4L4ARMlmblHYDM4fx5Cwzy19wGYTrXTh
yixyKwX1At18AfCrS4jrdZnD52UxmZZi2g1+raIO1YuxKyc6lz6mtYF0Eo2w
x3EeucrNZoVGSSNoTuL7zWVgb16+KchPngtSPE2T9Z9gL1695ik1PxVEugUc
cmzD3vf7ncXiG3mw5hbvCCcfe/mRsH6zv7lQxSYwmL8P+1GLh5fmDBvgRUp7
3N1q/JwruaEadiXNUJeVbmA/hPcb+EFH5uR8KzyjY2R2+D2uz40nBwZJUe1w
/3JZmXk+rqcC6TXnxL4OaME0YDUVfERuaWP2aXtmJ4xeobvThYHPhcaMImsn
dsExku5Gg6//yf8Kldu50jwYW064XGmJc1t0b+3AXhketMlp/UKow/0wRTQJ
dUjpgtdn18V7B+C8vSJnacRI7IQnOTtSg81xX92KUgm/OvYMJoUa/OLDwPk5
+o9PrmVbGyR2rWbJr8L5KaTdOPCjQytUct3oftgC56dLNGvCSNgMs4L2f6wZ
wP3cqZSru4bRBBdM7rtpzGC/MMsnEYQQevg+p2hex+v0V+59K1tYByk9B8OS
qvB9V+hFFFUH1MBwveOEqPU4//k7yTZW3ZUwTI37WSjE+yqpN+osaL8PT/nW
X/whA9fB6ZEd2W5bBUyx5rGmHHHdeOe8WiCBA3fVa6+zlcHfQW6ta4PhRBnU
Mo9ROBaE6+/p2AinVUqX+mRHwsko/P2lk9WajpvcgbHhEs3UXfgc20/tHoh6
kgWtVUPNUrqxdxTs+vY/UM/43//Av7Il8gQ=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9RWGGNI9ghRezQZYpK6NaUVhaxKpNWMl7yFaBUSbSQp
hUmavJPaGEbjLeUiEWGYkdlQasUQyeStbK3VP/fu2XvO/edznnOf5/7u7/k+
jw4j0NFTRkpK6tDiJCxOlVjjhSEYvM124fv4CG6lfx+joJPNvTCszwbVY5rd
TX3YP1nnEgN97oAuavt1dhh2QNOYvSm4D2zOv5hO7ZpATqbJPRcbcMCJPx3N
chc+IFeMvcaYK+MAt75maZs12EcgmcGo5ADHmYmuh5vHkcunJ+qoL3oiL02b
sn8MOZ2VbEJf9PmEZFaxx3vkTnx5dd8qDqDKTlXLuo8i93VJzF9ZwwHcr/2N
4YdGkLuRTr90hBxQoWZECnUTI1+r98NdWhMHdK842/uH+zDyD+XMyK9CDmj0
qhNm2A4hl4Sc5TDHOaBIvqrI2uQdctuNfj0NKiXgzrqC5k6tQVyfkmeZvrYl
IFM1elqF8BfyCktw+WBqCfCao211/vIGueZpfzFhpgQU9DsnufUNIC94wlj/
Pq0UuCraB/Id+5APUOJdJGe5YMLAdEjJSIR8mLVJ1r2+DBD7SzOmfhYirxNn
j3fk8UB6gGuckNuBvH2J6/KcmQqQo2RK6SM9Q16Z+st9ie5DcMqCGWf3th65
5QNf2qXJx4BCjMqaT69GHrScLOeiVA8MysmEdzJlyIdczuX3pj4BqpZqxRzf
QuQUYXabIaUJjDNZVGJqBnKGtCfL0LQFmMaOe+pnXEPuwXLQvVfbClY0Z33z
XBOPfH2jVEKRQxuwkJnVlCjGIKcyqeSxtnaQs1A3oj8Uhtx5j2AzaR8fdBzz
4FGdg5DzGYZLWqI6gXhDuHuvKBA/p/vl0Cr/LrBKfn6UY43XH7u3WyL2FQAD
kZemTW8KctP0Uc/mFCGwKlT/fGVZPvIifccxp7FuMKkWn70FcpGzrK+OZEb0
AEPwkOjDeYQ8hddUo0/tBcSY7d1B83zkTJfzpgnCPmANBnXzwl/g6232eP24
5RXQ6+THlvXhPjEmZxv97vYaKEYe9Q4cfIvc+/W5i1ypARA9dcBZFeD+tys/
I5bWGAD0HWG00iL83mm0Jx6mZb0G8ZnBPQoEnA+pB3WIw1mvQGSUQ7c8Q4Jc
S+VjlOPyfvDWZ7p7q9wUch3xzXk73ktAlGziFYRM4/yxDwr50tQDrDbSi+ev
zCC3UFDL084VAp+auJhup1l8XmYTKUnGneC3CtpgrRj78njH4if0FpBKohP2
2M8hV77ZqFAvqQeNCQKf2TTsjUs3BvjI80CSu3Gi7lPshatWP6PlJoNwF79D
9i3Ye27dXSi8kQOrbvOPcHOxlx4J6TX5mweVrfwDBfuwHzV7dGlWvw5epLbG
3KvEz7mCF6xuU9QItdmperaDeL/+H7VkTs41wzNaBiaHP+D63Hh6YIAU0Qr3
L5WVmRPgeiqQ3nBP7GuDZiw9dkPeJ+TmViaft6W3w8hl2judmPhc6KwIimZ8
BxwlaW/Q+/af/C9TvpMtzYfRpYTL5eY4t/vur+nfK8OHVlnNXwk1uB8miUbB
dkkd8PrM2lhPP5y3V+TMDZjx7fAkd0dyoCnuq9sRyqFXR5/DhGC9X72YOD9H
/vHKNm9pgcSOVWz5lTg/RfQbB7bbNUMl5w2uh81wfjpFsscNRI0wI2D/p6p+
3M/tStnaq5kNcN7ogYv6NPYLMwISQQShm/cLKvk6Xqe3fO872fwaSO06GJJQ
ge+7TCesoNKvCobqHCdErMP5L9hJsbLoLIchqrwvIhHeV1GtQXte6wN4yrv2
4k9puA4Oj20oNlvLYJIlnz1pj+vGP+fRBAlcuKtWc621DP4O8qqd6/THS6CG
aZTCsQBcf3f7ejilXLzYJzviTkbg7y+Dotpw3OgujA6VkJN34XNsPbW7P+Jp
BrRUCTZJ6sTelrfr+/9ALfN//wP/Al0yWxY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BEatUeTISapuymtKDSrEmk14yVvIVqFRBtJ
SjGTrLyT2hhG4y3lIhEZgxGbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8eI4juJSMlJXVoaRKWpmqcyeIwDNluv/htfAD89m9jAnRmcC+MGGaAmnHt
nmYR9o+2ecQg39ugi8q/nhGOHdC05m523wN255/PsLomkWvS5J6JyRxw4k+6
ed7ie+SKcdcY8+Uc4C5qkbZbi30UajIYVRxAn53serBlArl8epKexpIn8dJ0
KfvHkVuzU0ytl3whMYVd4vkOubNAXsOvmgOostM1sh5jyP1ckwpW1XIA98tA
U8ShUeTupNMv6JADKtWNSWHuYuTrDL67Q2vmgJ6VZ/v/8BhB/r6CGfVFyAFN
3vXCTPth5JLQsxzmBAcUy1cX25q+RW6/yb+3UbUU3F5f2NKpM4TrU/o0y8++
FGSpxcyoEv5CXmkFLh9klQLvedo2l8+vkWufDhATZktB4YBLsrtoEHnhY8aG
d2llwE3RMUhAFyEfpCS4Ss5ywSTZbFjJuA/5CHuzrEdDOSAOlGVO/yREXi/O
mejI54H0QLd4IbcDOX+Zm3LubCXIVTKjiEhPkVexfr4n0X8ATlky4x3eNCC3
uu9HuzT1CFCI0dkL6TXIg5U15VyVGgC5QpPwVqYc+bDruYJ+1mOgZqVewvEr
Qk4R5rQbUZrBBJNNJbIykTOkvdhGZq3ALG7CyzDzGnJPtpP+3bo2sLIl+6vX
2gTkG5qkEoud2oGlzJy2RDEWOZVJ1Rxv54PcxfpRw+Fw5C57ureQ9glAxzFP
HtUlGLmAYbSsNboTiDdGePT3BeHn9LgcVh3QBVbLL4xxbPH643d3S8R+3YDc
561t15+K3Cx9zKslVQhsijQ+XVlRgLzYkD7uPN4DptQTcrZCLnK27dXRrMhe
YAQeEH05D5Gn8pprDan9gBj7Y0/wggA50/W8WaJQBGzBkH5+xHN8vd0e7++3
vgQGnYK4chHuExPNHOPf3F8BxaijPkFDb5D7vDp3kSs1CGKmD7ioAdz/DhVn
xNJag8B6RzitrBi/d1r8pMO07FcgISukV4GA84F1UI84kv0SREU79cgzJMh1
VD9E05UHwBvfmZ5tctPI9cQ3Fxx4LwBRsplXGDqD88cxOPRzcy+w2WRdsnBl
Frmlgnq+bp4Q+NbGx/Y4z+HzMp9MTTbpBL9W0obqxNiVE+glj61bAYtkTdjj
OI9c5WaTQoOkATQldvvOpWFvWr4p0FeeB5I9TJL0n2AvWr3mKS0vBUS4+h9y
bMXe+/udxaIbubD6luAINw972ZHQftO/eVDFJiCoex/2o+YPL80Z1sOL1LbY
u1X4OVfyQjTsipugbgbLwH4I7zfgg47MyfkWeEaHbHr4Pa7PjScHBkmRbXD/
clmZ+W5cTwXSa+6Jfe3QnG2Q0Zj/EbmFjemn7el8GLVCd6czE5+LNTuSop3Q
AcdIuhsNvv4n/8tVbudIC2BMGeFyhQXObdG9tQN7ZQTQJrvlC6EW98MU0TjE
IbkDXp9dF+flj/P2ipwFmZnAhye5O1KCzHBf3YpUCbs69gwmhhj84s3E+Tn6
j3eORWsrJHaszpBfhfOzz/rGgR8dWqCSy0a3w+Y4P52jMibIfU0wM3D/x+oB
3M98pRzdNcxGuGB831VjBvuF2W4SoQ9Cd5/nVM3reJ3+ir1vZQtqIbXrYGhi
Jb7vCr3wwir/ahimd5wQuR7nf/dOio1lZwUMVeN97uvD+yquI/Pz2+7DUz51
F39Iw3VwemRHsdtWDpOtBBlTjrhugnOezZDAhbvqtNfZyuDvIK/Gpd5wohRq
mUUrHAvE9fdwbIDTKiVLfbIj/mQk/v4yKGqNx43vwJgwiWbKLnyObad2D0Q+
yYRWqiGmyZ3Y2/N3ffsfqGP+73/gXwg/xBk=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns4lFkcB3CMW2orjHFJ9hEatY8mQ0xSp6a0otCsSqTVjEtuIVqFRBtJ
SjGTrNxJbQyjcUs5aCLCuMVmlFoxRDK5la212j/O2WfP85x/Ps/7nPc9v/N7
v++rywxgeMhISUkdWpyExakSY7wwBIO22S58Gx+A1L9jErSn8S4MG6SBqjGt
7gYR9o/WOcQA79ugg9p6PS0UO6Bpzt7svAdszj+fZndMINegyT0Tk7ngxB8M
s5yF98gVY64x50q5wFXUKG2zBvsI1GAyK7iAMTPR8WDzOHL51ARd9UVP4Kfo
UPaPIadzkkzoiz4fn8Qpcn+H3FEor+5TyQVU2akqWbdR5D7OCXkrq7mA96Vf
EHZoBLkr6fQLBuSCcjUjUoirGPla/e/u0Bq4oHvF2b7f3YaRvy9jRXzp4gKB
Z21Xuu0QcknwWS5rnAsK5SsLrU3eIrfd6NtTr1IMbq/Lb2zXHsT1KX6a4WNb
DDJUo6ZVCH8iL7cElw+yi4HnHG2r0+fXyLVO+4kJM8Ugv98p0VU0gDz/MXP9
u5QS4KJoHyBkiJAPUOKcJWd5YIJsOqRk1It8mLNJ1q2uFBD7S9KnfuxCXivO
Gm/L5YNUf5fYLl4b8tYlLsuzZ8pBtpIpRUR6iryC/dM9id4DcMqCFWv3pg65
5X0f2qXJR4BCjMycT61CHrhcQ85ZqQ6QyzQIb2VKkQ85n8vrYz8GqpZqRVyf
AuSUrqwWQ0oDGGdxqER2OnKmtAfH0LQJmMaMexikX0PuznHQu1vTDFY0Zn71
WBOHfL1AKr7QoQVYyMxqSRSjkVNZVI2xllaQvVA7YjAUitxpT+dm0j4haDvm
zqc6BSIXMg2XNEW2A/GGMLe+3gD8nG6XQyr9OsAq+flRrjVef+zubonYpxOQ
ez21bPqSkZumjno0JncBqwL1T1eW5SEvNGCMOY51g0m1uKwtkIecY311JCO8
BxiCB0Rv7kPkyfyGagNqHyBGb+8OnBciZzmfN43vEgFrMKiXG/YcX2+zx/P7
LS+BfrswplSE+8RYI8voV9dXQDHiqFfA4BvkXq/OXeRJDYCoqQNOqgD3v13Z
GbG05gCg7willRTi906zNeEwLfMViMsI6lEg4HxgH9QlDme+BBGRDt3yTAly
bZUPkYzl/eCN93T3Vrkp5Lrim/N2/BeAKNnEzw+exvljHxj8uaEHWG2kF81f
mUFuoaCWq5PTBbyrY6O7HWfxeZlNJCcat4NfymmDNWLsy+MYRY/pTYBNohP2
2M8hV74pUKiT1AFBfKf3bAp2wdKN/t7yfJDoZpyg9wR7warVT2k5SSDM2feQ
fRP2nt/uLBTcyIaVt4RHeDnYS44E95n8xYfKVn4BnfuwHzV7eGnWoBZepDZH
363Az7mCH6RuUyiAOmlsfdtBvF+/D9oyJ+ca4Rltssnh97g+N54cGCCFN8P9
S2Vl5jpxPRVIr3kn9rVAM45+Wn3uR+TmViaftqW2wohlOjsdWfhc6JxwilZc
Gxwl6WzQ//qf/C9Vvp0lLYRRJYTLZeY4t0X31vTvlRFCq8zGL4Rq3A+TRKMg
u8Q2eH1mbYyHL87bK3LmZFZcKzzJ25EUYIr76la4csjV0WcwPkj/Z08Wzs+R
vz2zzJuaILFtVZr8SpyfvfQbB7bbNUIlpw0uh81wfjpGpI2TewUw3X//x8p+
3M+tSlk6q1n1cN7ovrP6NPYLM50kQi+Erl7PqRrX8Tp9ZXvfyuZVQ2rHweD4
cnzfZbqh+RW+lTBE9zghfB3O/86dFCuL9jIYrMr/3NuL91VYQ27Nbb4PT3nV
XPwhBdfB4ZENxWZrKUy0FKZN2uO6Cc+5N0ACD+6q0VprLYO/g/wqp1qD8WKo
aRqpcMwf19/Nvg5OKRct9smO2JPh+PvLpKjWHze6A6NCJBpJu/A5Np/a3R/+
JB1aqgSZJLZjb8nd9e1/oIb1v/+BfwDyNiUX
            "]]},
          Annotation[#, "Charting`Private`Tag$5757#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& }], {2153.25, -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True], InsetBox[
     Graphics3DBox[{{GraphicsComplex3DBox[CompressedData["
1:eJx1nXuUlmXZvslPCsEdbooPsw3YRsXPDaCm4htqmFsUTSgtw21YphDZBsiU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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[21, 85], 0.24705882352941178`], 
            NCache[
             Rational[31, 255], 0.12156862745098039`], 
            NCache[
             Rational[7, 17], 0.4117647058823529]], Opacity[0.6]}, {GrayLevel[
           1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQeUFFXThndZYGenZ7p3ZswRJaMoRjAnREQQcw6oBFEx4weoKGAAE2aC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               "]],
              Annotation[#, "Charting`Private`Tag$5787#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUlVUaxgGtRCDJMvGSF6z0kBRSaenYnhY1ecHbJKKmVJJEGkMeVg5E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          "]], {}}, {
        GraphicsComplex3DBox[CompressedData["
1:eJx13XnUnmV57v9ItUbAAYddduxgwTpAqBWwqCW+ohhXnYKKwnaoRlCMQymp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         "], {
          {RGBColor[0.409582, 0.542008, 0.909424], AbsoluteThickness[3], 
           EdgeForm[None], FaceForm[{RGBColor[
            NCache[
             Rational[133, 255], 0.5215686274509804], 
            NCache[
             Rational[36, 85], 0.4235294117647059], 
            NCache[
             Rational[176, 255], 0.6901960784313725]], Opacity[0.6]}, {
           GrayLevel[1], Opacity[1]}], 
           StyleBox[GraphicsGroup3DBox[
             TagBox[Polygon3DBox[CompressedData["
1:eJxMnQeUFFXThndZYGenZ7p3ZswRJaMoRjAnREQQcw6oBFEx4weoKGAAE2aC
gogJA4IBRUVERVBRMWAAMSMqoGIW4/8+vsXhP8e2366pvn27qmd22Xmq7mYn
n3XImQ2qqqqObFlVVaP932lV1XeNqqou18G+Om6hTS9VNdXWUJteqrqixr6b
adu8yprXmsXrjbW10lanLa9tpYxXyakgfVO5qupGbfqvajf9r6T91to6xXU4
rzqrqvpJ51xfY1suxvpBtmtkK0pPr1RV7c5YOv5e9hHaJ7L/KH2dtG6jqnnM
pTbuozbGqtH4v8jvZvmtKz1J+3u1rSX9r+z3SD+f98n3c6/1VVV3ab+RTI9J
V2sbp+M/5Tte+/VlXyV9G+Mxf533oHRr6Y4xD66faPzf5TdGrzWW/lX6Fumc
9G/So6T3iThyzl4RX2K/5/+L995hw++BGtv30JZpnL80zh2yNdAcHtK+jewn
V3lc5vKi7quRXpvCfWk/WfstyJ/0w9JbSt+quO6lbaqO58q/sV57hJjovuu0
zZB+RfZa2R+Vni9dJ/249Cy9Xqvtaen3ZE9kf1L6bem89DTpPcvOeTdtz8q3
kbYnZH9NPjn5PCb9oXRR+inpD6QL0tOlR+vcUdra6dzb9QzM0QOU6rXP5JNp
/6x8ZtY4Hsdr6xFxJGb1ev05vbaf9AkRM+J6UrxOjHpW+bnneTwxXuf8UyJ+
vFbWOM9rnP2lx2su47QdyPMs+5+y38ncZOuobbaOv9Lc1tZrL0lXtH9B+y5c
r+wYnK6tJPss2TtLfyH/tXT8oo7Lyunfyumd0t/Ivo7sc6RXSK8rPVf6d+kN
pV+Tnq1YJtpelf5V9g1kn8ezKr2R9OvSL+v1TNub5E77tbUtka7WG2gT+bwl
fVHEjzgNjfsnNpdETInZxfE6cZqrMYra3tC5g8OG39s1HudCbUPiWWSsS2MM
jscpj68qjxvr2ptqe0fn9JK9ifQC6d7SBc2thY4/1HGddHPpRdKZdEvpxTzP
0k2l35fuVHZcR2i7W/oubWdIT9R+P20fyOdHxWR9+b9CnHVuK+mPpN/QfVS0
fc57S7Z3te+jc9eTTxsdf6rj8ZrzG5rzlsRXviVtH8u+oXy24HmU3lz797Q/
VeeuI3trHX/CmNJtpb+UHhuxId53aMy3NeYuem1pje1jiE+VY0rst9ZrX+u1
y6Rvi/PIw/h4nbhuJZ+v5DOM5zBe5/w74nXysI18lsnnCumWms92Ov6Wz1LF
ZD3pl3m+y47ffdpay2d72b+Tvan0ttLLpR+Qz/3arpJPO9m+ke1y6UmyddG2
Qse7y/6X9hNlnxDX55naWuPsqNdW6rW9pHeVXsXnhmK5obbfpf+ocQye1Laj
fDrI5yfZdpHeWfoX6Xflu762X6U7yL6T7D/zWSa9g/T30tMjlsT72YgX8dhW
Pu3l84N8nol4Ee+Z8TrzfSrOI94z4nXOf1vXXFfbjzr36Xid82s1ZjONuZDP
Ie3/1v4u2Z+XfYCO99cPy65lx/UlPgdk30v2f+X3MJ8J/HCUz1Ttp2ibpMOu
8ukonxrZz5A+VHpd6e7S+0o3lF6ouWysrbH0R9pvpq0gfax89pdPnfQR0vtJ
10rvJ723dLX0UdKdpXPSh0h3km4kPUHP5Ht6JrvwHtN4m2rLy76/fPaRrYH0
SdIHSBel04bO1bvauslWr+NZzF86k35O+kDpkvTz0h9EfInfoirngBh/GHty
tTBe57WzdK3DdP563Lv2Ze1fkL2P7AfreG0dvxfPCznvXnaMv9DWVz6HyGcd
+ZwifZB0RfoJ+UzTNkc+78d5zOlx2Q7StpZ8FsdceC7O1bmH69z1Zb9G+mTp
LaQvkD5CekPpAdJHSm8k/YVi1lzbJtJDZD9G9s2k71RsFym2R+v4QtmP0n5j
2Y/Xvrn2n+hamzd0LH/S9kuV7405/hp74vdb7InTEl2npbYmOm9VxJRY/hF7
7uNYjd+UZ0T658gV4x4nezPZP5Y+QbqF9KfS5WpfH98Ziscz2paQE+0P1dZK
fsM0/xN1Tkuen7LjXa3zRsp+iuxbyj5C+iTpNtJXSveQbs01NN+m2jaQvlH2
nrK3JT7SfaV3kF6m17fQtq30aNl7y95O+lbpXtJbS98m3Ud6G+mv5Nta21bS
y7Vvq2176YmK+ceK+any27Gh76ukeVaqfX/EeD/9grmtflncSz9315X99yrH
cu1qx514r1PtPa+tV+3XifEZGncnjfu39IXS3aQ31Ov9pHeW/kf2WYrPEdp2
1fEUzflcvban9H3SZ0nvJn142fHbVNtpsrWX7U+d+4Lsz2trIPtd8j9Tr+2i
1x6SPkd6D+n7pc+W3l36dO07aP+Xzn1U9vN0vJeOv1M8tta2t3S7aseAPHdp
aL21tm3CRmye0bkX6Nx99fpdiuHniuH/dPyjxthOW2fZf9B+G22dpC/Sawdq
v5HO3TbGWEvbQNkPkH196Sc05vk63kfHO1Q7psR7kGxdZdtAers4j9jvGK8T
7+k6t7/8Ospv+3id81+U/WLZu8s+R3E6mvew9FWynaT9TvKZK5/BOj6Yz72y
Y7ybtu7VjgX3/bLsc7U1kX5b/kPlf7j8X5O+VPpQ6VekL5E+RHq+9BDpw6R/
UQx20HaE9AkNHctu2u5W3JYqblfwe4z8L9f+aL3+gfRl0kdJ/67z2ms7hs8x
2YfJfqT0Z9JXSh/P+1qv76TtOOk9ZftHPzfu5nM18tYuYvZLfE4cVu34Er9D
IqbE7ODIDceHhg2/qzXmyRp7Z+kR0j2kO0gPlz5Rur30QREnzv9Cc7tGr52i
136UvkG6r/Q30tdJ95Z+Q7F8Xdvu8j+27Hgfq+0r+Vwrn17EVvbjtPWU/l72
62U/VXqF9EjpPjzHuu9dtJ0m/avsN8p+OnGTvkn6DP4hqhjvIZ+zpf/Vfjdt
Z0rfo/gv02u38DNP/xi9VftzZO9X7diR/6u1nVFt25lh417PjngRv7E67wKe
HelR0ufxfpU+J14nluc2dM5PR4eNPJwV4zHWGJ3bX35HSo+WPp+fz3H9bjGn
Gs3zNr32P732tmJzorYB0uvIfqfsl0jX6J720j0Oll5P9omyXypdK3279EDp
gvR4fs5IZ9J3SF8kXSc9TnoQP8v+331vKPtdsg+R/YqGvo8R2k4oO28DtdXq
uvvqupfx/op7Ze6NZd9H9qGyb6Zx7tE4l0sv0LnvkGP53KtcfCe/u/kZLp8J
2l8sn2vj+sTp/mqPS05GRg6I8fWxJ6736bzhOu986aYa5wEdX63jSdqP0L4/
15K+Uvo86Q7yeUTHN/O+01xO1naN9CLtF2obJJ+W8nlQPtfK3lr6Ienr+FzV
/ip+zvM+k/1hHV+v422lp0jfIJ3XPe2ne7+R34vKjtMo3nvymSqfm2TfRfpR
6VukGzXQZwLvA217yf647GP4WaD4/KixHuP3Ku3315i3yp5KHyA9WvqBiA15
mxT5IV5jG1rfp+26iCWxezB8ifE+utZTGvsOfv/R/nZ+9sr+cMSaGE+O8zme
Jp/b5HOD9EMxBq9Nl3287DdLPyk9Tvom6Y917720TdBxz7JjME3bp9KfaBst
vb/m8IzOmSifrtIzpO/i9wfpmdL38B6TniU9iZ9Luvduuvd7pbvL/qzsd0sP
kJ4vPUP6WOnnpe/nGVAMf9U5L/B7ofYH69yHyIt8XpRtMu836eek7+PnRcSM
WM6NPc/gy7En3mtpnO4a5wE+/8NGXF+NPbGZF3vit0T3eqq2x+U/W9eZws98
2fuUHY93tL0k+1TZp3Jd6UelH5U+RXN7WcePMTftH9H+EXLU0PN8SdtSjfOl
tiekL5D/G/J7Rq+fJf2a9HTpvtKvSj8h3Uf6Felp0mdIz5N+ks/emC/5X0/3
eCh/w5H9XPm8Lp+npPeTflr6TukLpd+Ufpb3heL8h855S8cvNPS8vtC2kWxH
apxZ/A4kfbj0TOkhOvdt+T7f0M898SWWX1Y7B8R+Sdwfx0vDht/X4Uu8l/Fv
fG0va5x3Nd5L/BwmptIvSr+OT+SD+1sg+2x+Fkl/E2Pw2jDN5329NpefudrP
0f5N2beUfbKOR+r4tLJz9YO2K2X/QPZXZB8t/bH0m3x+Si+Snid9m/Qn0m9J
j5T+UPo16U35fZ+/k0jfKvtHss/nvSe9WPp1ft7pWsu1LdC1Npf/sfJ/W/aG
DRwj4vFeQ8e4Wram8jlePgv4TFAu/tHxp+RJY36m/bt8HkgvlH6VnxcNHF/G
atDA43D8p36G3iyffvJp3MC5Id65Bo4XsVyi1xfq9W+lP5d+X3o5+Zb+gLkz
rvQi6e+k+5Uds0xjnF32vq22H7Fr+5H3lub2tc75WOdMl/5WegnvAenl0p9J
PyT9jfQn0ndJL+V3KN5L0sukP+U9If2V9Ed8pkmvkP5CuoXicSJ/z5FeqWue
qW2x9DPy+U4+X/I5L5+T5LNUulkDfy4Tg6YNHHeOm4etVtvzOnelzv1G/k0a
OA/EcrPYE+NlDW3fVNvvuuZv2uqlW8QYxPVFjfOLxvlevg8qdw3k872Of9L2
rWyJfH6V7RxtK3X8g+zL+bkt+8/S3/GzXbqN5n+K5v+1jn+UfQU/i2Sfq/F/
1fEPfF5J/yb9Iz8Ly87DAdrelv0P2X/hc0D6d64vvU8Dx4L7ni/7Ktl/lv1D
6b+lV/F+kf5T+jfptppDL/4Ow89W2f+S/XfpdrL3kf0P6b001uYR190jNsTv
M/n/K/+/5bON/PvK/y/pfxraZzdtDyk+jTXvf+S3Z8SasfaIMVYf10TO9o7r
NIt4fx3v+xr9266B/m3XhrzxpYB0K74Ekf5X12tJDqWrZW8t/Y+u+be2raT/
0v58bQ312heac0P51Uh3jDiR269kbyR7I9n/lC5IF6W3132dzt9PpL+XPSd7
TnqFdK10rfSP0nXSddLfSDeWbiz9u3QiXZD+VTovnTTyvz8Xxr/z22v8fho/
lb2D9FnS9dLlRo7fsdqOi1gS+xMidsTypIgXOT8xbOTq+PDF7xJtPcL35PDl
vus1l7V0jU7SJem1pfeTLkuvI905ztsrrtFAefyfYrieXrug7GewLzmTvUZb
V+lM51b0+r7kTv8eX0vH6+u4Tnpt6Q2kC9LrSG8ovbvu9zzd7+bcr+zryb6x
9MMaL9U1NtLxLvI5h7/DyL6efDaQrYn0htIbSm8mvY70+tKbStdIV6TXld5D
5/bXuc2kB0eMuKcLI6bEqUUjx3ggz6LO3VjnNpdt0P+LfSb7urJvJPvFkQPG
uijG4LhaPql8SvK59P/Fe1PZWsnWk+daPpvreAsdN9G+tfa9ZN9EuqX0KcxB
uo10b+mW8m+q47Y6Hlh2vK/kM0jxGaTjLWXPS9dpO0321vJvJv+tyIHufaDu
fUfpHWVvJft20ttKt5TeRnpr6RbS7aT35m8D/K1GekvZm8u+tfQu0m2kd+D5
lG4tvb30ZF0zrzkUdTxFuiy9BX9/kc+W2u8kn3ENHHeewdERY+I6PmzEaUzY
yMltEVNifHvsOX9svM5rnTTPCzXPDhq/Lc+H9kN4njWHTNtwnnHNYRu9tgf3
qP1u2g+TfSvpXaWHSreT3l36MumdG3luo7hG2TG+R1uq8S7W8Z56fX+NuZ3O
2Vu6q/T20vtId5feQbqj9BHS7aX3kz5EekfpfTlXc76Yv7FIHyV7B9k7S0/V
+Oto/J11/Ij0BtL7S3eT/xD5d5XPgY08r2nanom4ENfpETti80TMnRgfq/F3
0hj767wnw4bfSbLvwtiyPx2xZqynYgyOu+q6l+i6XeQzI65DrnbVed35jpL3
vMbZW8dH6LiP9F7Sh0ufIb2P9JG877Q/RPuJ8l9L93Wp7uswHV9Sdlxf1HaK
/PeU36GyH6brXqnr9pA+S/aOsh8lfaF0Z+nj+SzU/iDtJ+jcC2TvpONjdXyo
zr1c554gfa7s+8p+tPQA6f2kj+NzRvuD+T5O5x4k/2H8rYbPDc1tbW33yj5E
/l3kd5Lsj8q2ieZ6lI4XROyJ8buxJ67vRw6I36LIDTH7IGzE+L3wxe8ajX+I
xjtd4x+g/SnaPyt7N+le0s9JHyjdW3qW9DD5d9dxHx0vjPG4xtCy4/eZto00
zw21zeZzQf4Hyb8vz6f2PbWfKfsI2Q/W8Wk6Hil9qPQZ0tVpVdUVPHfSo2U/
Qvps6SMVnxH87UX6RtkPk72f9K3Sh0ufxeelfK6Vz/nSx0hfLX0u36XL50j5
nCN9ciPH7R1td8p+tOz9+dnXwPdDzH6JGBHLnxo41sT4xziP45/Dht8FjWz/
QdtvEWvG+jXG4PgYXed/8vuQ94L0AOnF0sdJD5T+SPouzecEHV/I57Did4Vi
epH05tKb8XdS+Twkn5Pkc4ns90mfKH2x9OVlx/5fba/JfrbsN8k+Rfpk6Uul
T1BMRvK3FOknZO8p+zDp6dK9pC+Tvl+6h/Rg6ZPkf4P8r5B+TNffXNfoo9dO
lv0m2YfzTMr/FNmGSD8vfar0COmrGjkeWY0+A2usiV9fvX61XlslXa5xfInl
abJfI/sf0pUa28jD2jWOI3Fdp8Z7crVWjV/ntWd03d46/3Kdf7r21/K7kuyv
yH6Wjm/U8fCyY7OxzntR9n6yj+TzQfvrtP9Lr7XQPY6Q3/U6LtV4vsxvrvzP
lN8NsreST0ttgCrHyzZIto/lM18+5+j4Zn528ndB/sZCvmXvL/sY6fekz5Me
Jf229LnSt0h/IH2+9Gjpz6T/Jz1O+nFdp4Xmc4GOT9WYozTmWNn7So+Rvl16
fCPHuK22AfK7Q8frSm9b4zgSp3Y1vh/ivXXkg+NtwobfVjVrcrV9jeNOvLeL
MTjeQPMZxt8g+Lmka03gdx++W5aeKL0BLIHmf4mO7+Pntfyvkf/d0t/Lfqns
k6SvLjsPu8AzyH6x7PfI/o30YOl7pbfSuW35vJPPINnulG19ciKfITq+X8dn
Kw53KA5Tybfsl8k+WfpX6aHSD5Jf+dzG31h4j8s+TPaHpL+Qvkj6Lj4PdJ02
mtPlfI7If5z8H+bZbuS4HqCta8SYOHWLPbE8MPbEuHvsievBkQPiN1zjPs7v
O9KHhI0YHxS++I2Szzx+5kiPkJ4m3R4OQZ+HV+v4SX5H0jxHap7Tpa8rO35H
a7tSrz8m2w7StfK/RsdP6bhO+lrpp6UL0tdJP8N7U/sn+L2JnMs+UsczdFyW
vl76WenzFIc7+RsLnz+y3yL7S+Rb+kbpWdJzGjk2fWEVZL9J9uf5bNE8t9L8
buYzT+Pco3Fmy36B9F3SL0hvL5/ttO2qc0/7fzG+Vee8ys9P6TMjpsTpjIg7
8T49fDnuFzb81tEcbtD5z/FsRA6I91kxBsej9fprev1wWADpN/j9SLqZzh2r
4zd1vLPmtRP8BDGqOMb/07Yb89V2jHQL+d8m/3f5TJC+Xfo96TbS46Q/4PmX
Hi+9SPr6klm41bzb5lVmrdrJZ4J8PiW/0ndKf0Z8pCdKf8F7QfoO6cXST+r6
O8Og6Li97Mt53/AM5/Uc1Ji1G6Jr3QdDIvszeXNi8GT65+h/rBfXvrlsfg5u
Tf8E/o8Ra1a1hm/jGL6tZRzDzLWKY/g4NFgbvBw8HnwabB5MHZzYjLw5Nti2
RjE2134ybx4P1g7mDm5vqypzfFv765b/2Dy4O1iy6XnzdbBtT+XNucG2PZ03
5wb/9kTerB6MX8PErAzczuPB18HVLQtuCt5pZt5sGxzUc3kzUTB5s/Jm9uD3
yM2eVea6ZmiMZ+rX8HswfTvHazBLx0dM94pzuNd9qsyBEceOcUwc943jG7jR
xmbu4Ps6RXzh/WDt9qsydwdT1zlit3dcA9YOvg5mbHbevB0M3pzg8WDt3gmO
DkZuVLBhxPfdYOdg5MaWzcDB470eDB683JvBzsHgvRrMHmweue8U9/BcsHbw
eDeWzMvBysHrPaP9UfABwdrB3S0Mfg/u7uPg8eD6YANh+LrK/0U+G+rN3X2a
N4sHH0hMT4xYc/894ph4nBTHxPfkOCa+p8Qxc+0Zx/B6PeMe4Pdg5HpVmZeD
wetdZR4Ppq4P398H0wX/NidYOPg3WDx4u9OqzOvBhhHfCWUzfLB5S/Lm8+Du
vg3WDr5uZbB2MFE/BR8FM7Y0OD0Yv8bBnsGVrQruDh4Plm1o3M8/weDByMHK
zdf+AtkBV2Hf4PFelf2VejN4N5XM461m6GC9LoyYXhzHz+bNocJ8/hUcIIwf
Mb20ykwYMR0Sx8R0aByTj8ExFtwdrN2wKnN3MG+XVZl/g2G7PHJ2SZwzJb4z
4PsCeDp4u+HEP77/5fvZYnB6MHv3ls3hwUTlg4+C36sPrg9+7/Xg6GDkFgRb
Beu1frBzcHebBF8Hm8f9w1zBZr0Fz1hvpg527wvtb5a9EnwgXF+TxLwerONG
wfLB6V0YY8CH3Vwymwd/t3YwgXB9xOj2uB73Py6OWwQLB+fWLDFXBxcH+wY/
d2/EekKVeTLYPPi9O6vM8sHLTawyrzchcrNTcG4wbPcHJwaHt13wcrBq5GF8
zKNtsHlwbjsEzwaT9lDZfB5cX7tg4WDtLo25cH6bYP/g+uD3YALvkn3X4Ojg
6z4MrgxmDM7uN9ke5XMzMasIp3dLyfwevB4xgtd6KmIKTwWP9YHOfb/ejB+M
Gwzc7IjjM3EOc4KzmhFznBnHcLUzI45jY2zGhS2Er5tVZdYOFuJ5Pk8SsxEw
deNiPK7RKVg7frBOCTaM+M4IngS+5aBg7WDqugQjB+f2aNlMHrxct+Df4PGO
DqYOdu7wYOdg8A4NNg+ObvfgFWEUjwvWDh6P+4DdguW6tWSODoauR2LmDn4P
5i7hOyn5fMLvCPVm7U4Irg8eb3qMsZp9Y/9uxHRhXIP7XxTHqxk7juHyFkes
4fRg9mDD4PTg6+DQ4OBg6T7nsywxewc7B+MHywczBgsG+1VVbZ7uiyrH97Rg
8+Du+gWDB7t4dnCMsHy9g8eDtesffB082OfBhsHUDQy+DqZuetncHrzfRcHa
wc4NDo4O1g7mblO+h6paw8nBwyzlc6LeDB6x+D1eG1UymwdzR/zgZ36uWsPb
/RIxxQY3dl6wiHCAxHFVjHVFsHBwcTB1sHzwVzB3MGKLq9YweZwDjwd3B991
aWIeEH7vssQcHkwdTCA83t/xflg9xjPBiRHrq4Kpg6+7Kbg7OLprg7uDUZxZ
NsMHd3d9sIuwebcHUwc7902wczB1twSPB0c3Jlg7uLvxwdrB4xEb+CuYI+IC
MwZD9q3GWFFvfm9CYuYOBm90yVwf/B1M33Z8h1Xt+DLGahaPPWPB1cMPP1e1
hr3jesQOFgwmDJ4OZm6TavNyMG8wZs8H30WMYOFg8+DK7k7M5MHO3RscHTwe
/B6cHsweuWRsrje7bPYONu+p4NZgzx4Lfg+mbnJwdzB4DwTLB4M3Ndg8GD84
PuZM7lcGgwf/Ni3YPHi8mcHawdHB0+2nfRudMysxcwdr9zM/G+vNEo8pmSuG
3SNecFntIkYwXdtFTLeN10rx+tbxGszSwXGfO8Q5MHrwYswVZg8eD+4LNg+m
sUPke7sYd3Zi5u8/7i4YPLg7+DsYu10jTzvGNeYGA0ZuXi2bt4PHezXYPJi6
xcHFwci9GdwdfN3Hwc7ByL0T3B1s3m/B3cHLLQx2Dqbu3eD34PFgMuES4QDh
7I6V7hz3QAwOirjAXsFg/cn3lvXm7j5NzO7B3Y0tmceD73s9OECYwG1ijNUs
YfcYi5geGrHm/g+LY3i6wyIu8HWwdrBkcHfwivBgsIvweHBiSxLzebB2S4O7
g5eDm4OrO6banB2MFvH9J77Th3+DgzuLz1rem8HmwdStDL4O1u6n4O7g994s
m9uDzfsnuDtYu1XB3cHa/RXcHczAsmD54P3eK5v3gj2j8AvmDh6vYcH8HDzb
bSUzeKtZOdix0yNe/eKY+J0Zx8T1rDgmV2fHMTE9J47zwbzBszXQ+NUlM35w
evB1MGCwdnB3MGMweLB8/SMf58ZYjYO7g7WDuYN7G1Btfg2mi/jC/Z0buYTt
geGBOSkGUwdr1yk4KzioSnB3cG5rB/MGs7d+sHwwe3Bzw/js1zgbBcsHg9co
GD94P1iwUdpPlE+Tghk6GLzbS2btVvN6sGAjIo5Xx/EmwfXB5hFHOK5rIo7X
xTFxHBnHdRozVzK/t5q94zV4uusjXvB1MHiwYYvLZulg52Dw4OXgwdoEUwdH
16xglg5OD/4OTu7WavN3cGLEt0WwfLB5/WKO3EPb4PFgcnYPjg4urhDcHXzd
dsHmweO1C4YHTm+H4PRg8+AG4QNh3nYNJhAeb6fg9OAD9yyYv4O1q+ffyyWz
eeNK5vRWc3ZwYvdFfO+PY+b6QBwz9wfjmPg+FMfEd3IcE9OH47hLcFZwcd2C
kYOLg9ODr4MTg7WDu4MH61gwhwfLB6P3cOQJ/g727vFqM3fwZsT387I5PDgu
uD7YP5g0aqT4dwb/Nj4oeDz4OuYNcwV/dXiweTB4leDxYOeODo4OTu+4YPZg
8E4IHg9eDm7uQe1naZweBXN58Hj1wabCox4aXB/sHzGF/3qpeg2TN6d6DZPH
8bqawzols3yrObxXqtdweK9GTF+L4/Els38wdMP5DNf2ZSMzePB1sGE78zMk
58/5a4ObgumC44Pbe1s+PQtm9WDzegenB+P3ZXBixPrs4Otg8PoHRwdTd2nB
rBxcHEzcc/xMI2fBj8GJXRRMI3xdv+D34PQ2CDYPxm9wMHgwdecF7wenNzA4
QHjIr8tmBOH9Tgv2Dw5wE+rtSmbw4OJg52C3YOdg5GC6YOpg4WC94OmWRRyJ
PWzY0oj113E8N2xwZTcF8wbPdlXwcrBnc+J1eLM7SuYAVzOD2GDRviubgYOv
g++DvVsp+xXB6cH7LQ+ujFhfVjC3B79Hvr+JOd0STB2s3QPBhsGY3R7MHmze
ZsHjweCNCR4Plm988Htwd83l06xkjg7ODf4NtmpCyXwdLB5zhzuC/YKJg+1a
FnGBGYMf477hkvCD6XuHn58RM17nNe6fMeDGuA/GWc0usWesCQXzffB+MHhw
d/BgsHlwdzBjdxfM4cHI/RDcHfF6LHg5mLp7g6ODhfu5bCYPdm5qsHYwdbBy
MHypzp8cnB4MXqtg6uDrZhXMrMGeVYJvgb2ZGXwdTN2W8t+iZF7uqWDzYPxg
7r7iuea78eD94PRmBAcIm8f7dlnk9c6SubvVbB3c16YRF/irZhFHuK/NI+7N
4pj4tQg/GDn4OrgvGDBYL/gluDuYOrivOcHmwd29GVwc/NsfZfN8MHVweXCN
WzYwl8f45Oy34OuI++yCWT0Yv9eDwYOvezXYPHg8uD6YPdizd4K1g8d7N9g8
mDruExYLfmtiybwcfBwx2CNeWxzcHWwezN2f2neQ/dOCuTmYuo+D34PHq4k4
bRbbnjEWHFzHiNfWwfXB+BFLuC84rv++eGhkRosx9orziW/H8FsYfCAcYNM4
Dz/4Ohg8OLGlwdHB1MF9wZLBLy0pmNWDr6uqmMODqfslGDk4Olg8WMYuvN+C
u4OX+yn4Oji6v4MxIx/fBlMHa7cqODqYup11jzuVzFyt5jiJKzxdxvdNfNdf
MpcFT/dX8HhwfTQkgF2CtdsxGD/YvH+C/YPHWzuYNNizlcH7wf6RM7gv2DDY
OXg5OC6YOjg6WK+GRbN0cGjEDu7sxIgvXBh8GKzcyRH3vcPWI54VxoY/axw8
G9xdMTg62DnyfULMo3HFHB6sXX3wdbBq8HqweqfKJx88HgzenjEXzofdgysj
1tspDtuWzHPuFtwdTF234FJgJ+D1mpJD6Y2Cx4PB2yR4PFi+JkWze3B33AN8
18DY4JFGxf1dGK8xD1gv+C54Obi4oREPGLFLYr6Dw28vzW3Pkjm9HvH64IjF
RTEuTB3cHWwYbN2lEfe7S2b84P5g8GDtYMOaFc3ewebtEIwcLNx2wcjBy3UM
Rg6ODuYOTozYtQlOD+6ubTB4sHOFivk8+D3uc0zc/07B48HRdeZ34JJ5uRbB
B8L1we615/s7+d9TMlMHp7ZrMHjweHsWzdzBwsEDwghewWdKMHuwf+2C5YPx
Iy5jYx7kAJZpWoM1vN1tEcdxcQxbNz5yAEcHLwdDBXcHR3dHxH58nHNAcG7w
bx2LZuxg8GDo4OrubmBGDwaM2JUr5vao2YTNg9OD7+oWrB183UHB2sHXHRqs
HUxdp2D8YPMOD9YOvu7oYPDg63oHYwZ71qNozg6m7oRg5ODcjgseD14O9u0A
7adGnp6MGN1bMjsHi9dd+sCSObqLImarYzo9zoE3g3+D6YKbmxExIqYwXKv5
O/ZPRexmxGtjw8ZYMG9wa3BcMHjwbzBjPYtm7GDnYOvg6l6QfT3N//daf4/Q
Lzg9eLz1Kmbd4PROC2YPfu/sYPZg7Q4JLg6m7uhgwGC9BgZrB0c3OHg8WLvV
PByM1hHUiZTMzsHinaj9G3xWBMsHj3dp0WwjjN9FwebB9U2LMeC67iuZwYMd
6x8sH5weMX0vrkdc3o/jK4KRg5O5rGh+Dl4OdgZO7tOIKawZnBjcHVwcbBiM
HNwdbBgs3qLIwZjg3GDhYOtgveDtbgp2DhaO/HwQ87g2+Dq4vluCl4Od26Ri
Pg8e7/pg/+Duno65cP5VwezB5t0eDB7s3Pjg6GDqegRLBj92vPRxJXN0MHfn
ab+igfk1uLR/pCcUzS3C5hEv+K6fIr5wVvBhk0rm8eDpFsTrP0ZMf4lz7i6a
u4KRg6mDo1sVc4cLW83fsYcNg7n7PWL9ftgYC+4OdgtODB4PBg/2bP2imW1Y
7nuDx4PBg8ck3nxGTA0GD6bugWDw4OWaVczqweNNDo4OTu+pYO3g66YFLweD
91iwebBz8H3waeR1RvB48GzEAEYLXuv+kvk62LpZRbN4MHgweldqn+f7bWo3
SmbwZgYXB79HHBljNYvHHt6LmMJ/cQ3iAuvFMXGC+eIYNg+mDtYLdg8ujJjC
8sHswZvB3cHRwWjB0MHbbVRj/gvea+cac3NwX9znq8HUweYtDC4O/u2d4Ojg
4l4Pfg+OcXbRrB7M3pvBN8LatamYyYPN6xPcHXzdu8HXweDNCd4Prm9xsHbw
eB8HmwdTxz3DYa1m4ti3i/vfLl47XeOfVjKbR+xgwNpGTLeO4wdK5vfg8uDX
YLS4Z2K5fYy1pGhmDvYMpu827VvVmKmDc4MTWxp8GuwcTB/nEndYOFg72LBP
i2YD4QBh/+DxdohnpV3MqV3FLB18HewY3NhRMAnB2sHprQxmDzbvl+Dr4OX+
Cl4Opu7M4Ohg6n4Klg8Gj7jAVcFX/RMMHuwcTbPg6WDzzuV3tpKZ3gdL5nth
61YFpwePt5qr61qzhqvrVrOGq+MYLm8KP2MjPwfFa8T0kJjHk/XuczSxxhwd
nBusF4wcDB5cGazcIZEP2DxYO7i77YL1ImeNg7uDtWuYmpmDwVsWvCKM4o4V
c2ywdhsFFwf/tnZwdLBz9cHdwdcVg8eDwasEdwdrlw9mD05v/WDY4Ov6B4MH
z7ZJ8HWwczB0L2rfEw4hNWcHXzeoZE5vNZcHV9c34gg/d3rEDB7uzIhpv3it
a7zOOffWmvGC6SKmZ8c5sHkwiufUmFeEozu3xkwdHN15kY8zY9zJJTN1cHTw
dLB0F9SYoYOnI9awfmdH/uDr4OkGSF9cMl8HUze1ZL4Opu7xkrk4/s42rGS+
Di6Ov719rf1QnTu0ZF4O/u3ykvk6mLoRJfN1MHXwcTB3g+V/YcksIOzfNSWz
dTB1SZXjAOd2T63Zvc1gDOr0vqw1azdS/n8pB9/K/x/th9fY75KSOUDYP46x
67+q++vtD6v3o57TlxuZq7y6xhwd12TPsf5p9x9Pd22N+9Sxvybs99XaD9Zu
Uq3t8HIP1vMlvJ6hOIaj21L7kTXWxbBxTF+7cbqX+2vNzt0h/VCtWbufG5kN
5Cv4PWA/as3sNdDYN9VY0zcPzSUfqHevPa47Wbqh9K3S4zXmg7Ueq208Zzyb
D9W7bx0+E+QzudZcH5zi7TXufTdVPnXyGavjR6UfqTdPeKf8H641+1fI7M95
E2WfUms9pd498ji3VvvRNR6/Abxwrce5R/6P1ZoDvFv60VqzT3dJP1JrbvCP
Rt6vp/k8oXNTjTVBxw/Xu9ce406Xro/PnGn17p2Hz2pmnc/+imx315gzZEPT
A/Bp+a+t1+7j87OR2ULsnRTbl0o+vlfzmVZrLvGWsp89WMSHZX+x1gzefdJP
hP3JWnOF8IlP15oh3D+emYfifc17HO4Q5vCpevcuZA7Tw74f34dnfu4Za1KM
w/P2VIwDl8jc6Hm4a5Wfs4fjuds/NL3p5uWdX9jCB+Q/s9Y84YPSz4X9pbyf
MdjFMWU/M3CJ98vn2dB7wxuEz/t55wue8I28nwd4xcYwhLXmG1/I+9mGjZys
cZ6vNQ85s975JW4PyT4rzl2Q97PBuZNkfybOfSvv54pzp8g+O667KO/nB77x
67zvC740p/Hn1JpvnCr/l8KHWLwQufhI/o+HT17+c2vNOu6vvL9SMkP5ND9b
4jn4JO9nAJ/bys41nCT5fT5y8WqtGcde0q/UmseE9WuS+ZmYGfnFp5Psj2hu
L8c482rNQ/aO/M6KZ+DlvD8TyNdrca0+IE/1nj/P8r58t1trdvFRjfl6rbnH
z/OOIfrLvHOHz+PyeTNi9Zj0/Fozk3eUneuX4hrEin53y/N+TuAnX6r3Mw+H
+aTOfafW/OQT0m/Xmqv8Lu+con/IO+/4TJPPWzFOQeMsqDXb+XPezwy6S9H9
mqinmy7/d+NaT0m/V2sO82np92vNRv6dd67hMGcoV89E/uo1/sJac5hdZXu9
ZEYzlf2D8H+t3uPDKN5Zdi5gNVtlzh+s5oexvzDyCwPaU/rfvJ+ZNyN3CyLv
H4W+rMr5ejdy+ozmvCjG/zjsl1c5vu9FvC8PfYX2ucQ5gqucoXM/qTVTPVP6
87A3Spx3ONV7ys4jTOaz8vksdGf+vRs+i2P+wzR+kjgX8JxlxWFprdnIUuKc
wlimiXMKz/mcxvwi/GdJLwl7g8TPG3NbK3FOGed5+XwZ4/yR93uQfL0g+1cR
8xelv641C7px4rzAgm6QOL/wnOsmzjs+s+X/Tdg3TZxf+M+Zyu+zkeO1dC/L
Ypzusr1VMj+6juzLw//7WnObE6scE3jNodLtMucbXvQlXWtFrRnUb8MG/3hf
2XnE/lGMQzy/i3HuhGvK+zPqtcj1N/E8kNdlkfe5Gv+nWvOcmyfOL6xpq8T5
heGcI58fwn4A3+nUmk19sOz8cm7zxPnFvjKudRefGzr35xhn+8T55e8/r8r+
a63Z0Vekf6k1a7pF4vyit0qc35UxFnO+m58j8v+t1szqNonzi36n3jmF731N
PqtCt0+cX9jXN2T/s9YM6uvSf4R958Q5xb5b4tzBVR7C76Il86mHJf77FRzm
HonzCKc6uewcrYqc/hXx/7fW7Crs5Hxd65/w2YDf/WL8Dpnzit9Gsv8dY1J0
AZ/6XOQUPUF6lubzXDxP1Tlfa1aVY/53PEtv6VqNcmZKHyk7v+jOiXMBd/p8
lbnWF7R/U/41OXOt+ybOLyzr3onzjn0TzS2f872/Lf/GOY9zcOJcwKM2yHkO
jH1g4vzCu74r/7qcfQ5InGsY1wWy53L2uTvmQ57fkb02Z58DNf+GOc9nUb1z
CjN8sOzr5Mx2Hpk4j7Cy7+vcQs76A+lizkzsC4rZ85HL4xPHH8b1mMTPAz6V
nDlVuNPD5buwZEZ2c36Xy5mbfazsPMLKLtT49TnrJvxOmPOYpZx5W7hO8ggL
CwdbDg0He2LiXDNmdVyXXBND2Fdy+oh82ubMAZ6cOEfwseSsHDlcK/zhaT8J
+6faP1n2MwDL2itxDInVIs157RjnPekk53h+KL1u+H8ivWHODOqZiXMET3t6
4rzA2S6Wz3o587cfSa8f9lMTPxvYz0mcd8b5WD4bxDjnJ36WYHGbKW4bhf6s
3vOBy/1f4jzC5X6mczcJ/bn0pjlzubP5W1zk6eLE8YfRHZQ47/h8U+cYwqwe
Jd+PSuZ3W8Hq5szEPlV2HmF3v5D/5qFbyKdJjNk0Z4b3p8gj3C28bLPQcLaX
JH5OmsSz1Cxy3Tz0X5Gv5vGMHabrtsqZ6SVnLSKPz5adC3jav8NOj8clmlvL
nNndyxM//5w7NHFOsXfO/Pwx1y/l3zrGuSFxTonDV7JvkTO7u1S6Tc587/DE
OUVfnTin+LSIOTOXr+W/Zc5873WJc4r+VPaNI3c3J84pfO/X9bbD/S6XT7uc
Wd9l0luHvY18tgr/UYlzjc+Wsm+bMw+8Qv7b5MwSj038DKDHJc4RPnP4HTly
TF7gYmFiv9W52+fMDG/F92M5M8N3JH4G0M+VnXd8juXv6iUzxDvkzBTDtx6U
+TngeM/Mn++8z3eMa8EGt8+ZE4YHvidxfmGAO+TMCcMAH8nfQcNOXneO2E5M
nF/44e80551Ccw4+9L1sHuPzvL1Ydn7hh3+U/+4588APJs4vzPCkxPmFGf5e
PruE/0rpXcPeIubG8/lw4vwyzg/y2S3G+Ul6j/gsejxxvv7r86l47hn6+3rn
FPb4Z/nvFfoX6b1zZpufTZxTOOSnE+eU+ognEz8b+Pwl/4Ny5nK31Zgdw/8E
5eXLktnl5xLnEW55e/nsG/pXnbtPjPmbdKeceeajMucSnnm/2MPkvqwx50a+
ySOMMnxy59DtI6ddI7+/a8wDcmaSyWm3yPVLiXMKn9wl7PDAbLDB9L18IXFO
u0cuD4zcvlT288k8j6GGJcZ5I3FOicMfuu6BOTPMq6S75cw2v1J2TtEvJ84p
PvvHnGGq/5R/95xZ4nmJc4p+K3FO4Zz/ls/BoRckzils846K7SGhf613TmGh
/5H/oaHfT5xfuOh/ZT8s9KLEuYC15o9nh4c+OmfGuVvEGV4ZVvlV/s0UOT5J
+29KZqk/SZxf2LmPEj8PcNrzys4vHHW1xj8qdI/MOeYaHTTnI8K/sXxOzplJ
PiauCxfdUPYeOTPGx+bMS8NIk8eTIobHhYaXJpcnR36PDE3fzs8TPxtw1A00
5vGhf0gc276Rlx7xXM0vO4+w0DXyPzH014lzzXy+TPw8wGMvT5xH+OpG8j8p
9HeJ3y/c1/FwxeG/VUE/a3PmVGvlf0rMYVPZ++bM9+6q+PTMubbu73rnFB77
t8R5hMfO69w+OfPYddK9w56T7hX+acGxhbf8O3HM4cNfUx7nRS57av9tybz4
v4l5SPjtPxI/G4z/Vtl5hK9ONP5poU/N/NzAde+ueZ4a458eNthkcgo/DTt9
RmjY7AYF5wI+vF/OzDacdkHjnxV28ts/8k4uL4hc9w9Nf84zwwfbnvWOIfNv
VHDM4bozjXlezpx2ruDnCm783bLzC7veA74r/IvyPyfsx8bceCaTgvPLOKl8
zo1x6vPOKXEuFZxT2O+S7P1Dr1VwTuHA99Y8LwjdsOR8wXuX5f+/0OsWnFNY
8YrsA0JvUHDeYcXPzhxrOPCLYw+n3FHjD8qZ/X6Df/tGjvto/0PJ3PlaGnNg
jNNJ/hfGs/d+2fmFA19bPheF3rjg/DLmBrJfEc8wOYURhw9vVXBMroucDo9c
XxL6xsjXiMj1paHhxsnlVZHHm0LTa3Tzgp8HGPKfE3/u8b4YHNeFRT+F7+5z
Zsg/LDt3cOnrap7DQq8jPSTGWU/6spjnFgU/G3Dm68t+eejmBT8PjNmHeuE6
MznbFJxTmPOPpBfkzNclJecOLn37gvMLf95ZsR0eeiONMyJ8di44/rDoTWUf
lTP7vYn01WHvonOvyZl731T263Lm0vcoOF/w6m8qp/Mjr+0Lfk5g2k+T7ZeS
6wd2K/h5YJyPys4p43TV+NfGOBtr/Kvi3AGZnye495Gxh9Heu+AYwp/Do8Ol
07+0ic69Kezk+vbIC/kdF3m/MTTn3RA+8O0HFvwswZ/vW3AeqaHYXGPemjMb
T67h3WHdN5P9lpyZ9gMKzhdx6637ujnO7Vxwfjn3+jgX7v2zsp+HO+PZGh/P
XjONOTrmwP08GvNsLvuYnBn1wwrOIzx8ueQ8wsO3lM/tOfPwLaRvC/uBiu3Y
8L80cxxh0Y8pOL8w88cXnF+Y+YPkPz702/wtIfJ3ZMF5YfwTC84XLP0h8r8j
9BdlPxuw8a00h3ExfmvpCWG/M64Pf72n7K/lzEjflXM9Czz8xJzrvaltuT70
w5GvqRHD+REf+qbenTNLPz/y+0jk9GDN88qI28kFPxvw86cX/JzDt2+hOdyX
M6/eV/O/N2euvlfBeUR/VXau8Wkj/3tinC2lJ+XMt59a8HOCbst3CjH+mQXn
FCZ/K76/CL219IM58/PnF5wjWP31S84dvP02fGeRM1ffju9Hwn6YYv5Q+F9d
8LWoFxhUcMxh+C8uOI+w+kfwfVboBcrnO9pW8TlR8DPD+JcUnEdqBI7iu4/Q
35SdO7j9bfmOI8bfju9Wwj48c17h6h+LPVw5uZkTeXk8Z6Yfzv/bsNOvlbzP
jlyTx5fiGXgiNL7Twod6gbM1979LrmEYWnAu4PB31Hyezpn5/7bsnMLzX15w
TmH4t5fPk+F/hnymh31izI1ag+EF55RxdpD/UzHOOQW/B8lXe76ziJh34DuL
nGsobi44L/D/NxScX+oRris47/jsJP9nwz6q4PzC/zcpOb/UBRyj+M+McXbm
e42w78J3FuF/At9x5Mzkv8ffriIu4wrONXUEu/K9Rs51B8fxnVfYxxacR+x3
FJxrxjlPY1SXXSfQL54R6me+LzvX1CNcnznH1CC8nHNtAvw/+aUOAW6evC6K
3M0JO/UCc3OuHaCW4Yk4d0Xk94N4Nnbj79JxLcZlHPrNTio4v3xWnKX5vJpz
HcHu8n8l57qDiQXnF31PwfnF56WYL/z+HvKfl3PdwU9l5xf9YME5pdZgL/m8
HvrhgvNLbcLesr8R+pGC80hdw+MF54s6go7yeSvnOoUeivmbYd9H9vnh/3LB
n3tw+E8WnFNqE54uOF/UIHSS/zuhny04d9Q1tCz5eWD8D5Sj9yNnF2jfqOza
hucKfjaoj9hX47wd4/fku6Sw/1J2nKmP2E8+74Ump99Gjt7Pue6BOoBFYf+v
TiHn2oNc5HRF5HdhaGocPggf6gtOrvfvJ0sjl99FbvfXdT/Kua7hpYJzSu3D
CwXn9Pu4Hv70zu0s/w/DPjpzXpnfqrJzyjjnSi+OcbrI/+OI87yCc0odxAGy
fxL6jYJzSp1FV9k/Df1WwfmiJqKb7J+FXlBwTqmP6K37+jz0ViXnnZqFTwqO
M7UPp/G9Q+juGmdJzrUJiwrOL3UTB8n+ZegDpb+IcU7lO6+cf69bxN8yI8cD
6Ztadq3F+wXnlzG/Lvh+qUf4s+ycwsN/WXBMqHeYkDmv1HF8E/vdIl/UYFB/
sSz0vpFTai7I4/LQneJ5oIaFXB+mOa+M6x4s/XVcl1oLai7ox/t5wbmjtuIQ
+XwbekWMg29/zfm7mOe/ZT8b1F8cKv/vQ7eJMf97Dhv7dwB+viwvOKfUWfSU
f12d2f7vCs4ptQ9HyP5j6COlf8q5XmOHkmNODcXPBeeUWo8fCs47PsfLv7rO
dQpHSf8S/kdL/5pzTccfBeeRGo1jZP8t9BnK488x5plwzjnXaCxWHj+MXF6k
fbHs2o/fCn5OGPPfgp8faj3O5juO0NUVx5n6kb9zrmGhdmNS5ryWI7ZrR77+
DBs1DX/lXL9xSuSUc/eNvGOnpuPvgp895vlPjEOdSKOKc0EcjtM9/ptznQiv
UUtC79/Oof/Lf9G5xudY+f8Rcx4ANFTn2pBGRecdnSv6WaLW4wT5N6izTmT/
Ief6kRNlr6mzTovOKTUjPWRvWGddKjq/1IWdJHujOuu1is4FdTHnwhfVWV+i
+yqVXR+yadFxpgZk3aLzC+t7isbJ1VlvUHR+ecZ2Lfl5oN5k46LzSy3J+Xwv
Vmf9MX97jhyfrHFq6+y/Yd6/o/LvuAv4jqPO1+0te6nONR29pAt1rhmZmjmX
1IAU67wfGDmlVoQ6kbTOmvoRno1Wkeuszpr6lMPzjifvl9qK89I88tcm8jks
NH2GNy8611vE89A6nrfmReeRuo8LdW/l0EnF7xf+rVpfZ3/G43dh/p3zdLXr
evm3Db+fb1F0Tqk9KVX871xqK07T6+vUuQakr/Ta4bNV0bnGvk3R+aXOZZ+S
Y0udS/ui80Wtyqca85PI8SC+V6pzjck5GrN5XOtM6Q3rXJ8yQD7r1bmOpp/s
G8Q4uxWdU849Q/b141o7F/2Zw7mny75uzGf7op8xxhmq669ddm0MMdktcrFZ
nWtSqB/ZPOx3Rr52jTxOz5xv6mg2jT11MGfpWpvUuQanM3VSdeZSBus6zepc
Y1Ks+PnBZ4+inzHqbi7i+5fQ+xadO/z3LvrZ2yPmQe0M/ZDP1rWahv2ysA+L
5416G2ptzpVPi5hDkzrXkFA/cmDReaQW5oCi80iNzHnybxn6fOlW4XNY0fGn
LuZy6sPKrm8ZrDm3CfsF8t+izjU7l/I9UZ3rYo4pOo/UxRxZdO6oqTm46LxQ
g/M/nbtl2LuUnEfGOb7oZ4NxBsinbYzTX7p1nPs53wlELk8sOobU5gzlO47Q
szLnibqb7epc/0ItTKXifFGDs028Pi2eAXyoSxqoa7ULn20jhtTObF/nmhpq
c3oVnV/qg+6htqXONQgnF50j6muGaH47hg/5OyTyOUjj7xA+m8eYPHvPhQ89
nJtETpnPuhW/R6jBuVDntg99ZtH5ogbn9KLzSM3OxfLZKfRg6Z3D5/yic0dd
zGVlz/m/+hfFbdewXyr/3epcy3MF3x/VuWZnUNG5oO7mf0Xnjrqec4rOC3U6
Q3Tu7mE/uORng3EuLvrZYJyh8tkjxrlEepc4d4nu8Yt4zoZTg1B2LRC56xnx
71jnehtqcPYNOzU461ecL2qIXs6cV+qA9ok99SvDdK29w+ci6Q51rmMip73i
2bhM9v3qXAd0SdHPEjVH1C5Sw0gP4cuLzilx6xTn8vrQonPKucP5LibOnRXn
ktuNK84ddT3Di54D9TuH17mehpqPyzWH/cPnSukD6lwfdHPROaI+6ArZu8S5
1xWdX+qDRsjerc51RlcX/Qxw7nDZu4bPUSXnl/qsa2Q/uM51Q6cW/blBTK6W
/aA61zGNK/oZoJ7oKtm7x7lji84j516l+z0w5jaq6GeAc69UDo+J98UNReea
uS3le6TI8RF1rv9ZFflFL4r8DohcX8d3H3WuS7pWczisznVMb2bOMbHbtOL8
Yr+G78VizkfGONQNTSw6v9QlXS3/zcqugyKvgyKP12n8o8OH/A6MZ+zP8KEH
9R1F55f5HBU+vL5tPJ/UgjWtOI/UGT3I31Trorai6JxSczSp6DxSl3S9fI4L
fYP08eHzSNE5pf5otOyn17m+5ibpE8N+ve63R53rlW6V/ZQ61yU9WXQeqWk6
seTcUQv2cNHPA7VRN8v/pLA/XnQeGefpop8NxrlFPifHODdKnxDnPlt0nKld
upHvqkKTU2qQqD/qU+daKGpxTg07tUjPFZ1TaqOaV5xT6qFGafzeoW/WmL3C
56Win6XrI6fXxDNDLRM1TfS1/lrjfBV5Pa3O9VC8/kLROSVufeNc6qTI5XWR
u+v4jC27RuuoOJdn5oPM70/u4Sq9fkbM4dPM90YN0RjNuV+d65teLjqP1EzN
KzqP1EbdLp+z61wPdZv0WWEfK31m+H9UdAypdXqr6PxSY7Wg6PxSJ3WrYnJu
6N4l545aqjeKzgvjv190vqjVukPjnx96UdHPBnVV42Q/J8afIN0/7KP5Tirm
8GXR90t901jZ/1fnOqYbFKvWZddELeP7w4jdJ0XnC5+BERvqCe7U+APqXJO1
RcX5RbeWPjbixrNBDRUs/udFP+fUXl1U53oraqkurHP9FLVXfUPzLJ0WPuR0
UIxDjRXnUIdFD+0NQvM8TNR8Lo7xr9W8B8c9wkXQ560lfwuVz6V1riG6S/qS
OtdnfV10vrAvLzqP1GfdK5+hda7PapB6fGqRfig6ztRh/Vx07qjb+qPomFO3
NUnnXl7nuq3bFefLwuce2YfE+P2U6/PC5z7Zh8WY90tfUef6rN+KzjX6u6Kf
N+bzAP/GiWv9XXR+qf+6us41XtR6fJ05ZxwTQ+qvqL26mRr0smu6JmhuI+pc
L7ZNxTnlM+3fop8N7A/pWiPj3q+JcajnIgdPRB7H811YzIH8ToucHh4+R0Su
H488Xhc+vL5C110ez9+14UNdWKPUeaQW7Hq9dn3ogYrbD7q3udK51DmlhmuH
inNKXdjjmvOYOteFTZa+Iexp6pxSF5akzgV1YQ/L58YYZ4r0TWGfKn1z+D8m
PbrONWLnl5xfasTWSp1f6s4ekc8tda4vm6iY3Br2Uur8Yl83dX4Z51H5j4px
Rub93uHnywap88v8t674s4hnddPU+aLu7Du++41c3s13UnWuUxsl205l16qt
zPxMUJu2WeqfWdQ93Uv9Y4yzcercce4rjezbN3L0WuSCWjFqxqhBa19xzdsr
MSa1VPvX+NnAh5qyASXXWZGj1xu5fo2aNfI7L56f+Y08PvVr88KP8XlW3ohn
4yKN87PGeSd858c4TVM/k9SO4ftWjLNLxXVl+O9Tce3Z0kauiVugfX/5PCz9
fiPXvO1Rcc3bwjjGTh1cy9TPA3VwzVM/e9TTDYZNzuy/e8XPFeetgiFv5Fq5
1qmfHzTX5Dzq77ZI/SxRm3apxvlT53wk/Xkj18RdAi9e8vPA8Tapnzdq6D5p
5Hq7i+Wzdernijq7G5TnSfXWe1Zc/8aY1Ot9pf0Q+V9BDw9dawnvkdTPCXV8
1Pcx50HyuYpeNJljxXm8Tk3fpzE/6vX2rriuj3Hapn7OmdN2qd9r1PftVXF9
IPNdyd+14lncNXX9GD3xd0z97FHrd618KWRbwWdXaHrr71txvR+9+ztWXB+I
D7WGy2JuT5dcF0df++kl1wHiT30e/fFX1/TRH79N1PShqeO7jphE/SB1efS+
X12jR097aqqo50OnUY/ImK2lO6Su3+O6NZlr9jTFqi0y11fQL3tGyfVv9M1/
puS6PPrp75S6Ng+9c+raP3xmllxTR3yeLbn+jj77u6Su00NPK/neiQE1d/T5
30HXfb7kOjf66e+WuqaOPvvU09FXvH3Vmpq69atcS/dnaOr7GIe6v91T1+Yx
zqySa+sYZ63MNXIby2e/imvk6Nf/Qsk1dOjZJdet0VufOjb66VPHRL0a/fQ7
R10aPfSpU5sc9jbhgz+xpc6JXvB9wp8e+12ohUxdG0af/fUz162h90xdq0av
/Mkx/v7y3yt1zRu99TfMXAuH3jt1/Rt99qlTY3xyvVHmejbs+6SuT6OP/8aZ
69DQ+6auK6OHPjVr9PMn/ptmrivDTm0g/fYPl71j6ro1evFvkrluDU0NHT7k
ZYPMtV7Mv0vFdWj03ycOpYgbdWP0ze8lfUDF9WP0/Z8b9Wn4v1xyvRl2au6Y
26FVridjnN6h6yMvnSuuXSRfL0TMiRu1Y5WI+X6p68RYv6FT6hqztcIfn1Pl
s1nmGjPs+6eu9aLPfufU9Wb03988c50e4zTNXFeGvVnmmjH8W2SuF6L3PfVf
9N4/r8q1ZqwFcA5cd+a6Mnr3Uzu2ftxjl9R1aNgPSF0zxjjU42wQubgm3uM8
e11T15LRx79bxXVi9O6nNqtJxOrAimu3Ngk7PfQvp7ar5Dox7NR7bRp5WRDn
XlblWivsw6RbZq5V41rvxTg8291T13TxWdE6c00Xaw9QV7V54zX1YWjqh7ql
rgfDZ17JdWjMuU3mmjF68R+YugYM/Vb8XDxfYxyUuo6LHv0Hp67jop8+dVut
IrZtM9eAYaeGC/vIKtdt0bf/BumtMtdo0XP/6NT1PPSXPzR1jRY9/Q+quP6K
Hv3USNEfnxqZN0uus6Iv//yS67jwoc6rdeT64Irrr/DZOnNt2BYxzlYRz69C
U+9zSOpaMubzTVyL+KPpg09ty3aZa5zorX9E6voo9JGp66Dop08d1jYR520y
11axHsDhqeu16K1/WOq6LOw7Zq5f4t63z1w3xTjUQNHzf0rUTrWLZ4b6Kfr5
T65ybVSHiOdRqeuyWA+AWq32EXPOZT53S++QueYKn2NS11PRg7595ropNPU4
+8V1D6u49ok+/odWXE9Ff/9dMtcC0e/+nZLrqbBTz0T/fepfqHmiTzd1MQtK
rpXaNXx2i5j/Hf7kdOfMNU701j82dV0TffmpK6Jv/wtRY7RH5IL6pj3jvv4O
OzU1x6WuoWKcnTLXRDHOtpnr4oj/8anroJj/lplrFHmeqXWiV/88anxS1zjR
r3/XzDVRrAGwW+a6Kew9Utcs0bufehzi9nqVa806RY5OSF0Txbm7Z65Zwp+a
oa4RnyMrrkei1/8RFdcv0et/j8z1TvT0f7/kuiPsJ6Wuj8KexTjUqnxQcm0D
44zP+9+D/Nufa9GXn7oV6o3o47+63oi+/dSvUKPUPeK8V+a6I/rv90xdL0SP
/lNS1xrRu//k1PVI+HTJXH9Cr/l9Mtca4d8xcw0SPf17p64joj/+vpnri9B7
Z647Ykxqiw6P+FOTQm//5VWuJzoiYtsrdc0SY/ZJXV9Er/9OmWuH0KemrjWi
7z+1O8dGfI6uuI7o6LDTi5+6iQ9Lrv/BvrjkOhz6/jeNc6nXOKbi+iLs1Fgx
z2+qXFtzXMT2tNR1O8SBup4TGq+pDTo+Yt489OraIHyoI9kvcx0Uc94/c40Q
awb0TV07hC5H7njOT09d/0Mf/zNS1wXRu79b5nohev13zVzng/2AzHVB+PdL
XQuEDzU7vSLO1P70jPui9gpdW+16H3zq4HJT1wKxNgB1M/TWp7bik5Jrcujp
3z1zbQ/rAZyVuv4HfVzF9Tn4HJi5FohxPi25Poc1AI6vuOYHXYrnls+TDnEt
ckG9y+mRu3NS18bQW586mzMitodkrp9Zbae3P3UbZ6euz6G//8GZ63zQ1O/0
i1x0iPGpDTk3db0NffypnTkvYnJ+6rodev2fl7rehp7+h2au4cH/sMw1Odh3
irlRM0I9DuM0lz48c60g41BHc37EuX/q2hvWIDkic70N+sSKa2no+39B6poZ
1gY4MnN9DvqLkmts8KEOhn791Cx8XXJ9BX3qu4ad3FHvMiju9+jM9TD066fG
hR7+O4cPvfKpm+hRcX3OgPC5MO6ra4xDzcX/UtfbMA61MxdF/JeUXM/DuQNS
18PQ3/+YzDUwaOpT6NW/b7XrWYZGrKhVwc7f3walro1hDYALU9cd0ff/+My1
MejjMtfh4EO9CP304fMvSl3rwloCX5Vco0If/4Gpa3Xo3X9i5noV1hU4peIa
lf/6+2eujeHckyuudeHcYzPX53DuxalrZjiX2hzmv0+1a0eGRy56V1wjQb97
alNGRNzQ9PdfXZtCb39qGk7KXE9Cf39qVa5uvKaW5arICzUd9OE/BZY+dV0K
/fcvTV0nQ3//UzLXoqCHpK5Fodf/4NR1L4w/NHW9DX3/e2WugUFTh8JaTidx
3cy1LowPb39D3CO1JzdG7n4rmUWmr3efzLUlrD3QO3PdCOsEDEtdl4K+LHW9
Cj4rSq4bIT7LS645Yc2AXhXXoqB7RNyo+6BehJ7+1BFcnro+hH791H+MiXhS
/zE6/M8PfX7Y8ekf9lHxnFB7MrbxmpoSNPUHfTPXjTD+FanrQFhj4LTMdSPo
0zPXgdD3f3jq2hJ6mo9IXQdC339qPSZEPPtlrgnBfkbmmhz84U/oUT+u2nUf
rAswhLqH1PUerAdwZuZ6D/TVqWs26OlPXQnjXyL/Uyuu62BtgO9LriNC9624
foN1AqgluTOen5Ul141gp36Cnv6w+sNDE+drUtdL0Jef+oz7Ip7nZK6LWG2n
7//qWg36/K+u17i/8Zp6jkkR/7My15Aw/2tT12awTkD/zDUV9PEfmboGgz7+
16Wu02ANgHMz15bgf17mmg3sw2Nu1Bdcn7ouhXHOz1xnxThXpq7VIV/UZUyJ
uFErMTVifmPqugvWGLghdS0E6wRQr4HPHTwnmWs2sJ9RcT0GawOcXnGtBesH
/C9zrQXj/FRynQb2n0uuqcCfGorpESvqIejvT60B9RD0/Z8aelrkZVzYucfb
wj4lahcY59HQT0YuemauPeO9f1Pq2gzWpbg5de0E6w1cnJnRp//+LalrLVh7
ACYINugZjXNh5voK7BdlrtNgnYBRqTkizr01de0K9oGZ6ze4FrUSM+PZPrNi
ppnPisGZ6x9YM4C6hucittRNoJ+VHp26pgKfQZlrOZjzJZnrJVhjYEzqOgf0
WRXXOdDr//eSay3Q1C6wVgd8+9TQU0KzBgCsO/UKsIxwjNQpzG28pv5jTuTl
kfCfGuw8/efhrMemrklgPYDbUtcz0HN/aOaaBPTtqWsV6OnPmIwPmz8uda0C
awZclrlWAT0+da0C/f2HZK6FYPzLM3Pw2KlfYH2BhdWuX3g98nVOxYw+6w1Q
X/BGxPPPkmsMsN+RuraB9QYmpK4rYF2BKzPXLaCvyFzPgM+wzDUbzP/cimsP
6ONPHN6NuFEfwLoC8OSw/KwrAE/+V8n1CfjPDju5oJ6CuX1Y7ToDxvk29ILI
C/UF70Ws7kxdP8B6ACMy1xWgJ6auE2C9gasy1w+g70pdk8BaDldnrtNA3526
foB1F67JXBuAvid1LQFrGJxfMYtPz/1/S2b00dQXLI6YUxfA2gGrql1H8FHc
y7WZaw8Y57rMrD9rD9yXuh6ANQZGZq4TQFOPwJi/6dyHUjPu9OvvXzGLz3oD
D6Su1aEXPyw/awDAe38QmjijWasAbnxhaHKBZp2A1Sz/kogzmvUC4MFvyczT
c12ayVFjwHVvyMzxs2bA/anZfdZUuDFzPQAa5v/LeC/clJnjZ54Ppub4WVfg
5swcP3pS6poBxoRRpQc6nCp8PmsBrA2nkZmlprc7PD9rB6zbwKz+ioj5rZl5
fdYM+F/F/D1rEjycmt1nHYLJqfl7fO7IXKdHH/yashl9/BuWzbKzxgC8PH35
Ya1XhCbOozLXADAmDP6PEWc06wesZuR/ijgPqJjpZ0zsrAUANw1X/3PEfEpq
np71Bm7PzMGz3sDU1Fw+6wQ8lpqJZ22AsZnrFrDflpmnZ12BR1Pz9Jz7SGrm
HvuKmCd8+LjMPD3jTEvNuxMH2PU/I7Zw9X9E/OHt0ds1MA+Pzw7SYzLXCTDn
8ZkZetYeeDw1W48eVDEfz9oDtWWz+OgLK2bTWcMgVzYHj4ZzZ10B+Of/FiGu
dfzRrNMAO10dulXoBrVr2HY08b87M2tOn/2nU7PmrAfwRGrenfUG7szM4qOf
TM2184wxDusOwE1PT83Ts2bAXZm5dvRTqZldxoelx79NcNb06ofbvSczs851
YbqzuC+YdtYvIJ6w66xBcGgDc+ZoYvtMapadNQbuzcyyo2ekZtlZV+C+zFw4
mpqX5fG5AUvP+AdrnMEVc96sW1Aom0dHV2I+cMgXV4J3j3my9gAs8dqhO4Xm
vQmHnJTNwePPWtX02du+ymx5OeL2efTLhbN4IDNHzpoB92fmy1mHYGZqjh/7
c6n5ctYkeCgzR87aA3NTc8b0nX8+NVPO+iIw5KyncJau9WLqGgPWDIAPXz/i
CVu+XsThwczMOuPDe+NzjuyTM7PpjPlwZo6cdQheSM2Xo2elZtyZz5TMTDnX
urRiTp31CeCym0R8WodezWuzFgB8bn3ZvDhrBsB9bxLxR7NWAexxy7DDGD+e
mavm3uG9N4vnao7mc2reawNkZfPxzOGl1DXJrB/wWGaGG5/Zqfl11gN4lN+Z
i/YZUjHLznweycyO49M65sMz8HJq5pt1C57JzArTTx+mmnUNrm1gprpl5ALG
u1XE9tXUDDfrB7ySmttmvQE4bXxGBrO8dcTqycw8N/6Vstlo1iS4rGKumnUL
1iqbvUY/kZnzZky47LYRNzRrAMDQ7haa2A6rmPlmzN3iuqt5atYXgMn9PDV7
Rx/w11Lz6PQWnJeat2adAHjsdpHTpzKz2tjfSM1Ps8bA66nZa2L1dGYWnHGm
ZebjieeMzBw2/jMzc9KsHwBHzboDkxuYc2Y9ggeln83MTLNuATz2jhH/+alZ
bexvpmapGQfWun3E+a3U/DRrFTyXmatGX1Exz816BldWzDqzPsF6ZTPTaDho
1gyAPYZNZk0C+FXsrCsAK9s9fOByYWC7hv2Q8CfOsNB7RJzfTs09s6bC85n5
afTBMSa5eyEzh8oaAwtSc7qsQ/BiZr4ZzfiMCVf7bmrWmXUIZmfmodHvpeae
WT9gTmZ2mTUD4I1ZF+AVfndKzSKzJgFc9L4Rc9jmTpGL91MzzZwLF419nuzv
pOawmefczHwz4/SMOMCLblQ2i8yaBBuWzROzhsGIivlm9FUVc8n4vJSZpe4Y
4xwQsT0lNBzsusG7kztiztoqq9lk1i+AY30lM6PM2gYwyQfWrmGQu0UeF6Zm
nfGZl5kVZh2CVzNzyawrsCg1i4z+MDVzjM/i1FwyaxJ8nJoVZu0B+OTDIrav
Z+Z9WfPgo9T8MRo+GZ+v5PNaZnaZcWCGD4/Ywhijv2lg/r1tPIdvZGaOudb8
zFwy6xzA9rI2AKzmpmWzuaxhMDDs5OLairlh1i2AL2ZNAtjRAaGJbZOyeWJ8
PknNRh8Z47AOAYzo25mZXdYS+DQ1K8zaA3DBrHfwVzDCx0Ve4I2Pj7xcUzFz
zNw+S81vMc5bmesHGOedzHwwn0VfpOaAWcNgQWZmF70kNYPLmgTvZuaD0bC7
p0Rsv0zN7LI+AXwv6xrU1pgZxqdRjRnR88L+XmbeF//3M3O9rEkwsmIuljUM
mpbN7KLhintGjpqVzciy5gFsL+sNwGReE5o4L03NJTMmdtYqgNW8NjS5Q7M+
AXzmoswcLWsPwOeypgC/V3yTmpdlvQGY3jMi5gsz88GsH/B1ah6Xc79KzUz/
t65AxWwx8/wwM5vLOP99j6Z9c43/UWbulrUNFmdmalnDYFlqZhe9PDXLe07M
7fR4NmB0z43Ywtaim8IrpsHg8hxkZnDR36bB3fK8ZWZ/0TdWzNeyZkDLYGrR
N1XM0bJuQauy+WM0rCvrCsBJTghN/D/PzKrSB39lap6VtQTgZFmfYDUbOyhi
jub3tw4xDuscwGR+l5qXZZ2DzzIzwejvU3OxF8eYAyOn8JhXxny+yMzIct0t
yuZEWW9gSWY+lfUMfkzNzrJWwZeZeVk0jCtrHOxVY252SMQTVpb1CPapMe86
NHLHdVknAP7wh9TsLOP/nJp/Zc2DrzLzr+hbKmZbmc9PqTla1lG4tWJen/UP
tiybi0U/FvcFi7g0M7+L/9vx+zBsz7SYA3F7omQGiz71MK0jIuZo1imAW/wl
NS/LGgbLMvOprDHwTWaeFTss8VWRlykl84j03P8tNYfKWgW/p+ZQWcNgRWZu
Fb0qNZPKGga/pmZbGR/ulLUPTqwxj3p9xBm+lHUNTpJenpl5ZXwY1Bsi5n+k
ZltZR+G7zOwpGpaTtQdgMr/PzImyFsK8sBO30RXzpqyF8FBwuayF0K5s9hS9
ddncKj7fZmZhR8Y4rGcAz/lTZs6SdQvgVlgXAHYF5pN1Ds4LPSqehzfCDiP6
Z2rel7mNqZgXZRwY0TGr85KZ6STOYytmOFnb4NfMvCb6kZI5TtYP+D0zr4l+
NFhN1jz4IzP7uHr9A9Y7WM1k3hHxh5lk7QN4zutL7uXepMr93NGbSf+VmZtk
XYTbKmYvWV/hn8yMJhr+c0LkbpeyuUmevWl596LfFF4uNOM/FpwnYz6bupaY
f6PBLtJ3vpV8nsq7J/y2wUbSm751MHjoNsFKTQo9OTTc1BN593WHl3sxdFsY
rbx7yLeN98uIyMuDcV3Gn5t3b/ltpKfn3dsc/Upo5nNrrHewFZxVzHM76afz
7jOPnh+af6veHP3q21X530PUNbPm2oy8+8nz/j255JqU7/R5Pjt61B8m+7N5
97GHwXs8+tLvCHOVt8b+Qfh0gJ2Lvus7E/N694TfNdg8ervvV+X7RXfCHv3S
udYNJfeB3x173uPsJD2j3v3kd6tyj3h8WDtgVt7j7yL9Wd4+nDsz7773zOfD
0DtF7p6KOXyTdz/8g6RfDd1d+vW8e7lj/yrvfu/Yv8i7V/wB0nPy7hWPnh32
LtK/5n0vcHTv5h1DuDsYRfrgww3Oijl0jmfm6dA/5t0HHv/v8+4Pfwg8WOiD
pd8JH+wrYp7Yb491B7pKL8y7tzZzqEvcI/1MmKW8e4wfKf17+BwhvTjs6I/z
7hWPz8vR8/8Y6SV59zCHtXux3n3gj5W+seQ+8MfFPdLPvXeVuT56wcP70Rse
H/r8z411B46K5wGfntLVicdkHPjAebVrOMx5Mc6nec/n6Cpzhlyrj3RN4rn1
lV6ad793dG3ifu/9pFfm3af9LOmJsRbAadLL8o4PPoXE/d7xmRC94s+Q/jZv
OzH8Ke/e72dLr5O4Nz483kfRH/tx6XnRt/9c6VV592bHp5z4XBjCOdFXH58s
8dwY85e8z8VnbKw1cKD0eonHOZ/Pw7x7v6PnRw//AdJvRN/+C6QBurH/j2e7
3v3YB1a5Rzv92+nVv0niXuI3Rb7o8z404k/fdhjCxol7p19ZZVaQXu1wel+H
DwzhZonHHxR5+TjsX8WYjNM0cf92xmkY+grpm0qeD+dOij78w6Xvjf7tV0lv
m7iP+kjpSujrpNdO3LMde+vEPeGvkd4ycZ/2a6XrE/dpRxfDjs8/eceqP89n
9Pa/XnqjxL3Wb5RumXgOV0uvn7hPOyziLuFD3F6Pvu6c2yF8ODcf8+HcHRP7
cO670Xv/Zj4/o9/+rdI7JO7fDlPXJLH9Fj63S+7BPrrKbCE93OEJ36p3X/dR
Ve7Pjs+YyAs+8Id7JfYZHbmgV/uEKvOE9GSHM3woerBPkt4w8XNFTFok7rV+
j/R+iX3ul26WuO86XOLD0W//3ng2Vsbc9gkfzv2g3j3Jp1WZmfwu5rZ/4n7v
D/C8Re/0h/nsqncc0Ecktk+Rbpe4Z/uD0tsl7uv+kPQhoYlb9/DB3ibGZ847
Je7BzjiLo7/9o9JtE/d7Zw7HJu61/oj0nonfy49JHxXnTpXePfG5+HSNc5nP
rnEuPlvH88bzeVLie3+Cz5PEPYGL1WYa6b0OG0mPZno1PxnxwT4zcl0dPnBi
9F6Hi7u15B7aC6Q7Ju67DtPYKXEf9ReluyXuhf6ydJ/EvdbnSj8e/epnV5mZ
ZPxZ0o9GP/Y50qfEmIzTN3G/dMbpEnpuPD8N4twz4lqvSB+UuB87ekDiHulv
SB8dGr7xuMT9z7Gfm7gH+388ZPTwf036w+i1jj48sR0f+oZz7/SuvzDGmS/9
Sb17pL8jfVbM4VXpHol7nr8lPSSxD3E7IXE/ds5dEv3z35Y+NObDuV9Ez/w3
pS9IPB/mT+7osU5/9dsS9/r+NuJJX3U4zGahYSbhIemrDhvZO3Ff9M+keybu
i/5p5Het8L8xcS90GMWnYx2Bz6WvTNx3/Uvp0xL3QkePCL1UeliMyfjXJO6R
/pX02Yl7oaNHhv5aenr0cl8ifV5cF3v/xD3SmQOsIH29YREHJu5/vlz68+id
vozPluiTj741sR2fwYn7nxOfiyJWK6RHxzjophFP4rYsetp/V2X2kj7p8JCj
Su5t/qP00nr3Qv9Benn0yV8pfWdiOz6XJrZ/H+MzDr3W6Y3OOD9FjprH+OSo
RdwjPYroX0RPqisS90j/V/bLEvc/h5+8KzT2WdEnvwrOJ3E/85rgCenBDTd4
f9gb8h134v7njehTF73lc3x3nHgtgMYwPIn7nOMzM/qoN5CeEnZ8ro1xGPOW
xOPAbT4a46DvS3wu8/km+p9zrScSazjMb+vd3zuT/jH6z6fSzye218PhJO6F
noexSdwjPZH+IXrgF6SfCR/sdyfuJQ4PObrk3ub1wU/SrxwOc0zinurMAYaT
/uawmjtF3PChDzrn0t++Q5yLz/Q4l/m0j3Ppi/5iXHdj6XsT9zxHjym55/ZW
0nMT9yTfDI4let1vIj0jcT/wVrAc0be8ifRriXuSN5V+JXEP882lHwjNOJPD
B/vUxH3R8X8qce9xeM5fohd9C+m3E/c2h/l8LHQz6WmJfbDPj3Gwv5e4tznj
rIw+54xzS8k/O/j58kFcq1XEkOcZTnhV9J/fUvbfo199G56rxLq19KzEPltU
uy85saL//GeJe5gTt5/rrdtKfxixah25o086PdLnJO4Hvku1OU96lP/H0zZ0
b/EO8Qyg28d7pEvYT4xxsH+RuFc548wODQv6WvSf31X61ehPvrv0V4n1HtIr
Evch34tnPnGv8j2lXw87+s3EPcnx+TFx/3PYzmWJe2IfL/1u4h7L/zGf0Xu8
o/THifuH70c8E/ch7yT9a2IfuNDvY/y94U/CB/tf0a+ecf5M3FeccRaHZpx3
Yj6c+2/0h+8s/WninuT7V5vhpB/3ERFb9OER8+PCXl1wr/Ku1e5BTn/ybhFn
epHTh3xsyXZ86gq+9xOqzYsyDkzpm9Eb/LhqflB5Dl2klybuK360dG3BPsRt
SeJ+5jClb0e/92O433rP5wDpmoJ9OPe8mA/z/zZxX3HmAFf5X09znvnE/dtP
5HengnUP6XLBPcbhS/+pd//wk3mvJe4xjv2nxD74b1ZwT+/TpNcp2B8WdL2C
e4z3JEeJ+4qjNyxY92LOJY/J+I1L7gHem5gU3Gu9D3EoWZ8qvSrxmIzfoOTr
9pW+reRe5cyhEr12/4+pO4/Xda7+P77Pue99Ds497OtslcwNylhIKkP1baR5
UElpUiGiJKRJMpQpCZnJUKZSKFRU5lk0GDJHmYeSpPD7PM967x9/7Me19mev
a12f+7o/133OvT7v9Vq/znuKFf6F3BM8cSxxLHP+GPK7Z5xPf1A88O3yfrlX
tKnfSpwFDPlB3U/37QXx377ZKw+K9f3VZi8yKFb5l33OhBm+Y7Ovm+HAN/vF
gxrnM2dQ4+IME+crzV4hcdhTg+LAi//S2F/zegfFDGc/a1BscBrURbqyd2r2
moPih9OjLjkoNvjOzX7uoJjexie78uH/nkHx62gs147/N82tK9b3Ls1edlCc
8F2bPerK3q3Zr0xM8f9vUDzwbzX7sK6432zMbzae/NKDivnNvBd43Fjch8ae
0Q9/PfbN4bEfmPWMA06/emP42wfNKl2rcZrV1w+KK35As180qHPZL8w4rezC
Xc1z92a/eVBxDm72y3IfDvMZOyge+KHNXn9QDPBDmr1ibP6rxMf4YZmzub1z
UBxycVaNLc7qee+8Xy8fFAPcPR90xQA/otkbDorRfVSz3z+ocbrWrit/Pq+K
j/FFu+J+H93sDw2KB/6DZq8TW5xXD8rH+GsHxf0+JnPG46ZlxfPGFcdm//ig
GOA/tA67so9zn7vyMf6sruIcO6v0sfsmzqGxsb6fnFfPuGf/p7kW7Ssd7ALG
d7PfMijm9hnN3mQQvnezN8/4mc1+06A43sZvD8f7F83edFC2c+8Is/30rIf9
cq23D4oTLs5iXTG6fVa8d1AsaAzDdw2KaXhWs7eMP3vrjPN5Q+ZG0/u+QcWh
ld0mcdiX5t9K/4ZuN6jPJbrZHQbF6D6n2R8ZFNP7N83+8KBY38a/HNv4El35
/LbZz+mK3X1esw8aFGv6xmZ/Y1Dj588qVjd2Nx477SsG91W559jcV+Q9wsjG
x/7YoDjhv5tVOtuj43NEV3HOz3skDg3t+YnDXrKrc89t9icHxe6mrf1m7Kub
/blBsbKvbfZeg2Kbs7+T8euafVf43n9s9mcGxev+k2c89p99PgzKx/hXBsW7
9tq/MCgutzgHDoq5TTf76UFxws1hma443jc0+0u5b3z2y7n0t4t3dS6fe8KN
v6bZXxzUuXwOzXVvavbXBsXlZn9vUOzoR5v9gq7427c2+/ld+dzc7AfCpv5H
s3calM8ts4pjjb+Nr/6DQXG5b/fZ2JV9W7OP7Mrn9rxH2Ny43LsNion94KzS
5WJw0+LS7mJw35f3i31v1sMvMn5t4hg/ZlCcbXF2iU1/+9m8X+7/Q+GrP9Ts
D2YNW88nD4qz/a9mnzAopvcjzd4j9j+bvXd8jJ+ae0VneMqgWNzu276xxfnR
oO6Vcw8YFIub/xGD4mb/t9lnDoqz/XizfzEohjYd7/O6sh9r9sHxMf6iruIY
/9WguNziHBZbnM/mO77v/it0da3/+Zzvir/9ZLN/NyjO9kT7PntUV8xqtvuJ
o71QtL442jS992ac7hfbmj9u+cpd8ZyXir764vgfOyhWNk3vebGHzf7hoHja
w+i0L0rMR8LKnmr2RYOyu2afOCgmeRddsfi0xJdkfD7t4qAY2uzLY0/TE3bF
vn42bdigeNqLNvvPgxqn7z1tUDxt4z8fFEOb1neVrmznXhMf44+G8T6ieRsU
41qc1bpiay/Z7HMGxRV/brN/PSie9mJeb/zZf8k4n59mbub820HFWaLZq3YV
Z/FmL9fV+/VUe+9uG9Q9X3p2cbJxs5fJ+4WL/eK8X9jZuNk/6MqH/1MZ53P+
oNjXK+beYmfTEtMYX7/Q07pi47TEf43/Sq41KK71avSNg+J7v7TZj4eP/ZJm
/y/M85Wb/fdBjfO5cFDj4lyROKs2++7EYR81qLX6RHu9vx8UK9u1/jAo9vXq
zX5sUDzqNWneBsXHpiW+cVC8a+NrdDW+hvduUDxtuuLrcy77pV2N83kw1xL/
v4nzCpqlrvI/6zT7lV2xr9ei8+yKR/3KZt88KJv/rYPyeVWz/5E5m9usYfGx
xXlZV/baeV9wrjGuaZLZM9rve2PTHmNn03gvmvEZHfh9se8YFNea9nj2dPGr
3xJ/zGU6W6AdrOy3eZYHxbV+e7P/OSg29buaPRgWh/mdzV54WD7vaHZvWPHX
t2YG5WN87rBiijMeFvtanIcGZYvzt0HNx7nzh3UtmuR/DYp9zX51V5zq91vb
g7LfZ87DYl9/oNnPHhbXmrZ5sWFxsDew3gbFvmb/Z1DjfJbPa6fjfU1XcTbM
fcanxqZeu6s5vKfZx3TFst5odumQ/5f7tlZXPOoPzi6+NR/c8jW7mo9znzcs
H+cuMaz5vC/v3ZOZw5u6Yh1v1+z+sPjV9MwviL1psxcCQ2o+mzV7kezLb9Hs
OdPFr/4Me1g+/NccFl+a3niF+G/p83lY/OrPNntqWGxq9ktjb+U1Dium+KsP
i1lNw/ysYTGi2a/ryv5cs4eJKf66XV3X+HOHxbU2h88Mi+N6QbOXHhab+gvN
XnJYPOptPEfxZ6+dcT7/1xUXevtmLzuse/XFZr+xqzjbzi5ttvtJZ/5/w/Lf
YXbpmTGsv5n3Hav6G3kf8aCxoDGqMavxydfOOJ9juxrfIfHFoZdeJ3HYLxwW
g5rm+fWxd7UehsWpZg+mixP+rWa/eVj2t5u9/rA42Hv4bB8Wd3rPZq8yLO60
8RXjw3/R6WIpH9vsd8Z/r2a/Z1i8aJrnlw+LR81evyt7n2a/LTHFf/+wONL0
z68aFneavWHsfX0WJab46wyLU238Q7G/69kcFoOajQ+NI431/dphsaa/l/uJ
0Yyt/fauxvdv9seHxZc+sNnHdXUue72uxg9o9hu6mqf5vzNxaFzfNKz7cMzs
0kVjQ9NR013jUx+V9+h58V83Psbf1tWc92v2JsNiUIvzhtg02KPpeu9287k0
XUzpHzb7LcNi//6o2VsOiyN9QrM3z/jxzd50WP583h4f49sMi/9MO731sHjU
J5pzbHHeGx/j7xsWg5r/R4bFhT6l2TsMiyn9k2ZvNyx2NA32W7uyT272B+Nj
/F1dxTH+5WGxqcX5cGxxpvOMe/bf29W1ftrsDbpiO5+ae4sxTWv9jWFxpE+f
XRps4zTtP+yKKX163i+cX4zfTWI7F2eaD5b4x4YV/2d5H9dInN2HxX/2WfHp
YXGkf+daw2JH02l/Kv502t/MOJ93djW305q92HTFOb/Zi09XnHOb/e18Fl3Y
7M8Oi//M3iv2Rc3+3LB40ezvxL642fsNi89Mv/2erhjRlzb7i8PiThv/Qnz4
nzwsjvGdzT5wWP702wcNi/98ebO/MixGNPvQ2Fc0+wNdxRR/o6740lc2e6dh
cZWv8jx2Zf++2V9KTPHf3xXn+epm/2BY9jXN/lFXLGg2zTZ28015j3ClMaV3
GRb/mR57+4zTftOB403fmPv/ptifzDifrw1rnuZ/TOLc0uy9cx/uMIdhMZ//
6vN8uvjqtzZ7t2HZ/JeeLp/bZxe32pzxyU8YFgtanD1ii7PvsFjN7vMpsf/W
7O8NiwvNPjU27fcBw2I4sz/SlX2XZ6cr/jP7F8Oy6bcPHhYjmn1m7HtmF+8Y
9/jh3CtMZzznI4bFfL7XZ11X9n3NPmpY2rn7m33YsNjR4mzcFdv5wWb/blj2
Q80+vqv47F/FX8xrhsU9pqPeM9elIb98WCzlXrTlGNCP573ecOGnNeRseuxj
h8V8pg8/L/YTnuVhcaTZL5ou+8lm/3xYjGXX3SHxXffEYfGcZ9FwxZ7d7B9n
PuwXTheLdaLZPx0Wh9k8r4rdb/ZpeV3si4blL+b/hsVufUOzP9XVHOZEg42B
S0f952Fxnmn1zxoW25n962HxnBdq9mZdsaMXoW/K+MLNvi7+fDbtihn1wmb/
dlis5nnN/mRXTOZhs28blj1q9gldMa7Z5wwr/sJ5X/CasZqPjP3/Nf+xN+8q
/iCvxfj/1/zH/kFs+vNLh8VVXoZufFj85yVo/jO+bLMvHBaP2viK08W5XbrZ
fx+W7dyVp8tnyV7xp80fe/yKYbGaxdmyKw6z+/CHYfGZn9/s3w+Lmfw8uv34
sx/MOJ/zMzf1CH8aVhy69H8kDvvRYd1nuvTrh8VkZj8W+0V0YcPiP7P/G/vF
tGPD4jOzt+7KXp5OeFiM5RWa/bmu7BWbvUVXHOaVmn3HsLjTtOK9Udmv6hXT
Gdt5lbxf+M7YzqfFtsZmjSrOyr3S0lt7a+Y9+krsn8emYz+xq5j8lxjVGn5j
s/82LA6z627VFff4dc1edbp4y+s0e+6o7HWbfc+wmMzshUdlv5qea1i8ZfZg
VPZraKyGxWRmf6yr58Lzsvp0XXetZs8fFT+Zpv1fw+Its7/QlW0+41HFeW2z
nz2qedK3/2dYvGX2YqOyPZv/HFZM/mox/d+VfvjJYfGQvXYcKJwoPdm36Yqf
jHUMCovD/OZmb9+VvV6znz8qn7fkvcBExkP+Vlfc3U/2SldvnH6eBh4TmaZ9
reniDG/Y7P6o+Mbvz3u0T3xO6ornLP7lGX9f3t+9E3POqOJ8wOdY4rBxnZ2L
Db7mdLGLN2r2i0Zlf6jZzxoVW5iO/SWjYvyyv9HV+MeaPRwV3/jDzZ4aFdN4
Y89p7I94luNjfNlR8X4/1ewvdsU3FmeNUXGDN2n2IqPiLZvD6qPiHn+i2UuP
6r7xWXVU59LDL5lz+Syfc83nuTmXz3Tmbz6vyBw+3SvWKmbsz3qlnccZXnai
eL64vvv2is+L07t/r/TpOL006vTmxmnX6d/5rzJRzFzs3B/0itWL2fv9XvF8
cY8P7pVunU27jrmL4Xtor/i/4h/QKy4vbi9eLx06mxYdhxfX98he6eLFp4en
TzdOE04Pbg404TRf2Ig0ZvTjWK805HTlP1y4tOvH98r+ofU8p3xO6JU+1/2h
D6cBx91960Txdtmn9Iqz7L7t2iuuLtbuqb3i2mLgntErfTeOLl03TTfuLl03
xi77tF5xdfmc3iutujg06vTgOLZ041i27J/3SocuPh04li6+7pm90n2z6b3p
vnF66b3xcPFyz+4VoxbD9rxe6aCxbT87UTpr45tPlF6bP802Lin+6S294tXi
2V7YK14tzu1FvdJQs+mr8WdxaC/uFetW/At6xanFsb2kV1ppNi00Ni3W7WW9
0muLT49NQ22cvhrHFs/28l5ppdk00hivWK/X90rfimdL40rba3zPiWLUYthe
3StuLH7stb3SKbPplmmc+dAq02ubP802Li0+7Q290iZjwtIk48Pix97YK/4m
ruxfeqUL5r/XROmRje89Udxbc7uiV0xZcW7qlZ5UHJpS3GTv11m90hS753TF
dMf4rrTHmLDYsHf2igmLN3tbr9ivfG7tlX7ZOA0zZih26/29YrZit97bK+2w
OPTD9LzGaXppgfmfMFHaW8zWH08UdxWj9aFeMV4xYx/slQ4XS5bOlmbWON0s
tqzxB3rFcxXn4V5peMU5eaJqyzz76lOwYHFj/9krniym7iO90qviqZ43UYxX
3Nd/9YqRipU6q1/6XOO0uzS5uK90U9ipzn2qV/xW4//ple7YtWiGaWPFoX3F
PfVZMdkv3Sv26SUTpY3FXL14orir7Nn94qLy6fVLR2zOdMI0qvirtKZYq+x+
vxirWKtz+6U5ZV8xUUxVLNaF+qWlZdPQYqRipS7cLy4qzuqwXzpQ/NLbJkr3
apz2lWaWP+3rAhamz+R+8UmxT5/VL7YpJuqz+6UtZdtjwiTFJn1Ov7io4k/3
i3OKfbpYv7Sl7LsmiiGKJfrcfulMxadZpTM1fvdEcU+xUJfol26UTTuKB4oL
+uJ+aUVxUO+bKN2lcdpLLFEc1KX6xS3FL31ev3SgbFpQmlM+90/UXpn508Fi
mGKZrtAvTSVeKF0llijW6Er9YolikK7YLx0lf1pKWk7jtJd4rOa2ZL94o+Ks
3C9tpjg0nPSY7jNNJs4o3uhL+6XBZNNA4oTijq7aL20jm74RVxRfdLV+6SvZ
NJb4oTiiL++XTpNNY4n1if+5dr8YnFic/9cvjSGbtpC2EVOUdhHHE//z1f3S
M7LpGOkoxaGfpG30/zqaRhxPXNDX9kufyKZRxCEVc91+8SBxId/XL96nvjKv
7xenEtPyvf1ifeJ/vqFfukU27SK+J+bnG/ulMWTTGeJpYnKu3y8dIpsuEX8T
h/Od/dLNuS7NHo2k69JM0gbicNI24FdiYL6nX3oHNk0gjaE4NId0guZJH4iz
ib25Qb80fWzaPBxPMd/dxs+eqho6NXH4nfieH+iX1ga7j8YGTxOTc8N+6QHZ
9H50f1iadIDYlBiVm/SLxYnJuXG/OJt8PtgvLRW+Ig0VDR1/Ojr6OzxMGjzs
SzzMT/dL08emqaO/E5Pejy4MG5M2DPsSD3Ozfmnr2PRy2Jdifqpf/Et8zM37
padj09dhYeJybtEvjRvmJ20b3iXu5Zb94kjiVW7fL02ccfo62jo8TBobHEzn
fr5ffEzjn+0Xv888N+2Xfm1BnFnFkXQfvtIv3Rm2Ie0ZnRpeJa0aTiX7S/3i
HvLZsV+6P3OmzaNfw66kVcOjZH+5X1xJfMmv9kv3xKZ9wo/Eqfx6vzRobJo0
bEq8yp36pSlj05XhPOJVfqNf2jQ2/RjuJC7lrv3Sc7Hpzeit8BvprzAa8TH1
ZsV8xIrcu1+aLzYdF/6jNbZPv3iUeJV79ov5iCH5nX7pvNh0XLiQ4u/bL00Z
fxqz7br6HvemXunIXJe+i44JF5EGiZ4LC5J2C/8RH3L/fum52PRamI8Ykgf0
S8PFpt3CfMSKPLhfmiw2LRbNrOeFPhZjUvzv9Yt1iNP4g37ppNi0UjiM5nN0
vxiLuI5H9ou9iMF4TL80UGw6KHxGnMZj+6WB4k+L9cNR9bPHpqOBwnykg+qm
qn5PXR6GHSbe5f3Sj+Ax0jvRRmE10pPgMxo/vl8cRjzGE/rFK8RFPK1fDERc
xJ/3i12IbXhmv7Qq+If0RbQkrkVbQkOEl0jHQieF60jXRE8kDk0RTqJzz+iX
dsm1aIcwCp37i35pssyHLgsLUpwf90vHZA40SBiCuIIX9Uu/g21It0NTY5zG
BrvQ+O/6xUPETvx1v3RJbLomWiRMQzolPD9cvyv6paPBG6STwTvk86t+8Rox
HM/ql6aJTbOERcj/sn7xCjEML+2XvgbnkMaGTsc4fQ7WofFL+sVtxHI8u1+a
HXOgw8Gtw8TTy9777X3/fb+YhTiGV/VLg8OmvaHB4UNjgwOIQ/infmk38Alp
SGg0jNPS0Lxg+tG60KTg/tF44ADiFt7cL1YgfuBN/eIeYiFe3S/9i3G6F0xA
cf7SL1agOLf0S/8iDt0L7Y9zaYHwCs3n1n6x0DAEb+uXhoVNx4L9hwF4R7+0
JLh89CE4gtiCf+2XVoUPvQpmH5+7+6Wd4UP3QsPiHtKx0IZg99F14O7h7+ll
j+uEB6WXLgYfFt8/+qX74EPXgd+H7/dwvzQgfOhAMPXEfLBf+hE+NCT0a95T
ujX8PjzAR/ql3WDTb+Du4e/pQY/Vh9mnfz2tB5v2gwaED60I7h4Wnx7x9rex
zuyV02gYp9mgfcDNo2GgfcC+o23AwlvAx5ssdt4Cht5k8QRxBf/TL32EcRoJ
rD1x9JrHzlvA0JssnYU4NBW0J86lJ8HOW8Dumyw9BZu+AsMO107vcloDTDx6
AxoE43QIWHr4evrCY+fh6enhTh/BppegX+BDL0GrgnVIr4J9gIGgTzpNATad
fX9cvQV8vcnSDuDX0Q9gw7lveqDTMjiXPgFvzrl6ptN9OJfeA/POufq2Y8/h
2umTjleHbac3uj1qzDT70TQLfOxd0h1g2NEbYLdhuOkVbm/TuXQLuHX4dXqj
0xfg49EY4N45V69zGgQ+dAi4bxhx+onLZcpp2pfHfXRP/tWv/Xx8OXv0mHS4
fAv6gy9c59IA4M05Vy6UNsHc6Arw5pyr/7i9Ys+FvWAcPXPTtx0TDWtOD3F7
79hx9tzx4Nh6eeO+YcHpnW3fHoeOBsD+Oa6c/X08OPdNf3CcOeN6gtMFmDNt
gL13cezFY7RhtemRTWtgDvQAeG34b3qR2/fmY48b6w0LTt9te+B87INj4JmP
PuP22PnYc8dntD6Hk8Vow2rTU1uOGb9GbhmnDfdNz2tcN9w3va3tk7Ptj9v3
5mO/G7sNz00vbHuDeFz2Cu11G7f3bX8Yz80+tX1g/DT7vzhleGV6RmOu4bDp
PY0Zhx2nB7d9ZuP2mjHgxNH/GnNNHH2B7TmLY//aPrxz7bNjruGw6Tdtn5lt
fxkTDWNNr2f7t1hq9oLtAxu3l4q7hsumBzS+Gs6antH2k9n2fO0581mwNz23
+GP6GuOm4afp6WxPFa/MnimGGv6bntf2abHO7L3il7lv+ibbN3au/WKMM+fq
uWw/3Ln2uPHRnKunMwac+ettbb/XHOzJYmZhbemNa28W68yeLM4Z3pl+x3hm
uGb6JttfxUyzN2oP1ri9V/u3/O3b4nxhf+n/i0GGRabPMjYZjpkex/ZR2fZP
scOwyPQsxkcTX/9lfDGcMT0i7Tey7Tnii2Ee6jVs31V8e6/2No3b07S3aQ72
MXGv8K/0q7WHiSNmn9TeJhaZPU0MMra+wBhjfPQmtvfo/th/tFeDR2bvEj+M
re8wNpz7pj81RhhWmL7D+Fx4X3rj2nPD8rL3Z38Sy8u+JJ4XW79gnC8++vza
/xTHfqW9QUww+4O4YGw9Z+0rim9P0F6f12i/T+27Xjzq3+3p4XnZ17MHiP1l
HxDfy7j+ufhhOGJ68djfw/uyr4edhNGkTyi2F96XHru4XVheeuBiY2Fz6Sdr
vw5ry96ZvTg+9tfsJYpvDxF7i4/etfYMxbRXaD8Nj8s+GiYXWw9QrDHz0f/X
3ppr2VPDxsLI0lvWHhf+lX0uTCu2HrI4WdhZ+sbaK8Ppsv9lHwyfy54a/pbP
NH1pMbqM60trj8Vrt89ib1Ace2T4UzhU+qva0zMHe3lYV1hY+sbaX+Jjfwd7
C49Ln1l7U3zsT2GEmY/+tvbQ+Njnwr3CwtKP1Z4S276S/ATWz+G94l1hYOmv
ii2FkaVnq70bvCF7K/amjNsPwrfCvNKDFQcLJ0sPVvtF4tjzstdk3F6SPSX+
9pswijCP9utVf0hcpJXbutq9V2wmXCZ7U5hUm2SPybi9Eowq4/q66iMpzirZ
SxLH3hONlX9faKv0izR/+034dNaqftD6aeL22kvSIxIjyX6QvSGMp+9nv8n4
wdlXwjx6Rfae3LeXJxctjn0o/Sidu3r2lfgfmfnjTNkb0v8RnwibSL9IPKNX
Ze8Jn8j+F76R8WN61Y/SuP0pPSLFWTb7UOLYe/Laz8091I+RbY9Jn8fzcn/c
8wti88Enekv2p86Pv/0pPj/tVV/Fi3Lf8Ipwi37Rq/074z/LPqDei6dmD0uP
SHtSekpiJ9n/0jvyktwTPSgxkuyFWVeX5Fz2xbmW+39Z/O1nXRofHKMLMze9
Ji9/xvt1ea7rvbg676m9M4yk07NHZvzneU+vzLl6U14Vf+NXxd/+2pWx7cf9
Oe+7fbRr8r6z/5h7olcmPtTMvtsfci0+7tt7s06uybjn7o+JY1/visxf30zn
2u/TZ9P87ffZxzQHe4L6RuIubTZRc9ML0/6d/pjXZZ0Yx3ua2ePTN/Os7PFd
H3/r87rY+mbiKGEo6cX5l6xJ/TdxoGb2BG9MHOvzpmes2xtyXf09saLsG+I5
sX/Zq7V6S9Y8/78kjr6bxn/dK4bTrbHtbWH03JjXq6emPUf7sHhe9iL162S/
Omv49qxne5F3xN/4X2Prs/nXrD2v/dq8p9bVnRnXW/PuvI/2cHG+7D/iQmFI
nd+rPp7szSeqL+ffs87tjd4ZH3uX+nVemD3Zu+LDvjvjeoPiTNk/tXd5T8bt
k+rvaW9Uf8/7sgb0A8Wcsr9p/1Tfz4uzf3p//K2l+2K7/0/kvdD388GsKz1G
ca+2zn7lQ4lj3T4cH8/OA7muvdd/ZA3zYduH1TMU9+pz8X8wcezP/jM+Pjce
ybnisC/tVa/Sx7KucK3+lXHr07i9Wnu7j2YNG/93bOP/jo+9bD72f+0dP5zr
8sHYsv9rbxcby/6pXqL/zT2xnh/PHOwL/ycx7Rc/Hn9zNjd7zfqiirNtzv1v
fNzze7Nm7NW651f2iiP1ZGw9UrG3cLes86fyrOmjyse+s16kxn/fqzWsj6ln
XL9UHDT76dhd4vCxz27c3rQep/ztTWNl4XNdl3WrL+qCtTqnGFu75RnpzXt6
L7sfWx/VXvz1SxVn94na+55MTHvNN+W51jsVT21mDS8U2963Ps72tfV0xpuz
bvWdxFPbOv7G7Y/b+14ktvU8L/76sRq3F09v4FrXx2eQ+Hqz+qywV24/fZTP
DXvow/joFcveK2t+lDnQACyU6xof51y9XNmfy/8rzsu/j9Z2l3F78dht1ob9
fQyym+IzP7Zescb3yTpfNP64YjhlN/eqTyl+1rETpZfAj/tC1uRz5j29hvWN
3TbjuG/26/k/J7b5LJqY+swuFn9aCDFpMOgBnvuMc9nfzWsxH/oEegDXog3Q
Qxb/y/rUa1bP2Tt6tQ6XyXrWrxabDJeMfmDJnEtjoP/s7b3qb4srR1fguVgq
MekHvHa6AmyzZRNfD9kXZO157UskprX6/Kxh9gtyrt64eHM0GO7n8zOuv635
0D/QafC5M8/IcolP28C+r1fvI64cvYHeqS/O2tO7FvuMzoGGQb9aegacsxfl
XH1yV8gas56Xz7n0JOLQUdBUGH8ga36F2PQPuGN0Efrhrpz1bA2vlJj0EivG
n0ZipfjrsWv8hInqzyvOiTl35fhgyy2d98K/rS9JfFqULmvVa18ta1VvX2w1
egz+L83rpcFYNbbeu5hr9Bh0Gqtn/dB7rJZ7qPfuSxOTJuRlGafZ0Mf3kdhr
Zh2Kg3n349h6+v6jV+y3l8f27KyRa1nPr8i5dC/i0IHQNfvuT8+s1/ArswZc
C/ftlKzVtTJON8KmDzG+dmz3bd2sW/2aMd3oNPQOXjvjdB36AtNy0Jnwf7RX
TLhXx7a2X5NnRM9g9mO90p+sk2v5fv3ajOsdjNNHY0Nvw6Y/0b9YzJ/l2Xld
Pjf0BGbTq+j/+/qsVVw3DLiJfvlgw507UX2H35w1QyfzhpxL9/LG+OtH7Nzz
JmqdvzEx9UQ2T3kAmh9xaGms4bdm7VmrWH60LvQ268U2vl6uq5/y+vH3Wl6f
OdDMvCX++hqzL5ooncyrsmb0Jn5b1qe+xth2F0+UrkbPYpoZOpy3530xt7fF
tobfkXPpbd4Vf+PvjK3f8TuztvUy5nNJ1vC7M07zg0N32URpBXHi6H/4vCc2
n/dkPeutzOfSidL2vPsZPnonz+nXOt8g/tb2K/N6se7eFx8aJAxEWiDrZ6Os
SRohfaxpgeiCjNP/6L+84TN8cPdoh+iFPhh/93bD2Hzen2dEL+YPZb3h3mHk
LdKvtb1xxvWDxu+jOzKfD+W6NEUfji3+BxJTH2dxaI3olDZOTD2e5ZcG/eoH
jdN39URx+D6WcWv1E1nD+j5jKdJr0W6xaZz0c+YzHRtT79a8R9iCdEd0UJ+M
D82Svs+L9kvvpC8zjZMezZtm7en7jNNHN6VP9CZ5LnD4Pp1zPWufyrg1vFnO
pRMT51mZ/ya5rp7Rm2fd8t8817Umt8p6o01Sz09bRWdlfLGs7S1m1vy4eIv8
jW8Zf3qtLWLrQ43ld9dE9aHeOuuQRuvzuSf6XGMI0mLRa30u16LX2ibr3Ny2
zrj7+fnEoQf7TOavV7Vz/z5RfbTN/28Tpe/6Qq6l3zT2Iu2Z+HpgL55r4Qze
PVEasO2yVtn6YdNT0b8Zpw3DF/xizrU+v5p1pS/2DlmTzsUovHeiNGNfShzr
c8f4eBa2z7X0pP5y4vBh05Lpu41XeF/8d0gcWrKvxIf2zByW7pc+CgOO7l2P
bb22l+0Xy/Br8dGzm31/1vnXs+Zp89wfujXMwp1yrl7ebAxDnwnb5n2xnnfO
Otc7G6OQFo4ubgGjMGv+m7H12v5m1rNe3HyejL1zfGjt9ONevl/rfNf44xru
lnE90HfPmqHlY9PO0dHpjU4jpwf3t7MG9ArHQ6SXo6PTm5umjnZuj/hbS9+O
7d4eknuur/deWVf6gGMd0trR1O2dONbtPvHx7OyZ6+oP/p2sfz5sejw9xHEV
6fH475U4tH/7xse6/W7OpeVj00bSSWIs0u/x2S/jmIsL2Iv96jmO4UhDaK3u
n7Xt3P3jQwf4vZxLZ7hPrksTeGDWLe3fAjZiv3qIH5R7Yj1/Pz50kvxfmnO/
H3/X2i/XNS4ObaFzD4qPe/6tvI80h+75arn/h8a2bg/PWtUPHf+RFlHf80Mz
Tot4WPyt2yOzVvVDx4icF+2iOKv3ixN5RGz90fmv0a91i6e5duyjsz71TMf0
pOHEpDwq/rSdxuke9Vs3jqmr1/kxeRb0OT86Mekzd8wzaxybEpfS2j4u/rSL
eqnTQOqfjh1J96jX+QlZeziRxtfplxYUW3PdrOfjs871ZP9RbPrJYzMHPick
vn7rPiueH+3lSfncoL08MT56vrOflzV/UuZA23lc5mD85JyrD/vJWdvW809i
q8dh02rqw35K1iefUzKutztm5QuiU/1ZfNhYorSjNJ8/i03z+dOcq9c5Tijd
qX7xWJa0oJ6L0/O80KCyX9cvG+NyuYyfGh8a0V9krdLEsulFPQtnZJx+9bTM
gb9x2lG948/M+uR/Zsb1l8f0pCmlLz0r4zSlxulLreFf5lz95X+VdWv8V/Gh
U/1lbGzOn+e1WM9nxx87E0NzvX6t1d9kTepfj7O5QnSt/N/UL+7mObG9FnOj
U/3odMXB4dTb/jeJSd/rPtO+WlfnZg3rOc+mfdXX/rysWz7nZZwPhuZa0bie
n3Hr+YL409Cy39WvvvY4nmtH93tZ1irdLJt2l34YR/XdWbcXZ63SxLJpa3E6
L0xMPpdkfIdRscZocelvL834RuOKKQ79MP4mHa8e95dnfX55VHxM+lu97DE9
Xxu97hWZm/V5Zfzpjdm0uxuPi6lqffK5KuM7jooHSuuLzem678+/6ZcnJg3w
1fNKz2xu12QNW5PXZJw2+PeJSYf8h4xbM3+Mv3P/mPjOvTrzoYPFnaR3pR/+
c9YDLS72JV2uNXxtxvmwN8z4dbGt7Ruy5vlgj9JVfmRcPstH06uvPW0wTTL/
D+bcv8T+yqiYpDP65BszTrd8fa5Fk3xTszdq9ldHxUWlYcYrvTnjHx1XzBXy
jNyStb3bnLI/7N/B6WKbrp/1if1K/3xXV/xZGu895xRXFFOU9ts4XbTx2+P/
8XGdu3bi3J4171m7KXOgl74j/tbeXVmHGKV4pp/slwb7ztjW8J2J+bVR+dBa
Y6DemvnTluPP0kh/Yly2mJuMiz/72qzzu3PPvz4qziydNm32PRm3hu+NP/02
m+ZZH/P7sj753JfxnUbFS6XrpuW+P+PWHqYtnfbOo+Kf0nJ/alxcWs+Otfpg
1tU3RrXGPprxB3ItcR6OP334w4lJB/6PPJu02Q8kjvf9iawB+vB/xp8O/PGs
bec+0uzPxMZppSHHVf1XxunJH826pQ1mb5G19++M82HTltP5e17o7T2/j2Ru
fDBYabxpzv8Tf+v58aztT4+L4cvedFxM3jdnzf935nkc1bNJr24OjyUOXaLe
1rSv9Ope+1b94vBh+Z3e7APa+FNt/HP9Ykk+GR/r56ms+U/ZLxgUP3aBPn9Q
GvhvjYqj+tWs29mDWv+bj4ufax3uOioeKz08bTwmLI09/15sPFrxzeGQOeWD
GcueHR/6/Mlm79CvZ2Ey8e/raj7qBTBf58TnM+Ni/lrDdPXzBqWZtw7Z1uSW
4+LPWld0+AsNSntvzS8ce7dR8Wdp9bcY17hzF9Q4DErbL+Yg8T87Lv6v9aze
wRxo+31OjnIt9jjn7j4qRq26ANr+UcbNYaHMn/5/mPjqCBbJ3KzhLtfCfMV+
3blfdQG4wx/POmfP1AhMx+aDb/v1rO1F4//tUfmo3VAvsPig6gKwb/l/rV+1
CdjE6gus2+cMag2rO2DvlPiLxp/PYhnng5OrHkENwnOfMf7sxPFvjetaz1uP
i3Gs/kKNwFsHVatirS6V8T1GxeHdOecuMXi6lmHJ2NbYMlnDe47qXqlxUPuw
VO6beo0u9+fYOeW/S7/WLTbxnrGfn/X5UBde86zi9S4bfzUmxtVNbDZd47i+
nx9XHM/CCXMqjphs/FzsXPUOL8y49bxc/PcaFW9XHQTmLnuvftWSYB+rufjC
uBjH1pJ1snzW7Tbj8mGrX3jFoGoi+PBXl6EOaMXY1ttKiaN2g61GQ33H8s/w
WTnj+4yK1XtI3qNVMr73qGIenOflJfmsUPfBVt/xxXHxl6036xPDVy3Jd0bF
9lUPsu+o2MHqTdSerJpz1YmsFn91KKtnPYuzWmJuO655uq6akZfF39p7RdYh
7i9e8H6Js0Zsa36NxDTO5/C8lpdmDupr8KDVg7i3ayamOpfl8h5tNy6O8865
//jCM/Upaw2qDkV9yqvyvpjbK2Nbw2vlXLUq68Tf+Nqxtx+XbT1/d1Q+R+Uz
Yd2MP9IVP1r9zmntuq9p9kH94hbjFx/o37VR2T/Ien5N1q16mXXjg0n82py7
xXTZWMdbjesZ98yqFXItdTRntnNfN6j6l++NijV8Wtb56zOOK2z8qPhjAZ+a
df7GrHl1NG+MjxqZN+RccV6XZ2fHcfGmrTc1QdjHanC+PC7G9IIatza+XnzU
KPFXv6OWZ734f2lcc3Pd/UcV54ycu3581Pj4LFLL85Vx8awPzfp/W8YPGBUf
WV2Sep+3Z1wd0DsGVe9z4Kj4yOqAvjoutvXMOn9HYmIV4xqf2C9e8rtyrrqh
dzf7uGafM6c444dnnb8n4+K8M/5qiN6bcWt+g/g7l/3Dfp377szBOBazmiM8
5vfF5zdzip1tDas5wq49Pmv4Axm3VjfKOuT/gWf4bBjbuHPVKH1tXOP8vz+q
eeJCq10SR73SwaO6D2qF1A19OOOu9aHYXx+XbQ0fNCof9VDqwsz5R/2qgdo4
99P63zj+1vZHs57PnVP2yc1nq+liOuM5YzN/LOOPdcXyViOmXoz946zPT2QN
XzSnbDVW3xgXg9v657PJ4Onaq80GVQ/1zXGxua0Zz8Wn4q9Wi+3/bIeM6v9v
Vyc+TjRG9M7jYnZbq+rR2Oq5PAubZVwd1idzXesBX/us+GyeOai9wphW/6XO
6zMZt4a3yNzUcLHVdu0yLq73WVnnW2b8sFHxjtWIqSP7bMaPGBVjWm3XoaOK
r15s13Exwb3v1vnWmcPho5rPtRnfKtcy/8/HX83a5/Na1G1tk3WrBm2rxFFX
5f/DaprUc30h/l7vPonv3G3FTBysajVf6sK2y1plbz+o+jJ1dsbVi2FafzHn
/mBULGm1abuNi1F+Ts7Fy1aDpjbtS4ljPe8YH8/U9rnW7uNil8+sebbasSNH
xey+Mf47JI7/838lPj43vppz1Z2xz2nj/+uKb65eD0v7axlXx2dcDZ11/vWs
+c9PF18bWxtjm/3b5nP1nPJhq7nbMde1xnbOmlS7t2uzL27jf55TLGwc7G+P
i2luDRvnf1HO/Wbso0Y1N3VVvrPsGn91f7vEBz97t8TfY1xMc2tJHSL7kqzh
b2VcLR5bvd6e4+KhW598vp3xo0fF2p6p49sj49bwnvE/dlR8bTWD6iLZl8cH
k11t4DGj4nSrAVRjuPfg6ZrBPWOrJdwn5+49Loa758Ka/E7G9xpXTOtzl1F9
R/P/Xmv4u/HfZ1z8eutBbeN+Wbd82OocjxsVV139ptrD72Xcut0//s5lX9kv
Gyv83/n83zbPlJrT7+ZcNZUY8eoTrefvZ22rW2SrYcQIPyAx+Rw0eLq2EU98
pp7x4GeMH5g4HxpXXk5+7zvj4sVbD/TI9Mo4PeoZcbfVIVrPh8+smVGxyNVI
qkk8LM++2kY+1zT71mYf2ew/9ovxfFRsawzDXZ3jd8dlP5j3+id53/kcnfXs
uTgyz8jE/OLOq1G9c075iLPtdMXHkVbHykfN5o9GxWFXL4mPfkTm5lzsctxy
6xALXp3m98ZlW1cnjIpLrjZT/ebx8cEFxze/0f/rxsV/t56PH9W4OlD1m16L
2swTR3UP56fG87icq2702Mzfs3Zc7oP1fHLuuRrSk2IbPylz239cPu6V+tAT
Mzd1suajzvSAcTHrH817hCOvBlYd608zN/f8lNgnjWpc7ao1/LNnrGccfLWl
B46LZe99P3lUXHX1sNbh6VnP1tsZWXvY6njrt/erRvX02GpXf5aYxvmoV1W7
elrG1eRi5atRVa/6i8Tkf2quZdy11Le67pmxjeO2Pyc1sL/Ma7cGzs56UPd6
Vvy/P677Y1yt66/j7779Mq/3x6MaVyf7k1Hx39XD4rjjud/Vr5rQuwZVH/qg
HH7G+/OLxa9eGOvduX9r49tP17k48OqUz8645+U3Wc/W5/FZY+qOxbk76+fc
rGE1uTjvD2b8vNiPzKlx7Hfr9oKsT1x2fPaH+lXziKuuDvSQcXH5rXnr6uLY
Pgcuyxo2jsuvtlc978Wx1fBekJiHjsuHvxpnMWdqfi+N/09HZS+o8x3VfNQU
qx12LTXFh42L9W9NqvnFiFf/e+qo7NWyZq7OOlRrfEXOVZt8ZfwPH1dvAD7W
/5WJefC47pV7or5YHLWf1u0fsya99ssT87RRselXT60on0dzD6+Jv7raPyTO
z0Y1n1Uzz2syjlX/p5yrzlqvAjXLPxgXf999UMv856zhI8bVV2Cx1DvfMKha
Y2v42viw+aiDtoZviL841w6ero/GxH95arr/kjg/HxXXXg2yNXNu1o+1elPW
OeY9n8fb+Omj4u+rp1b7fFPGjxxXzOemrvnGxD9mXNz/VVOLfX3m86S9gGb/
r9m9ucW1Xy/r2X1QN60W+47YC82vvghLx+f2rG3n3h4fde581Hd7Nm/J82XN
35l7q8ZcrwK12ztOF8cfwx+3Hr++P1lr9a6sT3Xcd2b86HGdaxz7/9bM/xej
Onf9rLGrsvbEuTufCeeNipP+hdSS3zt4uh78nvhYw/fmXh07rh4Mq6UO/f74
/2pUHPwN8lw8EJ/jxtXbYPXUbv8jz7Vacox+deX8H4ztWvcl5lmj8lHnrlb9
gfioSX94UDXg1vbDiX/mqObzjqz5f8Tnl6PqMfCu1KT/e1B16N73f2ft/XBc
fR3WzDwfafYik8Xm/1ds5z4afz7G1ZKrf/fah4n5WOL/aFy9HKxhtef/zHys
w8dzLfZ/c674+geohVcv/3jGPZuP5L6pnf9P4uMJmI/6es/CE7mWennsfjXv
vx5VPwO1+XoasEdtfKgWoNlT6sTnV38InIGvyv8Pq9+BtfRU1iHeP+7/YpPF
JeCv9n++eoFh1emfMK4+DQt6NCxUtnF9D8R0LbX5/Yxb25PxV+8/mfjOFdNz
d/aorquW/8Rx9XtYwDFYuPoKqNk/aVy9Irzv1u1C8cE94K/GX73/Qrkn1u28
+J8zqnu1Rc5dOD5qxp/IvcIQ4I8tYN2Oc132aFjr8zej6k+wZZ6LQfzxHIax
Tx7XOP8fjyuONYldMErM347qdX02a6aLj/rWPzb7wObzu1Gx1LEI8Ar0tHh3
/NnYBVgE07H56KmAS+D+6/eAM6CvgvGlJ4vDoL/FDJdATwXsgp+Mq9fFBll7
zxnW+vRcLJrrYho8J/7sZ8eHLc7nc+5i8TGfRXNdz87iiY+ZwH5e1swyWYd6
L/iMen4bX3Jujb+w2eeOqq/DNlnbSw1rnWMaLBV/7IUlE/N5c6uPgh4KO01X
jwf9HYw/P/fklHH1z5hhWeirge3ws3HdN+tQX4hlMwf307mfzufAErnW1Pw6
FwcDn+GFie85Wi5x8ApWz/uiD4BeDitPFgtiudjW+UuyHs4flQ/OA57D8sPi
POBg6KWB7XDquOwt8jmwfOzTxtWfw/q8cFS9H/Al8CJWGhZHAndixcS8YFQ2
1oQ1vFLOFXOF+BhfOeeePi7bPM8Y1b8dnkHMh1Xig7PRZU3iPOhFsWpe40tj
/3xctrV90ah88CKsZ/cK2wGnYrXYxleLPybGSxLn4lH1lsCRsJ5fkXWoT4Xe
FatP1v1fI7ZnYY28F8b54FpgXLws18L90O8EywLXYs3EZIuPd/GLcfUX2SbX
fWXGMTHWGhZDA1fkVRm3PteK/xnj6kfi32L8jXXi7x6+Ne+XZ2Hd+Fw6qt4Y
GB2Lzq9+JFgfK9H8N/uVk9WDgs+audbaiWkNvybrH99j3fjom/HanPvN6bL1
17hkVPPBQsEVcS0MEGv7dXmm9MrQM+O1bfyyUdn4G78cVz+Sb+dZ0L8EuwOj
4w2xrf83Zm2vOrfG9cjABvHaMXzwT8TBA7l8VH0yfhT/1yXOr8bV78S9wgzh
87qs7fUyB/b6GT9rXPNxXbyR9TKOMfLGvJZfj6uviXWIs6HvBUbHFaPqvYFJ
gqny9swTd+gdw2KMXDmq3htYK2ePq5+KNWn9vyMx9c3Qh+NNk1U//q6ci1Xy
7mFxSDBJ3vOMNfmejIvzzvhjlbw349b5BvF37gaJ79x3Zw7GXRfbBP9Evxb8
lutH1SMBo+OccfVr8b5btx+ID94Lf7wU534g98S63Sj+xt2rH+fcDeNjPb8t
9wrzhD+Oin4gepC8Jet246zt34+qj8hP8lx8KP5YKx+O/ZtxjfO/elRxMFhw
WjZOTGv7o1nPa80t+21tfLfp6hGiP8hi86tnDC4NRg0bd+U1zf8Tw+K0sPUI
0R/kd+Pq72KdW8+fyLr1XujFgqOC5fLJnIv38qlmb9Dsa0bVdwTjRc+QT2dc
nE3ij2+j1wtWjPW8WdY8hgwbB8Zz96nM4bxx9Yk5Put/8/j8YVS9kbBiMGH0
I8GHsW63iL+1t1XWKs7MFs/w2TL2H0d1Lo7N+eMa53/uuOZpbvgz4uC94Mls
kzWG5fK5jLvW1rEvGJeNmfCnUfng1WDmfCbzx5D5fO6ne/v5+Ovr8rG8j38e
VU+Ui/NMbZvr6m2ib8pGmc+2sXFsvpCYxvlg2uDebD8stswC5s+wGDjGt8t6
XsDbiX3huPrlWJ/XjqrPCq4ORs2Ow6d5O19KTHHYWDrW8I45V8wd4mP8yzn3
onHZ1vNVo3rGvXbcnq/EB9vnq83+iGdnfvXOwR3SI+VrGccjMo7P4759PWv+
29PV60WfFz1e2B9rPuvPLZ+P5dn8auZgPe+c9Y/Js2uzN2s+75hbPV30c7lk
XP1yrG3j/DfNs/DN2NeNam5XZP3vGv8FjKD4+Lf1VfnM0bNlt1wL+0j/Hoyg
y8bVa+fCrJlvZZ3jCLHxhYx/O7b1v2f88X/0XMHnwSMyvkV89opt3erNs2Xs
fbI+/zKqfjO4TzeMqk8M3hEe0d459/JxxeF/xbjiWJ+4SfskJn7UHpnbjaPq
MYNlhF+0b3zwi/SSwSNi79/srSarn8wBsY3vlzV806h60mAfYRmxP5s1v19s
6+eQrFVMpAOzJq3Vg3JP+H83c+bz/Yyz3TesJGwo5+IpXTmuc8XEEfpuriXm
9xMfE8l1MZSuGlcvImvAfTg+9xAH6bD4mOehsTeeW71k9JG5eVQ+2E363uiF
s81kMZoOj239H574t4zK596s8yOz5q8eVw8h/97hUOljhOmkf44+Ots2e6/p
svXTWXZ++WBVbTi34mybuR09LO6TNXx0ngWfP/vnfTF+THwuHdcatlb1vdEL
5yuTxY86LrY1f1zmduuofNSWYkm5V5hRWFt6HeFKXTMu2z1Ui3psrvWHcfU0
slZvH1W/HFwp7KmThsW2wps6MTFvG5WNT2U9n5RzvUcnxMf4yTn3j+OyrVs5
Ad/xfSfCrfpxfHC0fjIsJpW1fUrsv46qTw+2lbX6s2esW72UFnCr5tY4G+fq
pzn3hfOrjxHu1h2j6uuDf+W5OD3PC/4Ve+fJsvUWwstinxof/KtfZD3jgLGx
sHw+nJFxrK3TMgf+xnHG/jyuXk335PPkzIzfOaqeQFhbuFtnZRwLyzimlnX+
y5x77bh6L92b9f+r+GCa/TK2fkQ/z2ux5s+Ov94+egh9K+v2N1mrfxtVryDc
LSwv/rtNVu+gc2bsuTU3HLDvTFccfYg2nVtxxPzTuN6vBSy1heueY3xt2XzO
HRbji60fj14814+rz9MTWYfn5pllnxf/v4+qhxCGmPV/Qfyxxc6PD4aY8X0n
q4/QhbGxwvQowiL7y7h6QVnP1vDFWbcYa3o7LWCLza1x/jeMa5zPXaOKs0zO
vSQ+1udPsp6t4csS/8Zx9b6yVq1DPaUwne4eVU8j7LJ7RtW7CLsMx8w4Vhtu
25Xxv2lc5/YT58rExFi7bMZ/4Yqzf973P2bdWof6cmGd4UpdHdv41YkpX3RN
/M3/8sTET/tD/O8dlT3DT9M/CVdNDyW2XBOW2p+zNtjXDotdhh1nHGPN2r42
PjePq8eVNY+9dn38vV935T5b/zfE55Zx9ceyPu8fVb8l/DQsNT2ZDs7z8pfY
rnVdYt43Kh9sN1y1G+KD7XZTsw/JOr8p8c3ffHDb9HG6OT6enVuy5q09/a7w
3G4bl219fnlu9XPSy0mvJ/2fDpss9p0eXdhxzr0963/5+TWOiYf/5rXPMOXu
SPzbx9Uryz3Zbm7NQcwHRtW3CXcOK4/PcVn/d2Y+eivxObaN7zdd89GLCo/u
zoyb8+251l/H1bvL+sSv0xMLI+7BUfV8wqnDo7sn88TBu3dYPLqHRtX/Cafu
jnH14ppZ2/cmpnWl5xbWHI7c/TkX1+6BYXHh7hxX7y7rzdp+MOPi3Bd/XLuH
Mi7mw/HHl3s48Z37QOaAcfePrNt/jKovFCYeNt0LRtWDiY++U/+Xtf1I/HHz
/jkz57k1fuJkrdt/Z53g6T0aW6+qf8XHer4794oPf4w+61b/sB/Hfjzrk49e
Vq/Pc/FY/LH+/hP7b+Ma5//3ccXxLGAAPp6Y/xxVjzpsQBy//2Xcen4i/o+M
qg8Wvh+GOvsnzWdXOf9m/7TZK8+vHmN4hgfI+Y/SD2vh8rGWvBf6cmHx4R/y
x/3bQ85/VGzAu8fV28xatbZ7GddTS0zX8l70M27dTsYfY5B9Zp4LMT1f/xpV
HyxcQb2w5sTnnnH1KrNW8Qz1ncJytG4Xyri1N29UaxXbcKFn+Cwc+9FRnYtn
eO+4xvl7Xf2sGaxIcXAL7x/XfbCuMAyHGXetQez7xmVjJ/57VD5YiziQ5oyv
iIU4yv10b0fxx3V8Iu/RY6Pqy7Vx1mc3eprxqI/aDCOxi42LOJWYOIp8rHP2
ov7tnywu4nT8/zMq+yNZz4s+w1//MOxETEW9uD4e+zmjYi3i5erNhrVonG09
W8PPia3P2LNyXeOL5dwHxmVbtw+P6hn32rEZnxsfXMfFR8VX/O+o+odtknW+
RMb1EzN+brMfH1UvsU9knS81qjWP07hUfLAcl8y54iyeOVify2TN41Xq/XbB
ZNnPG1WfuIOmq/+Z3mf7zy3/8yerF9mysR8c19xcd9X5FQf38uLJiiPmwXPr
s+j3nt9x9XX7QD6jXphx63y5jB8yt+xrJou9qcfbn6zbcfVL+3DW/4uzhv81
Lh/2MfLSzb57snz4/7nZh7XxFZp9nTU2rh5vG2c9r5jxQ+dWTP6HN3ulZt/g
Po+rP5w1Y72tnHHnrpD5WGOrxOeIuWXf2HyOnFu96Kyro5q9WrNvm6x18tKM
/29cfeO8j/yN3zxZDE99426drHWyWtakOKvGNp+V8lr4rJ743qM1895ZA/rV
/bWN/6Cd+7LYxl+W6z45Lp9N8lpekvkf3fxf3uw7s/ZeHp97J6svnZ50rvWK
3HM95bBBV5koPihbbzp95/BAcSYxQdn61Okdh92JOYnfydZTTo84bFCsSBxQ
tt50mJQYl/iX+q3hP+K/6SOH14mFiNnJ1ndOTznaObxE/euwRzEn9YLDxHzr
RLEt2RiceseJ/86JYovy1wcPVw93D+sOM9J1cTfx//ABsQMxI7EjMSz1hcOU
xPTDlWRjYerzhu2IfYfpyMaJ1EMMwxEfD7uRjfemZxr+HZ6YvnPiYwPqz4Zj
+NmJ4heysQ/1YTOfrSaqLxxm4uYT1ecNf3DrieIOsrEM9UzzunDVsBX54ynq
O6Q2nhYRe88c8Pn0ksI0uWui+Hk4eth7erLh1u0+UT3c8OP2nCj2GwYcLh2e
nHHsN3w7/vh2+nFh/VwyUb3XcOX2nqgeazhu+0wUy42Nm6VnGr4YfpS+beLv
NVH90/DOsKEwt9hYaPqk4YgdN1G8OvHx6vDDjOOQ6Z+G53XCRDG92Jhh+oPh
T2H44HvhfGGAYUcZx6/SPw2366SJ6pOGz3XyRDG32Lhc2F18MMxw0cwf700P
NGwpPB/MJEwlXCv9zTCYLpqofmiYUPg2GFT88a4wooxjR+nbZm6YTnqdiXPx
RDGcxMGCwlJyn7Ga9DfDRcKQwUZiYyPpY4YrdOVEMYTYmEZ6lOEHXTVRDCE2
hpCeYxg9t00Uj4eN66O3GK7NnRPV7wtv5f6JYq6w8VrwaXBq8HL0AcOv+ftE
MWzYuDvYNuLgA2HYWHvYOXp84cLcN1EMGDa2hN5oYv5torgO1jCugx5l+Cz4
Evpo4UqotddDDBsFIwIHhY2hop8Y1gnOA8YJGzdFDzHsEjwHnBI2dog+Y5gj
WA16BnoucPbwWlwX0wWfA78D50PfMGwOvAIcDjY+Bx6JOHgn+BbmiTOhlxcO
hXp8LAo2Toa+ZGJiJvyua///8e/xRPUHw5JQd48NL6/qu7y+XlgMas/1CsOJ
UPOO5cDGlsBj4IO1oAcXBoGaa/WmalzVp2IJGMcqwAzAEcAbUGePC6BGX88u
9fzql/X1wghQT62HGBaDGnCcAON4Bvp3iaNeW18vcdQ7q+MXBz8Ap8G5+A16
dqmNVy+sJp6thl5/KnXU6k/VYavNVsOtrtq4Oml9utSQq6vVU0sduPpT9d9s
dfnqy/moQde3Sn2sukL9uNRyq0WlT6dTV3OsJ5jaezXLapTVKqu31iPLfVPb
qA7buWq49dRyLn27Gn3nquPXj8u56sv0CjN/dbhqYc1B/a7+S+q11Lmol1Vb
q/ZXvyy1ymoA9eNS46o2UG2o2tEFfbEGNb6gZ9eg/NXjLuhDNap6KH2x1I6q
p9OTSk2mGrEFtZijqvlb0P9qVPVl+muJr3ZvQf+rUdWgqY9kq61c0P9qVHVe
alLFV5OqxtG4Wkk1i+ag3pEOiB6IPkitnpo99Xlq/tT+zfS8Yqul0tuKj/om
dWzuj1o39Xbq8Wb6U7HVGek/5r6p/dTDSg2beh89mtRfqSVRm6VGS/2ZWjQ1
bDO9rdhqc/Sz4qM2R92bOGrm1GOpy5rpScVW86KuS3y1WfpEqXFS66HOia3+
SZ2QeiH1UvpHqS9Si6HHlBoh9RFqetQXqQdSM2RcDZDaI/7qlvQRopOmO9Ub
Si2Nugk9fNScqB1Qd8JWN6PHlHoeunc9qcRXc6Gnk1oRmmc1Imz1Jfo+qf2g
gVeLI776GPUfxtV/6B+lhoQ2Xu0IWy2I3ko0+rS+6jPUbKi3oNk3Tpuv75Pa
BnpvfZbUD9CEqxtgq29Q68BHzZP6GPNXi6OPk5oBemkadvp4Ond9nGjr6Y31
cVIPQBdNs89fbYH6AOP0/vqAmRvtvf5O4tAt0+aLo7ZAHzDvl7obmnT3nM6d
rpw2nZZcDyUaazpVvZVorGlf9XHiQ6NLc22cdluPJrpqOlJ9mWiXaVBptMWh
9aZlNk6jTX/Nn86a7pX+lU5WLyN6YtpIPZdohWkvaaLpp+ms6YKN0zLr42Sc
plSvJHFoFGmNxaEvVuvs2VcnrbcSzRO9kx5KdKi0hTShdLG0nPos0bPS/ulF
Q5dJY0bfapy+lT6UVpW+VX8k59LF6blknA6Qrsq16PppOcWhVdT7yGcF/RU9
I10jzSPtJA3lTD8lNu2Z3kd8aMNoZs2Z/pdWkZZxpm8Sm+5L7yO6QzorukI2
PZf+RXR49Et0dmw6Pj2FaIvplPQmol2jsaEpoy2jX6NlM07vRt/Hn3ZPfxs6
A/uzehnRq9Hz6B1EE0YzQxfGpvnSL4jei6ZFjyPx6Xz0IKJbokWhXWLTYell
RDtFK0KbJj4dHJ2UcXoovYNomGgq6JjYNEF6O9iDt/9OW0SHRDdkT944zY4+
RbRBNBX6LNEA0UjQ9bDpg2iF+NA30ZeZP12bHj70LvQAtA90G7QeegHRi9gf
11+IxsVePP0LfzoamhfjNC96IpkbPYYeQeLYZ6QxEYcOhY7Dfab10COI9sI+
Nf0Fm45D7x26Cvu/tBJsWgy9d2gd7PPSILDpHfQRsq9vv9XePps2Qd8euiL7
mPrh2Lu152X/lm1P2B64fXT79voC2V+352gvnb2gX9Cw4tAd2Bv3/zp76frV
2PO2P2Wvm23/WR8hMe2H6jNjv0e+XY8d+8H2zvSlsU9mjwC71z6rfSh7rWz7
sXr12BO1Z2RflG0PVn8e+6n2huxzsu2p6tVjX9Oejv0l17UHZf/Zde1R20u0
Z2lvU08e+4X2ROwNsu372ecUx96p/TrztI+nr479M3sB9sTY9sr0/BHTHpD6
UDV06uD01bFHJVc/2f6P3G8/0r567Nivkku318S2T2VfyP6Q/SU9bezNyC3r
XWPfRY5aPxM+8vNycnJ2cm/2Vfjbh7FHYT/DvoQeOPYb5GntM7DtjdjDEdMe
jn0D+w32H/SikSuUJ5QvZNtP0G9HTDlkPWfk/eVI5fLZ9gr0zJErl+uT65Xz
lQ/W90Z+XL5OPxy5WvkrOXLjcrHyzXLQ8tP63jhXbk2vG+NydPr2mKe8sVyv
OHLG+sO4D3JE8qzyrfK1crRyuzP9cNgL+uAsUj7yZnL55izfL2cpvznT64Yt
T3VG+47zP+twonrWsPWmObONPzFaUM418Z3Yxp9qxycz/sBk2bv16uhv32r2
WR0I6IJ0/YKeOGy9bH6JtzNe8OvEj6fafRlXL56D2s/cZi86Ubmt2ePqp/Or
5t/Lunpksuz92/hJUxVHTDmvfuI4WosHWvNdxRfze72K6brYfr7HYQfKi7mu
/ji/aDHH4+pxYz4LZXwR+fz286yJypex9dBx9LdDmn1Ou9a8Zj9b/Kmy+Qzl
8DNuz9bzYj/27K7ii/mbZo+a/dyJ6sszyhx+29V8Fp+ofJk4+vJ07TiVcfk4
tj47jv52dK98XfuwZq/QbsCK7WfDXjET9HXFMVD7Oj2uvjz6VOhjIR/1bPNq
P0u1+Oe2OSwa+8nJso+zBibLR7+e49rrWWxcfXz0FtCnR95PHxu9beTu9MDR
O0dO8vFcS75Onxy9eeQwf9nu23MS84LEkfO8JOfKDU7MqWud2Ku+Pc6VtzQX
8/5RGz+vqzhLT1TfG3OQ89TbRI8TOT29TfRQkau8K+Pyk3/NuHydvi76x8z0
iGDLeeoPoz+NvKi+GfpwyNfp16E3ifzkdfGRh9SHR2+emb49bPnSB+Mv/6nP
if4o8of6b+jdIgf7QMblJ+/OuLzoGe2eLzuufjFPZA7ynBj5mPtyYnpf6IEh
H3hJ819+XH03lp5T9jW96oPBRz5T/wr9LeQVV/Edstl/61X/CuNbTVSvCX0v
5Dz1PdBTQU5GfwZ9GuTf9JrQc0JeUY8LfTXkJ7uMy4sOEkfOcInEkVdcPHHk
ZhfKufKxf5lb89ETQZ8EPRVmeh2w5Uj1H9C3QC4Rsx+vf5+J6leg/4Hc40rx
kdt8aXzkEpePj/zqS3IP5Utx9DH35UUx3fHo5QZx+PD45DHub3N75bj49m+M
j7wopj62vrziOnPK5/FecdDFlOdcNz7yq+M59Z6e0ysOPa79DG+eLY+K447n
Lq+IAY8dP8OJZ8uXvjs+8qX45bjn8opYv9jB8swbZ1yO9K3tb69t9qhfjG0s
b3lOnG/ccHlCnG+scHlIbHUcdjnMT2VcHvWpuRUHw3zzxJGH3Cxx5F03yrly
v9jeeN8zLHC2fDWWM6az/N5GXn+zn98vZrNxeVG8alxs+UlMa5zrGV41+6qJ
YuLyuXKiWP4Y/SdOFNcZ61lOEp8Yi1mOFAscT1wuFGsZ6/lvE8VXdt/kD7+V
c+Vg98q5cpWfz7mXThTv2blym5jEGMfyk7jC+MJykjij2AT2Ag6Jj7zr5nIi
1mS/eLr4vHKth+dc+V4MYCxgOUxcXkxeudYXLFTn4gkfFx+5Wdxc/Fz/3uG8
4snKba6feyI3jn2LnyvXiguLFSsf+JOcKzd7Zs6Vwzwpc5PLPSXnynPemedC
bvNHmZuc6svb3DYcF0cXrxTzVB718tjykHilGKbynFiteK/yyXir2KnytJfk
vsltXpRxOdKzM2e536sTRw72ze26HxsXY3OHOTWHt/SL2YndKTe4+5zy+Ui/
GKJYonKeN8VHTvW8zEdu9ob4yPd2C9X6xH7HxcTHlOdUT48jIMeCZ4lxKUeK
kYmbOcO/ZMvfPhAfeV38RdxGeU6cMwwyucfHMy43i8WI5ygvivOHVyjXiomI
nyif/ME2t83GxTbEwsTHlCM9cE6Nb9MvBqQ4cq1zE0cudDJx5HIfzrnyxviF
OIYzTES2POoW7VqfGxfLDg8Pd08O9rg5Nb5bv5iF+IZypFhfmF8zjEC23GwX
H3lgjDR8N3lL3Dv8OzlSPDmsOjlG3EQcRrlWbDmsOvnklXPf5D+Xy7lyxSvk
XLnTUc6V035xzpV7WSLzl0ddLXOQ78U3wleSA8RUw2WTm8VOw1CTR/1quw87
jIuThjeGBSbHe/qcGj+kXyw0/vLAWFOYU/KWWGIYZPKrOGG4YzOcMLbcLzYY
Xph86esTXw4Wowv/a4bpxZZzxsTCxpIvXS/x5ZY3yrgc78aZgxwvdg62jlwf
XhTmlLzuee33nbwXbf7fWahs3KpN4iO/ukXuj3wvXhSelFz6prHlXV+Z+ybP
jPOE/SS/+oMW81vjYgrhAGEeyetiMuE6yQNvHVtudof4yItulTgLGGiDYh7J
M385thzsNXMq/rn94gB5jfLDz23/V3xv+3/nr2cVUwfTR04Y4wcPSO7x2xmX
d8XRwdORa8WwwdyRy8VOwHGQJ8SnwdORO/VdGXdGThWzBEtFLvS29rOva/WL
JcNH3nifxJeLPm2h8sGBOSQx5ZkxVDBl5JOPiS2v+53MR773+FxLbhnrBfNF
3hV7AwdEvvdXseVRL2jXOqjZvtRhumCvyC3jl2CsyNOemc80OdhTMi73e2Ve
u9zvQ3Mqzj39YmNgZMijnpQ5yGnjZGBwyLVeFh+5YowKrAp52ovjI898cuYj
J3xBfOS3sQcwL2aYFmw5ZDXZ6rrlTnEa8BrkV3EjMCbkY9XBq8+Xs70h4/L5
eAz4FHK817Z7ctS4OAw3JY588lNzavzJfvES+Ms5YwZgE8jx4g3gGsjB4iJg
Q8iFYi1gK8hX35tx+ee/Z1wO9sHEkbN9IHHkq+/Kvy/28h7L/OWBd89atXeg
Pl7NvNzs3Zgq46rBV3eOHSBfPZpb4/MnqzZdrbvc7NzcNzneycSRo/5vzpUT
nhd/uWj10Gqb5ZzVYavrlqdVg64WXS5XDboadTnqLuNyzoOM24daInHkaRdP
HDnq/2L4jKveeam5Zb9osmqm1U7L8aobVocs16pGWa3yTB0zWy56pfjIOasD
Vg8sL6oWTW3bgv7vGZeLVjur5lb+Wb2mek555uHC7RkYVz2smle1tfK6apTV
Kssbr5txOepXJo788OsTR75Xv3tx1pqs2mLnyrGrQ1XXOlMzypZzVoOoFlEO
Vl2j+kn5540zLues9lFNqTyw2k11oTO1nmx57HfER65bjZ1aO/nYZdrr+u24
6hPV/6m7k+NVz6r2VT5ZLaC6RLnrzXPf5Hj1kXfuOyarVs+5cstvzbly7Jvk
XPnhDTN/ueWtMgd5bPUl6kzkP9Xhqd+TD1e7phZOHli9mro1uV994S9u9icm
q4bMuNz1jvGX61YzpHZIHlh9mPoxOV71MepkZmq52PLYarnUfckJr7ZwxVfv
ptZKzdVMfRVbTlvdlfqrBTnhxJdL/27G5bcPyRzktOm8aMLk8fR5/32zt5us
WiI1S/Lbh8aWy339wuWjJuj43B85Z7U76ovkvY+JLZ+8de6bXLp6GvU58sZq
PtSByPGqd1F3IaetFkGNDQ3DybHlhE+JjxzySYkjZ65eRF2KHPuZseWTz058
ee/3tTlfN67aGX3b2XtMVr2F+g05cHUS6iXkrtVGqLWQE1OvoBZCfvuyjMuB
Xxx/eXK6WvpaeVG1Dmoe5JPp99UJzGj22fLeNP7qAeSNL098uehN2zxvHZeW
Xq929hGTpc2n0Zdbvjrx5b3vzLjcOO08nf2MBp8t/09nTW8t10rDTh8vN/54
xuW3adLp3eWcadXp12d06Gx57wfiI39+U+ZvH4F2m4ZbPpkGmXZZ3ps+mmZa
bvlL7XXdNS4N9hPxl2PXY934qZOlMTc3+fC5iSOPPZk4cuDn5f2S/5+Xey4v
TV9Mlyx/TntLgyufTMtM0ywvPYiPvHSXcbn0PdvcHhqXlpW+lc5Vbn/xxJFX
XyrjcukHzC3/C9ucXza//d/B+9grfSvNK03r6m38H83etI2v1uyHm71Zs7/U
1TitrDgPx3aOOPSxyyWO3PueefbtD9K90r/SrtK60sjSur68xf9Ps7/cq9//
PS5dK+0qPSuN6hrza3zHXmlI6WLl5GlfnUsTu2LGjb0417IXsEriyNuvkc8K
WlF6UnpWufo1W/z/Wp/RxLLpZlePDy3qCpmzPYhXNP8nrLFe/Y1Ny7pc/g21
b+saT41Lv0qDOjFVutMj2jmzmr1YG1pnfo3vIo8+VeNrTtTR74f3Ki/ca/aS
bXzRdpxuP/tP1Fh/qvLMc9pxsv1s0MbntuNCU9V7V2/lORk/Jz7i6y0+O7Yx
PnqU69kt5lpt/KzpisUWj73hRP29l3H9oxfK+CLtuHD72YiWsh1HU9XX+FfT
9TsffV2NbydXKZ/ffraZqKPf9XfWA3eQ8QviY/5nT9drd+6UPYX2s0Ozu3ac
P1U9bV3fPPQHN+Zv+05UP9D5sZ3nfP2RL4+Pa+m5vEjmr3ftVOK7pvuuL6pe
n4vm/r+wHV/Qfu6ZqN6dz272gRN1fFZs/deWbvblEzXmb3rX6uG4WLN/0sb/
ID+fuS0W27ij3/UzXbwdn9t+TpUnb8el4rOEdTFV/UD1W1w8PnzZ+or6O7/T
7YlM19/Mf+nEMTd9RZeMj/dnmPvs7/z0lHzl/FrP32gxn9/Gntd+rmk+y7Tj
slPVn/F30/W7Oei1Z/z3zb4t98q19LB7fs4Vg61vI99l4s/X/dWzT4+w5Zv9
0ET1F3tRsx+wJ9KutVz8jS2XcUe/652nn9oL8x69eKri6JHn+OLEfEe++9N6
rdjGVvD8zKqj3/VfW7kdVzLPNn7BdNmupZfTyhnXv+kl1v2sOq4Smy8f/cvW
bcdXT1Uvj1Xb8aXmOquOftcfSt+fVTO+ejuuZh6zKp64epkZ87eZnlCrx2eN
dnyZ68lNJb7XYszf9ITST2eN+KzZji9vP2+YVX1YXslnVo35m35Da7Xjq9rP
W2ZVn5Q1439Juw+vyHUdnat3j+MrEuei6Zqr+yOGWHrfXDZd94LP2u24zlT1
cHH0+ydmVa+TtXLdJzLuuo9mzu6PeynOp2dVv4x1cq4+YivmtetJ8er4vKYd
XztVPU362Pvx14fC+Gaz6via2K+bKp+dmn1Fm/PrE0cPgtdl3N/Zemq8Yap8
dplVR7/rYYHrvl6zj5hVxzfHfqP3cKr6Uzj6fbdZxfl/U2z9At6QmM5zvj4I
87r63Rzuyrq1zt/Sjuu3n6Nn1dHvegS8vR3fMVWs+Le141vbz7GziiFsXK7G
mL/pI2Ds7Rmf35Vtznjsb8u5V03XNcztXe34zvbz22ZvMFX5nxusmXZ8d/s5
d1b9nR/G+9XT9bt5YmK/K+div78l43jX78m5YrAx3sV2jV+Gk7xBrvX+dnxf
+7l5VjGH3x/7D9M1Lr6jcWztDdvxA+3nVrm7dvxg+3lsVjH6NrOm27/jy3Y1
Lj5W7Ubx2bgdPzJVXOIPWddTxQd29Pv/ZlVs18Di/tN0jZuPeOJgL4sh1pOz
ijH74ZyLXbxh5obp+pH4fKwdP9p+nu07YDt+cqo4sY5+X3J2sSs/GRuP9GPx
v7bN4eOJ7/iJqWLGOvp9cVqmdtzcs0qD1I6faj9rNPv6du6m8XlxV3NwHzAP
Px0ff3ff8Dxf0tW5rmts09xP55kPlq+/O/fR8EI/kfiubx7YmPhIOzR7H9+v
23EL68D3vq5s18W42zLjn23HraaKB+jo9/fPLl8++JBfaMdtp4o7h0e3VXy2
bsfPTRX/ENeOvWEb36YdP+9vcl/TFdNrMeZv+Hi4ZNvER+wF15hdMbZOnJum
a9y18MG2jQ/NxYlTpaPwWrfP6/1iO243Vfw6xwW/zy4m2Haxd2zHL7Wf/WbX
ec7HSXt9V7+bDz7kZ/Ke3jJd/q771Xb82lTxpjCXvtLs/WfX8cux8Z12THxj
/oY5JoZxLLK3dBXLnMVjnzy72D5fi71TO369/fy02bdNly0mXs1OGd+5Hb/R
fk6dXdybnWN/sx13mSoWkKPfL51dvnwwhb5nvlPFQMDx2CU+f23X2jXxHXeb
KsYO3gj7yjb+7q5imufuYkwVSwd7hP37Nr5HO37bsza7zts1527Y1bhrOfKb
4b3sEX+ch32a/UCz72zz2TPn7tuO32k/c3o1ttdUsVD47h1/R7/jluBI8Llv
ds1r98zto13FcS33wL0Y+E7drvXd+OMS7Jtr8WVjU+w3VT6L9Cr2nvFXj79f
xv2djUHhffN+4XSpx98/1/p0m8MBiX9QO36//Szfq7EDp4pR4Oj3F/aqvvvA
2Ie048HtZ8Vened89f53T9fv5qBu+qDE5OscNfiHt+MRU1WTq072sGa/rvl8
ts3n0MQ3dmjGHf2uNlwN9SG57r3TFUt88dhvavY6XT3nPlvUrh6R8SPb8aip
qpu+v517TMaPbscfWD+9Gjt2qupbt+1q3BzUVB4dH3/n98le/d24mlyxXWO9
XtUzHhsfOrITpkpX9t32f/IfeYZ9T2zHH05Vrauj32dqHn8YWy3tUYm5c5vP
8Z7VZu/SVRzz8SFEB0YDNiv2d3ul+Tp5qnRf9GB0ZgdknE0bRp91ylTpsk5r
x59N1fdcmi76rYOj//rJVGm0Dm3zP7fZ606U76nt5zn5/ntazv1Z7MPzvfn0
qfreOi8x6cTouX4+VdotOi+asyMzzj6q2f+ZrPjiqD06Y6rqj+i7zpwqrdf8
2LRevhefnWvRQdFR0VD57mzc9+XnZJw+6lft+Ou8ll/MLfsE639+/W0Zr2Vu
zV8OgH1O4v+82b+bqu+tvmf/dqq+X5vDb6bq+y+b/xnySHNr/IzM4ayp0mX5
/ivOOhP1XV6cBXmAdjyv/XyojV88t+yze/Xd+vzElytgX5r4F2ScD/uy+F84
Vd+X/zS3bOO+L140Vd/x5QTYvvv7bn3FVH23/fvcsm+xzts9uSTzcby0/XzJ
d9u5ZV/dq+/pF0/V93E5gcum6ju+616eOYh/eWL6/s7f9/pr2/G69vPzfH+/
cqq+z/r+/qep+l7s+/hVU/Ud3/d9tu/mP2pz+33m43h1+/l+s++bW/advfpu
fs3U07kFtu/pT86t6/6nV7kO1709/n+cqu/s/5lb9j979V3cfPbP/flDYvq+
/uepyiHILbB9x//x/Hpt309+4A+Jo7fd7K76P/rOfn2u5bvkv6bqe5zr3pBx
Puy5vkdgucf2ffymqcoD+C5+41R9l+fPx/f3+9rx/vYznlV5A/6+v9/sfTCn
iepNzx7267v8rTlXjkLMRXLd2zLOh71E/G+fqu8yp82vuN5Hvctvj4/v+H+d
qu/+8gzsme/7f5+q7+zyDHdM1fd9596VmGe1mHdmnnqC/63Zz+vX96e/x8ff
jT+cHI75Lx4fcfRP/838uhcPJy9xz1R9x9eH+u748GcvlDwAnweSizC3BTkQ
zPap+l7vOz77oYnq3ew+61fue/wDieO7Lft1udaDGefDfn38H5qq78j6nD6U
cd/FH56q7+NyF2w5BPmBf0xVvkLv1H9PVV9U3+Mfm6rv+P9sx0fazyqzqpcu
W19p38X/lWvJgYgjz+C6j2acz6OJyRbfd/kL5lfccb5H97r6Pi6n4bryCb6L
T3SVB5C7+M9Ucgjt3MczH8f/tp+3zqpeqGx9fuUM/pdryV2w5Rm8xicyLhfn
eZHjkqMQX25EP80np6qHrBzDU1OVr5AnYW+V+E/ER77CPOUWrsZs6Wo+jp7N
zZPrENNrtFdyQlf7OHIXXrscgv8D+L8Cdoc+hpNd9fR0f/rPsI3vlDzDnK7y
EvIYc7vKJ+gb9Zyuep9d2+azUOagD+DCXfXB1H9t0FWfRNeal5jyCovElj8R
Xx5D3sO4/IN44uwef3GOiD0vMeUzzGez5CKGXeUK5DTYM3kJ+YUfZT7zE8f4
dFf5h5va/Me5lp5uU131MeTTxd/fjR83q/IDi+VcvcCmE/+vLc6z4yPXMeoq
xyK38Kyuchr+7r6dl3zFol3lIuQ9+Mg/yM84d6ZXI58Tk+cxHzkWeRVzkKPQ
j8Z35scyN/qYXyWPsXhXuQV5iSW6ylHIeyzZVd5AbsS4fIW+TovnXPmN53eV
c7i7va6lMmc9jJbuql+YPMMyiS9PwpZzkJcQ/9zkIuQ4ror/8zJPc35exsUW
87ZZlcNw3ZuTA3lBVzkK330+0NX3IL1mluuqj9KDbW4vzLlyGvzlTIzxeWpW
5QTcH/165Fhe1FV+wPiLMh/v43Pznhpfvqvcgp4dK3fV10aeZMWu8iFyKSt0
ld+Q22DLe8iR8JFL0T9l+Vx3pa7iLNVi/mt+/W5uchSr5FpyKeyZ3isvyTif
l3aVi9Drgf3v5DRW7Sof8t8Wc/XEl99Yrav8jLwIn8Xz/f11XX1n5/uy9rN2
chdrJL58C1sew7VennE5HzHlTPiv2dV3Fv0C2HpPyFu8oqvchd4Q4ut1It9l
XM5EruKVXeUK5A3Y8iG+A/kupO/Aq/y9/XwwOZB1M2ccfuP6TcjJrN093bNg
ncyH/9qxzfPlmRtm+7qJv4Bb3hXPXx7mNV3lQORqXt1V3kYehf3+5En4yLHM
mq75uW+v7SrO9s2eO12/fzDv10vyHsnbuOdyJu6/vMnLkt94Y1d5EuNv6Cq/
YZ6vz+vF1n5D/Ict/ptzLXmSN3WVn5HnEUeeRN7GuPwJ3/XazwGz6zv127rK
h8idyKfgdct9rd9Vfsb4+pmD674lNva1OBjvGMhvzbn82XIaPjeWzeeAfI5r
zXC2395V/kT+Qx4EP/kd7fjO9nNaci/vyXONS2wcZ1tu511d5WRc9925Fv93
xZafEV8eCXv2PYmP3fr+7mm+8Qbd0+zi93aVn5FfYf80ORk+ckHT0zU/9+19
XcW52j2Zrt/NWf7HZ5E8jOtu2D2dn2Hj37I/2FXOBEf0gxmXF9qoqzzMMi3m
hxNfHuZDXeVb5Ej4yOHIJ2zZVZ6B78bt58HZlWP5SOLLBbHlW1zroxmXXxJT
bof/x7rKn2A2snFN5V4+3lVOBs9T/C8mF2R8t+S+PtFVvkiuiS0PJtciL4P9
uEk7frL9DJOT2TRzxkU0jhEqR/SprnI15vDpzIf/p7qnc0cfzdzwCTdNfNy5
LbriK8oLbd5VfkYeabOu8jlyOexFksPhI3e03HTNz337TFdxVrLXP12/D5Mv
cp9PzHU/m/m7/2yMRPZWXeVYMNC2yrhcztZd5XbkkdjyRfIrn+sq/yMXxJbP
Wa1d9/OZg5zPdl3lcORUtu8qf+L/aV/IteSd2PI2rrttxsXYpitGGf8vdpVj
wcti+z+e3I/4ckeYZvyx++RjvhF/eRvXldv5WTt+vSu9BP0FTQYNxj9iX9Ts
k9txx640G5dMlk3vgW/2ZeutjX+lK5tmg3bjK7Hlplz35sTcoSsdyNfa8atd
aTNoMb4W2xj7+smKJ84fmr1T5klHQU+xU2xj7JuafUpifqnF/1675yd2pbHB
FpOfkpuiiz68K433qdZdVzqNWybLvjH3Sg4Lf4wWY7eu9Bj4Y7uaR+75Lrmf
amoO6KpuyN/539H8H2xz2L2rPJvjt2LLv7Gxxfjumvh7eG660njYG98jtjH2
3ybrHLF27pXWY8+u9B6/aMe9vJ5m7x2bPkTd375d1X4a87f72vh6crldatPU
p3ZVK8pWR3p/83njdJ277ETlCY2rLT0t86RXUeMmjlq/DabrPqgtUgv2va7q
19S17ddVzdRbp8tW4/aO6fJRL+a17J05q9Xav6u6tndPl61u6wPNPrCrOg41
HWz1UBvJ63ZVU6O+hq0WaeM2flBX9SxqW9hqdj7Wxg/uqt5E7QlbvckmbfyQ
rmox1GWw1ZvQeB/ZlS79i3jgzXazNm/2YV3VEagpYKuh2HK61hjt/aebfWhX
NRdbN/uIrvTztPRsWv1tpis+DbkaDf7qPnxn9B3N9zvab9elRac5/FFXukr6
5x90peX+cotzdFdaYrpiNv3z1+STu9Lo0uuy6Yq/0caP7UorSzfLpt2Vx905
z+wO0xWfvnr3Zv+wK70l7SWbpnSP6ZoPDeQuzT6uK53q3s0+viudIc0hm5Zy
3+n6rkrXR9fKn85WrlTOVO6URs7zS+93Uztu2M55MHladbyP5XPIZxPtGN3a
SV1p53yOnZzPq4PbeT/uSpP2k64+I3w+HNLGf9qVBswzflrWs88Anwt0W4Nc
S/7Z54zPSnqwaycrljh/maw41+Vz6dR8nnw11zo0mjLn+oz942TNB+PR38T5
U55xc6D/kidXg63GWv5cnbac+eyM29dTx31mntmfd/X8fzPPOBsP8p7J+ptx
eWw1zHLX8udqm+XMz5gun7vMp9mnd6XJ+ftk2T5vFoq/umr5eTXbarLl7dV+
q/uem3H5/F7G1Xz73Dgjnyfy5+ql1UNf1a5xRVd5VPXNGF4z+XM+cu/zM64G
Wk2zOmc1zb/DFfEMzmn/D2vHS9rPByeq5vj8fF5d2I4XtJ+1J6pe8+J81hm/
yNqbU8cL4/OsxFdD/cvpGv9Vr/Ry4sif37ZIxVEDessidb5z5czVMx/fq3PM
R+76sq7mZ26/ni7b6541b2Li8q5qfM9p41c2+6+9+rtzlkrt7+X5nLyqK5/t
m/3UIuUjprErMr7MvPJj/8H68lw0+7/t+HhXPb5d4+qu8sO/nS6ff7ex57Vz
f99VPbGxq3Ou+GKunDpjPjvm3whrD1eAv+ut3XxeM69s517rs8qanqhr/Kmr
3K+xP2X83On6fZ7v1O3c67qqc720jf+t2R/qV62qcf+m3NCO15vfRNXz3djV
vwXG/+KezKnjDfER2zze0sbPn67xZfp1PXF+33y+Ma/iqGH9+rw637kfnVfn
mqdzfAbJtd7cle2z6K/teHv7Gc6q422xL56u39/cL/9b2s9m6qdazFu7p+tH
2f7NOnJe+Yip/viPXf17J4ZrbD+n7sed7WelWeV7c/zVSt7R1b9xf+/Kj89v
5tW55mMezpV3vXC6zn1ZG/vdvDp3h8R3/m7qntr4XV3VXKqHe6Srf+NumVc+
4t/Tjne3n/XlJAft/xRd1Syq0XSuf1vv7cqPz1Pz/l9T5x5lVXHl4dvdt+nb
t7uBrmoElQYE5DUBXZNJnFFBTBwZEGLU0VFwibp0jPjCmKAQHYxEHj5njEqc
mIiRl5Io75goCQE0aIyoqOMzAhp1JaA8jIJRmP3173fX9Y+z9j777NpV99xz
6lSd+k6V9tH5X0nL+89nsnyuKGrb0ap3j70j5oehX8S73CadE77Pfjb8Pwh9
BuML4bOzVd8vYtthf3TSzvc3lJSt4/vKVh3D58Ws++K3ReVP2e7qpLi7WvVe
8eOQf4vtgdDnFqXz7u6TVh3D/lzE2d2q48dFefaEfiNlbtZ545tCjmNf4e8s
KTPtgRey4iwpatvXqvd1+O9ynPMizt5WfdtHeff5XiYd5Vjnb/7wob1BPrud
dmKzfCgn/zfXJ+/qiUO98HwnzW18RNJ8yJyLz1v1Lu77kfaz1uo3eei0W/a3
yuct6wdatb5654jRkrRuI2ukH7AP38axVjptG9aRrktaSxpZa31z5FuT9D6N
dPudluM19mEddeLwTR520rOu9StZ++9FjJez0hKPtalZ67ryrRs6D8u/x7HG
pHdWfB/GOr60bcpJdtY8bQjZKWmtXiT7lfWBG2x/LesY8bok/X5+e1NSLOLw
/RZrrNIeo3z1Se/lWFu1yT5d6nXeeO/0RlZabKyzSlq+AyOfeufLcdKyjitr
C1N+vnX7U1YZ+tVrrSfWguL7G9bM7OKysS4l61PynRZ+rUnvo7ZE2hT6UfWS
2FkfkG+58KfdyHporJHGt0T45KT1BlkPkDUIK99LodOeJFa3pHdQ+CbH7M47
86S12LZl6SfVS3KM9dlYnzDbn7Xautufb5goA23Lfsy5nbTWyTsR55DQJ9ZL
Hpy0vhVx0Xnnc2jSMex8M8T5oR3LOleH2s5xdNa/4lxy3lh3lLjtSe9nrgr9
sKT3J6z/0ztpLaF3owy9ko5j62U7kn3WC0Jvt51vhlhPiDYzawqh870Rv+kw
/673s/ZnRcyFjAmGvrGo73VY/4Z2Neu09LM/a7Ng55se0hye9G7kLxFnQOg/
Dtt63rcm9UOxDUxag4I1K1i7gu9shvDfJq0bgD44aV0Avr/Bp7PTEp+1M4iL
D+9DWMtioO3bs9I/Uq94QxyH4wPsw5oD/2B7x7oESd/B8E0J86rzHQpzq6NX
vhHhGxLeSwwLOdR11wdZ++ttp05j7nbkMPscnfTbmRucdxF8l7LRfXy+waDP
3vFdTtJ7A9rtfE/yuvvjMOvv+v0G37psdpuf7z063j/Uqzy8e+GdBt+Z8B7j
mKS8yXdnlk57e1TIf4vtFffl+X6DvjnHSUMb/l9DnhDbpILmNT+mUv6IMyJ1
JCvsgX/mNxdk3+X945J8hhUk2We+po/j+N/gj2P/o5DH2wfbyNDHFWTf4/2v
JfmMDftDDYqD/+MNOob9ePstjfjTm/V84Tn1ifO5pKBrmWuV9YX2hf3E0OfQ
zvTv5DfyW9E3RJy9Wenx29KgczW7IPso+2MbZTu/6wSX59OsPEbH/jf4TcTk
/ESck0JfaJ8xTottjO1I9rdHGf7uGIto94Y+NvQneB+SdYx99HFOO875FeI+
LZakk+/+8Pmm9QOwyqG/HfopSfZtBUn223geRkfq1NBr4hyWQ2+M7bzY//fY
TiN+jST7g8L/jJD/EduxodeF7+nUO+EzqCQf/A8qKT551bYpD/zotJ32BfsZ
9iceeq8a+VBuynR0ScewF9uU35mx3ynk2ZSBsbwkfXyNJPsXFOV/ltOOhX+2
P2nrY5uQdBz7N2mr+3fPDZ9zSopDzIkhz43tmqLSkf/wGtk4dk3ok0v2Cb0U
Pg2xnZOkT3Sc8c6PMjT6+NQa+VKWCYzxhTw/trtDfzpiXhF651rZOHZLlOGG
knR8WiLtBaGvYrwv5H/GNq8oyf7KsDe36bfh1zXkJSFfCPudJfnh0yXsF1HP
MBYf8lv26dwmvRLnQufLM+Ji+xCT9JNiv9Vyl9O2OO6lSfnurJFkn+cL99C9
vo/4rZf796Y2xbos9h8tyZ+02bYu4dPWpv3JTkf6N4pKe7n9uZ7P9//Szb5D
I+1BoX8n9C9Z59hVsX9lbN8mbVHxr3R53ijJjv+37Yf+3aQ4Y2hvOMZJtbJx
rFivNei/a58ebfKbQpliu5pzbfvV9mH97mts/17IabHNpM0QPgfHNtXp8GEt
+8PDNjv09jr5THNa1jv+ntP2DPuhsV2Ln+WCWtmIN8s+19kf+V9JaxOz9iv6
/FrFJibrhvdqU6zp3P+W6xk7C3l9bOtC7xP2GdaxcYz1Z7H9IGmdTdbl/L59
Dgv/G0LfWqvj+G1xnN4+Rlmuc3lYu/AH9ukfx/v5XPQNOdN2bDeGfqBW9sO8
PyvJZ3+tfsv1jsk6cbNsn2k/1kk82P/bxWG/KeSc2HrWSbLPmnEDw+fm0I+p
01paN9mHss1xzAFt+s/wY62iW0MeXSf7LfbHdovtSPZZb2tQm/K4LXV0UQp3
pA50p2Ntl/9OmtMPn9udFtvttiPZZ52jwY5xVp3ewcLjwuIuss77WO577vGV
RT3vyevIguZb/KHzZ39u0vElvEtPOj7O9m+EnN8glrS3n913Jz3Teb6j8xyH
M8UH7pR8fpiqsX/kOLCgcLfwn9j+13byvcf+99gfHcn+Mpf3TtthXIkD77qm
QXHw4bn5uZ+XtDeol2gb0J74SeiX2v8+54vtp7bfZx07kv0n6sSswozCi/Is
fyT0JwtiR7HDi9Im+VlS22w+92Vsr4b+QNL+TQXlwf4ljj/P+c6xHR/aJsSh
rbKpQXHwWeA4l9o+z2XDttBptzZIJ1/0JbYjH7KOZH9Hndoti5PaMxx7MKks
i6wvLqgdhQ9tG373Uv924vzcPrSRHk5qw8DQwrDCr8KKwozCoy72eSP2ngal
pQy0f0hLWwjelbQwrvCupIU1XeZ8FzvtMuuPh/xNbLXxXKiP+nl56DVF+S6z
Tjvl10ltFezLXX7aWiuT2k4wnrCe8KIwtOir3L7ChzYYaVYl/f/wpXCcMJyr
Q/4ytm5FydWp6ov+TkFl+6Xtb/sY9u5hf9Rp8X3U9gf9f/EbYUHJC0a0cr1y
X65J+v340+Z7zOeBffS3LR+3fXBJ52pwUbY11inDGsehvce5on0Imwpjuqug
tOsdhzbi70Lv47bi2qQ2JO0+dNqBtfahXDCqxIEjJca6VD2+znHoy9P3p8+O
Db/h8I0Rf4N1OE14TZhP2l9PJrUJSf/7pHI9FXKjYw63fUSN2p/40z6EVYZH
7OAhS0qDP+metv+4kvRTimJNYT2HOt5G+9BGfSapHUi7FJ32Ksf+mJQ/vk85
zgTbz7Z81vom6yPcRn0hqZ2JjWMXFtWOxU7bFftzTgtrCutZ4TzRYbAnluRD
WthUyg+PSprNSWW5Mnxe5j61/0upevzF2KbVqF272fpLtp/t87PJZcb2sn3Q
X3JM+GH+L9haWE3OOcwnbexXktrAr4Z8LbYf1Sg9++RJWw8f2ntzbccH3zes
U/7Xne/rjjPNPuzfGvFnlOSPvjXkFqdleyspNm3hPyW1h2E4YT3vcfscO+1w
mFXss5yOOKtr1F5/yzrX7QZfS+S71Xnhu80+tMv/zHmsEUcKD7rAtndth//E
DjdL2/6dpGf3avuRJ8/0Drvjk9f94fOe46x2+5z3P7TtF0Wc90lb1PH3rN9V
ko4/9vddBuzbHBP2Er4TnhOmFx3OE7+/Jv2mXdZ3W263jtzBPVCU3O74lGeH
dWwf2B8mE14TbvPzkPtjG1vrfkBSXwC/XUl57g75UWxdw2dP0j7H6Vfssv1X
JcWnDLvsg53+CDHpa2Aj/ZtF+e9xHFhWygM7+oeS8sIHvhRGEz5zb8h9lKco
n32Oj/3T2IbVqg/4cVJ/hH7LJ7Yj91rv6n3KfsC/HfubJcUhPvucF2LAh1IG
uFP6KZ8l9WVOsg/nDTYV7rPdfR986MvQ76E89IngPPGBw9zn8nR1vgdchhzt
0uZoUw2tV7kYwCX+hyXp9fViHmEfYS85VpdVFvo4tVl9IphPfI5x/6iU1Qe5
2P6TQtaHLH4hfr11bOgHuy9GTPpNNRGnk+3wn3CWMJawlugwnHWOOcl9H/Kl
b8V+Y1b+zKX9L1ltbGI25erxcmyza9W/arTeZDs+8KLwl7CX2Jrtg970hfPG
+eRcwV7iDzPZlXPGOzXGu7P2F9YqPfuz3AfsnNWPW2D7QvfvsM/0f9TqfFsd
Bx2Z7H94o3TygtuEZbzLfbq2rH4T/UR0+nf0A7uFvsFpuzsOtoNsr+xTLhg6
WDpYPo7jf3roR0XaHtZhOGEl4SThJdHhMLs7JvHoSx6S1a8kj0OzyrLV+rZa
+fbI1eM9bW+3jp18263Tx+yT1QfkeC/7sx2WFXt0o+wX14ulhL+EdaT/SFr6
obCj2GEy6ddSTvq8BxynUCdOkvMAT9g3ZL/YrquX7Jurefa1P/n2s52ytbsM
rEve32nx7W9/+FP+OzhY+qMDsvqkHBuYVZbBIQfZv932XnXqF+Pf0c+1D3bW
jx6StQY6tsHWKcNgx8E+xP5wm/CRLU57hO30mYeGfqz7zl/K6vPS/0WnX9zL
PpQLvpI4cJvEGJarx4c5DvduJ99r2PBjnWvWzD3S+pdD/lNs4+vEPcJQwjF+
xfZj3Xf+x6w+NfukobxnWSctfXl86F+T15FOS15fsQ6LQ10xpU5M0VFZ7BD5
fNVx0PFnPV/WZv2qdThVygbbSfp/pt6oU/1Df559Yh+dVRfxTgCdPOEbj8ni
J8nj2KyyX239mpAjQg53GWCKjsvijijDiFxNN9z+fZqiXZzFbMAsjczijmAM
v5bFLsIafT2Ld4IXOiGLESIGMeGR4P7g/2A8YG5OzFUWBh3uBVbq+CzeCdso
29eWpZNuUaNYQ9gbuD/4P/iZe0OOzuJlfhJybBYbAzuDHb5lS8QZk8XqLGtU
WngYjo+xz72NKmefglgY4sDAnJx1HmBRYAxhDeFtCswTnsXY4DvO/o81yge+
BZ6RMsMXwcKc7Dg/zdLhaJ5oFJsIpwGfiA4/c1/IU3OVeUFfUZA8zfrIJukw
M5saxU3Ct8BOosM5zAt5eq6yKujPF8Q2wjvCq/ws5ISssf1XG8VHwsPARaLD
0tyfxc7BsBDjDMfBdlYWQ3J9k3T4mbcbFX932M9tkj/8DGzFBVnsBBwB+cKW
bGG+0yxuZB7zhGexLjsaxV/CpcBdosO9PBDynFxlUtDhSZATra9tkg73Qp4X
Ol/yPNv5zg95Xq6yJOiwJcjzrX/SKNYTFqWmLL4TDgSuEx2+ZUFWHrAncKD4
w8PcHPKWrHHVQrPKAB8ynfsma2waThO+E+5lIWXM4keQ38piMGBC4URhVPo0
yw6XAt9xkX1GlcVZwiEsCjkpiydBXpLFb4xslg5D0rssxhTeo1tZ8eFzFoe8
LFdZEnTG4JCXW4dhmeSY5zbLDkMyuCw+FcYDLhUd5uShkFdlMRVwH5Oz2Ay4
DOywGdiutP3LZfGs8B4wregwJNc3ywfmBDaW8sPGEOM7jrOWObezuI4lIadk
cRPDy+Ju4TfmNcsf5gQeFjtMyINZ5YBhIR1x4CXgJqZYh2PlPMOE/Dzk1Fzl
QdDhMZDTrG9plg77cUpZfC0sB1wtOtzFL0Jem6scBzqsBfI664+EvCFXmQh0
3o3A4cLmwng8nHVtVbiM6b7GCi2KA+/Rp0XXHkzChWXxu7AWcLvocB0TyooJ
szGvRdcw7AF5znC+M8pidmEPriiL2YWpgMNFh+VYyrWZqwwFOowEcqb1c1uk
w2xMLYsPhqloKuu+gHEa2aJ8YUVgH2Zn8Q/IOdavb5EOdwFTTBw4E5hiygnH
sjzrnqzwFzf73lyWFQtGY36dWFI40lvL4o9hJBjPYmyYcejbQt6exR6syNqv
sBK32b62RT6MU68M+T9ZjAN1OPU79Ta8A/YOLiL878jiKFhM6a4sdmJVyDuz
uID7y/omAa5gblkMNBwFjDN2uAvi3eGYpCMO3AJMwZ3W4aZJC+OxJOLcncVI
wD6jz/Q8kbC8cLywybDOzIUJz4uduSTnZq1zD0sAzwAnDSMNm4zOHJysdY8P
HAUsJc8knkewsTy/eXbzPOS5SHtjdVZcGAyerTzX282Uct54JvLsJi3PdPhS
0vI8hcuY6/LAwZJ2kzkKyg+nzfOLMowxb/aw7xeeZTzneH7BNvJc5JkIP8nz
hmcNzwWeGTyneNZg5/nCMwV/nlmwY9R3m80E8mzguQAzSP1eqdvR55vro76m
roafJD7PI9g86mLqYepe9HXm96inqKN45hCfZwr1FvbnXR9SBuo3uC84s3rX
T9RZ1EXUZ9SPH5qFQ6eexB8f6jTqj4ddV1AX/cJ1CPwYOvUVPCznjbYBfBb1
FHUUnMYK3xfcW8t8b3LvL/X9zjvepa4fOrgq34PUM4/4fuce5b6tsE/Lff9y
n63w/QUHtNL3F9f/St9HXO+rfB/B76z2dQUbA7MOP8N6YY9mMS0w7Ngf8LW9
2tctbRXmDeyYa7FV85BW5iP9ta9hrmd0jtP+ZI5R+G2YGeLD2GB73Nck1yc6
vrQ5mUsUjp25Vn7lmMwTssbXNvI31rnm0UnH/JbrfE8xd8dvfY9wr2Gn/Yht
ba62J0mzvKD5NH7ntNxf+NBWZe6Ux1xO2o3MawnnzH0B+wu7zMa8k5V5Lzf4
GmAejPXWuTawd/DWLgfcOOme9P3FHBRPWIft4v+irmNeiN/7vuMehIfmf2CO
x6d9j/zZ+zDJ+G60P3NEPGUf5nV8xvcgbTz2YYa514hDDOZS+IN9uGfxx5d7
EzaXdhYbcwvC9DLv4rO+l5nr4I/Wucex085lww6HTLrnfI8z58CmXG2bce/T
HqNNxfyDsMHIF3zv8237S65PaI8xbyB8L7aXbec7/c2uE6gf4JLxpa2FX2W+
wRftwxwCzzs+9RVx8GU+vdd871MnwMXSRuNb9f9z/cA+Opwt8hXbqa8oM7+D
78dfdRzqHXSYVdpIzFUHN8t336+7DkG+YZ26BR1f2kLMTwfXioRPpa7mO+i3
XM9Qh2PHl++v37QP81994Psd3y252nZirjeYUr5x3ur6B7nNOm0n0sC10m5h
vrbKXG1vu45CvmOdeo/4pKMew0462irMrQbzyfe56Fe5ncA8YnCV1Glwn/jy
LSr2H7t9wlxpMKJIOM5ZrlfROc53uO/ZTl1K+bs59l8ch285d/g8MJ/Ydt9f
tD3Yh7ek/sSfcvFd6l/tQ3nfdZlpPxAHLpH7lDjEoF7lPHOc5y/fK1a+VUSn
jkXutE7di44vfCGcYbh2SLjDrq4z0YfbB4YQrmCk9SM8Jg7DB9fHBqc32z4w
iHBHX7fO2CjyY9uJ8ZFj4gMfyNj6idYZi0futR22AX9iM6ZZa+ZttPNlfLyD
pzNvxxg6XOBo+8D4MZY91jrj3cjPcpX3Q+c4G6wC48snW2d8mfxg5BjfJM9P
/XvxgaljLPtU64zzIikPdmLsd8wOHrBNY7KnW2dMFllrO2Pc+BOb9iDtQtqH
Z7oMjKvCB8HW8H6Ysdei+Tk2WDrGQJGdrMPEdfBwHiftVGHj7M/YKKwWzBZj
FvjC2I13Wrg6xv7Os86YILJs+wTHH28fuDjG7y6wzrgestl2xlVLZvUY72s2
R8cG28Y42kXWGV+rMHA7PdbW2fzbZbbvsj+8HONryK7WGXfran5ukn02e0yz
bDaRGMnxYc04F4zpwMHBqzEuQ17ZOuNfyczcZNsZJ6K8nV3+yY7D+WR8p82c
HGNDB5lpY4NbYyxminXGaJA9bGe8pocZKTZ4KcZKplpnrAR5iO2Mpxxi/owN
Fo3xCDgveK91fk/ex9wXYxY9za5VODauq+nWGUe41nFmeWyil7m0CqNGzBus
My6Ab0/nyzej9ONg4/GBE+O9PbwVTBXvfrH1tZ13+33NkrHBmfEufbZ13qUj
+9vO+/b+5tPYYMB4p829UvQ9e6PzZUyB994DzImxDXQZbrPO++ebHafd76gH
meti453wmX5PjM77XnwHOF/eFQ/xe+P/B8+dCuU=
               "]],
              Annotation[#, "Charting`Private`Tag$5808#1"]& ]],
            Lighting->"Neutral"]}, {}, {}, {}, {}},
         VertexNormals->CompressedData["
1:eJztnXtUlVUaxgGtRCDJMvGSF6z0kBRSaenYnhY1ecHbJKKmVJJEGkMeVg5E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          "]], {}}, {{{}, {}, 
         TagBox[
          {GrayLevel[0], Thickness[0.005], Line3DBox[CompressedData["
1:eJxd23k01U/YAHBLJFJkyU9SWduThGwTUagoW6Ik2SMpIXu7nSwhiRCyXPte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            "]], Line3DBox[CompressedData["
1:eJxd1n04VFkcB3CMt9RWGOMl2UeI2keTISaps01pRaFZlUirGS95C9EqJNpI
UoqZpMk7qY1hNN5SDpqIMN4yG0qtGCKZvJWttfpjz9ln7/PcP+7nuc+55/7O
737v0WUE0j1lpKSkDi6ehMVTJdZkYQgGb7Nb+HZ8ADfTvh1VoJ3DOz9swAFV
Y1rdDX3YP9rkEAN9boMOSus1Thh2QNWcvdF5D9ieez7N6phArkGVeyY25ILj
f9DNcxbeI1eMvcqYK+UCt75Gads12EegBoNRwQX0mYmOB5vHkcunJeqqL3oi
P1WHvG8MOY2dbEpb9PmEZHaRxzvkTkJ5dd9KLqDITlXJuo8i93VJzFtZzQW8
L/2C8IMjyN1Ip17QIReUqxmTQt3EyNfqf3eH2sAF3SvO9P7uPoz8fRkz8ksX
Fwi8arvS7YaQS0LOcJnjXFAoX1loY/oWud1Gv556lWJwe11+Y7v2IK5P8dMM
X7tikKEaPa1C+BN5uRW4dIBVDLzmqFudP79GrnXKX0yYKQb5/c5Jbn0DyPMf
M9a/Sy0BrooOgUJ6H/IBcryL5AwPTBiaDSkZi5APszfJuteVAmJ/SfrUT13I
a8VZ4225fJAW4BrXxWtD3rrEdXn2TDnIVjIj95GeIq9g/XxPovcAnLRkxtm/
qUNudd+XenHyESATozLnF6//9aDlGnIuSnXAsEyD8FamFPmQy9m8XtZjoGql
VsT1LUBO7spqMSI3gHEmm0JkpSNnSHuyjcyagFnsuKdB+lXkHmxHvbs1zWBF
Y+ZXzzXxyNcLpBIKHVuApcyslkQxBjmFSdEYa2kF2Qu1IwZDYcidd3duJu0V
grajHnyKcxByIcNoSVNUOxBvCHfvFQXiebpfCq307wCr5OdHuTZ4/LG7uyRi
305gKPLSsu1NQW6WNurZmNIFrAvUP11eloe80IA+5jTWDSbV4rO2QB5yts2V
kYyIHmAEHhB9uA+Rp/Abqg0ovYAY82N30LwQOdPlnFlCVx+wAYN6ueHP8f22
u72+3/IS6LcLY0v7cJ+YaGQZ/+b2CihGHvEOHHyD3PvV2Qs8qQEQPbXfWRXg
/rcvOy2W1hwAtO1h1JJC/N1ptiYeoma+AvEZwT0KBJwPrAO6xOHMlyAyyrFb
niFBrq3yIYq+vB+88Znu3io3hVxXfGPenv8CECWb+Pkh0zh/HIJCPjf0AOuN
tKL5yzPILRXUcnVyuoBPdVxMt9MsXi/ziZQkk3bwazl1sEaMfXk8vegxrQmw
SDTCboc55Mo3BAp1kjogSOj0mU3FLli6McBHng+S3E0S9Z5gL1i1+ik1JxmE
u/gddGjC3nPzzkLB9WxYeUt4mJeDveRwSK/pX3yobO0f2LkX+xHzhxdnDWrh
BUpzzN0KPM8V/GB120IB1OGw9O0G8fv6f9CWOTHXCE9rG5oeeo/rc/3J/gFS
RDPct1RWZq4T11OB9Jp3fG8LNGfrc+pzPyK3sDb9tC2tFUYu09nhxMTrQmNH
kLXi2+AoSWeD/tf/5H+p8u0saSGMLiFcKrPAud13b03/HhkhtM5s/EKoxv0w
STQOtk9qg9dm1sZ6+uG8vSxnYciMb4UneNuTA81wX92KUA69MvoMJgTr/+LF
xPk58rdXlkVTEyS2reLIr8T5KaJd3/+jfSNUct7gesgc56dTJGfcUCSA6QH7
Plb2435uVcrSWc2sh/PG913Up7Gfn+kkEUQQunk/p2hcw+P0lu15K5tXDSkd
B0ISyvFzl+mG5Vf4VcJQ3WOEiHU4/zt3kK0t28tgiCr/s0iE36uwxrA1t/k+
POldc+GHVFwHx0e2ZNutpTDJSsiZdMB1E571aIAEHtxZo7XWRgb/B/lVzrUG
48VQ0yxK4WgArr+7Qx2cUi5a7JPtcSci8P+XQVatP2Z8B0aHSjSSd+J1bD65
qz/iSTq0Ugk2TWrH3pK789t+oIb5v/3AP3Y0SsY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9RWGGNI9giN2qPJmJikbimtKGRVIq1mvOQtRKuQaCNJ
KUySvJPaGEbjLeUiERnDkNlQasUQyeStbK3VP/fu2XvO88/nPOd57v3d3/O9
jw4zwMFDRkpK6tDiRVi8VGKMFoZg0Dabhe/jI7iV9n20gI507oVh/XRQPabZ
3dSH/ZNVLjHA+w7opPGvp4diBwyN2ZvC+8D6/IvplM4J5GSG3HMxhQNO/Olg
krvwAblizDXmXBkHuPY1S1uvwT4CyUxmJQc4zEx0Ptw8jlw+LUFHfdETeKna
1P1jyC3YScYWiz4fn8Qudn+P3FEgr+5TxQE02alqWbdR5D7OCfkraziA+7W/
MezQCHJX0umXDpADKtQMSSGuYuRr9X64y2jigO4VZ3v/cBtG/qGcFfG1iwMa
Peu6MmyGkEuCz3JY4xxQJF9VZGX8DrnNRt+eBpUScGddQXOH1iCuT8mzTB+b
EpCpGjWtQvgLeYU5uHwwpQR4zjG2On15g1zztJ+YMFMCCvqdEl37BpAXPGGu
f59aClwU7QIEDn3IB6hxzpKzXDBBoQ8pGYqQD7M3ybrVlwFif2nG1M9dyOvE
2ePteTyQ5u8S28VtR85f4rI8Z6YC5CjRqX2kZ8grU365L9F9CE6ZsWJt39Yj
N3/gw7g0+RhQiZFZ82nVyAOXk+WcleoBpZxMeCdThnzI+Vx+b8oToGquVszx
KURO7cpuM6A2gXEWm0ZMyUDOlPZgG9BbAD1m3EM/4xpyd7a97r3aVrCiOeub
x5o45OsbpeKL7NuAmcyspkQxGjmNRSOPtfFBzkLdiP5QKHKnPcLNpH0C0H7M
nUdzCkQuYBosaYnsAOINYW69ogA8T7fLIVV+nWCV/Pwoxwo/f+zebonYRwgo
Ik9N695k5PS0UY/m5C5gWaj++cqyfORF+g5jjmPdYFItLnsL5CJnW10dyQzv
AQbgIdGb8wh5Mq+pRp/WC4jR27sD5wXIWc7n6fFdfcAKDOrmhb3A91vv8fxx
yyug1yGIKevDfWJEzjb83fU1UIw46hUw+Ba51+tzF7lSAyBq6oCTKsD9b1t+
RiytMQAsdoQySovwd6fBTzjMyHoN4jKDehQIOB9SDuoQh7NegYhI+255pgS5
lsrHSIfl/eCt93T3Vrkp5Drim/O2vJeAKNnEKwiexvljFxj8pakHWG60KJ6/
MoPcTEEtTzu3C3jXxEZ3O87i/TKZSE406gC/VTAGa8XYl8c5FD+xWJwXyYKw
x24OufLNRoV6ST1ojBd6z6Zib1y60d9bngcS3YwSdJ9iL1y1+hkjNwmEOfse
smvB3nPr7kLhjRxYdVtwhJuLvfRIcK/x3zyobOkXINyH/ajJo0uz+nXwIq01
+l4lnucKXpC6dVEj1E5P0bMZxOv1+6glc3KuGZ7Rohgf/oDrc+PpgQFSeCvc
v1RWZk6I66lAesM9sa8NmrD10hvyPiE3tTT+vC2NDyOWae90ZOF9sWCHUzXj
2uEoSXuD3rf/5H+Z8p1saQGMKiVcLjfFud13f03/XhkBtMxq/kqowf0wSTQM
sk1sh9dn1sZ4+OK8vSJnSmHF8eFJ7o6kADruq9vhyiFXR5/D+CC9Xz1ZOD9H
/vHMNm1pgcT2VenyK3F+iixuHNhu2wyVnDa4HDbB+ekYkT5OETXCDP/9n6r6
cT/zlbK1V7Ma4LzhA2f1aewXZoQkgghCV68XNPJ1/Jze8r3vZPNrIK3zYHB8
BX7vMp3QgkrfKhiic5wQvg7nv3An1dKsoxwGq/K+iER4XUW1FH5e6wN4yqv2
4k+puA72j62p1lvLYKK5IH3SDtdNcM69CRK4cFet5lorGXwO8qqd6vTHS6AG
PVLhmD+uv5tdPZxSLl7skx2xJ8Px+cukqjYcN7wLo0Ik5KRdeB9bT+3uD3+a
Ac1VgowTO7C35e36/j9Qy/rf/8C/bd5QNg==
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BEatUeTMTFJ3U1pRaFZlUirGS95C9EqJNpI
UoqZZCfvpDaG0XhLuUhEGIzYUGrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8eM5DhKSMlJXVoaRKWpmqsyeIwDN5ut/htfAA0029DBDq4/AsjhlxQNa7d
3diP/aNNDjHQ5zbopLZd54ZhB3StuZtd94Dt+ecz7M5J5Jp0uWdiMg+c+JNh
lrP4Hrli7DXmfCkPuPU3SduuxT4KNZnMCh5gzE52PtgygVw+LVFPY8kTBam6
lP3jyK04yaZWS76QkMwp8niH3Ekor+FbyQNU2ekqWfcx5L4uiXmrqnmA/2Wg
IfzQKHI30ukXDMgD5erGpFA3MfJ1Bt/doTfyQPfKs31/uI8gf1/Givwi4oEG
r1pRut0wcknIWR5rggcK5SsLbUzfIrfb5NdTr1oMbq/Pb+rQGcL1KX6a4WtX
DDLUomdUCX8hL7cElw+yi4HXPH2b8+fXyLVP+4sJs8Ugf8A5ya1/EHn+Y+aG
d6klwFXRIVDI6Ec+SIl3kZzlg0kybVjJuBf5CGezrHtdKSAOlKRP/yRCXivO
mmjPFYC0ANc4Eb8dedsyV+Xs2XKQrUSj9JOeIq9g/3xPov8AnLJgxdm/qUNu
ed+XfmnqEaAQozIX0qqQBylryrko1QFymSbhrUwp8mGXc3l97MdAzVK9iOdb
gJwiymo1ojSCCRaHSmSnI2dKe3KMaM2AFjvhaZh+DbkHx1H/bk0LWNmU+dVz
bTzyDQ1SCYWOrcBCZk5bohiDnMqiao63toHsxdpRw+Ew5M57uraQ9glB+zEP
AdU5CLmQabSsOaoDiDeGu/f1BuLndL8cWunfCVbLL4zxbPD643d3S8S+XYDc
66Vt25eCnJY25tmUIgLWBRqfrqzIQ15oyBh3Gu8GU+rxWVshHznH5upoRkQP
MAIPiD68h8hTBI3VhtQ+QIz5sTtoQYic5XKeliDqBzZgSD83/Dm+3naP1/db
XwKDDmFsaT/uExPNLOPf3F4Bxcij3oFDb5B7vzp3kS81CKKnDzirAdz/9mVn
xNJag8BqRxi9pBC/d1ptiYfpma9AfEZwjwIB5wP7oB5xJPMliIxy7JZnSpDr
qH6IYigPgDc+M93b5KaR64lvLtgLXgCiZLMgP2QG549DUMjnxh5gvcmqaOHK
LHILBfVc3RwR8KmOi+l2msPnZTaZkmTSAX4tpw/ViLErxzOKHls1AzbJirDH
YR65ys0GhTpJHWhI6PKZS8XesHxTgI+8ACS5myTqP8FesHrNU3pOMgh38Tvk
0Iy95/c7iwU3smHlLeERfg72kiMhfaZ/C6CKtX9g1z7sR80eXpozrIUXqS0x
dyvwc64UBGvYFjZAXS7bwG4I79f/g47MyfkmeEaHbHr4Pa7PjScHBkkRLXD/
clmZ+S5cTwXSa/6Jfa3QjGPArc/9iNzc2vTT9rQ2GLlCd6cTC5+LFSeCoh3f
DsdIuhsNvv4n/0tVbmdJC2F0CeFymTnO7f57awf2ygihdWbTF0I17ocponGw
fVI7vD67LtbTD+ftFTlzMiu+DZ7k70gOpOG+uhWhEnp17BlMCDb4xYuF83P0
H68s8+ZmSGxfzZVfhfOz1+rGgR/tm6CS80bXw2Y4P50iuRPk3gaYHrD/Y+UA
7uc2pSzdNax6uGB830VjBvuF2S4SoRdCN+/nVM3reJ2+sr1vZfOqIbXzYEhC
Ob7vCr2w/Aq/Shiqd5wQsR7nf9dOirVFRxkMURN87u3F+yqsIbflttyHp7xr
Lv6Qiuvg+MiWYrutFCZZCrlTDrhuwnMejZDAh7tqtNfZyODvoKDKudZwohhq
0aIUjgXg+rs71MFplaKlPtkRdzICf3+ZFLX648Z3YHSoRDN5Fz7HllO7ByKe
pENL1WDTpA7srbm7vv0P1LD+9z/wLw99g5E=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns4lFkcB3CMW2orjHFJ9hEatY8mQ0xSp5RWFJpVibSaccktRKuQaCNJ
KWaSJndSG8No3FIOmogwbrEZpVYMkUxuZWut/jlnnz3Pc/75PO9z3vf8zu/9
vq8uI5DuKSMlJXVocRIWp0qs8cIQDN5mt/B9fAS30r6Pl6Cdw7swbMABVWNa
3Q0i7J9scoiBPndAB7X1OicMO6Bpzt7svA9sz7+YZnVMINegyT0Xk7ngxJ90
s5yFD8gVY68x5kq5wE3UKG27BvsI1GAwKriAPjPR8XDzOHL5tERd9UVP5Kfq
UPaPIbdiJ5tYLfp8QjK7yOM9ciehvLpvJRdQZaeqZN1Hkfu6JOatrOYC3td+
QfihEeRupNMv6ZALytWMSKFuYuRr9X+4S2vggu4VZ/v+cB9G/qGMGfm1iwsE
XrVd6XZDyCUhZ7nMcS4olK8stDF5h9xuo19PvUoxuLMuv7FdexDXp/hZhq9d
MchQjZ5WIfyFvNwSXD7IKgZec7Stzl/eINc67S8mzBSD/H7nJDfRAPL8J4z1
71NLgKuiQ6CQLkI+QIl3kZzlgQmy6ZCSUS/yYfYmWfe6UkDsL0mf+rkLea04
a7wtlw/SAlzjunhtyFuXuC7PnikH2UqmFBHpGfIK1i/3JXoPwSkLZpz92zrk
lg98aZcmHwMKMSpzPq0KedByDTkXpTpALtMgvJMpRT7kci6vj/UEqFqqFXF9
C5BTurJaDCkNYJzJphJZ6cgZ0p5sQ9MmYBo77mmQfg25B9tR715NM1jRmPnN
c0088vUCqYRCxxZgITOrJVGMQU5lUjXGWlpB9kLtiMFQGHLnPZ2bSfuEoO2Y
B5/qHIRcyDBc0hTVDsQbwt37egPxc7pfDq307wCr5OdHuTZ4/bF7uyVi305A
7vXSsu1LQW6aNurZmNIFrAvUP19Zloe80IA+5jTWDSbV4rO2QB5yts3VkYyI
HmAIHhJ9uI+Qp/Abqg2ofYAYs707aF6InOly3jShSwRswKBebvgLfL3tHq8f
t7wC+u3C2FIR7hNjjSyj391eA8XIo96Bg2+Re78+d5EnNQCipw44qwLc//Zl
Z8TSmgPAakcYraQQv3earYmHaZmvQXxGcI8CAecD66AucTjzFYiMcuyWZ0iQ
a6t8jKIv7wdvfaa7t8pNIdcV35y3578ERMkmfn7INM4fh6CQLw09wHqjVdH8
lRnkFgpquTo5XcCnOi6m22kWn5fZREqScTv4rZw2WCPGvjyeXvTEqgmwSFaE
PQ5zyJVvChTqJHVAkNDpM5uKXbB0Y4CPPB8kuRsn6j3FXrBq9TNaTjIId/E7
5NCEvefW3YWCG9mw8rbwCC8He8mRkD6Tv/lQ2do/sHMf9qNmjy7NGtTCi9Tm
mHsV+DlX8IPVbQsFUIfD0rcbxPv1/6gtc3KuEZ7RJpsc/oDrc+PpgQFSRDPc
v1RWZq4T11OB9IZ3Yl8LNGPrc+pzPyE3tzb5vC2tFUYu09npxMTnYsWOoGjF
t8FRks4G/W//yf9S5TtZ0kIYXUK4XGaOc1t0f03/XhkhtM5s/Eqoxv0wSTQK
tk9qg9dn1sZ6+uG8vSJnTmbGt8KTvB3Jgaa4r25HKIdeHX0OE4L1f/Vi4vwc
+ccry7ypCRLbVnHkV+L87LW6cWC7fSNUct7getgM56dTJGec3CuA6QH7P1X2
435uVcrSWc2sh/NGD1zUp7FfmOkkEXohdPN+QdW4jtfpK9v7TjavGlI7DoYk
lOP7LtMNy6/wq4ShuscJEetw/nfupFhbtJfBEFX+l95evK/CGnJrbvMDeMq7
5uJPqbgOjo9tKbZbS2GSpZAz6YDrJjzn0QAJPLirRmutjQz+DvKrnGsNxouh
pmmUwrEAXH93hzo4pVy02Cc74k5G4O8vg6Jaf9zoLowOlWgk78Ln2Hxqd3/E
03RoqRJsktSOvSV31/f/gRrm//4H/gVliFWm
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9RWGGNI9giN2qPJEJPULaUVhaxKpNWMl7yFaBUSbSQp
xUyy8k5qYxiNt5SLJiJjvGU2lFoxRDJ5K1trtX/cu2fvOfefz3nOfZ77u7/n
+zw6jEBHTxkpKalDi5OwOFVijRaGYPA224Vv4wOQ+ne8Bu3p3AvD+umgekyz
u7EP+0frXGKgz23QQRNcTw/DDugaszc77wGb88+nWR0TyMl0uWdiCgec+MPR
NHfhPXLF2GuMuTIOcOtrkrZZg30EkhmMSg5wnJnoeLB5HLl8WqKO+qIn8lK1
qfvHkFuyk40tF30+IZld7PEOuZNQXt23igNoslPVsu6jyH1dEvNX1nAA90s/
P/zQCHI30ukXjpADKtQMSaFuYuRr9b67Q2/kgO4VZ3t/dx9G/r6cGfmliwP4
XnVdGbZDyCUhZznMcQ4okq8qsjZ+i9x2o19Pg0oJuL2uoKldaxDXp+Rppq9t
CchUjZ5WIfyJvMICXD7IKgFec/Stzp9fI9c87S8mzJSAgn7nJLe+AeQFjxnr
36WWAldF+0ChYx/yAWq8i+QsF0xQTIaUDEXIh9mbZN3rywCxvzRj6scu5HXi
7PG2PB5IC3CN6+K2IRcscV2eM1MBcpRMqH2kp8grWT/dk+g+AKfMmXF2b+qR
W9z3pV+afASoxKis+bRq5EHLyXIuSvWAUk4mvJUpQz7kci6/l/UYqFqoFXN8
C5FTu7JbDaiNYJzJphFZGcgZ0p5sA5NmYBI77qmfcQ25B9tB925tC1jRlPXV
c0088vV8qYQih1ZgLjOrKVGMQU5j0shjrQKQs1A3oj8Uhtx5T+dm0j4haDvm
waM5ByEXMgyWNEe1A/GGcPdeUSB+TvfLoVX+HWCV/PwoxxqvP3Z3t0Ts2wko
Ii9Nm94U5CZpo55NKV3AqlD905Vl+ciL9B3HnMa6waRafPYWyEXOtr46khnR
AwzAA6IP5yHyFF5jjT6tFxBjtncHzQuRM13OmyR09QFrMKibF/4cX2+zx+v7
LS+BXrswtqwP94kROdvwV7dXQDHyqHfg4Bvk3q/OXeRKDYDoqQPOqgD3v135
GbG0xgCw3BFGLy3C752GIPEwPesViM8M7lEg4HxgHdQhDme9BJFRDt3yDAly
LZUPUY7L+8Ebn+nurXJTyHXEN+fteC8AUbKJVxAyjfPHPijkc2MPsNpoWTx/
ZQa5uYJannZuF/CpiYvpdprF52U6kZJk1A5+qaAP1oqxL493LH5s2QxYJEvC
Hvs55Mo3+Qr1knrAT+j0mU3Fzl+6McBHngeS3I0SdZ9gL1y1+ik9NxmEu/gd
sm/G3vPbnYXCGzmw6pbwCDcXe+mRkF7jv3hQ2co/sHMf9qOmDy/N6tfBi7SW
mLuV+DlX8ILVbYr4UDudpWc7iPfr/0FL5uRcEzyjRTE+/B7X58aTAwOkiBa4
f6mszFwnrqcC6TX3xL5WaMrWS2/I+4jczMr407Y0AYxcpr3TiYnPxZIdQdWM
b4OjJO0Nel//k/9lyrezpYUwupRwudwM53bfvTX9e2WE0Cqr6QuhBvfDJNEw
2C6pDV6fWRvr6Yfz9oqcGYUZL4AnuTuSA01wX92KUA69OvoMJgTr/ezFxPk5
8rdXtllzMyS2rUqXX4nzU2R548B2uyao5LzB9bApzk+nyPRxiogPMwL2f6zq
x/0sUMrWXs1sgPOG913Up7FfmOkkEUQQunk/p5Gv43V6y/e+lc2vgbSOgyEJ
Ffi+y3TCCir9qmCoznFCxDqc/507qVbm7eUwRJX3WSTC+yqqpQjyWu7DU961
F39IxXVweGRDtdlaBpMshOmT9rhuwnMejZDAhbtqNdday+DvIK/auU5/vARq
mEQpHAvA9Xe3r4dTysWLfbIj7mQE/v4yqKoNxw3vwOhQCTl5Fz7HllO7+yOe
ZEALlWDjpHbsrXm7vv0P1DL/9z/wD/qMH6c=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BGi9mgyJiapuymtKGRVIq1mvOQtRKuQaCNJ
KUyy8k5qYxiNt5SLJiIMMzKbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8ePdjZW0ZKSurQ0iQsTdV408VhGLrdfvHb+ACoZt/GEOjOYl8YMcwCdePa
vS0i7B9tC4jBfrdBD6XzelYEdkDTmrvJvwfszj+fSe+ZRK5Jk3smNmKBE386
mxcsvkeuGH+NPl/JAh6iVmm7tdhHoSadXsMCzrOTPQ+2TCCXz0zW01jyZE6G
Lnn/OHJrZqqZ9ZIvJKUyy7zeIXfhyWv417IARXa6TtZzDLm/W3LRqnoWYH8Z
4EYeGkXuQTr9whmyQLW6CSncQ4x8ncF3d2gtLNC78mz/H54jyN9XMaK/CFiA
69MoyLYfRi4JO8tiTLBAqXxtqa3ZW+T2mwL6mlXLwe31xa3dOkO4PuVPc/zt
y0GOWuyMKuEv5NVW4PLB9HLgM0/b5vr5NXLt04Fiwmw5KB5wTfEQDSIvfkzf
8C6jArgrOgbznEXIB8mJbpKzbDBpRB1WMhEiH2FulvVsqgTEgYrs6Z8EyBvF
eRNdhRyQGeSeIGB3Ie9c5q6cP1sN8pWoZBHpKfKa9J/vSfQfgFOWjASHN03I
re770y5NPQJkYkzuQmYd8hBlTTk3pSZgVKVJeCtTiXzY7VxRf/pjoGalXsby
L0FOFuR1GJNbwASDSSGmZyOnS3szjaltgBo/4W2YfQ25F9NJ/25DO1jZmvvV
e20i8g1cqaRSpw5gKTOnLVGMQ05hUDTHOzpB/mLjqOFwBHLXPfwtpH080HXM
i0NxDUHOoxsva4vpBuKNkZ79wmD8nJ6Xw2sDe8Bq+YUxli1ef/zubonYnw+M
hD7adv1pyKmZY96taQJgU6Lx6cqKIuSlhs7jLuO9YEo9MW8rZCNn2l4dzYnq
A8bgAdGP9RB5Gqel3pDSD4hxP/aGLPCQM9zOU5MEImALhvQLI5/j6+32+Hy/
9SUw6ObFV4pwn5hq5pn85vEKKEYf9Q0eeoPc99W5i2ypQRA7fcBVDeD+d6g6
I5bWGgTWOyJoFaX4vdPqTD5My30FEnNC+xQIOB/SD+oRR3JfgugYp155ugS5
juqHGGflAfDGb6Z3m9w0cj3xzQUHzgtAlGzmFIfN4PxxDAn73NIHbDZZly1c
mUVuqaBeqFsgAH71CXG9LnP4vMwn01JMu8Gv1bShBjF25UTnssfWbSCdZE3Y
4ziPXOUmV6FJ0gS4SXy/uQzs3OWbgvzkOSDF0zRZ/wn2ktVrntIKUkGkW8Ah
xzbsfb/fWSy5kQ9rb/GOsAuwVxwJ6zf7mwNVbAKD+fuwHzV/eGnOsBFepLTH
3a3Bz7mSE6phV8qFulnpBvZDeL+BH3RkTs63wjM6RmaH3+P63HhyYJAU1Q73
L5eVmefjeiqQXrNP7OuA5kyDrObCj8gtbMw+bc/shNErdHe6MPC5WDOjyNqJ
XXCMpLvR4Ot/8r9S5XaeNA/GVhAuV1ng3BbdWzuwV4YHbXJbvxDqcT9MEU1C
HVK64PXZdfHeAThvr8hZGDESO+FJ9o7UYCruq1tRKuFXx57BpFCDX3wYOD9H
//HJs2hrg8Su1Vnyq3B+Cq1vHPjRoRUquW50P2yO89MlOmvCSMiF2UH7P9YO
4H7uVMrTXcNohgsm9900ZrBfmOWTCEIIPXyfUzSv43X6q/a+lS2qh5Seg2FJ
1fi+K/QiimsCamG43nFC1Hqc//ydZBvL7ioYpsb5LBTifZU2GHUWtt+Hp3wb
Lv6Qgevg9MiObLetEqZY8bKmHHHdeOe8WiCBDXc1aK+zlcHfQU6da6PhRDnU
osYoHAvC9fd0bILTKmVLfbIj4WQU/v7SyWrNx03uwNhwiWbqLnyO7ad2D0Q9
yYZWqqFmKd3YOwp3ffsfaGD873/gXwcniQE=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BGi9mgyxCR1tymtKGRVIq1mvOQtRKuQaCNJ
KUyyk3dSG8NovKVcJCIMMzKbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8ePdjZW0ZKSurQ0iQsTdV408VhGLrdfvHb+AB8fb6NEdDN4lwYMWSB2nHt
3hYR9o+2+cRgv9ugh9J5nRWBHVC15m7y7wG7889n0nsmkWtS5Z6JjdjgxJ/O
FvmL75Erxl+jz1ewgYeoVdpuLfZRqEmnV7OB8+xkz4MtE8jlM5P1NJY8mZuh
S94/jpzGTDWjLflCUiqz1OsdcheevIZ/DRtQZKdrZT3HkPu7JReuqmMDzpeB
5shDo8g9SKdfOEM2qFI3IYV7iJGvM/juDrWFDXpXnu3/w3ME+ftKRvQXARs0
+zQIsuyHkUvCzrIZE2xQIl9TYmv2Frn9poC+JtUycHt9UWu3zhCuT9nTbH/7
MpCtFjujSvgLeZU1uHwwvQz4zFO3uX5+jVz7dKCYMFsGigZcUzxEg8iLHtM3
vMsoB+6KjsE8ZxHyQXKim+QsB0wamQ8rmQiRjzA3y3o2VgDiQHnW9E8C5A3i
3ImuAi7IDHJPEHC6kHcuc1fOm60CeUrmZBHpKfLq9J/vSfQfgFNWjASHN43I
re/7Uy9NPQJkYkzOQmYt8hBlTTk3pUZgVKlJeCtTgXzY7Vxhf/pjoGatXsr2
L0ZOFuR2GJNbwASDSSGmZyGnS3szjc3bgHn8hLdh1jXkXkwn/bv17WBla85X
77WJyDc0SyWVOHUAK5k5bYliHHIKg6I53tEJ8hYbRg2HI5C77uFvIe3jga5j
XlyKawhyHt14WVtMNxBvjPTsFwbj5/S8HF4T2ANWyy+MsW3x+uN3d0vE/nxg
JPTRtutPQ26eOebdmiYANsUan66sKEReYug87jLeC6bUE3O3Qg5ypu3V0eyo
PmAMHhD92A+Rp3Fb6gwp/YAY92NvyAIPOcPtvHmSQARswZB+QeRzfL3dHp/v
t74EBt28+AoR7hNTzVyT3zxeAcXoo77BQ2+Q+746d5EjNQhipw+4qgHc/w6V
Z8TSWoOAtiOCWl6C3zutzuTD1JxXIDE7tE+BgPMh/aAecSTnJYiOceqVp0uQ
66h+iHFWHgBv/GZ6t8lNI9cT31xw4L4ARMlmblHYDM4fx5Cwzy19wGYTrXTh
yixyKwX1At18AfCrS4jrdZnD52UxmZZi2g1+raIO1YuxKyc6lz6mtYF0Eo2w
x3EeucrNZoVGSSNoTuL7zWVgb16+KchPngtSPE2T9Z9gL1695ik1PxVEugUc
cmzD3vf7ncXiG3mw5hbvCCcfe/mRsH6zv7lQxSYwmL8P+1GLh5fmDBvgRUp7
3N1q/JwruaEadiXNUJeVbmA/hPcb+EFH5uR8KzyjY2R2+D2uz40nBwZJUe1w
/3JZmXk+rqcC6TXnxL4OaME0YDUVfERuaWP2aXtmJ4xeobvThYHPhcaMImsn
dsExku5Gg6//yf8Kldu50jwYW064XGmJc1t0b+3AXhketMlp/UKow/0wRTQJ
dUjpgtdn18V7B+C8vSJnacRI7IQnOTtSg81xX92KUgm/OvYMJoUa/OLDwPk5
+o9PrmVbGyR2rWbJr8L5KaTdOPCjQytUct3oftgC56dLNGvCSNgMs4L2f6wZ
wP3cqZSru4bRBBdM7rtpzGC/MMsnEYQQevg+p2hex+v0V+59K1tYByk9B8OS
qvB9V+hFFFUH1MBwveOEqPU4//k7yTZW3ZUwTI37WSjE+yqpN+osaL8PT/nW
X/whA9fB6ZEd2W5bBUyx5rGmHHHdeOe8WiCBA3fVa6+zlcHfQW6ta4PhRBnU
Mo9ROBaE6+/p2AinVUqX+mRHwsko/P2lk9WajpvcgbHhEs3UXfgc20/tHoh6
kgWtVUPNUrqxdxTs+vY/UM/43//Av7Il8gQ=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9RWGGNI9ghRezQZYpK6NaUVhaxKpNWMl7yFaBUSbSQp
hUmavJPaGEbjLeUiEWGYkdlQasUQyeStbK3VP/fu2XvO/edznnOf5/7u7/k+
jw4j0NFTRkpK6tDiJCxOlVjjhSEYvM124fv4CG6lfx+joJPNvTCszwbVY5rd
TX3YP1nnEgN97oAuavt1dhh2QNOYvSm4D2zOv5hO7ZpATqbJPRcbcMCJPx3N
chc+IFeMvcaYK+MAt75maZs12EcgmcGo5ADHmYmuh5vHkcunJ+qoL3oiL02b
sn8MOZ2VbEJf9PmEZFaxx3vkTnx5dd8qDqDKTlXLuo8i93VJzF9ZwwHcr/2N
4YdGkLuRTr90hBxQoWZECnUTI1+r98NdWhMHdK842/uH+zDyD+XMyK9CDmj0
qhNm2A4hl4Sc5TDHOaBIvqrI2uQdctuNfj0NKiXgzrqC5k6tQVyfkmeZvrYl
IFM1elqF8BfyCktw+WBqCfCao211/vIGueZpfzFhpgQU9DsnufUNIC94wlj/
Pq0UuCraB/Id+5APUOJdJGe5YMLAdEjJSIR8mLVJ1r2+DBD7SzOmfhYirxNn
j3fk8UB6gGuckNuBvH2J6/KcmQqQo2RK6SM9Q16Z+st9ie5DcMqCGWf3th65
5QNf2qXJx4BCjMqaT69GHrScLOeiVA8MysmEdzJlyIdczuX3pj4BqpZqxRzf
QuQUYXabIaUJjDNZVGJqBnKGtCfL0LQFmMaOe+pnXEPuwXLQvVfbClY0Z33z
XBOPfH2jVEKRQxuwkJnVlCjGIKcyqeSxtnaQs1A3oj8Uhtx5j2AzaR8fdBzz
4FGdg5DzGYZLWqI6gXhDuHuvKBA/p/vl0Cr/LrBKfn6UY43XH7u3WyL2FQAD
kZemTW8KctP0Uc/mFCGwKlT/fGVZPvIifccxp7FuMKkWn70FcpGzrK+OZEb0
AEPwkOjDeYQ8hddUo0/tBcSY7d1B83zkTJfzpgnCPmANBnXzwl/g6232eP24
5RXQ6+THlvXhPjEmZxv97vYaKEYe9Q4cfIvc+/W5i1ypARA9dcBZFeD+tys/
I5bWGAD0HWG00iL83mm0Jx6mZb0G8ZnBPQoEnA+pB3WIw1mvQGSUQ7c8Q4Jc
S+VjlOPyfvDWZ7p7q9wUch3xzXk73ktAlGziFYRM4/yxDwr50tQDrDbSi+ev
zCC3UFDL084VAp+auJhup1l8XmYTKUnGneC3CtpgrRj78njH4if0FpBKohP2
2M8hV77ZqFAvqQeNCQKf2TTsjUs3BvjI80CSu3Gi7lPshatWP6PlJoNwF79D
9i3Ye27dXSi8kQOrbvOPcHOxlx4J6TX5mweVrfwDBfuwHzV7dGlWvw5epLbG
3KvEz7mCF6xuU9QItdmperaDeL/+H7VkTs41wzNaBiaHP+D63Hh6YIAU0Qr3
L5WVmRPgeiqQ3nBP7GuDZiw9dkPeJ+TmViaft6W3w8hl2judmPhc6KwIimZ8
BxwlaW/Q+/af/C9TvpMtzYfRpYTL5eY4t/vur+nfK8OHVlnNXwk1uB8miUbB
dkkd8PrM2lhPP5y3V+TMDZjx7fAkd0dyoCnuq9sRyqFXR5/DhGC9X72YOD9H
/vHKNm9pgcSOVWz5lTg/RfQbB7bbNUMl5w2uh81wfjpFsscNRI0wI2D/p6p+
3M/tStnaq5kNcN7ogYv6NPYLMwISQQShm/cLKvk6Xqe3fO872fwaSO06GJJQ
ge+7TCesoNKvCobqHCdErMP5L9hJsbLoLIchqrwvIhHeV1GtQXte6wN4yrv2
4k9puA4Oj20oNlvLYJIlnz1pj+vGP+fRBAlcuKtWc621DP4O8qqd6/THS6CG
aZTCsQBcf3f7ejilXLzYJzviTkbg7y+Dotpw3OgujA6VkJN34XNsPbW7P+Jp
BrRUCTZJ6sTelrfr+/9ALfN//wP/Al0yWxY=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1n00lFkcB3CMt9QqjPGS7BEatUeTISapuymtKDSrEmk14yVvIVqFRBtJ
SjGTrLyT2hhG4y3lIhEZgxGbUWrFEMnkrWyt1T/37tl7zv3nc55zn+f+7u/5
Po8eI4juJSMlJXVoaRKWpmqcyeIwDNluv/htfAD89m9jAnRmcC+MGGaAmnHt
nmYR9o+2ecQg39ugi8q/nhGOHdC05m523wN255/PsLomkWvS5J6JyRxw4k+6
ed7ie+SKcdcY8+Uc4C5qkbZbi30UajIYVRxAn53serBlArl8epKexpIn8dJ0
KfvHkVuzU0ytl3whMYVd4vkOubNAXsOvmgOostM1sh5jyP1ckwpW1XIA98tA
U8ShUeTupNMv6JADKtWNSWHuYuTrDL67Q2vmgJ6VZ/v/8BhB/r6CGfVFyAFN
3vXCTPth5JLQsxzmBAcUy1cX25q+RW6/yb+3UbUU3F5f2NKpM4TrU/o0y8++
FGSpxcyoEv5CXmkFLh9klQLvedo2l8+vkWufDhATZktB4YBLsrtoEHnhY8aG
d2llwE3RMUhAFyEfpCS4Ss5ywSTZbFjJuA/5CHuzrEdDOSAOlGVO/yREXi/O
mejI54H0QLd4IbcDOX+Zm3LubCXIVTKjiEhPkVexfr4n0X8ATlky4x3eNCC3
uu9HuzT1CFCI0dkL6TXIg5U15VyVGgC5QpPwVqYc+bDruYJ+1mOgZqVewvEr
Qk4R5rQbUZrBBJNNJbIykTOkvdhGZq3ALG7CyzDzGnJPtpP+3bo2sLIl+6vX
2gTkG5qkEoud2oGlzJy2RDEWOZVJ1Rxv54PcxfpRw+Fw5C57ureQ9glAxzFP
HtUlGLmAYbSsNboTiDdGePT3BeHn9LgcVh3QBVbLL4xxbPH643d3S8R+3YDc
561t15+K3Cx9zKslVQhsijQ+XVlRgLzYkD7uPN4DptQTcrZCLnK27dXRrMhe
YAQeEH05D5Gn8pprDan9gBj7Y0/wggA50/W8WaJQBGzBkH5+xHN8vd0e7++3
vgQGnYK4chHuExPNHOPf3F8BxaijPkFDb5D7vDp3kSs1CGKmD7ioAdz/DhVn
xNJag8B6RzitrBi/d1r8pMO07FcgISukV4GA84F1UI84kv0SREU79cgzJMh1
VD9E05UHwBvfmZ5tctPI9cQ3Fxx4LwBRsplXGDqD88cxOPRzcy+w2WRdsnBl
Frmlgnq+bp4Q+NbGx/Y4z+HzMp9MTTbpBL9W0obqxNiVE+glj61bAYtkTdjj
OI9c5WaTQoOkATQldvvOpWFvWr4p0FeeB5I9TJL0n2AvWr3mKS0vBUS4+h9y
bMXe+/udxaIbubD6luAINw972ZHQftO/eVDFJiCoex/2o+YPL80Z1sOL1LbY
u1X4OVfyQjTsipugbgbLwH4I7zfgg47MyfkWeEaHbHr4Pa7PjScHBkmRbXD/
clmZ+W5cTwXSa+6Jfe3QnG2Q0Zj/EbmFjemn7el8GLVCd6czE5+LNTuSop3Q
AcdIuhsNvv4n/8tVbudIC2BMGeFyhQXObdG9tQN7ZQTQJrvlC6EW98MU0TjE
IbkDXp9dF+flj/P2ipwFmZnAhye5O1KCzHBf3YpUCbs69gwmhhj84s3E+Tn6
j3eORWsrJHaszpBfhfOzz/rGgR8dWqCSy0a3w+Y4P52jMibIfU0wM3D/x+oB
3M98pRzdNcxGuGB831VjBvuF2W4SoQ9Cd5/nVM3reJ3+ir1vZQtqIbXrYGhi
Jb7vCr3wwir/ahimd5wQuR7nf/dOio1lZwUMVeN97uvD+yquI/Pz2+7DUz51
F39Iw3VwemRHsdtWDpOtBBlTjrhugnOezZDAhbvqtNfZyuDvIK/Gpd5wohRq
mUUrHAvE9fdwbIDTKiVLfbIj/mQk/v4yKGqNx43vwJgwiWbKLnyObad2D0Q+
yYRWqiGmyZ3Y2/N3ffsfqGP+73/gXwg/xBk=
            "]], 
           Line3DBox[CompressedData["
1:eJxd1ns4lFkcB3CMW2orjHFJ9hEatY8mQ0xSp6a0otCsSqTVjEtuIVqFRBtJ
SjGTrNxJbQyjcUs5aCLCuMVmlFoxRDK5la212j/O2WfP85x/Ps/7nPc9v/N7
v++rywxgeMhISUkdWpyExakSY7wwBIO22S58Gx+A1L9jErSn8S4MG6SBqjGt
7gYR9o/WOcQA79ugg9p6PS0UO6Bpzt7svAdszj+fZndMINegyT0Tk7ngxB8M
s5yF98gVY64x50q5wFXUKG2zBvsI1GAyK7iAMTPR8WDzOHL51ARd9UVP4Kfo
UPaPIadzkkzoiz4fn8Qpcn+H3FEor+5TyQVU2akqWbdR5D7OCXkrq7mA96Vf
EHZoBLkr6fQLBuSCcjUjUoirGPla/e/u0Bq4oHvF2b7f3YaRvy9jRXzp4gKB
Z21Xuu0QcknwWS5rnAsK5SsLrU3eIrfd6NtTr1IMbq/Lb2zXHsT1KX6a4WNb
DDJUo6ZVCH8iL7cElw+yi4HnHG2r0+fXyLVO+4kJM8Ugv98p0VU0gDz/MXP9
u5QS4KJoHyBkiJAPUOKcJWd5YIJsOqRk1It8mLNJ1q2uFBD7S9KnfuxCXivO
Gm/L5YNUf5fYLl4b8tYlLsuzZ8pBtpIpRUR6iryC/dM9id4DcMqCFWv3pg65
5X0f2qXJR4BCjMycT61CHrhcQ85ZqQ6QyzQIb2VKkQ85n8vrYz8GqpZqRVyf
AuSUrqwWQ0oDGGdxqER2OnKmtAfH0LQJmMaMexikX0PuznHQu1vTDFY0Zn71
WBOHfL1AKr7QoQVYyMxqSRSjkVNZVI2xllaQvVA7YjAUitxpT+dm0j4haDvm
zqc6BSIXMg2XNEW2A/GGMLe+3gD8nG6XQyr9OsAq+flRrjVef+zubonYpxOQ
ez21bPqSkZumjno0JncBqwL1T1eW5SEvNGCMOY51g0m1uKwtkIecY311JCO8
BxiCB0Rv7kPkyfyGagNqHyBGb+8OnBciZzmfN43vEgFrMKiXG/YcX2+zx/P7
LS+BfrswplSE+8RYI8voV9dXQDHiqFfA4BvkXq/OXeRJDYCoqQNOqgD3v13Z
GbG05gCg7willRTi906zNeEwLfMViMsI6lEg4HxgH9QlDme+BBGRDt3yTAly
bZUPkYzl/eCN93T3Vrkp5Lrim/N2/BeAKNnEzw+exvljHxj8uaEHWG2kF81f
mUFuoaCWq5PTBbyrY6O7HWfxeZlNJCcat4NfymmDNWLsy+MYRY/pTYBNohP2
2M8hV74pUKiT1AFBfKf3bAp2wdKN/t7yfJDoZpyg9wR7warVT2k5SSDM2feQ
fRP2nt/uLBTcyIaVt4RHeDnYS44E95n8xYfKVn4BnfuwHzV7eGnWoBZepDZH
363Az7mCH6RuUyiAOmlsfdtBvF+/D9oyJ+ca4Rltssnh97g+N54cGCCFN8P9
S2Vl5jpxPRVIr3kn9rVAM45+Wn3uR+TmViaftqW2wohlOjsdWfhc6JxwilZc
Gxwl6WzQ//qf/C9Vvp0lLYRRJYTLZeY4t0X31vTvlRFCq8zGL4Rq3A+TRKMg
u8Q2eH1mbYyHL87bK3LmZFZcKzzJ25EUYIr76la4csjV0WcwPkj/Z08Wzs+R
vz2zzJuaILFtVZr8SpyfvfQbB7bbNUIlpw0uh81wfjpGpI2TewUw3X//x8p+
3M+tSlk6q1n1cN7ovrP6NPYLM50kQi+Erl7PqRrX8Tp9ZXvfyuZVQ2rHweD4
cnzfZbqh+RW+lTBE9zghfB3O/86dFCuL9jIYrMr/3NuL91VYQ27Nbb4PT3nV
XPwhBdfB4ZENxWZrKUy0FKZN2uO6Cc+5N0ACD+6q0VprLYO/g/wqp1qD8WKo
aRqpcMwf19/Nvg5OKRct9smO2JPh+PvLpKjWHze6A6NCJBpJu/A5Np/a3R/+
JB1aqgSZJLZjb8nd9e1/oIb1v/+BfwDyNiUX
            "]]},
          Annotation[#, "Charting`Private`Tag$5829#1"]& ]}, {}}},
      Axes->None,
      AxesEdge->{{-1, -1}, {1, -1}, {-1, -1}},
      BaseStyle->Specularity[
        GrayLevel[0.5], 30],
      Boxed->False,
      DisplayFunction->Identity,
      FaceGridsStyle->Directive[
        GrayLevel[0.3, 1], 
        AbsoluteDashing[{1, 2}]],
      ImagePadding->Automatic,
      Lighting->"Neutral",
      Method->{
       "DefaultGraphicsInteraction" -> {
         "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
          "Effects" -> {
           "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
            "Droplines" -> {
             "freeformCursorMode" -> True, 
              "placement" -> {"x" -> "All", "y" -> "None"}}}}},
      PlotRange->{{Automatic, Automatic}, {Automatic, Automatic}, {
        Automatic, Automatic}},
      PlotRangePadding->{{
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& , 
        Charting`FindScaledTicks[
         (Charting`SimpleTicks[#, #2, 6]& )[
          SlotSequence[1]], {Identity, Identity}]& }], {2544.75, -189.}, 
     ImageScaled[{0.5, 0.5}], {360., 360.},
     ContentSelectable->True]}, {}},
  ContentSelectable->True,
  ImageSize->Full,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.822269910584857*^9},
 CellLabel->"Out[54]=",ExpressionUUID->"9a8e51d3-d54b-4705-857b-27dc9053c1b2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1327, 1312},
WindowMargins->{{549, Automatic}, {-48, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 192, 2, 98, "Title",ExpressionUUID->"a88fa96b-c83f-43f0-97e7-c9aea94dd85f"],
Cell[775, 26, 169, 2, 53, "Subtitle",ExpressionUUID->"82de6776-2a2a-4cda-b909-0ec76589094f"],
Cell[947, 30, 154, 2, 35, "Text",ExpressionUUID->"47d19951-184a-4f40-9c99-1a0e02f1f23f"],
Cell[1104, 34, 1123, 20, 127, "Text",ExpressionUUID->"1d13517f-375f-4539-a14b-ebe834f67022"],
Cell[CellGroupData[{
Cell[2252, 58, 336, 4, 67, "Section",ExpressionUUID->"79deb966-cdb1-479d-b1d6-b0e67aae5e30"],
Cell[CellGroupData[{
Cell[2613, 66, 251, 6, 54, "Subsection",ExpressionUUID->"7d040900-e4ba-4a1d-a576-3383159eb650"],
Cell[2867, 74, 471, 13, 35, "Text",ExpressionUUID->"d5a98af2-3ad3-4211-8823-52cccaeed9fb"],
Cell[3341, 89, 363, 11, 30, "Input",ExpressionUUID->"546535da-f7a7-463a-87be-7d1a56cd8bed"],
Cell[3707, 102, 736, 21, 35, "Text",ExpressionUUID->"c2d3ddb3-ebac-47f8-8664-68e3104813d4"],
Cell[4446, 125, 353, 10, 30, "Input",ExpressionUUID->"9679bb40-ef5f-43df-8c77-4e7752cefc22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4836, 140, 203, 3, 54, "Subsection",ExpressionUUID->"1b19b952-785f-403e-bd84-50c9d2a0cbab"],
Cell[5042, 145, 610, 15, 58, "Text",ExpressionUUID->"08bfaa36-de59-4a3f-b8f6-571d18f3764f"],
Cell[5655, 162, 1945, 61, 52, "Input",ExpressionUUID->"d2a194f3-217e-4838-aff7-d33467cd279a"],
Cell[7603, 225, 421, 7, 58, "Text",ExpressionUUID->"8c80fb1a-6974-4dc3-9104-bdce5aee9df3"],
Cell[8027, 234, 1197, 36, 73, "Input",ExpressionUUID->"8b90cd71-fd01-4c04-91a3-b61a3c0063d2"],
Cell[9227, 272, 297, 5, 35, "Text",ExpressionUUID->"23609d4a-5492-465d-8715-9c3f8e7acfad"],
Cell[9527, 279, 1411, 48, 94, "Input",ExpressionUUID->"500232ae-9f84-4ea4-a76e-73bf74ccdd0a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10975, 332, 235, 6, 54, "Subsection",ExpressionUUID->"9ca5ad62-e298-4112-8d7c-b25466a3eccb"],
Cell[11213, 340, 424, 7, 58, "Text",ExpressionUUID->"ea3e0006-f8ea-4433-8ff3-35c3bc11ee78"],
Cell[11640, 349, 5512, 180, 136, "Input",ExpressionUUID->"7c6e1943-5dda-482a-835d-7a609e7fe7db"],
Cell[17155, 531, 216, 4, 35, "Text",ExpressionUUID->"bf26ebfa-5920-4b4e-b012-3827bbbc6989"],
Cell[17374, 537, 863, 29, 52, "Input",ExpressionUUID->"5710ee0c-3c79-40d6-ab20-f6f3b8a018a7"],
Cell[18240, 568, 227, 5, 35, "Text",ExpressionUUID->"817322f5-ae87-4769-a974-0c8bbd788b16"],
Cell[18470, 575, 3429, 104, 136, "Input",ExpressionUUID->"982fd364-a76c-4b7c-ae1d-82e0cc7ed8a0"],
Cell[21902, 681, 281, 5, 35, "Text",ExpressionUUID->"a0365a1e-b252-477c-a3c8-f19f1d138a77"],
Cell[22186, 688, 1780, 57, 52, "Input",ExpressionUUID->"b4052c02-13b4-4a97-8bad-5144ada99a5e"],
Cell[23969, 747, 419, 7, 58, "Text",ExpressionUUID->"f5e7fdb5-503c-4231-8335-6e490bf175b2"],
Cell[24391, 756, 5303, 141, 178, "Input",ExpressionUUID->"4459d1f5-a8c8-4571-bc13-4c808698615e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29731, 902, 417, 9, 81, "Subsection",ExpressionUUID->"686d69c9-271c-4370-a5c7-44d7d8223174"],
Cell[30151, 913, 540, 16, 30, "Input",ExpressionUUID->"9679838d-7578-4db1-acc7-c62e5a757417"],
Cell[30694, 931, 456, 14, 35, "Text",ExpressionUUID->"f59416f1-6065-4886-9f20-5d22a73895fd"],
Cell[31153, 947, 936, 29, 30, "Input",ExpressionUUID->"e981bb7c-7909-4fda-8b3b-874ccd87c45d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32126, 981, 338, 7, 54, "Subsection",ExpressionUUID->"7e9acf5b-f433-40f0-b56f-9e6f3e2cf52a"],
Cell[32467, 990, 1388, 44, 73, "Input",ExpressionUUID->"8b6dafce-20d6-405b-9a76-da740e04aa52"],
Cell[33858, 1036, 345, 6, 35, "Text",ExpressionUUID->"8bb25d83-7778-4b5f-809a-6a8bb462b39f"],
Cell[CellGroupData[{
Cell[34228, 1046, 9898, 252, 577, "Input",ExpressionUUID->"b3ee557c-d1cd-4eed-afdb-f65b145a233e"],
Cell[44129, 1300, 1371973, 24006, 363, "Output",ExpressionUUID->"c2dda8bc-d621-4c51-92e5-9526e0ab10cb"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1416163, 25313, 363, 5, 67, "Section",ExpressionUUID->"7bb6c2cd-a9bc-4cb6-9bb9-87a04502d32a"],
Cell[CellGroupData[{
Cell[1416551, 25322, 240, 6, 54, "Subsection",ExpressionUUID->"e5c5d87f-f94c-43c0-aa1a-b2ed9960d4b4"],
Cell[1416794, 25330, 7077, 238, 157, "Input",ExpressionUUID->"b63dda93-3cea-427f-bd8c-d5563cc0d58a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1423908, 25573, 202, 3, 54, "Subsection",ExpressionUUID->"93baff90-1925-4ab4-b071-3d135c037f2e"],
Cell[1424113, 25578, 3261, 104, 136, "Input",ExpressionUUID->"dcf17c07-d75d-468b-b918-b97f650b2233"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1427411, 25687, 245, 4, 54, "Subsection",ExpressionUUID->"94d1423d-ced9-400f-8e61-1f12a2d39206"],
Cell[1427659, 25693, 261, 5, 35, "Text",ExpressionUUID->"416784b3-9936-48f9-9a49-b5fd00d75607"],
Cell[1427923, 25700, 1834, 54, 52, "Input",ExpressionUUID->"69f9eb0f-6af7-4187-893b-00d51f828d31"],
Cell[1429760, 25756, 225, 5, 35, "Text",ExpressionUUID->"088ffc91-a892-4065-ac02-f0b706b94afe"],
Cell[1429988, 25763, 626, 19, 30, "Input",ExpressionUUID->"7ee7af4c-1e64-4568-be4b-1de04e7d80e9"],
Cell[1430617, 25784, 483, 14, 35, "Text",ExpressionUUID->"41116717-7414-4830-ac1e-a0781d94abe4"],
Cell[1431103, 25800, 1379, 42, 30, "Input",ExpressionUUID->"a6b648dd-2d13-461c-ad48-db512e7dc56a"],
Cell[1432485, 25844, 249, 5, 35, "Text",ExpressionUUID->"5e7fe9db-24ac-4e7e-a22d-71d2503616ed"],
Cell[1432737, 25851, 627, 20, 30, "Input",ExpressionUUID->"2b9046f2-5478-44a7-b05a-b2d595144f7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1433401, 25876, 340, 7, 54, "Subsection",ExpressionUUID->"98c374c5-5477-4f12-98c8-2efcce8e7fbf"],
Cell[1433744, 25885, 762, 22, 30, "Input",ExpressionUUID->"73ad7b89-15c9-4dc1-8778-a1c2fa4974e7"],
Cell[1434509, 25909, 355, 6, 35, "Text",ExpressionUUID->"eda63c09-280b-4c68-b725-afd561758115"],
Cell[CellGroupData[{
Cell[1434889, 25919, 4687, 117, 346, "Input",ExpressionUUID->"bacee7aa-cdd0-411d-8a23-b113b95cf4c1"],
Cell[1439579, 26038, 3531592, 59298, 387, "Output",ExpressionUUID->"d141eb1f-1f1e-4490-9d10-5c5c2466b2aa"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4971232, 85343, 335, 4, 67, "Section",ExpressionUUID->"cd4bd3c9-2403-429e-8ba2-ff83b0aa25da"],
Cell[CellGroupData[{
Cell[4971592, 85351, 287, 6, 54, "Subsection",ExpressionUUID->"4d2332dd-5c47-44eb-a2ca-c4b9b4e935e6"],
Cell[CellGroupData[{
Cell[4971904, 85361, 3428, 93, 199, "Input",ExpressionUUID->"c71f1249-ef64-408c-89b1-2d26b5efb483"],
Cell[4975335, 85456, 4583546, 77020, 499, "Output",ExpressionUUID->"22cf6857-8386-4281-b8fc-db7d751c8762"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[9558942, 162483, 335, 4, 67, "Section",ExpressionUUID->"79e240d1-d499-4075-9776-609e4f97f564"],
Cell[CellGroupData[{
Cell[9559302, 162491, 298, 6, 54, "Subsection",ExpressionUUID->"3f6a9819-8a09-494f-bc68-173ffd81778a"],
Cell[9559603, 162499, 2122, 57, 52, "Input",ExpressionUUID->"d56f8a52-2928-44ec-b7fc-2322f544ead5"],
Cell[9561728, 162558, 239, 5, 35, "Text",ExpressionUUID->"a73f091f-7aee-47c6-a89c-4f1118041779"],
Cell[CellGroupData[{
Cell[9561992, 162567, 1018, 28, 52, "Input",ExpressionUUID->"59a768c0-565a-4ea5-a793-46100a5770a5"],
Cell[9563013, 162597, 2435614, 40938, 499, "Output",ExpressionUUID->"6a6387a8-50b7-4e43-835a-d4eecf255da9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11998676, 203541, 224, 5, 54, "Subsection",ExpressionUUID->"57197f72-f6bf-4bc6-a7f5-5dc4e9f55050"],
Cell[11998903, 203548, 301, 6, 35, "Text",ExpressionUUID->"3d4de0e5-ff3e-4550-af61-31d56ed5a1ac"],
Cell[CellGroupData[{
Cell[11999229, 203558, 336, 8, 30, "Input",ExpressionUUID->"1183e96a-4558-424d-9ac7-7bcc6138881e"],
Cell[11999568, 203568, 2018, 57, 34, "Output",ExpressionUUID->"36ae4bcf-731c-4b23-8141-75e3047ed69e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12001623, 203630, 343, 8, 30, "Input",ExpressionUUID->"d26d407d-0471-4f0e-b721-3942ed98c9f6"],
Cell[12001969, 203640, 2038, 58, 34, "Output",ExpressionUUID->"4df6ecfd-c086-43a8-9c78-639016331515"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12004044, 203703, 3884, 98, 199, "Input",ExpressionUUID->"b5d62608-21de-4724-b1be-e7c0c8153636"],
Cell[12007931, 203803, 3552575, 58545, 224, "Output",ExpressionUUID->"9a8e51d3-d54b-4705-857b-27dc9053c1b2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

